(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('vue')) :
    typeof define === 'function' && define.amd ? define(['exports', 'vue'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.naive = {}, global.Vue));
})(this, (function (exports, vue) { 'use strict';

    let onceCbs = [];
    const paramsMap = new WeakMap();

    function flushOnceCallbacks() {
      onceCbs.forEach(cb => cb(...paramsMap.get(cb)));
      onceCbs = [];
    }

    function beforeNextFrameOnce(cb) {
      for (var _len = arguments.length, params = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
        params[_key - 1] = arguments[_key];
      }

      paramsMap.set(cb, params);
      if (onceCbs.includes(cb)) return;
      onceCbs.push(cb) === 1 && requestAnimationFrame(flushOnceCallbacks);
    }

    function getParentNode$1(node) {
      // document type
      if (node.nodeType === 9) {
        return null;
      }

      return node.parentNode;
    }

    function getScrollParent$1(node) {
      if (node === null) return null;
      const parentNode = getParentNode$1(node);

      if (parentNode === null) {
        return null;
      } // Document


      if (parentNode.nodeType === 9) {
        return document.documentElement;
      } // Element


      if (parentNode.nodeType === 1) {
        // Firefox want us to check `-x` and `-y` variations as well
        const {
          overflow,
          overflowX,
          overflowY
        } = getComputedStyle(parentNode);

        if (/(auto|scroll|overlay)/.test(overflow + overflowY + overflowX)) {
          return parentNode;
        }
      }

      return getScrollParent$1(parentNode);
    }

    function unwrapElement(target) {
      if (typeof target === 'string') return document.querySelector(target);
      if (typeof target === 'function') return target();
      return target;
    }

    function happensIn(e, dataSetPropName) {
      let {
        target
      } = e;

      while (target) {
        if (target.dataset) {
          if (target.dataset[dataSetPropName] !== undefined) return true;
        }

        target = target.parentElement;
      }

      return false;
    }

    function getPreciseEventTarget(event) {
      return event.composedPath()[0] || null;
    }

    function parseResponsiveProp(reponsiveProp) {
      if (typeof reponsiveProp === "number") {
        return {
          '': reponsiveProp.toString()
        };
      }

      const params = {};
      reponsiveProp.split(/ +/).forEach(pairLiteral => {
        if (pairLiteral === '') return;
        const [prefix, value] = pairLiteral.split(':');

        if (value === undefined) {
          params[''] = prefix;
        } else {
          params[prefix] = value;
        }
      });
      return params;
    }

    function parseResponsivePropValue(reponsiveProp, activeKeyOrSize) {
      var _a;

      if (reponsiveProp === undefined || reponsiveProp === null) return undefined;
      const classObj = parseResponsiveProp(reponsiveProp);
      if (activeKeyOrSize === undefined) return classObj[''];

      if (typeof activeKeyOrSize === 'string') {
        return (_a = classObj[activeKeyOrSize]) !== null && _a !== void 0 ? _a : classObj[''];
      } else if (Array.isArray(activeKeyOrSize)) {
        for (let i = activeKeyOrSize.length - 1; i >= 0; --i) {
          const key = activeKeyOrSize[i];
          if (key in classObj) return classObj[key];
        }

        return classObj[''];
      } else {
        // Here we suppose all the keys are number formatted
        let activeValue = undefined;
        let activeKey = -1;
        Object.keys(classObj).forEach(key => {
          const keyAsNum = Number(key);

          if (!Number.isNaN(keyAsNum) && activeKeyOrSize >= keyAsNum && keyAsNum >= activeKey) {
            activeKey = keyAsNum;
            activeValue = classObj[key];
          }
        });
        return activeValue;
      }
    }

    function depx(value) {
      if (typeof value === 'string') {
        if (value.endsWith('px')) {
          return Number(value.slice(0, value.length - 2));
        }

        return Number(value);
      }

      return value;
    }

    function pxfy(value) {
      if (value === undefined || value === null) return undefined;
      if (typeof value === 'number') return `${value}px`;
      if (value.endsWith('px')) return value;
      return `${value}px`;
    }

    function getMargin(value, position) {
      const parts = value.trim().split(/\s+/g);
      const margin = {
        top: parts[0]
      };

      switch (parts.length) {
        case 1:
          margin.right = parts[0];
          margin.bottom = parts[0];
          margin.left = parts[0];
          break;

        case 2:
          margin.right = parts[1];
          margin.left = parts[1];
          margin.bottom = parts[0];
          break;

        case 3:
          margin.right = parts[1];
          margin.bottom = parts[2];
          margin.left = parts[1];
          break;

        case 4:
          margin.right = parts[1];
          margin.bottom = parts[2];
          margin.left = parts[3];
          break;

        default:
          throw new Error('[seemly/getMargin]:' + value + ' is not a valid value.');
      }

      if (position === undefined) return margin;
      return margin[position];
    }

    function getGap(value, orient) {
      const [rowGap, colGap] = value.split(' ');
      if (!orient) return {
        row: rowGap,
        col: colGap || rowGap
      };
      return orient === 'row' ? rowGap : colGap;
    }

    var colors = {
      black: '#000',
      silver: '#C0C0C0',
      gray: '#808080',
      white: '#FFF',
      maroon: '#800000',
      red: '#F00',
      purple: '#800080',
      fuchsia: '#F0F',
      green: '#008000',
      lime: '#0F0',
      olive: '#808000',
      yellow: '#FF0',
      navy: '#000080',
      blue: '#00F',
      teal: '#008080',
      aqua: '#0FF',
      transparent: '#0000'
    };

    // All the algorithms credit to https://stackoverflow.com/questions/36721830/convert-hsl-to-rgb-and-hex/54014428#54014428
    // original author: Kamil Kiełczewski

    /**
     * @param h 360
     * @param s 100
     * @param l 100
     * @returns [h, s, v] 360, 100, 100
     */
    function hsl2hsv(h, s, l) {
      s /= 100;
      l /= 100;
      const v = s * Math.min(l, 1 - l) + l;
      return [h, v ? (2 - 2 * l / v) * 100 : 0, v * 100];
    }
    /**
     * @param h 360
     * @param s 100
     * @param v 100
     * @returns [h, s, l] 360, 100, 100
     */

    function hsv2hsl(h, s, v) {
      s /= 100;
      v /= 100;
      const l = v - v * s / 2;
      const m = Math.min(l, 1 - l);
      return [h, m ? (v - l) / m * 100 : 0, l * 100];
    }
    /**
     * @param h 360
     * @param s 100
     * @param v 100
     * @returns [r, g, b] 255, 255, 255
     */

    function hsv2rgb(h, s, v) {
      s /= 100;
      v /= 100;

      let f = function (n) {
        let k = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : (n + h / 60) % 6;
        return v - v * s * Math.max(Math.min(k, 4 - k, 1), 0);
      };

      return [f(5) * 255, f(3) * 255, f(1) * 255];
    }
    /**
     * @param r 255
     * @param g 255
     * @param b 255
     * @returns [360, 100, 100]
     */

    function rgb2hsv(r, g, b) {
      r /= 255;
      g /= 255;
      b /= 255;
      let v = Math.max(r, g, b),
          c = v - Math.min(r, g, b);
      let h = c && (v == r ? (g - b) / c : v == g ? 2 + (b - r) / c : 4 + (r - g) / c);
      return [60 * (h < 0 ? h + 6 : h), v && c / v * 100, v * 100];
    }
    /**
     * @param r 255
     * @param g 255
     * @param b 255
     * @returns [360, 100, 100]
     */

    function rgb2hsl(r, g, b) {
      r /= 255;
      g /= 255;
      b /= 255;
      let v = Math.max(r, g, b),
          c = v - Math.min(r, g, b),
          f = 1 - Math.abs(v + v - c - 1);
      let h = c && (v == r ? (g - b) / c : v == g ? 2 + (b - r) / c : 4 + (r - g) / c);
      return [60 * (h < 0 ? h + 6 : h), f ? c / f * 100 : 0, (v + v - c) * 50];
    }
    /**
     * @param h 360
     * @param s 100
     * @param l 100
     * @returns [255, 255, 255]
     */

    function hsl2rgb(h, s, l) {
      s /= 100;
      l /= 100;
      let a = s * Math.min(l, 1 - l);

      let f = function (n) {
        let k = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : (n + h / 30) % 12;
        return l - a * Math.max(Math.min(k - 3, 9 - k, 1), -1);
      };

      return [f(0) * 255, f(8) * 255, f(4) * 255];
    }

    const prefix$1 = '^\\s*';
    const suffix = '\\s*$';
    const percent = '\\s*((\\.\\d+)|(\\d+(\\.\\d*)?))%\\s*'; // 4 offset

    const float = '\\s*((\\.\\d+)|(\\d+(\\.\\d*)?))\\s*'; // 4 offset

    const hex = '([0-9A-Fa-f])';
    const dhex = '([0-9A-Fa-f]{2})';
    const hslRegex = new RegExp(`${prefix$1}hsl\\s*\\(${float},${percent},${percent}\\)${suffix}`);
    const hsvRegex = new RegExp(`${prefix$1}hsv\\s*\\(${float},${percent},${percent}\\)${suffix}`);
    const hslaRegex = new RegExp(`${prefix$1}hsla\\s*\\(${float},${percent},${percent},${float}\\)${suffix}`);
    const hsvaRegex = new RegExp(`${prefix$1}hsva\\s*\\(${float},${percent},${percent},${float}\\)${suffix}`);
    const rgbRegex = new RegExp(`${prefix$1}rgb\\s*\\(${float},${float},${float}\\)${suffix}`);
    const rgbaRegex = new RegExp(`${prefix$1}rgba\\s*\\(${float},${float},${float},${float}\\)${suffix}`);
    const sHexRegex = new RegExp(`${prefix$1}#${hex}${hex}${hex}${suffix}`);
    const hexRegex = new RegExp(`${prefix$1}#${dhex}${dhex}${dhex}${suffix}`);
    const sHexaRegex = new RegExp(`${prefix$1}#${hex}${hex}${hex}${hex}${suffix}`);
    const hexaRegex = new RegExp(`${prefix$1}#${dhex}${dhex}${dhex}${dhex}${suffix}`);

    function parseHex(value) {
      return parseInt(value, 16);
    }
    /**
     * Convert color string to hsla array
     * @param color format like hsl(180, 100%, 100%), hsla(180, 100%, 100%, 1)
     * @returns
     */


    function hsla(color) {
      try {
        let i;

        if (i = hslaRegex.exec(color)) {
          return [roundDeg(i[1]), roundPercent(i[5]), roundPercent(i[9]), roundAlpha(i[13])];
        } else if (i = hslRegex.exec(color)) {
          return [roundDeg(i[1]), roundPercent(i[5]), roundPercent(i[9]), 1];
        }

        throw new Error(`[seemly/hsla]: Invalid color value ${color}.`);
      } catch (e) {
        throw e;
      }
    }
    /**
     * Convert color string to hsva array
     * @param color format like hsv(180, 100%, 100%), hsva(180, 100%, 100%, 1)
     * @returns
     */

    function hsva(color) {
      try {
        let i;

        if (i = hsvaRegex.exec(color)) {
          return [roundDeg(i[1]), roundPercent(i[5]), roundPercent(i[9]), roundAlpha(i[13])];
        } else if (i = hsvRegex.exec(color)) {
          return [roundDeg(i[1]), roundPercent(i[5]), roundPercent(i[9]), 1];
        }

        throw new Error(`[seemly/hsva]: Invalid color value ${color}.`);
      } catch (e) {
        throw e;
      }
    }
    /**
     * Convert color string to rgba array.
     * @param color format like #000[0], #000000[00], rgb(0, 0, 0), rgba(0, 0, 0, 0) and basic color keywords https://www.w3.org/TR/css-color-3/#html4 and transparent
     * @returns
     */

    function rgba(color) {
      try {
        let i;

        if (i = hexRegex.exec(color)) {
          return [parseHex(i[1]), parseHex(i[2]), parseHex(i[3]), 1];
        } else if (i = rgbRegex.exec(color)) {
          return [roundChannel(i[1]), roundChannel(i[5]), roundChannel(i[9]), 1];
        } else if (i = rgbaRegex.exec(color)) {
          return [roundChannel(i[1]), roundChannel(i[5]), roundChannel(i[9]), roundAlpha(i[13])];
        } else if (i = sHexRegex.exec(color)) {
          return [parseHex(i[1] + i[1]), parseHex(i[2] + i[2]), parseHex(i[3] + i[3]), 1];
        } else if (i = hexaRegex.exec(color)) {
          return [parseHex(i[1]), parseHex(i[2]), parseHex(i[3]), roundAlpha(parseHex(i[4]) / 255)];
        } else if (i = sHexaRegex.exec(color)) {
          return [parseHex(i[1] + i[1]), parseHex(i[2] + i[2]), parseHex(i[3] + i[3]), roundAlpha(parseHex(i[4] + i[4]) / 255)];
        } else if (color in colors) {
          return rgba(colors[color]);
        }

        throw new Error(`[seemly/rgba]: Invalid color value ${color}.`);
      } catch (e) {
        throw e;
      }
    }

    function normalizeAlpha$1(alphaValue) {
      return alphaValue > 1 ? 1 : alphaValue < 0 ? 0 : alphaValue;
    }

    function stringifyRgb(r, g, b) {
      return `rgb(${roundChannel(r)}, ${roundChannel(g)}, ${roundChannel(b)})`;
    }

    function stringifyRgba(r, g, b, a) {
      return `rgba(${roundChannel(r)}, ${roundChannel(g)}, ${roundChannel(b)}, ${normalizeAlpha$1(a)})`;
    }

    function compositeChannel(v1, a1, v2, a2, a) {
      return roundChannel((v1 * a1 * (1 - a2) + v2 * a2) / a);
    }

    function composite(background, overlay) {
      if (!Array.isArray(background)) background = rgba(background);
      if (!Array.isArray(overlay)) overlay = rgba(overlay);
      const a1 = background[3];
      const a2 = overlay[3];
      const alpha = roundAlpha(a1 + a2 - a1 * a2);
      return stringifyRgba(compositeChannel(background[0], a1, overlay[0], a2, alpha), compositeChannel(background[1], a1, overlay[1], a2, alpha), compositeChannel(background[2], a1, overlay[2], a2, alpha), alpha);
    }
    function changeColor(base, options) {
      const [r, g, b, a = 1] = Array.isArray(base) ? base : rgba(base);

      if (options.alpha) {
        return stringifyRgba(r, g, b, options.alpha);
      }

      return stringifyRgba(r, g, b, a);
    }
    function scaleColor(base, options) {
      const [r, g, b, a = 1] = Array.isArray(base) ? base : rgba(base);
      const {
        lightness = 1,
        alpha = 1
      } = options;
      return toRgbaString([r * lightness, g * lightness, b * lightness, a * alpha]);
    }
    function roundAlpha(value) {
      const v = Math.round(Number(value) * 100) / 100;
      if (v > 1) return 1;
      if (v < 0) return 0;
      return v;
    }
    function roundDeg(value) {
      const v = Math.round(Number(value));
      if (v >= 360) return 0;
      if (v < 0) return 0;
      return v;
    }
    function roundChannel(value) {
      const v = Math.round(Number(value));
      if (v > 255) return 255;
      if (v < 0) return 0;
      return v;
    }
    function roundPercent(value) {
      const v = Math.round(Number(value));
      if (v > 100) return 100;
      if (v < 0) return 0;
      return v;
    }
    function toRgbString(base) {
      const [r, g, b] = Array.isArray(base) ? base : rgba(base);
      return stringifyRgb(r, g, b);
    }
    function toRgbaString(base) {
      const [r, g, b] = base;

      if (3 in base) {
        return `rgba(${roundChannel(r)}, ${roundChannel(g)}, ${roundChannel(b)}, ${roundAlpha(base[3])})`;
      }

      return `rgba(${roundChannel(r)}, ${roundChannel(g)}, ${roundChannel(b)}, 1)`;
    }
    function toHsvString(base) {
      return `hsv(${roundDeg(base[0])}, ${roundPercent(base[1])}%, ${roundPercent(base[2])}%)`;
    }
    function toHsvaString(base) {
      const [h, s, v] = base;

      if (3 in base) {
        return `hsva(${roundDeg(h)}, ${roundPercent(s)}%, ${roundPercent(v)}%, ${roundAlpha(base[3])})`;
      }

      return `hsva(${roundDeg(h)}, ${roundPercent(s)}%, ${roundPercent(v)}%, 1)`;
    }
    function toHslString(base) {
      return `hsl(${roundDeg(base[0])}, ${roundPercent(base[1])}%, ${roundPercent(base[2])}%)`;
    }
    function toHslaString(base) {
      const [h, s, l] = base;

      if (3 in base) {
        return `hsla(${roundDeg(h)}, ${roundPercent(s)}%, ${roundPercent(l)}%, ${roundAlpha(base[3])})`;
      }

      return `hsla(${roundDeg(h)}, ${roundPercent(s)}%, ${roundPercent(l)}%, 1)`;
    }
    /**
     *
     * @param base [255, 255, 255, 255], [255, 255, 255], any hex string
     * @returns
     */

    function toHexaString(base) {
      if (typeof base === 'string') {
        let i;

        if (i = hexRegex.exec(base)) {
          return `${i[0]}FF`;
        } else if (i = hexaRegex.exec(base)) {
          return i[0];
        } else if (i = sHexRegex.exec(base)) {
          return `#${i[1]}${i[1]}${i[2]}${i[2]}${i[3]}${i[3]}FF`;
        } else if (i = sHexaRegex.exec(base)) {
          return `#${i[1]}${i[1]}${i[2]}${i[2]}${i[3]}${i[3]}${i[4]}${i[4]}`;
        }

        throw new Error(`[seemly/toHexString]: Invalid hex value ${base}.`);
      }

      const hex = `#${base.slice(0, 3).map(unit => roundChannel(unit).toString(16).toUpperCase().padStart(2, '0')).join('')}`;
      const a = base.length === 3 ? 'FF' : roundChannel(base[3] * 255).toString(16).padStart(2, '0').toUpperCase();
      return hex + a;
    }
    /**
     *
     * @param base [255, 255, 255, 255], [255, 255, 255], any hex string
     * @returns
     */

    function toHexString(base) {
      if (typeof base === 'string') {
        let i;

        if (i = hexRegex.exec(base)) {
          return i[0];
        } else if (i = hexaRegex.exec(base)) {
          return i[0].slice(0, 7);
        } else if (i = sHexRegex.exec(base) || sHexaRegex.exec(base)) {
          return `#${i[1]}${i[1]}${i[2]}${i[2]}${i[3]}${i[3]}`;
        }

        throw new Error(`[seemly/toHexString]: Invalid hex value ${base}.`);
      }

      return `#${base.slice(0, 3).map(unit => roundChannel(unit).toString(16).toUpperCase().padStart(2, '0')).join('')}`;
    }

    function createId() {
      let length = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 8;
      return Math.random().toString(16).slice(2, 2 + length);
    }
    function repeat(count, v) {
      const ret = [];

      for (let i = 0; i < count; ++i) {
        ret.push(v);
      }

      return ret;
    }

    function indexMap(count, createValue) {
      const ret = [];

      if (!createValue) {
        for (let i = 0; i < count; ++i) {
          ret.push(i);
        }

        return ret;
      }

      for (let i = 0; i < count; ++i) {
        ret.push(createValue(i));
      }

      return ret;
    }

    function getSlot$1(instance) {
      let slotName = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : "default";
      let fallback = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [];
      const slots = instance.$slots;
      const slot = slots[slotName];
      if (slot === void 0) return fallback;
      return slot();
    }

    function getVNodeChildren(vNode) {
      let slotName = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : "default";
      let fallback = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [];
      const {
        children
      } = vNode;

      if (children !== null && typeof children === "object" && !Array.isArray(children)) {
        const slot = children[slotName];

        if (typeof slot === "function") {
          return slot();
        }
      }

      return fallback;
    }

    function keep(object) {
      let keys = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
      let rest = arguments.length > 2 ? arguments[2] : undefined;
      const keepedObject = {};
      keys.forEach(key => {
        keepedObject[key] = object[key];
      });
      return Object.assign(keepedObject, rest);
    }

    function omit(object) {
      let keys = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
      let rest = arguments.length > 2 ? arguments[2] : undefined;
      const omitedObject = {};
      const originalKeys = Object.getOwnPropertyNames(object);
      originalKeys.forEach(originalKey => {
        if (!keys.includes(originalKey)) {
          omitedObject[originalKey] = object[originalKey];
        }
      });
      return Object.assign(omitedObject, rest);
    }

    function flatten$3(vNodes) {
      let filterCommentNode = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
      let result = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [];
      vNodes.forEach(vNode => {
        if (vNode === null) return;

        if (typeof vNode !== "object") {
          if (typeof vNode === "string" || typeof vNode === "number") {
            result.push(vue.createTextVNode(String(vNode)));
          }

          return;
        }

        if (Array.isArray(vNode)) {
          flatten$3(vNode, filterCommentNode, result);
          return;
        }

        if (vNode.type === vue.Fragment) {
          if (vNode.children === null) return;

          if (Array.isArray(vNode.children)) {
            flatten$3(vNode.children, filterCommentNode, result);
          }
        } else if (vNode.type !== vue.Comment) {
          result.push(vNode);
        }
      });
      return result;
    }

    function call(funcs) {
      for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
        args[_key - 1] = arguments[_key];
      }

      if (Array.isArray(funcs)) {
        funcs.forEach(func => call(func, ...args));
      } else return funcs(...args);
    }

    function keysOf(obj) {
      return Object.keys(obj);
    }

    const render$1 = function (r) {
      if (typeof r === "function") {
        for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
          args[_key - 1] = arguments[_key];
        }

        return r(...args);
      } else if (typeof r === "string") {
        return vue.createTextVNode(r);
      } else if (typeof r === "number") {
        return vue.createTextVNode(String(r));
      } else {
        return null;
      }
    };

    const warnedMessages = /* @__PURE__ */new Set();
    function warnOnce(location, message) {
      const mergedMessage = `[naive/${location}]: ${message}`;
      if (warnedMessages.has(mergedMessage)) return;
      warnedMessages.add(mergedMessage);
      console.error(mergedMessage);
    }
    function warn$2(location, message) {
      console.error(`[naive/${location}]: ${message}`);
    }
    function throwError(location, message) {
      throw new Error(`[naive/${location}]: ${message}`);
    }

    function smallerSize(size) {
      switch (size) {
        case "tiny":
          return "mini";

        case "small":
          return "tiny";

        case "medium":
          return "small";

        case "large":
          return "medium";

        case "huge":
          return "large";
      }

      throw Error(`${size} has no smaller size.`);
    }

    function getTitleAttribute(value) {
      switch (typeof value) {
        case "string":
          return value || void 0;

        case "number":
          return String(value);

        default:
          return void 0;
      }
    }

    function getFirstSlotVNode(slots) {
      let slotName = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : "default";
      let props = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : void 0;
      const slot = slots[slotName];

      if (!slot) {
        warn$2("getFirstSlotVNode", `slot[${slotName}] is empty`);
        return null;
      }

      const slotContent = flatten$3(slot(props));

      if (slotContent.length === 1) {
        return slotContent[0];
      } else {
        warn$2("getFirstSlotVNode", `slot[${slotName}] should have exactly one child`);
        return null;
      }
    }

    function createDataKey(key) {
      return typeof key === "string" ? `s-${key}` : `n-${key}`;
    }

    function createRefSetter(ref) {
      return inst => {
        if (inst) {
          ref.value = inst.$el;
        } else {
          ref.value = null;
        }
      };
    }

    function createInjectionKey(key) {
      return key;
    }

    function ensureValidVNode(vnodes) {
      return vnodes.some(child => {
        if (!vue.isVNode(child)) {
          return true;
        }

        if (child.type === vue.Comment) {
          return false;
        }

        if (child.type === vue.Fragment && !ensureValidVNode(child.children)) {
          return false;
        }

        return true;
      }) ? vnodes : null;
    }

    function resolveSlot(slot, fallback) {
      return slot && ensureValidVNode(slot()) || fallback();
    }
    function resolveSlotWithProps(slot, props, fallback) {
      return slot && ensureValidVNode(slot(props)) || fallback(props);
    }
    function resolveWrappedSlot(slot, wrapper) {
      const children = slot && ensureValidVNode(slot());
      return wrapper(children || null);
    }
    function isSlotEmpty(slot) {
      return !(slot && ensureValidVNode(slot()));
    }

    function mergeEventHandlers(handlers) {
      const filteredHandlers = handlers.filter(handler => handler !== void 0);
      if (filteredHandlers.length === 0) return void 0;
      if (filteredHandlers.length === 1) return filteredHandlers[0];
      return e => {
        handlers.forEach(handler => {
          if (handler) {
            handler(e);
          }
        });
      };
    }

    function isNodeVShowFalse(vNode) {
      var _vNode$dirs;

      const showDir = (_vNode$dirs = vNode.dirs) === null || _vNode$dirs === void 0 ? void 0 : _vNode$dirs.find(_ref => {
        let {
          dir
        } = _ref;
        return dir === vue.vShow;
      });
      return !!(showDir && showDir.value === false);
    }

    const Wrapper = vue.defineComponent({
      render() {
        return this.$slots.default?.();
      }
    });

    const pureNumberRegex = /^(\d|\.)+$/;
    const numberRegex = /(\d|\.)+/;
    function formatLength(length) {
      let {
        c = 1,
        offset = 0,
        attachPx = true
      } = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      if (typeof length === "number") {
        const result = (length + offset) * c;
        if (result === 0) return "0";
        return `${result}px`;
      } else if (typeof length === "string") {
        if (pureNumberRegex.test(length)) {
          const result = (Number(length) + offset) * c;

          if (attachPx) {
            if (result === 0) return "0";
            return `${result}px`;
          } else {
            return `${result}`;
          }
        } else {
          const result = numberRegex.exec(length);
          if (!result) return length;
          return length.replace(numberRegex, String((Number(result[0]) + offset) * c));
        }
      }

      return length;
    }

    function color2Class(color) {
      return color.replace(/#|\(|\)|,|\s/g, "_");
    }

    function ampCount(selector) {
      let cnt = 0;

      for (let i = 0; i < selector.length; ++i) {
        if (selector[i] === '&') ++cnt;
      }

      return cnt;
    }
    /**
     * Don't just use ',' to separate css selector. For example:
     * x:(a, b) {} will be split into 'x:(a' and 'b)', which is not expected.
     * Make sure comma doesn't exist inside parentheses.
     */


    const separatorRegex = /\s*,(?![^(]*\))\s*/g;
    const extraSpaceRegex = /\s+/g;
    /**
     * selector must includes '&'
     * selector is trimmed
     * every part of amp is trimmed
     */

    function resolveSelectorWithAmp(amp, selector) {
      const nextAmp = [];
      selector.split(separatorRegex).forEach(partialSelector => {
        let round = ampCount(partialSelector); // eslint-disable-next-line @typescript-eslint/strict-boolean-expressions

        if (!round) {
          amp.forEach(partialAmp => {
            nextAmp.push( // eslint-disable-next-line @typescript-eslint/strict-boolean-expressions
            (partialAmp && partialAmp + ' ') + partialSelector);
          });
          return;
        } else if (round === 1) {
          amp.forEach(partialAmp => {
            nextAmp.push(partialSelector.replace('&', partialAmp));
          });
          return;
        }

        let partialNextAmp = [partialSelector]; // eslint-disable-next-line @typescript-eslint/strict-boolean-expressions

        while (round--) {
          const nextPartialNextAmp = [];
          partialNextAmp.forEach(selectorItr => {
            amp.forEach(partialAmp => {
              nextPartialNextAmp.push(selectorItr.replace('&', partialAmp));
            });
          });
          partialNextAmp = nextPartialNextAmp;
        }

        partialNextAmp.forEach(part => nextAmp.push(part));
      });
      return nextAmp;
    }
    /**
     * selector mustn't includes '&'
     * selector is trimmed
     */


    function resolveSelector(amp, selector) {
      const nextAmp = [];
      selector.split(separatorRegex).forEach(partialSelector => {
        amp.forEach(partialAmp => {
          // eslint-disable-next-line @typescript-eslint/strict-boolean-expressions
          nextAmp.push((partialAmp && partialAmp + ' ') + partialSelector);
        });
      });
      return nextAmp;
    }

    function parseSelectorPath(selectorPaths) {
      let amp = [''];
      selectorPaths.forEach(selector => {
        // eslint-disable-next-line
        selector = selector && selector.trim();

        if ( // eslint-disable-next-line @typescript-eslint/strict-boolean-expressions
        !selector) {
          /**
           * if it's a empty selector, do nothing
           */
          return;
        } // eslint-disable-next-line @typescript-eslint/strict-boolean-expressions


        if (selector.includes('&')) {
          amp = resolveSelectorWithAmp(amp, selector);
        } else {
          amp = resolveSelector(amp, selector);
        }
      });
      return amp.join(', ').replace(extraSpaceRegex, ' ');
    }

    function removeElement(el) {
      /* istanbul ignore if */
      // eslint-disable-next-line @typescript-eslint/strict-boolean-expressions
      if (!el) return;
      const parentElement = el.parentElement;
      /* istanbul ignore else */
      // eslint-disable-next-line @typescript-eslint/strict-boolean-expressions

      if (parentElement) parentElement.removeChild(el);
    }
    function queryElement(id) {
      return document.head.querySelector(`style[cssr-id="${id}"]`);
    }
    function createElement(id) {
      const el = document.createElement('style');
      el.setAttribute('cssr-id', id);
      return el;
    }
    function isMediaOrSupports(selector) {
      // eslint-disable-next-line @typescript-eslint/strict-boolean-expressions
      if (!selector) return false;
      return /^\s*@(s|m)/.test(selector);
    }

    const kebabRegex = /[A-Z]/g;

    function kebabCase(pattern) {
      return pattern.replace(kebabRegex, match => '-' + match.toLowerCase());
    }
    /** TODO: refine it to solve nested object */


    function unwrapProperty(prop) {
      let indent = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '  ';

      if (typeof prop === 'object' && prop !== null) {
        return ' {\n' + Object.entries(prop).map(v => {
          return indent + `  ${kebabCase(v[0])}: ${v[1]};`;
        }).join('\n') + '\n' + indent + '}';
      }

      return `: ${prop};`;
    }
    /** unwrap properties */


    function unwrapProperties(props, instance, params) {
      if (typeof props === 'function') {
        return props({
          context: instance.context,
          props: params
        });
      }

      return props;
    }

    function createStyle(selector, props, instance, params) {
      if (!props) return ''; // eslint-disable-next-line

      const unwrappedProps = unwrapProperties(props, instance, params);
      if (!unwrappedProps) return '';

      if (typeof unwrappedProps === 'string') {
        return `${selector} {\n${unwrappedProps}\n}`;
      }

      const propertyNames = Object.keys(unwrappedProps);

      if (propertyNames.length === 0) {
        if (instance.config.keepEmptyBlock) return selector + ' {\n}';
        return '';
      }

      const statements = selector ? [selector + ' {'] : [];
      propertyNames.forEach(propertyName => {
        const property = unwrappedProps[propertyName];

        if (propertyName === 'raw') {
          statements.push('\n' + property + '\n');
          return;
        }

        propertyName = kebabCase(propertyName);

        if (property !== null && property !== undefined) {
          statements.push(`  ${propertyName}${unwrapProperty(property)}`);
        }
      });

      if (selector) {
        statements.push('}');
      }

      return statements.join('\n');
    }

    function loopCNodeListWithCallback(children, options, callback) {
      /* istanbul ignore if */
      if (!children) return;
      children.forEach(child => {
        if (Array.isArray(child)) {
          loopCNodeListWithCallback(child, options, callback);
        } else if (typeof child === 'function') {
          const grandChildren = child(options);

          if (Array.isArray(grandChildren)) {
            loopCNodeListWithCallback(grandChildren, options, callback);
          } else if (grandChildren) {
            callback(grandChildren);
          }
        } else if (child) {
          callback(child);
        }
      });
    }

    function traverseCNode(node, selectorPaths, styles, instance, params, styleSheet) {
      const $ = node.$;
      let blockSelector = '';

      if (!$ || typeof $ === 'string') {
        if (isMediaOrSupports($)) {
          blockSelector = $;
        } else {
          // as a string selector
          selectorPaths.push($);
        }
      } else if (typeof $ === 'function') {
        const selector = $({
          context: instance.context,
          props: params
        });

        if (isMediaOrSupports(selector)) {
          blockSelector = selector;
        } else {
          // as a lazy selector
          selectorPaths.push(selector);
        }
      } else {
        // as a option selector
        if ($.before) $.before(instance.context);

        if (!$.$ || typeof $.$ === 'string') {
          if (isMediaOrSupports($.$)) {
            blockSelector = $.$;
          } else {
            // as a string selector
            selectorPaths.push($.$);
          }
        } else
          /* istanbul ignore else */
          if ($.$) {
            const selector = $.$({
              context: instance.context,
              props: params
            });

            if (isMediaOrSupports(selector)) {
              blockSelector = selector;
            } else {
              // as a lazy selector
              selectorPaths.push(selector);
            }
          }
      }

      const selector = parseSelectorPath(selectorPaths);
      const style = createStyle(selector, node.props, instance, params);

      if (blockSelector) {
        styles.push(`${blockSelector} {`);

        if (styleSheet && style) {
          styleSheet.insertRule(`${blockSelector} {\n${style}\n}\n`);
        }
      } else {
        if (styleSheet && style) {
          styleSheet.insertRule(style);
        }

        if (!styleSheet && style.length) styles.push(style);
      }

      if (node.children) {
        loopCNodeListWithCallback(node.children, {
          context: instance.context,
          props: params
        }, childNode => {
          if (typeof childNode === 'string') {
            const style = createStyle(selector, {
              raw: childNode
            }, instance, params);

            if (styleSheet) {
              styleSheet.insertRule(style);
            } else {
              styles.push(style);
            }
          } else {
            traverseCNode(childNode, selectorPaths, styles, instance, params, styleSheet);
          }
        });
      }

      selectorPaths.pop();

      if (blockSelector) {
        styles.push('}');
      }

      if ($ && $.after) $.after(instance.context);
    }

    function render(node, instance, props) {
      let insertRule = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
      const styles = [];
      traverseCNode(node, [], styles, instance, props, insertRule ? node.instance.__styleSheet : undefined);
      if (insertRule) return '';
      return styles.join('\n\n');
    }

    /* eslint-disable */
    // Inspired by https://github.com/garycourt/murmurhash-js
    // Ported from https://github.com/aappleby/smhasher/blob/61a0530f28277f2e850bfc39600ce61d02b518de/src/MurmurHash2.cpp#L37-L86
    function murmur2(str) {
      // 'm' and 'r' are mixing constants generated offline.
      // They're not really 'magic', they just happen to work well.
      // const m = 0x5bd1e995;
      // const r = 24;
      // Initialize the hash
      var h = 0; // Mix 4 bytes at a time into the hash

      var k,
          i = 0,
          len = str.length;

      for (; len >= 4; ++i, len -= 4) {
        k = str.charCodeAt(i) & 0xff | (str.charCodeAt(++i) & 0xff) << 8 | (str.charCodeAt(++i) & 0xff) << 16 | (str.charCodeAt(++i) & 0xff) << 24;
        k =
        /* Math.imul(k, m): */
        (k & 0xffff) * 0x5bd1e995 + ((k >>> 16) * 0xe995 << 16);
        k ^=
        /* k >>> r: */
        k >>> 24;
        h =
        /* Math.imul(k, m): */
        (k & 0xffff) * 0x5bd1e995 + ((k >>> 16) * 0xe995 << 16) ^
        /* Math.imul(h, m): */
        (h & 0xffff) * 0x5bd1e995 + ((h >>> 16) * 0xe995 << 16);
      } // Handle the last few bytes of the input array


      switch (len) {
        case 3:
          h ^= (str.charCodeAt(i + 2) & 0xff) << 16;

        case 2:
          h ^= (str.charCodeAt(i + 1) & 0xff) << 8;

        case 1:
          h ^= str.charCodeAt(i) & 0xff;
          h =
          /* Math.imul(h, m): */
          (h & 0xffff) * 0x5bd1e995 + ((h >>> 16) * 0xe995 << 16);
      } // Do a few final mixes of the hash to ensure the last few
      // bytes are well-incorporated.


      h ^= h >>> 13;
      h =
      /* Math.imul(h, m): */
      (h & 0xffff) * 0x5bd1e995 + ((h >>> 16) * 0xe995 << 16);
      return ((h ^ h >>> 15) >>> 0).toString(36);
    }

    /* eslint-disable @typescript-eslint/prefer-ts-expect-error */

    if (typeof window !== 'undefined') {
      window.__cssrContext = {};
    }

    function unmount(intance, node, id) {
      const {
        els
      } = node; // If id is undefined, unmount all styles

      if (id === undefined) {
        els.forEach(removeElement);
        node.els = [];
      } else {
        const target = queryElement(id); // eslint-disable-next-line

        if (target && els.includes(target)) {
          removeElement(target);
          node.els = els.filter(el => el !== target);
        }
      }
    }

    function addElementToList(els, target) {
      els.push(target);
    }

    function mount(instance, node, id, props, head, silent, force, anchorMetaName, ssrAdapter // eslint-disable-next-line @typescript-eslint/no-invalid-void-type
    ) {
      if (silent && !ssrAdapter) {
        if (id === undefined) {
          // it is possible to use hash to get rid of the requirements of id
          // if you are interested in it, please create a pr
          // i have no time to impl it
          console.error('[css-render/mount]: `id` is required in `silent` mode.');
          return;
        }

        const cssrContext = window.__cssrContext;

        if (!cssrContext[id]) {
          cssrContext[id] = true;
          render(node, instance, props, silent);
        }

        return;
      }

      let style;

      if (id === undefined) {
        style = node.render(props);
        id = murmur2(style);
      }

      if (ssrAdapter) {
        ssrAdapter.adapter(id, style !== null && style !== void 0 ? style : node.render(props));
        return;
      }

      const queriedTarget = queryElement(id);

      if (queriedTarget !== null && !force) {
        return queriedTarget;
      }

      const target = queriedTarget !== null && queriedTarget !== void 0 ? queriedTarget : createElement(id);
      if (style === undefined) style = node.render(props);
      target.textContent = style;
      if (queriedTarget !== null) return queriedTarget;

      if (anchorMetaName) {
        const anchorMetaEl = document.head.querySelector(`meta[name="${anchorMetaName}"]`);

        if (anchorMetaEl) {
          document.head.insertBefore(target, anchorMetaEl);
          addElementToList(node.els, target);
          return target;
        }
      }

      if (head) {
        document.head.insertBefore(target, document.head.querySelector('style, link'));
      } else {
        document.head.appendChild(target);
      }

      addElementToList(node.els, target);
      return target;
    }

    function wrappedRender(props) {
      return render(this, this.instance, props);
    } // do not guard node calling, it should throw an error.


    function wrappedMount() {
      let options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      const {
        id,
        ssr,
        props,
        head = false,
        silent = false,
        force = false,
        anchorMetaName
      } = options;
      const targetElement = mount(this.instance, this, id, props, head, silent, force, anchorMetaName, ssr);
      return targetElement;
    }

    function wrappedUnmount() {
      let options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      /* istanbul ignore next */
      // eslint-disable-next-line @typescript-eslint/strict-boolean-expressions
      const {
        id
      } = options;
      unmount(this.instance, this, id);
    }

    const createCNode = function (instance, $, props, children) {
      return {
        instance,
        $,
        props,
        children,
        els: [],
        render: wrappedRender,
        mount: wrappedMount,
        unmount: wrappedUnmount
      };
    };

    const c$2 = function (instance, $, props, children) {
      if (Array.isArray($)) {
        return createCNode(instance, {
          $: null
        }, null, $);
      } else if (Array.isArray(props)) {
        return createCNode(instance, $, null, props);
      } else if (Array.isArray(children)) {
        return createCNode(instance, $, props, children);
      } else {
        return createCNode(instance, $, props, null);
      }
    };

    function CssRender() {
      let config = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      let styleSheet = null;
      const cssr = {
        c: function () {
          for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
          }

          return c$2(cssr, ...args);
        },
        use: function (plugin) {
          for (var _len2 = arguments.length, args = new Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
            args[_key2 - 1] = arguments[_key2];
          }

          return plugin.install(cssr, ...args);
        },
        find: queryElement,
        context: {},
        config,

        get __styleSheet() {
          // eslint-disable-next-line @typescript-eslint/strict-boolean-expressions
          if (!styleSheet) {
            const style = document.createElement('style');
            document.head.appendChild(style);
            styleSheet = document.styleSheets[document.styleSheets.length - 1];
            return styleSheet;
          }

          return styleSheet;
        }

      };
      return cssr;
    }

    function exists(id, ssr) {
      if (id === undefined) return false;

      if (ssr) {
        const {
          context: {
            ids
          }
        } = ssr;
        return ids.has(id);
      }

      return queryElement(id) !== null;
    }

    /* eslint-disable @typescript-eslint/restrict-template-expressions */

    /* eslint-disable @typescript-eslint/strict-boolean-expressions */
    function plugin$1(options) {
      let _bPrefix = '.';
      let _ePrefix = '__';
      let _mPrefix = '--';
      let c;

      if (options) {
        let t = options.blockPrefix;

        if (t) {
          _bPrefix = t;
        }

        t = options.elementPrefix;

        if (t) {
          _ePrefix = t;
        }

        t = options.modifierPrefix;

        if (t) {
          _mPrefix = t;
        }
      }

      const _plugin = {
        install(instance) {
          c = instance.c;
          const ctx = instance.context;
          ctx.bem = {};
          ctx.bem.b = null;
          ctx.bem.els = null;
        }

      };

      function b(arg) {
        let memorizedB;
        let memorizedE;
        return {
          before(ctx) {
            memorizedB = ctx.bem.b;
            memorizedE = ctx.bem.els;
            ctx.bem.els = null;
          },

          after(ctx) {
            ctx.bem.b = memorizedB;
            ctx.bem.els = memorizedE;
          },

          $(_ref) {
            let {
              context,
              props
            } = _ref;
            arg = typeof arg === 'string' ? arg : arg({
              context,
              props
            });
            context.bem.b = arg;
            return `${(props === null || props === void 0 ? void 0 : props.bPrefix) || _bPrefix}${context.bem.b}`;
          }

        };
      }

      function e(arg) {
        let memorizedE;
        return {
          before(ctx) {
            memorizedE = ctx.bem.els;
          },

          after(ctx) {
            ctx.bem.els = memorizedE;
          },

          $(_ref2) {
            let {
              context,
              props
            } = _ref2;
            arg = typeof arg === 'string' ? arg : arg({
              context,
              props
            });
            context.bem.els = arg.split(',').map(v => v.trim());
            return context.bem.els.map(el => `${(props === null || props === void 0 ? void 0 : props.bPrefix) || _bPrefix}${context.bem.b}${_ePrefix}${el}`).join(', ');
          }

        };
      }

      function m(arg) {
        return {
          $(_ref3) {
            let {
              context,
              props
            } = _ref3;
            arg = typeof arg === 'string' ? arg : arg({
              context,
              props
            });
            const modifiers = arg.split(',').map(v => v.trim());

            function elementToSelector(el) {
              return modifiers.map(modifier => `&${(props === null || props === void 0 ? void 0 : props.bPrefix) || _bPrefix}${context.bem.b}${el !== undefined ? `${_ePrefix}${el}` : ''}${_mPrefix}${modifier}`).join(', ');
            }

            const els = context.bem.els;

            if (els !== null) {
              if (els.length >= 2) {
                throw Error(`[css-render/plugin-bem]: m(${arg}) is invalid, using modifier inside multiple elements is not allowed`);
              }

              return elementToSelector(els[0]);
            } else {
              return elementToSelector();
            }
          }

        };
      }

      function notM(arg) {
        return {
          $(_ref4) {
            let {
              context,
              props
            } = _ref4;
            arg = typeof arg === 'string' ? arg : arg({
              context,
              props
            });
            const els = context.bem.els;

            if (els !== null && els.length >= 2) {
              throw Error(`[css-render/plugin-bem]: notM(${arg}) is invalid, using modifier inside multiple elements is not allowed`);
            }

            return `&:not(${(props === null || props === void 0 ? void 0 : props.bPrefix) || _bPrefix}${context.bem.b}${els !== null && els.length > 0 ? `${_ePrefix}${els[0]}` : ''}${_mPrefix}${arg})`;
          }

        };
      }

      const cB = function () {
        return c(b(arguments.length <= 0 ? undefined : arguments[0]), arguments.length <= 1 ? undefined : arguments[1], arguments.length <= 2 ? undefined : arguments[2]);
      };

      const cE = function () {
        return c(e(arguments.length <= 0 ? undefined : arguments[0]), arguments.length <= 1 ? undefined : arguments[1], arguments.length <= 2 ? undefined : arguments[2]);
      };

      const cM = function () {
        return c(m(arguments.length <= 0 ? undefined : arguments[0]), arguments.length <= 1 ? undefined : arguments[1], arguments.length <= 2 ? undefined : arguments[2]);
      };

      const cNotM = function () {
        return c(notM(arguments.length <= 0 ? undefined : arguments[0]), arguments.length <= 1 ? undefined : arguments[1], arguments.length <= 2 ? undefined : arguments[2]);
      };

      Object.assign(_plugin, {
        cB,
        cE,
        cM,
        cNotM
      });
      return _plugin;
    }

    function createKey(prefix, suffix) {
      return prefix + (suffix === "default" ? "" : suffix.replace(/^[a-z]/, startChar => startChar.toUpperCase()));
    }
    createKey("abc", "def");

    const namespace = "n";
    const prefix = `.${namespace}-`;
    const elementPrefix = "__";
    const modifierPrefix = "--";
    const cssr = CssRender();
    const plugin = plugin$1({
      blockPrefix: prefix,
      elementPrefix,
      modifierPrefix
    });
    cssr.use(plugin);
    const {
      c: c$1,
      find
    } = cssr;
    const {
      cB,
      cE,
      cM,
      cNotM
    } = plugin;

    function insideModal(style) {
      return c$1(_ref => {
        let {
          props: {
            bPrefix
          }
        } = _ref;
        return `${bPrefix || prefix}modal, ${bPrefix || prefix}drawer`;
      }, [style]);
    }

    function insidePopover(style) {
      return c$1(_ref2 => {
        let {
          props: {
            bPrefix
          }
        } = _ref2;
        return `${bPrefix || prefix}popover`;
      }, [style]);
    }

    function asModal(style) {
      return c$1(_ref3 => {
        let {
          props: {
            bPrefix
          }
        } = _ref3;
        return `&${bPrefix || prefix}modal`;
      }, style);
    }

    const cCB = function () {
      return c$1(">", [cB(...arguments)]);
    };

    let _isJsdom;

    function isJsdom() {
      if (_isJsdom === void 0) {
        _isJsdom = navigator.userAgent.includes("Node.js") || navigator.userAgent.includes("jsdom");
      }

      return _isJsdom;
    }

    const isBrowser$2 = typeof document !== "undefined" && typeof window !== "undefined";

    const eventSet = /* @__PURE__ */new WeakSet();
    function markEventEffectPerformed(event) {
      eventSet.add(event);
    }
    function eventEffectNotPerformed(event) {
      return !eventSet.has(event);
    }

    function useInjectionInstanceCollection(injectionName, collectionKey, registerKeyRef) {
      var _getCurrentInstance;

      const injection = vue.inject(injectionName, null);
      if (injection === null) return;
      const vm = (_getCurrentInstance = vue.getCurrentInstance()) === null || _getCurrentInstance === void 0 ? void 0 : _getCurrentInstance.proxy;
      vue.watch(registerKeyRef, registerInstance);
      registerInstance(registerKeyRef.value);
      vue.onBeforeUnmount(() => {
        registerInstance(void 0, registerKeyRef.value);
      });

      function registerInstance(key, oldKey) {
        const collection = injection[collectionKey];
        if (oldKey !== void 0) removeInstance(collection, oldKey);
        if (key !== void 0) addInstance(collection, key);
      }

      function removeInstance(collection, key) {
        if (!collection[key]) collection[key] = [];
        collection[key].splice(collection[key].findIndex(instance => instance === vm), 1);
      }

      function addInstance(collection, key) {
        if (!collection[key]) collection[key] = [];

        if (!~collection[key].findIndex(instance => instance === vm)) {
          collection[key].push(vm);
        }
      }
    }
    function useInjectionCollection(injectionName, collectionKey, valueRef) {
      const injection = vue.inject(injectionName, null);
      if (injection === null) return;

      if (!(collectionKey in injection)) {
        injection[collectionKey] = [];
      }

      injection[collectionKey].push(valueRef.value);
      vue.watch(valueRef, (value, prevValue) => {
        const collectionArray = injection[collectionKey];
        const index = collectionArray.findIndex(collectionValue => collectionValue === prevValue);
        if (~index) collectionArray.splice(index, 1);
        collectionArray.push(value);
      });
      vue.onBeforeUnmount(() => {
        const collectionArray = injection[collectionKey];
        const index = collectionArray.findIndex(collectionValue => collectionValue === valueRef.value);
        if (~index) collectionArray.splice(index, 1);
      });
    }
    function useInjectionElementCollection(injectionName, collectionKey, getElement) {
      const injection = vue.inject(injectionName, null);
      if (injection === null) return;

      if (!(collectionKey in injection)) {
        injection[collectionKey] = [];
      }

      vue.onMounted(() => {
        const el = getElement();
        if (!el) return;
        injection[collectionKey].push(el);
      });
      vue.onBeforeUnmount(() => {
        const collectionArray = injection[collectionKey];
        const element = getElement();
        const index = collectionArray.findIndex(collectionElement => collectionElement === element);
        if (~index) collectionArray.splice(index, 1);
      });
    }

    function useDeferredTrue(valueRef, delay, shouldDelayRef) {
      if (!delay) return valueRef;
      const delayedRef = vue.ref(valueRef.value);
      let timerId = null;
      vue.watch(valueRef, value => {
        if (timerId !== null) window.clearTimeout(timerId);

        if (value === true) {
          if (shouldDelayRef && !shouldDelayRef.value) {
            delayedRef.value = true;
          } else {
            timerId = window.setTimeout(() => {
              delayedRef.value = true;
            }, delay);
          }
        } else {
          delayedRef.value = false;
        }
      });
      return delayedRef;
    }

    function useFalseUntilTruthy(originalRef) {
      const currentRef = vue.ref(!!originalRef.value);
      if (currentRef.value) return vue.readonly(currentRef);
      const stop = vue.watch(originalRef, value => {
        if (value) {
          currentRef.value = true;
          stop();
        }
      });
      return vue.readonly(currentRef);
    }

    function useMemo(getterOrOptions) {
      const computedValueRef = vue.computed(getterOrOptions); // Maybe it's not possible to lazy evaluate the value, since we can't make
      // render phase capture the deps behind useMemo

      const valueRef = vue.ref(computedValueRef.value);
      vue.watch(computedValueRef, value => {
        valueRef.value = value;
      });

      if (typeof getterOrOptions === 'function') {
        return valueRef;
      } else {
        return {
          __v_isRef: true,

          get value() {
            return valueRef.value;
          },

          set value(v) {
            getterOrOptions.set(v);
          }

        };
      }
    }

    function hasInstance() {
      return vue.getCurrentInstance() !== null;
    }
    const isBrowser$1 = typeof window !== 'undefined';

    let fontsReady;
    let isFontReady;

    const init$1 = () => {
      var _a, _b;

      fontsReady = isBrowser$1 ? (_b = (_a = document) === null || _a === void 0 ? void 0 : _a.fonts) === null || _b === void 0 ? void 0 : _b.ready : undefined;
      isFontReady = false;
      /* istanbul ignore if */

      if (fontsReady !== undefined) {
        void fontsReady.then(() => {
          isFontReady = true;
        });
      } else {
        isFontReady = true;
      }
    };

    init$1(); // For testing
    /**
     * Call callback on fontsReady is resolved. If fontsReady is already resolved,
     * callback won't be called.
     */

    function onFontsReady(cb) {
      /* istanbul ignore next */
      if (isFontReady) return;
      let deactivated = false;
      vue.onMounted(() => {
        /* istanbul ignore next */
        if (!isFontReady) {
          fontsReady === null || fontsReady === void 0 ? void 0 : fontsReady.then(() => {
            if (deactivated) return;
            cb();
          });
        }
      });
      vue.onBeforeUnmount(() => {
        deactivated = true;
      });
    }

    function getEventTarget(e) {
      const path = e.composedPath();
      return path[0];
    }

    const traps = {
      mousemoveoutside: new WeakMap(),
      clickoutside: new WeakMap()
    };

    function createTrapHandler(name, el, originalHandler) {
      if (name === 'mousemoveoutside') {
        const moveHandler = e => {
          if (el.contains(getEventTarget(e))) return;
          originalHandler(e);
        };

        return {
          mousemove: moveHandler,
          touchstart: moveHandler
        };
      } else if (name === 'clickoutside') {
        let mouseDownOutside = false;

        const downHandler = e => {
          mouseDownOutside = !el.contains(getEventTarget(e));
        };

        const upHanlder = e => {
          if (!mouseDownOutside) return;
          if (el.contains(getEventTarget(e))) return;
          originalHandler(e);
        };

        return {
          mousedown: downHandler,
          mouseup: upHanlder,
          touchstart: downHandler,
          touchend: upHanlder
        };
      }

      console.error( // eslint-disable-next-line @typescript-eslint/restrict-template-expressions
      `[evtd/create-trap-handler]: name \`${name}\` is invalid. This could be a bug of evtd.`);
      return {};
    }

    function ensureTrapHandlers(name, el, handler) {
      const handlers = traps[name];
      let elHandlers = handlers.get(el);

      if (elHandlers === undefined) {
        handlers.set(el, elHandlers = new WeakMap());
      }

      let trapHandler = elHandlers.get(handler);

      if (trapHandler === undefined) {
        elHandlers.set(handler, trapHandler = createTrapHandler(name, el, handler));
      }

      return trapHandler;
    }

    function trapOn(name, el, handler, options) {
      if (name === 'mousemoveoutside' || name === 'clickoutside') {
        const trapHandlers = ensureTrapHandlers(name, el, handler);
        Object.keys(trapHandlers).forEach(key => {
          on(key, document, trapHandlers[key], options);
        });
        return true;
      }

      return false;
    }

    function trapOff(name, el, handler, options) {
      if (name === 'mousemoveoutside' || name === 'clickoutside') {
        const trapHandlers = ensureTrapHandlers(name, el, handler);
        Object.keys(trapHandlers).forEach(key => {
          off(key, document, trapHandlers[key], options);
        });
        return true;
      }

      return false;
    }

    function createDelegate() {
      if (typeof window === 'undefined') {
        return {
          on: () => {},
          off: () => {}
        };
      }

      const propagationStopped = new WeakMap();
      const immediatePropagationStopped = new WeakMap();

      function trackPropagation() {
        propagationStopped.set(this, true);
      }

      function trackImmediate() {
        propagationStopped.set(this, true);
        immediatePropagationStopped.set(this, true);
      }

      function spy(event, propName, fn) {
        const source = event[propName];

        event[propName] = function () {
          fn.apply(event, arguments);
          return source.apply(event, arguments);
        };

        return event;
      }

      function unspy(event, propName) {
        event[propName] = Event.prototype[propName];
      }

      const currentTargets = new WeakMap();
      const currentTargetDescriptor = Object.getOwnPropertyDescriptor(Event.prototype, 'currentTarget');

      function getCurrentTarget() {
        var _a;

        return (_a = currentTargets.get(this)) !== null && _a !== void 0 ? _a : null;
      }

      function defineCurrentTarget(event, getter) {
        if (currentTargetDescriptor === undefined) return;
        Object.defineProperty(event, 'currentTarget', {
          configurable: true,
          enumerable: true,
          get: getter !== null && getter !== void 0 ? getter : currentTargetDescriptor.get
        });
      }

      const phaseToTypeToElToHandlers = {
        bubble: {},
        capture: {}
      };
      const typeToWindowEventHandlers = {};

      function createUnifiedHandler() {
        const delegeteHandler = function (e) {
          const {
            type,
            eventPhase,
            bubbles
          } = e;
          const target = getEventTarget(e);
          if (eventPhase === 2) return;
          const phase = eventPhase === 1 ? 'capture' : 'bubble';
          let cursor = target;
          const path = []; // collecting bubble path

          while (true) {
            if (cursor === null) cursor = window;
            path.push(cursor);

            if (cursor === window) {
              break;
            } // eslint-disable-next-line @typescript-eslint/strict-boolean-expressions


            cursor = cursor.parentNode || null;
          }

          const captureElToHandlers = phaseToTypeToElToHandlers.capture[type];
          const bubbleElToHandlers = phaseToTypeToElToHandlers.bubble[type];
          spy(e, 'stopPropagation', trackPropagation);
          spy(e, 'stopImmediatePropagation', trackImmediate);
          defineCurrentTarget(e, getCurrentTarget);

          if (phase === 'capture') {
            if (captureElToHandlers === undefined) return; // capture

            for (let i = path.length - 1; i >= 0; --i) {
              if (propagationStopped.has(e)) break;
              const target = path[i];
              const handlers = captureElToHandlers.get(target);

              if (handlers !== undefined) {
                currentTargets.set(e, target);

                for (const handler of handlers) {
                  if (immediatePropagationStopped.has(e)) break;
                  handler(e);
                }
              }

              if (i === 0 && !bubbles && bubbleElToHandlers !== undefined) {
                const bubbleHandlers = bubbleElToHandlers.get(target);

                if (bubbleHandlers !== undefined) {
                  for (const handler of bubbleHandlers) {
                    if (immediatePropagationStopped.has(e)) break;
                    handler(e);
                  }
                }
              }
            }
          } else if (phase === 'bubble') {
            if (bubbleElToHandlers === undefined) return; // bubble

            for (let i = 0; i < path.length; ++i) {
              if (propagationStopped.has(e)) break;
              const target = path[i];
              const handlers = bubbleElToHandlers.get(target);

              if (handlers !== undefined) {
                currentTargets.set(e, target);

                for (const handler of handlers) {
                  if (immediatePropagationStopped.has(e)) break;
                  handler(e);
                }
              }
            }
          }

          unspy(e, 'stopPropagation');
          unspy(e, 'stopImmediatePropagation');
          defineCurrentTarget(e);
        };

        delegeteHandler.displayName = 'evtdUnifiedHandler';
        return delegeteHandler;
      }

      function createUnifiedWindowEventHandler() {
        const delegateHandler = function (e) {
          const {
            type,
            eventPhase
          } = e;
          if (eventPhase !== 2) return;
          const handlers = typeToWindowEventHandlers[type];
          if (handlers === undefined) return;
          handlers.forEach(handler => handler(e));
        };

        delegateHandler.displayName = 'evtdUnifiedWindowEventHandler';
        return delegateHandler;
      }

      const unifiedHandler = createUnifiedHandler();
      const unfiendWindowEventHandler = createUnifiedWindowEventHandler();

      function ensureElToHandlers(phase, type) {
        const phaseHandlers = phaseToTypeToElToHandlers[phase];

        if (phaseHandlers[type] === undefined) {
          phaseHandlers[type] = new Map();
          window.addEventListener(type, unifiedHandler, phase === 'capture');
        }

        return phaseHandlers[type];
      }

      function ensureWindowEventHandlers(type) {
        const windowEventHandlers = typeToWindowEventHandlers[type];

        if (windowEventHandlers === undefined) {
          typeToWindowEventHandlers[type] = new Set();
          window.addEventListener(type, unfiendWindowEventHandler);
        }

        return typeToWindowEventHandlers[type];
      }

      function ensureHandlers(elToHandlers, el) {
        let elHandlers = elToHandlers.get(el);

        if (elHandlers === undefined) {
          elToHandlers.set(el, elHandlers = new Set());
        }

        return elHandlers;
      }

      function handlerExist(el, phase, type, handler) {
        const elToHandlers = phaseToTypeToElToHandlers[phase][type]; // phase ${type} event has handlers

        if (elToHandlers !== undefined) {
          const handlers = elToHandlers.get(el); // phase using el with ${type} event has handlers

          if (handlers !== undefined) {
            if (handlers.has(handler)) return true;
          }
        }

        return false;
      }

      function windowEventHandlerExist(type, handler) {
        const handlers = typeToWindowEventHandlers[type];

        if (handlers !== undefined) {
          if (handlers.has(handler)) {
            return true;
          }
        }

        return false;
      }

      function on(type, el, handler, options) {
        let mergedHandler;

        if (typeof options === 'object' && options.once === true) {
          mergedHandler = e => {
            off(type, el, mergedHandler, options);
            handler(e);
          };
        } else {
          mergedHandler = handler;
        }

        const trapped = trapOn(type, el, mergedHandler, options);
        if (trapped) return;
        const phase = options === true || typeof options === 'object' && options.capture === true ? 'capture' : 'bubble';
        const elToHandlers = ensureElToHandlers(phase, type);
        const handlers = ensureHandlers(elToHandlers, el);
        if (!handlers.has(mergedHandler)) handlers.add(mergedHandler);

        if (el === window) {
          const windowEventHandlers = ensureWindowEventHandlers(type);

          if (!windowEventHandlers.has(mergedHandler)) {
            windowEventHandlers.add(mergedHandler);
          }
        }
      }

      function off(type, el, handler, options) {
        const trapped = trapOff(type, el, handler, options);
        if (trapped) return;
        const capture = options === true || typeof options === 'object' && options.capture === true;
        const phase = capture ? 'capture' : 'bubble';
        const elToHandlers = ensureElToHandlers(phase, type);
        const handlers = ensureHandlers(elToHandlers, el);

        if (el === window) {
          const mirrorPhase = capture ? 'bubble' : 'capture';

          if (!handlerExist(el, mirrorPhase, type, handler) && windowEventHandlerExist(type, handler)) {
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            const windowEventHandlers = typeToWindowEventHandlers[type];
            windowEventHandlers.delete(handler);

            if (windowEventHandlers.size === 0) {
              window.removeEventListener(type, unfiendWindowEventHandler);
              typeToWindowEventHandlers[type] = undefined;
            }
          }
        }

        if (handlers.has(handler)) handlers.delete(handler);

        if (handlers.size === 0) {
          elToHandlers.delete(el);
        }

        if (elToHandlers.size === 0) {
          window.removeEventListener(type, unifiedHandler, phase === 'capture');
          phaseToTypeToElToHandlers[phase][type] = undefined;
        }
      }

      return {
        on: on,
        off: off
      };
    }

    const {
      on,
      off
    } = createDelegate();

    const mousePositionRef = vue.ref(null);

    function clickHandler(e) {
      if (e.clientX > 0 || e.clientY > 0) {
        mousePositionRef.value = {
          x: e.clientX,
          y: e.clientY
        };
      } else {
        // x = 0 & y = 0
        const {
          target
        } = e;

        if (target instanceof Element) {
          const {
            left,
            top,
            width,
            height
          } = target.getBoundingClientRect();

          if (left > 0 || top > 0) {
            // impossible to be triggered by real click
            mousePositionRef.value = {
              x: left + width / 2,
              y: top + height / 2
            };
          } else {
            mousePositionRef.value = {
              x: 0,
              y: 0
            };
          }
        } else {
          mousePositionRef.value = null;
        }
      }
    }

    let usedCount$2 = 0;
    let managable$2 = true;
    function useClickPosition() {
      if (!isBrowser$1) return vue.readonly(vue.ref(null));
      if (usedCount$2 === 0) on('click', document, clickHandler, true);

      const setup = () => {
        usedCount$2 += 1;
      };

      if (managable$2 && (managable$2 = hasInstance())) {
        vue.onBeforeMount(setup);
        vue.onBeforeUnmount(() => {
          usedCount$2 -= 1;
          if (usedCount$2 === 0) off('click', document, clickHandler, true);
        });
      } else {
        setup();
      }

      return vue.readonly(mousePositionRef);
    }

    const clickedTimeRef = vue.ref(undefined);
    let usedCount$1 = 0;

    function handleClick() {
      clickedTimeRef.value = Date.now();
    }

    let managable$1 = true;
    function useClicked(timeout) {
      if (!isBrowser$1) return vue.readonly(vue.ref(false));
      const clickedRef = vue.ref(false);
      let timerId = null;

      function clearTimer() {
        if (timerId !== null) window.clearTimeout(timerId);
      }

      function clickedHandler() {
        clearTimer();
        clickedRef.value = true;
        timerId = window.setTimeout(() => {
          clickedRef.value = false;
        }, timeout);
      }

      if (usedCount$1 === 0) {
        on('click', window, handleClick, true);
      }

      const setup = () => {
        usedCount$1 += 1;
        on('click', window, clickedHandler, true);
      };

      if (managable$1 && (managable$1 = hasInstance())) {
        vue.onBeforeMount(setup);
        vue.onBeforeUnmount(() => {
          usedCount$1 -= 1;

          if (usedCount$1 === 0) {
            off('click', window, handleClick, true);
          }

          off('click', window, clickedHandler, true);
          clearTimer();
        });
      } else {
        setup();
      }

      return vue.readonly(clickedRef);
    }

    /* eslint-disable @typescript-eslint/strict-boolean-expressions */
    let usedCount = 0; // Mql means media query list

    const supportMatchMedia = typeof window !== 'undefined' && window.matchMedia !== undefined;
    const osTheme = vue.ref(null);
    let darkMql;
    let lightMql;

    function handleDarkMqlChange(e) {
      if (e.matches) {
        osTheme.value = 'dark';
      }
    }

    function handleLightMqlChange(e) {
      if (e.matches) {
        osTheme.value = 'light';
      }
    }

    function init() {
      darkMql = window.matchMedia('(prefers-color-scheme: dark)');
      lightMql = window.matchMedia('(prefers-color-scheme: light)');

      if (darkMql.matches) {
        osTheme.value = 'dark';
      } else if (lightMql.matches) {
        osTheme.value = 'light';
      } else {
        osTheme.value = null;
      }

      if (darkMql.addEventListener) {
        darkMql.addEventListener('change', handleDarkMqlChange);
        lightMql.addEventListener('change', handleLightMqlChange);
      } else if (darkMql.addListener) {
        darkMql.addListener(handleDarkMqlChange);
        lightMql.addListener(handleLightMqlChange);
      }
    }

    function clean() {
      if ('removeEventListener' in darkMql) {
        darkMql.removeEventListener('change', handleDarkMqlChange);
        lightMql.removeEventListener('change', handleLightMqlChange);
      } else if ('removeListener' in darkMql) {
        darkMql.removeListener(handleDarkMqlChange);
        lightMql.removeListener(handleLightMqlChange);
      }

      darkMql = undefined;
      lightMql = undefined;
    }

    let managable = true;
    function useOsTheme() {
      /* istanbul ignore next */
      if (!supportMatchMedia) {
        return vue.readonly(osTheme);
      }

      if (usedCount === 0) init();

      if (managable && (managable = hasInstance())) {
        vue.onBeforeMount(() => {
          usedCount += 1;
        });
        vue.onBeforeUnmount(() => {
          usedCount -= 1;
          if (usedCount === 0) clean();
        });
      }

      return vue.readonly(osTheme);
    }

    function useMergedState(controlledStateRef, uncontrolledStateRef) {
      vue.watch(controlledStateRef, value => {
        if (value !== undefined) {
          uncontrolledStateRef.value = value;
        }
      });
      return vue.computed(() => {
        if (controlledStateRef.value === undefined) {
          return uncontrolledStateRef.value;
        }

        return controlledStateRef.value;
      });
    }

    function isMounted() {
      const isMounted = vue.ref(false);
      vue.onMounted(() => {
        isMounted.value = true;
      });
      return vue.readonly(isMounted);
    }

    function useCompitable(reactive, keys) {
      // @ts-expect-error
      return vue.computed(() => {
        for (const key of keys) {
          if (reactive[key] !== undefined) return reactive[key];
        }

        return reactive[keys[keys.length - 1]];
      });
    }

    const isIos = (typeof window === 'undefined' ? false : /iPad|iPhone|iPod/.test(navigator.platform) || navigator.platform === 'MacIntel' && navigator.maxTouchPoints > 1) && // eslint-disable-next-line @typescript-eslint/strict-boolean-expressions
    !window.MSStream;
    function useIsIos() {
      return isIos;
    }

    /* eslint-disable @typescript-eslint/consistent-type-assertions */
    const defaultBreakpointOptions = {
      // mobile
      // 0 ~ 640 doesn't mean it should display well in all the range,
      // but means you should treat it like a mobile phone.)
      xs: 0,
      s: 640,
      m: 1024,
      l: 1280,
      xl: 1536,
      '2xl': 1920 // normal desktop display

    };

    function createMediaQuery(screenWidth) {
      return `(min-width: ${screenWidth}px)`;
    }

    const mqlMap = {};

    function useBreakpoints() {
      let screens = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultBreakpointOptions;
      if (!isBrowser$1) return vue.computed(() => []); // eslint-disable-next-line @typescript-eslint/strict-boolean-expressions

      if (typeof window.matchMedia !== 'function') return vue.computed(() => []);
      const breakpointStatusRef = vue.ref({});
      const breakpoints = Object.keys(screens);

      const updateBreakpoints = (e, breakpointName) => {
        if (e.matches) breakpointStatusRef.value[breakpointName] = true;else breakpointStatusRef.value[breakpointName] = false;
      };

      breakpoints.forEach(key => {
        const breakpointValue = screens[key];
        let mql;
        let cbs;

        if (mqlMap[breakpointValue] === undefined) {
          mql = window.matchMedia(createMediaQuery(breakpointValue)); // eslint-disable-next-line @typescript-eslint/strict-boolean-expressions

          if (mql.addEventListener) {
            mql.addEventListener('change', e => {
              cbs.forEach(cb => {
                cb(e, key);
              });
            }); // eslint-disable-next-line @typescript-eslint/strict-boolean-expressions
          } else if (mql.addListener) {
            mql.addListener(e => {
              cbs.forEach(cb => {
                cb(e, key);
              });
            });
          }

          cbs = new Set();
          mqlMap[breakpointValue] = {
            mql,
            cbs
          };
        } else {
          mql = mqlMap[breakpointValue].mql;
          cbs = mqlMap[breakpointValue].cbs;
        }

        cbs.add(updateBreakpoints);

        if (mql.matches) {
          cbs.forEach(cb => {
            cb(mql, key);
          });
        }
      });
      vue.onBeforeUnmount(() => {
        breakpoints.forEach(breakpoint => {
          const {
            cbs
          } = mqlMap[screens[breakpoint]];

          if (cbs.has(updateBreakpoints)) {
            cbs.delete(updateBreakpoints);
          }
        });
      });
      return vue.computed(() => {
        const {
          value
        } = breakpointStatusRef;
        return breakpoints.filter(key => value[key]);
      });
    }

    function useKeyboard$1() {
      let options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      let enabledRef = arguments.length > 1 ? arguments[1] : undefined;
      const state = vue.reactive({
        ctrl: false,
        command: false,
        win: false,
        shift: false,
        tab: false
      });
      const {
        keydown,
        keyup
      } = options;

      const keydownHandler = e => {
        switch (e.key) {
          case 'Control':
            state.ctrl = true;
            break;

          case 'Meta':
            state.command = true;
            state.win = true;
            break;

          case 'Shift':
            state.shift = true;
            break;

          case 'Tab':
            state.tab = true;
            break;
        }

        if (keydown !== undefined) {
          Object.keys(keydown).forEach(key => {
            if (key !== e.key) return;
            const handler = keydown[key];

            if (typeof handler === 'function') {
              handler(e);
            } else {
              const {
                stop = false,
                prevent = false
              } = handler;
              if (stop) e.stopPropagation();
              if (prevent) e.preventDefault();
              handler.handler(e);
            }
          });
        }
      };

      const keyupHandler = e => {
        switch (e.key) {
          case 'Control':
            state.ctrl = false;
            break;

          case 'Meta':
            state.command = false;
            state.win = false;
            break;

          case 'Shift':
            state.shift = false;
            break;

          case 'Tab':
            state.tab = false;
            break;
        }

        if (keyup !== undefined) {
          Object.keys(keyup).forEach(key => {
            if (key !== e.key) return;
            const handler = keyup[key];

            if (typeof handler === 'function') {
              handler(e);
            } else {
              const {
                stop = false,
                prevent = false
              } = handler;
              if (stop) e.stopPropagation();
              if (prevent) e.preventDefault();
              handler.handler(e);
            }
          });
        }
      };

      const setup = () => {
        if (enabledRef === undefined || enabledRef.value) {
          on('keydown', document, keydownHandler);
          on('keyup', document, keyupHandler);
        }

        if (enabledRef !== undefined) {
          vue.watch(enabledRef, value => {
            if (value) {
              on('keydown', document, keydownHandler);
              on('keyup', document, keyupHandler);
            } else {
              off('keydown', document, keydownHandler);
              off('keyup', document, keyupHandler);
            }
          });
        }
      };

      if (hasInstance()) {
        vue.onBeforeMount(setup);
        vue.onBeforeUnmount(() => {
          if (enabledRef === undefined || enabledRef.value) {
            off('keydown', document, keydownHandler);
            off('keyup', document, keyupHandler);
          }
        });
      } else {
        setup();
      }

      return vue.readonly(state);
    }

    const internalSelectionMenuInjectionKey = createInjectionKey("n-internal-select-menu");
    const internalSelectionMenuBodyInjectionKey = createInjectionKey("n-internal-select-menu-body");

    const modalBodyInjectionKey = createInjectionKey("n-modal-body");
    const modalInjectionKey = createInjectionKey("n-modal");

    const drawerBodyInjectionKey = createInjectionKey("n-drawer-body");
    const drawerInjectionKey = createInjectionKey("n-drawer");

    const popoverBodyInjectionKey = createInjectionKey("n-popover-body");

    const teleportDisabled = "__disabled__";

    function useAdjustedTo(props) {
      const modal = vue.inject(modalBodyInjectionKey, null);
      const drawer = vue.inject(drawerBodyInjectionKey, null);
      const popover = vue.inject(popoverBodyInjectionKey, null);
      const selectMenu = vue.inject(internalSelectionMenuBodyInjectionKey, null);
      const fullscreenElementRef = vue.ref();

      if (typeof document !== "undefined") {
        fullscreenElementRef.value = document.fullscreenElement;

        const handleFullscreenChange = () => {
          fullscreenElementRef.value = document.fullscreenElement;
        };

        vue.onMounted(() => {
          on("fullscreenchange", document, handleFullscreenChange);
        });
        vue.onBeforeUnmount(() => {
          off("fullscreenchange", document, handleFullscreenChange);
        });
      }

      return useMemo(() => {
        const {
          to
        } = props;

        if (to !== void 0) {
          if (to === false) return teleportDisabled;
          if (to === true) return fullscreenElementRef.value || "body";
          return to;
        }

        if (modal !== null && modal !== void 0 && modal.value) {
          return modal.value.$el ?? modal.value;
        }

        if (drawer !== null && drawer !== void 0 && drawer.value) return drawer.value;
        if (popover !== null && popover !== void 0 && popover.value) return popover.value;
        if (selectMenu !== null && selectMenu !== void 0 && selectMenu.value) return selectMenu.value;
        return to ?? (fullscreenElementRef.value || "body");
      });
    }

    useAdjustedTo.tdkey = teleportDisabled;
    useAdjustedTo.propTo = {
      type: [String, Object, Boolean],
      default: void 0
    };

    let houdiniRegistered = false;
    function useHoudini() {
      if (!isBrowser$2) return;
      if (!window.CSS) return;

      if (!houdiniRegistered) {
        var _window;

        houdiniRegistered = true;

        if ("registerProperty" in ((_window = window) === null || _window === void 0 ? void 0 : _window.CSS)) {
          try {
            ;
            CSS.registerProperty({
              name: "--n-color-start",
              syntax: "<color>",
              inherits: false,
              initialValue: "#0000"
            });
            CSS.registerProperty({
              name: "--n-color-end",
              syntax: "<color>",
              inherits: false,
              initialValue: "#0000"
            });
          } catch (e) {}
        }
      }
    }

    function getSlot(scope, slots) {
      let slotName = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'default';
      const slot = slots[slotName];

      if (slot === undefined) {
        throw new Error(`[vueuc/${scope}]: slot[${slotName}] is empty.`);
      }

      return slot();
    } // o(n) flatten

    function flatten$2(vNodes) {
      let filterCommentNode = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
      let result = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [];
      vNodes.forEach(vNode => {
        if (vNode === null) return;

        if (typeof vNode !== 'object') {
          if (typeof vNode === 'string' || typeof vNode === 'number') {
            result.push(vue.createTextVNode(String(vNode)));
          }

          return;
        }

        if (Array.isArray(vNode)) {
          flatten$2(vNode, filterCommentNode, result);
          return;
        }

        if (vNode.type === vue.Fragment) {
          if (vNode.children === null) return;

          if (Array.isArray(vNode.children)) {
            flatten$2(vNode.children, filterCommentNode, result);
          } // rawSlot

        } else if (vNode.type !== vue.Comment) {
          result.push(vNode);
        }
      });
      return result;
    }
    function getFirstVNode(scope, slots) {
      let slotName = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'default';
      const slot = slots[slotName];

      if (slot === undefined) {
        throw new Error(`[vueuc/${scope}]: slot[${slotName}] is empty.`);
      }

      const content = flatten$2(slot()); // vue will normalize the slot, so slot must be an array

      if (content.length === 1) {
        return content[0];
      } else {
        throw new Error(`[vueuc/${scope}]: slot[${slotName}] should have exactly one child.`);
      }
    }

    let viewMeasurer = null;
    function ensureViewBoundingRect() {
      if (viewMeasurer === null) {
        viewMeasurer = document.getElementById('v-binder-view-measurer');

        if (viewMeasurer === null) {
          viewMeasurer = document.createElement('div');
          viewMeasurer.id = 'v-binder-view-measurer';
          const {
            style
          } = viewMeasurer;
          style.position = 'fixed';
          style.left = '0';
          style.right = '0';
          style.top = '0';
          style.bottom = '0';
          style.pointerEvents = 'none';
          style.visibility = 'hidden';
          document.body.appendChild(viewMeasurer);
        }
      }

      return viewMeasurer.getBoundingClientRect();
    }
    function getPointRect(x, y) {
      const viewRect = ensureViewBoundingRect();
      return {
        top: y,
        left: x,
        height: 0,
        width: 0,
        right: viewRect.width - x,
        bottom: viewRect.height - y
      };
    }
    function getRect$1(el) {
      const elRect = el.getBoundingClientRect();
      const viewRect = ensureViewBoundingRect();
      return {
        left: elRect.left - viewRect.left,
        top: elRect.top - viewRect.top,
        bottom: viewRect.height + viewRect.top - elRect.bottom,
        right: viewRect.width + viewRect.left - elRect.right,
        width: elRect.width,
        height: elRect.height
      };
    }
    function getParentNode(node) {
      // document type
      if (node.nodeType === 9) {
        return null;
      }

      return node.parentNode;
    }
    function getScrollParent(node) {
      if (node === null) return null;
      const parentNode = getParentNode(node);

      if (parentNode === null) {
        return null;
      } // Document


      if (parentNode.nodeType === 9) {
        return document;
      } // Element


      if (parentNode.nodeType === 1) {
        // Firefox want us to check `-x` and `-y` variations as well
        const {
          overflow,
          overflowX,
          overflowY
        } = getComputedStyle(parentNode);

        if (/(auto|scroll|overlay)/.test(overflow + overflowY + overflowX)) {
          return parentNode;
        }
      }

      return getScrollParent(parentNode);
    }

    /* eslint-disable @typescript-eslint/no-non-null-assertion */
    const Binder = vue.defineComponent({
      name: 'Binder',
      props: {
        syncTargetWithParent: Boolean,
        syncTarget: {
          type: Boolean,
          default: true
        }
      },

      setup(props) {
        var _a;

        vue.provide('VBinder', (_a = vue.getCurrentInstance()) === null || _a === void 0 ? void 0 : _a.proxy);
        const VBinder = vue.inject('VBinder', null);
        const targetRef = vue.ref(null);
        /**
         * If there's no nested vbinder, we can simply set the target ref.
         *
         * However, when it comes to:
         * <VBinder> <- syncTarget = false
         *
         *              Should hold target DOM ref, but can't get it directly from
         *              its VTarget. So if there are nested VBinder, we should:
         *              1. Stop setting target DOM from level-1 VTarget
         *              2. Set target DOM from level-2 VTarget
         *              For (1), we need `syncTarget` to `false`
         *              For (2), we need to set `syncTargetWithParent` to `true` on
         *              level-2 VBinder
         *   <VTarget>
         *     <VBinder> <- syncTargetWithParent = true
         *       <VTarget>target</VTarget>
         *     </VBinder>
         *     <VFollower>
         *       content1
         *     </VFollower>
         *   </VTarget>
         *   <VFollower>
         *     content2
         *   </VFollower>
         * </VBinder>
         */

        const setTargetRef = el => {
          targetRef.value = el; // eslint-disable-next-line @typescript-eslint/strict-boolean-expressions

          if (VBinder && props.syncTargetWithParent) {
            VBinder.setTargetRef(el);
          }
        }; // scroll related


        let scrollableNodes = [];

        const ensureScrollListener = () => {
          let cursor = targetRef.value;

          while (true) {
            cursor = getScrollParent(cursor);
            if (cursor === null) break;
            scrollableNodes.push(cursor);
          }

          for (const el of scrollableNodes) {
            on('scroll', el, onScroll, true);
          }
        };

        const removeScrollListeners = () => {
          for (const el of scrollableNodes) {
            off('scroll', el, onScroll, true);
          }

          scrollableNodes = [];
        };

        const followerScrollListeners = new Set();

        const addScrollListener = listener => {
          if (followerScrollListeners.size === 0) {
            ensureScrollListener();
          }

          if (!followerScrollListeners.has(listener)) {
            followerScrollListeners.add(listener);
          }
        };

        const removeScrollListener = listener => {
          if (followerScrollListeners.has(listener)) {
            followerScrollListeners.delete(listener);
          }

          if (followerScrollListeners.size === 0) {
            removeScrollListeners();
          }
        };

        const onScroll = () => {
          beforeNextFrameOnce(onScrollRaf);
        };

        const onScrollRaf = () => {
          followerScrollListeners.forEach(listener => listener());
        }; // resize related


        const followerResizeListeners = new Set();

        const addResizeListener = listener => {
          if (followerResizeListeners.size === 0) {
            on('resize', window, onResize);
          }

          if (!followerResizeListeners.has(listener)) {
            followerResizeListeners.add(listener);
          }
        };

        const removeResizeListener = listener => {
          if (followerResizeListeners.has(listener)) {
            followerResizeListeners.delete(listener);
          }

          if (followerResizeListeners.size === 0) {
            off('resize', window, onResize);
          }
        };

        const onResize = () => {
          followerResizeListeners.forEach(listener => listener());
        };

        vue.onBeforeUnmount(() => {
          off('resize', window, onResize);
          removeScrollListeners();
        });
        return {
          targetRef,
          setTargetRef,
          addScrollListener,
          removeScrollListener,
          addResizeListener,
          removeResizeListener
        };
      },

      render() {
        return getSlot('binder', this.$slots);
      }

    });
    var VBinder = Binder;

    /* eslint-disable @typescript-eslint/no-non-null-assertion */
    var VTarget = vue.defineComponent({
      name: 'Target',

      setup() {
        const {
          setTargetRef,
          syncTarget
        } = vue.inject('VBinder');
        const setTargetDirective = {
          mounted: setTargetRef,
          updated: setTargetRef
        };
        return {
          syncTarget,
          setTargetDirective
        };
      },

      render() {
        const {
          syncTarget,
          setTargetDirective
        } = this;
        /**
         * If you are using VBinder as a child of VBinder, the children wouldn't be
         * a valid DOM or component that can be attached to by directive.
         * So we won't sync target on those kind of situation and control the
         * target sync logic manually.
         */

        if (syncTarget) {
          return vue.withDirectives(getFirstVNode('follower', this.$slots), [[setTargetDirective]]);
        }

        return getFirstVNode('follower', this.$slots);
      }

    });

    const ctxKey$1 = '@@mmoContext';
    const mousemoveoutside = {
      mounted(el, _ref) {
        let {
          value
        } = _ref;
        el[ctxKey$1] = {
          handler: undefined
        };

        if (typeof value === 'function') {
          el[ctxKey$1].handler = value;
          on('mousemoveoutside', el, value);
        }
      },

      updated(el, _ref2) {
        let {
          value
        } = _ref2;
        const ctx = el[ctxKey$1];

        if (typeof value === 'function') {
          if (ctx.handler) {
            if (ctx.handler !== value) {
              off('mousemoveoutside', el, ctx.handler);
              ctx.handler = value;
              on('mousemoveoutside', el, value);
            }
          } else {
            el[ctxKey$1].handler = value;
            on('mousemoveoutside', el, value);
          }
        } else {
          if (ctx.handler) {
            off('mousemoveoutside', el, ctx.handler);
            ctx.handler = undefined;
          }
        }
      },

      unmounted(el) {
        const {
          handler
        } = el[ctxKey$1];

        if (handler) {
          off('mousemoveoutside', el, handler);
        }

        el[ctxKey$1].handler = undefined;
      }

    };
    var mousemoveoutside$1 = mousemoveoutside;

    const ctxKey = '@@coContext';
    const clickoutside = {
      mounted(el, _ref) {
        let {
          value,
          modifiers
        } = _ref;
        el[ctxKey] = {
          handler: undefined
        };

        if (typeof value === 'function') {
          el[ctxKey].handler = value;
          on('clickoutside', el, value, {
            capture: modifiers.capture
          });
        }
      },

      updated(el, _ref2) {
        let {
          value,
          modifiers
        } = _ref2;
        const ctx = el[ctxKey];

        if (typeof value === 'function') {
          if (ctx.handler) {
            if (ctx.handler !== value) {
              off('clickoutside', el, ctx.handler, {
                capture: modifiers.capture
              });
              ctx.handler = value;
              on('clickoutside', el, value, {
                capture: modifiers.capture
              });
            }
          } else {
            el[ctxKey].handler = value;
            on('clickoutside', el, value, {
              capture: modifiers.capture
            });
          }
        } else {
          if (ctx.handler) {
            off('clickoutside', el, ctx.handler, {
              capture: modifiers.capture
            });
            ctx.handler = undefined;
          }
        }
      },

      unmounted(el, _ref3) {
        let {
          modifiers
        } = _ref3;
        const {
          handler
        } = el[ctxKey];

        if (handler) {
          off('clickoutside', el, handler, {
            capture: modifiers.capture
          });
        }

        el[ctxKey].handler = undefined;
      }

    };
    var clickoutside$1 = clickoutside;

    function warn$1(location, message) {
      console.error(`[vdirs/${location}]: ${message}`);
    }

    class ZIndexManager {
      constructor() {
        this.elementZIndex = new Map();
        this.nextZIndex = 2000;
      }

      get elementCount() {
        return this.elementZIndex.size;
      }

      ensureZIndex(el, zIndex) {
        const {
          elementZIndex
        } = this;

        if (zIndex !== undefined) {
          el.style.zIndex = `${zIndex}`;
          elementZIndex.delete(el);
          return;
        }

        const {
          nextZIndex
        } = this;

        if (elementZIndex.has(el)) {
          const currentZIndex = elementZIndex.get(el);
          if (currentZIndex + 1 === this.nextZIndex) return;
        }

        el.style.zIndex = `${nextZIndex}`;
        elementZIndex.set(el, nextZIndex);
        this.nextZIndex = nextZIndex + 1;
        this.squashState();
      }

      unregister(el, zIndex) {
        const {
          elementZIndex
        } = this;

        if (elementZIndex.has(el)) {
          elementZIndex.delete(el);
        } else if (zIndex === undefined) {
          warn$1('z-index-manager/unregister-element', 'Element not found when unregistering.');
        }

        this.squashState();
      }

      squashState() {
        const {
          elementCount
        } = this;

        if (!elementCount) {
          this.nextZIndex = 2000;
        }

        if (this.nextZIndex - elementCount > 2500) this.rearrange();
      }

      rearrange() {
        const elementZIndexPair = Array.from(this.elementZIndex.entries());
        elementZIndexPair.sort((pair1, pair2) => {
          return pair1[1] - pair2[1];
        });
        this.nextZIndex = 2000;
        elementZIndexPair.forEach(pair => {
          const el = pair[0];
          const zIndex = this.nextZIndex++;
          if (`${zIndex}` !== el.style.zIndex) el.style.zIndex = `${zIndex}`;
        });
      }

    }

    var zIndexManager = new ZIndexManager();

    const ctx = '@@ziContext'; // We don't expect manually bound zindex should be changed

    const zindexable = {
      mounted(el, bindings) {
        const {
          value = {}
        } = bindings;
        const {
          zIndex,
          enabled
        } = value;
        el[ctx] = {
          enabled: !!enabled,
          initialized: false
        };

        if (enabled) {
          zIndexManager.ensureZIndex(el, zIndex);
          el[ctx].initialized = true;
        }
      },

      updated(el, bindings) {
        const {
          value = {}
        } = bindings;
        const {
          zIndex,
          enabled
        } = value;
        const cachedEnabled = el[ctx].enabled;

        if (enabled && !cachedEnabled) {
          zIndexManager.ensureZIndex(el, zIndex);
          el[ctx].initialized = true;
        }

        el[ctx].enabled = !!enabled;
      },

      unmounted(el, bindings) {
        if (!el[ctx].initialized) return;
        const {
          value = {}
        } = bindings;
        const {
          zIndex
        } = value;
        zIndexManager.unregister(el, zIndex);
      }

    };
    var zindexable$1 = zindexable;

    const ssrContextKey = Symbol('@css-render/vue3-ssr');

    function createStyleString(id, style) {
      return `<style cssr-id="${id}">\n${style}\n</style>`;
    }

    function ssrAdapter(id, style) {
      const ssrContext = vue.inject(ssrContextKey, null);

      if (ssrContext === null) {
        console.error('[css-render/vue3-ssr]: no ssr context found.');
        return;
      }

      const {
        styles,
        ids
      } = ssrContext; // we need to impl other options to make it behaves the same as the client side

      if (ids.has(id)) return;

      if (styles !== null) {
        ids.add(id);
        styles.push(createStyleString(id, style));
      }
    }

    const isBrowser = typeof document !== 'undefined';
    function useSsrAdapter() {
      if (isBrowser) return undefined;
      const context = vue.inject(ssrContextKey, null);
      if (context === null) return undefined;
      return {
        adapter: ssrAdapter,
        context
      };
    }

    function warn(location, message) {
      console.error(`[vueuc/${location}]: ${message}`);
    }

    const {
      c
    } = CssRender();
    const cssrAnchorMetaName$1 = 'vueuc-style';

    function lowBit(n) {
      return n & -n;
    }

    class FinweckTree {
      /**
       * @param l length of the array
       * @param min min value of the array
       */
      constructor(l, min) {
        this.l = l;
        this.min = min;
        const ft = new Array(l + 1);

        for (let i = 0; i < l + 1; ++i) {
          ft[i] = 0;
        }

        this.ft = ft;
      }
      /**
       * Add arr[i] by n, start from 0
       * @param i the index of the element to be added
       * @param n the value to be added
       */


      add(i, n) {
        if (n === 0) return;
        const {
          l,
          ft
        } = this;
        i += 1;

        while (i <= l) {
          ft[i] += n;
          i += lowBit(i);
        }
      }
      /**
       * Get the value of index i
       * @param i index
       * @returns value of the index
       */


      get(i) {
        return this.sum(i + 1) - this.sum(i);
      }
      /**
       * Get the sum of first i elements
       * @param i count of head elements to be added
       * @returns the sum of first i elements
       */


      sum(i) {
        if (i === undefined) i = this.l;
        if (i <= 0) return 0;
        const {
          ft,
          min,
          l
        } = this;
        if (i > l) throw new Error('[FinweckTree.sum]: `i` is larger than length.');
        let ret = i * min;

        while (i > 0) {
          ret += ft[i];
          i -= lowBit(i);
        }

        return ret;
      }
      /**
       * Get the largest count of head elements whose sum are <= threshold
       * @param threshold
       * @returns the largest count of head elements whose sum are <= threshold
       */


      getBound(threshold) {
        let l = 0;
        let r = this.l;

        while (r > l) {
          const m = Math.floor((l + r) / 2);
          const sumM = this.sum(m);

          if (sumM > threshold) {
            r = m;
            continue;
          } else if (sumM < threshold) {
            if (l === m) {
              if (this.sum(l + 1) <= threshold) return l + 1;
              return m;
            }

            l = m;
          } else {
            return m;
          }
        }

        return l;
      }

    }

    function resolveTo(selector) {
      if (typeof selector === 'string') {
        return document.querySelector(selector);
      }

      return selector();
    }

    var LazyTeleport = vue.defineComponent({
      name: 'LazyTeleport',
      props: {
        to: {
          type: [String, Object],
          default: undefined
        },
        disabled: Boolean,
        show: {
          type: Boolean,
          required: true
        }
      },

      setup(props) {
        return {
          showTeleport: useFalseUntilTruthy(vue.toRef(props, 'show')),
          mergedTo: vue.computed(() => {
            const {
              to
            } = props;
            return to !== null && to !== void 0 ? to : 'body';
          })
        };
      },

      render() {
        return this.showTeleport ? this.disabled ? getSlot('lazy-teleport', this.$slots) : vue.h(vue.Teleport, {
          disabled: this.disabled,
          to: this.mergedTo
        }, getSlot('lazy-teleport', this.$slots)) : null;
      }

    });

    const oppositionPositions = {
      top: 'bottom',
      bottom: 'top',
      left: 'right',
      right: 'left'
    };
    const oppositeAligns = {
      start: 'end',
      center: 'center',
      end: 'start'
    };
    const propToCompare = {
      top: 'height',
      bottom: 'height',
      left: 'width',
      right: 'width'
    };
    const transformOrigins = {
      'bottom-start': 'top left',
      bottom: 'top center',
      'bottom-end': 'top right',
      'top-start': 'bottom left',
      top: 'bottom center',
      'top-end': 'bottom right',
      'right-start': 'top left',
      right: 'center left',
      'right-end': 'bottom left',
      'left-start': 'top right',
      left: 'center right',
      'left-end': 'bottom right'
    };
    const overlapTransformOrigin = {
      'bottom-start': 'bottom left',
      bottom: 'bottom center',
      'bottom-end': 'bottom right',
      'top-start': 'top left',
      top: 'top center',
      'top-end': 'top right',
      'right-start': 'top right',
      right: 'center right',
      'right-end': 'bottom right',
      'left-start': 'top left',
      left: 'center left',
      'left-end': 'bottom left'
    };
    const oppositeAlignCssPositionProps = {
      'bottom-start': 'right',
      'bottom-end': 'left',
      'top-start': 'right',
      'top-end': 'left',
      'right-start': 'bottom',
      'right-end': 'top',
      'left-start': 'bottom',
      'left-end': 'top'
    };
    const keepOffsetDirection = {
      top: true,
      bottom: false,
      left: true,
      right: false // left--

    };
    const cssPositionToOppositeAlign = {
      top: 'end',
      bottom: 'start',
      left: 'end',
      right: 'start'
    };
    function getPlacementAndOffsetOfFollower(placement, targetRect, followerRect, shift, flip, overlap) {
      if (!flip || overlap) {
        return {
          placement: placement,
          top: 0,
          left: 0
        };
      }

      const [position, align] = placement.split('-');
      let properAlign = align !== null && align !== void 0 ? align : 'center';
      let properOffset = {
        top: 0,
        left: 0
      };

      const deriveOffset = (oppositeAlignCssSizeProp, alignCssPositionProp, offsetVertically) => {
        let left = 0;
        let top = 0;
        const diff = followerRect[oppositeAlignCssSizeProp] - targetRect[alignCssPositionProp] - targetRect[oppositeAlignCssSizeProp];

        if (diff > 0 && shift) {
          if (offsetVertically) {
            //       screen border
            // |-----------------------------------------|
            // |                    | f  |               |
            // |                    | o  |               |
            // |                    | l  |               |
            // |                    | l  |----           |
            // |                    | o  |tar |          |
            // |                    | w  |get |          |
            // |                    | e  |    |          |
            // |                    | r  |----           |
            // |                     ----                |
            // |-----------------------------------------|
            top = keepOffsetDirection[alignCssPositionProp] ? diff : -diff;
          } else {
            //       screen border
            // |----------------------------------------|
            // |                                        |
            // |          ----------                    |
            // |          | target |                    |
            // |       ----------------------------------
            // |       |       follower                 |
            // |       ----------------------------------
            // |                                        |
            // |----------------------------------------|
            left = keepOffsetDirection[alignCssPositionProp] ? diff : -diff;
          }
        }

        return {
          left,
          top
        };
      };

      const offsetVertically = position === 'left' || position === 'right'; // choose proper placement for non-center align

      if (properAlign !== 'center') {
        const oppositeAlignCssPositionProp = oppositeAlignCssPositionProps[placement];
        const currentAlignCssPositionProp = oppositionPositions[oppositeAlignCssPositionProp];
        const oppositeAlignCssSizeProp = propToCompare[oppositeAlignCssPositionProp]; // if follower rect is larger than target rect in align direction
        // ----------[ target ]---------|
        // ----------[     follower     ]

        if (followerRect[oppositeAlignCssSizeProp] > targetRect[oppositeAlignCssSizeProp]) {
          if ( // current space is not enough
          // ----------[ target ]---------|
          // -------[     follower        ]
          targetRect[oppositeAlignCssPositionProp] + targetRect[oppositeAlignCssSizeProp] < followerRect[oppositeAlignCssSizeProp]) {
            const followerOverTargetSize = (followerRect[oppositeAlignCssSizeProp] - targetRect[oppositeAlignCssSizeProp]) / 2;

            if (targetRect[oppositeAlignCssPositionProp] < followerOverTargetSize || targetRect[currentAlignCssPositionProp] < followerOverTargetSize) {
              // opposite align has larger space
              // -------[ target ]-----------|
              // -------[     follower     ]-|
              if (targetRect[oppositeAlignCssPositionProp] < targetRect[currentAlignCssPositionProp]) {
                properAlign = oppositeAligns[align];
                properOffset = deriveOffset(oppositeAlignCssSizeProp, currentAlignCssPositionProp, offsetVertically);
              } else {
                // ----------------[ target ]----|
                // --------[   follower     ]----|
                properOffset = deriveOffset(oppositeAlignCssSizeProp, oppositeAlignCssPositionProp, offsetVertically);
              }
            } else {
              // 'center' align is better
              // ------------[ target ]--------|
              // -------[       follower    ]--|
              properAlign = 'center';
            }
          }
        } else if (followerRect[oppositeAlignCssSizeProp] < targetRect[oppositeAlignCssSizeProp]) {
          // TODO: maybe center is better
          if (targetRect[currentAlignCssPositionProp] < 0 && // opposite align has larger space
          // ------------[   target   ]
          // ----------------[follower]
          targetRect[oppositeAlignCssPositionProp] > targetRect[currentAlignCssPositionProp]) {
            properAlign = oppositeAligns[align];
          }
        }
      } else {
        const possibleAlternativeAlignCssPositionProp1 = position === 'bottom' || position === 'top' ? 'left' : 'top';
        const possibleAlternativeAlignCssPositionProp2 = oppositionPositions[possibleAlternativeAlignCssPositionProp1];
        const alternativeAlignCssSizeProp = propToCompare[possibleAlternativeAlignCssPositionProp1];
        const followerOverTargetSize = (followerRect[alternativeAlignCssSizeProp] - targetRect[alternativeAlignCssSizeProp]) / 2;

        if ( // center is not enough
        // ----------- [ target ]--|
        // -------[     follower     ]
        targetRect[possibleAlternativeAlignCssPositionProp1] < followerOverTargetSize || targetRect[possibleAlternativeAlignCssPositionProp2] < followerOverTargetSize) {
          // alternative 2 position's space is larger
          if (targetRect[possibleAlternativeAlignCssPositionProp1] > targetRect[possibleAlternativeAlignCssPositionProp2]) {
            properAlign = cssPositionToOppositeAlign[possibleAlternativeAlignCssPositionProp1];
            properOffset = deriveOffset(alternativeAlignCssSizeProp, possibleAlternativeAlignCssPositionProp1, offsetVertically);
          } else {
            // alternative 1 position's space is larger
            properAlign = cssPositionToOppositeAlign[possibleAlternativeAlignCssPositionProp2];
            properOffset = deriveOffset(alternativeAlignCssSizeProp, possibleAlternativeAlignCssPositionProp2, offsetVertically);
          }
        }
      }

      let properPosition = position;

      if ( // space is not enough
      targetRect[position] < followerRect[propToCompare[position]] && // opposite position's space is larger
      targetRect[position] < targetRect[oppositionPositions[position]]) {
        properPosition = oppositionPositions[position];
      }

      return {
        placement: properAlign !== 'center' ? `${properPosition}-${properAlign}` : properPosition,
        left: properOffset.left,
        top: properOffset.top
      };
    }
    function getProperTransformOrigin(placement, overlap) {
      if (overlap) return overlapTransformOrigin[placement];
      return transformOrigins[placement];
    } // ------------
    // |  offset  |
    // |          |
    // | [target] |
    // |          |
    // ------------
    // TODO: refactor it to remove dup logic

    function getOffset$1(placement, offsetRect, targetRect, offsetTopToStandardPlacement, offsetLeftToStandardPlacement, overlap) {
      if (overlap) {
        switch (placement) {
          case 'bottom-start':
            return {
              top: `${Math.round(targetRect.top - offsetRect.top + targetRect.height)}px`,
              left: `${Math.round(targetRect.left - offsetRect.left)}px`,
              transform: 'translateY(-100%)'
            };

          case 'bottom-end':
            return {
              top: `${Math.round(targetRect.top - offsetRect.top + targetRect.height)}px`,
              left: `${Math.round(targetRect.left - offsetRect.left + targetRect.width)}px`,
              transform: 'translateX(-100%) translateY(-100%)'
            };

          case 'top-start':
            return {
              top: `${Math.round(targetRect.top - offsetRect.top)}px`,
              left: `${Math.round(targetRect.left - offsetRect.left)}px`,
              transform: ''
            };

          case 'top-end':
            return {
              top: `${Math.round(targetRect.top - offsetRect.top)}px`,
              left: `${Math.round(targetRect.left - offsetRect.left + targetRect.width)}px`,
              transform: 'translateX(-100%)'
            };

          case 'right-start':
            return {
              top: `${Math.round(targetRect.top - offsetRect.top)}px`,
              left: `${Math.round(targetRect.left - offsetRect.left + targetRect.width)}px`,
              transform: 'translateX(-100%)'
            };

          case 'right-end':
            return {
              top: `${Math.round(targetRect.top - offsetRect.top + targetRect.height)}px`,
              left: `${Math.round(targetRect.left - offsetRect.left + targetRect.width)}px`,
              transform: 'translateX(-100%) translateY(-100%)'
            };

          case 'left-start':
            return {
              top: `${Math.round(targetRect.top - offsetRect.top)}px`,
              left: `${Math.round(targetRect.left - offsetRect.left)}px`,
              transform: ''
            };

          case 'left-end':
            return {
              top: `${Math.round(targetRect.top - offsetRect.top + targetRect.height)}px`,
              left: `${Math.round(targetRect.left - offsetRect.left)}px`,
              transform: 'translateY(-100%)'
            };

          case 'top':
            return {
              top: `${Math.round(targetRect.top - offsetRect.top)}px`,
              left: `${Math.round(targetRect.left - offsetRect.left + targetRect.width / 2)}px`,
              transform: 'translateX(-50%)'
            };

          case 'right':
            return {
              top: `${Math.round(targetRect.top - offsetRect.top + targetRect.height / 2)}px`,
              left: `${Math.round(targetRect.left - offsetRect.left + targetRect.width)}px`,
              transform: 'translateX(-100%) translateY(-50%)'
            };

          case 'left':
            return {
              top: `${Math.round(targetRect.top - offsetRect.top + targetRect.height / 2)}px`,
              left: `${Math.round(targetRect.left - offsetRect.left)}px`,
              transform: 'translateY(-50%)'
            };

          case 'bottom':
          default:
            return {
              top: `${Math.round(targetRect.top - offsetRect.top + targetRect.height)}px`,
              left: `${Math.round(targetRect.left - offsetRect.left + targetRect.width / 2)}px`,
              transform: 'translateX(-50%) translateY(-100%)'
            };
        }
      }

      switch (placement) {
        case 'bottom-start':
          return {
            top: `${Math.round(targetRect.top - offsetRect.top + targetRect.height + offsetTopToStandardPlacement)}px`,
            left: `${Math.round(targetRect.left - offsetRect.left + offsetLeftToStandardPlacement)}px`,
            transform: ''
          };

        case 'bottom-end':
          return {
            top: `${Math.round(targetRect.top - offsetRect.top + targetRect.height + offsetTopToStandardPlacement)}px`,
            left: `${Math.round(targetRect.left - offsetRect.left + targetRect.width + offsetLeftToStandardPlacement)}px`,
            transform: 'translateX(-100%)'
          };

        case 'top-start':
          return {
            top: `${Math.round(targetRect.top - offsetRect.top + offsetTopToStandardPlacement)}px`,
            left: `${Math.round(targetRect.left - offsetRect.left + offsetLeftToStandardPlacement)}px`,
            transform: 'translateY(-100%)'
          };

        case 'top-end':
          return {
            top: `${Math.round(targetRect.top - offsetRect.top + offsetTopToStandardPlacement)}px`,
            left: `${Math.round(targetRect.left - offsetRect.left + targetRect.width + offsetLeftToStandardPlacement)}px`,
            transform: 'translateX(-100%) translateY(-100%)'
          };

        case 'right-start':
          return {
            top: `${Math.round(targetRect.top - offsetRect.top + offsetTopToStandardPlacement)}px`,
            left: `${Math.round(targetRect.left - offsetRect.left + targetRect.width + offsetLeftToStandardPlacement)}px`,
            transform: ''
          };

        case 'right-end':
          return {
            top: `${Math.round(targetRect.top - offsetRect.top + targetRect.height + offsetTopToStandardPlacement)}px`,
            left: `${Math.round(targetRect.left - offsetRect.left + targetRect.width + offsetLeftToStandardPlacement)}px`,
            transform: 'translateY(-100%)'
          };

        case 'left-start':
          return {
            top: `${Math.round(targetRect.top - offsetRect.top + offsetTopToStandardPlacement)}px`,
            left: `${Math.round(targetRect.left - offsetRect.left + offsetLeftToStandardPlacement)}px`,
            transform: 'translateX(-100%)'
          };

        case 'left-end':
          return {
            top: `${Math.round(targetRect.top - offsetRect.top + targetRect.height + offsetTopToStandardPlacement)}px`,
            left: `${Math.round(targetRect.left - offsetRect.left + offsetLeftToStandardPlacement)}px`,
            transform: 'translateX(-100%) translateY(-100%)'
          };

        case 'top':
          return {
            top: `${Math.round(targetRect.top - offsetRect.top + offsetTopToStandardPlacement)}px`,
            left: `${Math.round(targetRect.left - offsetRect.left + targetRect.width / 2 + offsetLeftToStandardPlacement)}px`,
            transform: 'translateY(-100%) translateX(-50%)'
          };

        case 'right':
          return {
            top: `${Math.round(targetRect.top - offsetRect.top + targetRect.height / 2 + offsetTopToStandardPlacement)}px`,
            left: `${Math.round(targetRect.left - offsetRect.left + targetRect.width + offsetLeftToStandardPlacement)}px`,
            transform: 'translateY(-50%)'
          };

        case 'left':
          return {
            top: `${Math.round(targetRect.top - offsetRect.top + targetRect.height / 2 + offsetTopToStandardPlacement)}px`,
            left: `${Math.round(targetRect.left - offsetRect.left + offsetLeftToStandardPlacement)}px`,
            transform: 'translateY(-50%) translateX(-100%)'
          };

        case 'bottom':
        default:
          return {
            top: `${Math.round(targetRect.top - offsetRect.top + targetRect.height + offsetTopToStandardPlacement)}px`,
            left: `${Math.round(targetRect.left - offsetRect.left + targetRect.width / 2 + offsetLeftToStandardPlacement)}px`,
            transform: 'translateX(-50%)'
          };
      }
    }

    /* eslint-disable @typescript-eslint/no-non-null-assertion */
    const style$1B = c([c('.v-binder-follower-container', {
      position: 'absolute',
      left: '0',
      right: '0',
      top: '0',
      height: '0',
      pointerEvents: 'none',
      zIndex: 'auto'
    }), c('.v-binder-follower-content', {
      position: 'absolute',
      zIndex: 'auto'
    }, [c('> *', {
      pointerEvents: 'all'
    })])]);
    var VFollower = vue.defineComponent({
      name: 'Follower',
      inheritAttrs: false,
      props: {
        show: Boolean,
        enabled: {
          type: Boolean,
          default: undefined
        },
        placement: {
          type: String,
          default: 'bottom'
        },
        syncTrigger: {
          type: Array,
          default: ['resize', 'scroll']
        },
        to: [String, Object],
        flip: {
          type: Boolean,
          default: true
        },
        internalShift: Boolean,
        x: Number,
        y: Number,
        width: String,
        minWidth: String,
        containerClass: String,
        teleportDisabled: Boolean,
        zindexable: {
          type: Boolean,
          default: true
        },
        zIndex: Number,
        overlap: Boolean
      },

      setup(props) {
        const VBinder = vue.inject('VBinder');
        const mergedEnabledRef = useMemo(() => {
          return props.enabled !== undefined ? props.enabled : props.show;
        });
        const followerRef = vue.ref(null);
        const offsetContainerRef = vue.ref(null);

        const ensureListeners = () => {
          const {
            syncTrigger
          } = props;

          if (syncTrigger.includes('scroll')) {
            VBinder.addScrollListener(syncPosition);
          }

          if (syncTrigger.includes('resize')) {
            VBinder.addResizeListener(syncPosition);
          }
        };

        const removeListeners = () => {
          VBinder.removeScrollListener(syncPosition);
          VBinder.removeResizeListener(syncPosition);
        };

        vue.onMounted(() => {
          if (mergedEnabledRef.value) {
            syncPosition();
            ensureListeners();
          }
        });
        const ssrAdapter = useSsrAdapter();
        style$1B.mount({
          id: 'vueuc/binder',
          head: true,
          anchorMetaName: cssrAnchorMetaName$1,
          ssr: ssrAdapter
        });
        vue.onBeforeUnmount(() => {
          removeListeners();
        });
        onFontsReady(() => {
          if (mergedEnabledRef.value) {
            syncPosition();
          }
        });

        const syncPosition = () => {
          if (!mergedEnabledRef.value) {
            return;
          }

          const follower = followerRef.value; // sometimes watched props change before its dom is ready
          // for example: show=false, x=undefined, y=undefined
          //              show=true,  x=0,         y=0
          // will cause error
          // I may optimize the watch start point later

          if (follower === null) return;
          const target = VBinder.targetRef;
          const {
            x,
            y,
            overlap
          } = props;
          const targetRect = x !== undefined && y !== undefined ? getPointRect(x, y) : getRect$1(target);
          follower.style.setProperty('--v-target-width', `${Math.round(targetRect.width)}px`);
          follower.style.setProperty('--v-target-height', `${Math.round(targetRect.height)}px`);
          const {
            width,
            minWidth,
            placement,
            internalShift,
            flip
          } = props;
          follower.setAttribute('v-placement', placement);

          if (overlap) {
            follower.setAttribute('v-overlap', '');
          } else {
            follower.removeAttribute('v-overlap');
          }

          const {
            style
          } = follower;

          if (width === 'target') {
            style.width = `${targetRect.width}px`;
          } else if (width !== undefined) {
            style.width = width;
          } else {
            style.width = '';
          }

          if (minWidth === 'target') {
            style.minWidth = `${targetRect.width}px`;
          } else if (minWidth !== undefined) {
            style.minWidth = minWidth;
          } else {
            style.minWidth = '';
          }

          const followerRect = getRect$1(follower);
          const offsetContainerRect = getRect$1(offsetContainerRef.value);
          const {
            left: offsetLeftToStandardPlacement,
            top: offsetTopToStandardPlacement,
            placement: properPlacement
          } = getPlacementAndOffsetOfFollower(placement, targetRect, followerRect, internalShift, flip, overlap);
          const properTransformOrigin = getProperTransformOrigin(properPlacement, overlap);
          const {
            left,
            top,
            transform
          } = getOffset$1(properPlacement, offsetContainerRect, targetRect, offsetTopToStandardPlacement, offsetLeftToStandardPlacement, overlap); // we assume that the content size doesn't change after flip,
          // nor we need to make sync logic more complex

          follower.setAttribute('v-placement', properPlacement);
          follower.style.setProperty('--v-offset-left', `${Math.round(offsetLeftToStandardPlacement)}px`);
          follower.style.setProperty('--v-offset-top', `${Math.round(offsetTopToStandardPlacement)}px`);
          follower.style.transform = `translateX(${left}) translateY(${top}) ${transform}`;
          follower.style.setProperty('--v-transform-origin', properTransformOrigin);
          follower.style.transformOrigin = properTransformOrigin;
        };

        vue.watch(mergedEnabledRef, value => {
          if (value) {
            ensureListeners();
            syncOnNextTick();
          } else {
            removeListeners();
          }
        });

        const syncOnNextTick = () => {
          vue.nextTick().then(syncPosition).catch(e => console.error(e));
        };

        ['placement', 'x', 'y', 'internalShift', 'flip', 'width', 'overlap', 'minWidth'].forEach(prop => {
          vue.watch(vue.toRef(props, prop), syncPosition);
        });
        ['teleportDisabled'].forEach(prop => {
          vue.watch(vue.toRef(props, prop), syncOnNextTick);
        });
        vue.watch(vue.toRef(props, 'syncTrigger'), value => {
          if (!value.includes('resize')) {
            VBinder.removeResizeListener(syncPosition);
          } else {
            VBinder.addResizeListener(syncPosition);
          }

          if (!value.includes('scroll')) {
            VBinder.removeScrollListener(syncPosition);
          } else {
            VBinder.addScrollListener(syncPosition);
          }
        });
        const isMountedRef = isMounted();
        const mergedToRef = useMemo(() => {
          const {
            to
          } = props;
          if (to !== undefined) return to;

          if (isMountedRef.value) {
            // TODO: find proper container
            return undefined;
          }

          return undefined;
        });
        return {
          VBinder,
          mergedEnabled: mergedEnabledRef,
          offsetContainerRef,
          followerRef,
          mergedTo: mergedToRef,
          syncPosition
        };
      },

      render() {
        return vue.h(LazyTeleport, {
          show: this.show,
          to: this.mergedTo,
          disabled: this.teleportDisabled
        }, {
          default: () => {
            var _a, _b;

            const vNode = vue.h('div', {
              class: ['v-binder-follower-container', this.containerClass],
              ref: 'offsetContainerRef'
            }, [vue.h('div', {
              class: 'v-binder-follower-content',
              ref: 'followerRef'
            }, (_b = (_a = this.$slots).default) === null || _b === void 0 ? void 0 : _b.call(_a))]);

            if (this.zindexable) {
              return vue.withDirectives(vNode, [[zindexable$1, {
                enabled: this.mergedEnabled,
                zIndex: this.zIndex
              }]]);
            }

            return vNode;
          }
        });
      }

    });

    var resizeObservers = [];

    var hasActiveObservations = function () {
      return resizeObservers.some(function (ro) {
        return ro.activeTargets.length > 0;
      });
    };

    var hasSkippedObservations = function () {
      return resizeObservers.some(function (ro) {
        return ro.skippedTargets.length > 0;
      });
    };

    var msg = 'ResizeObserver loop completed with undelivered notifications.';

    var deliverResizeLoopError = function () {
      var event;

      if (typeof ErrorEvent === 'function') {
        event = new ErrorEvent('error', {
          message: msg
        });
      } else {
        event = document.createEvent('Event');
        event.initEvent('error', false, false);
        event.message = msg;
      }

      window.dispatchEvent(event);
    };

    var ResizeObserverBoxOptions;

    (function (ResizeObserverBoxOptions) {
      ResizeObserverBoxOptions["BORDER_BOX"] = "border-box";
      ResizeObserverBoxOptions["CONTENT_BOX"] = "content-box";
      ResizeObserverBoxOptions["DEVICE_PIXEL_CONTENT_BOX"] = "device-pixel-content-box";
    })(ResizeObserverBoxOptions || (ResizeObserverBoxOptions = {}));

    var freeze = function (obj) {
      return Object.freeze(obj);
    };

    var ResizeObserverSize = function () {
      function ResizeObserverSize(inlineSize, blockSize) {
        this.inlineSize = inlineSize;
        this.blockSize = blockSize;
        freeze(this);
      }

      return ResizeObserverSize;
    }();

    var DOMRectReadOnly = function () {
      function DOMRectReadOnly(x, y, width, height) {
        this.x = x;
        this.y = y;
        this.width = width;
        this.height = height;
        this.top = this.y;
        this.left = this.x;
        this.bottom = this.top + this.height;
        this.right = this.left + this.width;
        return freeze(this);
      }

      DOMRectReadOnly.prototype.toJSON = function () {
        var _a = this,
            x = _a.x,
            y = _a.y,
            top = _a.top,
            right = _a.right,
            bottom = _a.bottom,
            left = _a.left,
            width = _a.width,
            height = _a.height;

        return {
          x: x,
          y: y,
          top: top,
          right: right,
          bottom: bottom,
          left: left,
          width: width,
          height: height
        };
      };

      DOMRectReadOnly.fromRect = function (rectangle) {
        return new DOMRectReadOnly(rectangle.x, rectangle.y, rectangle.width, rectangle.height);
      };

      return DOMRectReadOnly;
    }();

    var isSVG = function (target) {
      return target instanceof SVGElement && 'getBBox' in target;
    };

    var isHidden = function (target) {
      if (isSVG(target)) {
        var _a = target.getBBox(),
            width = _a.width,
            height = _a.height;

        return !width && !height;
      }

      var _b = target,
          offsetWidth = _b.offsetWidth,
          offsetHeight = _b.offsetHeight;
      return !(offsetWidth || offsetHeight || target.getClientRects().length);
    };

    var isElement = function (obj) {
      var _a;

      if (obj instanceof Element) {
        return true;
      }

      var scope = (_a = obj === null || obj === void 0 ? void 0 : obj.ownerDocument) === null || _a === void 0 ? void 0 : _a.defaultView;
      return !!(scope && obj instanceof scope.Element);
    };

    var isReplacedElement = function (target) {
      switch (target.tagName) {
        case 'INPUT':
          if (target.type !== 'image') {
            break;
          }

        case 'VIDEO':
        case 'AUDIO':
        case 'EMBED':
        case 'OBJECT':
        case 'CANVAS':
        case 'IFRAME':
        case 'IMG':
          return true;
      }

      return false;
    };

    var global$1 = typeof window !== 'undefined' ? window : {};

    var cache = new WeakMap();
    var scrollRegexp = /auto|scroll/;
    var verticalRegexp = /^tb|vertical/;
    var IE = /msie|trident/i.test(global$1.navigator && global$1.navigator.userAgent);

    var parseDimension = function (pixel) {
      return parseFloat(pixel || '0');
    };

    var size = function (inlineSize, blockSize, switchSizes) {
      if (inlineSize === void 0) {
        inlineSize = 0;
      }

      if (blockSize === void 0) {
        blockSize = 0;
      }

      if (switchSizes === void 0) {
        switchSizes = false;
      }

      return new ResizeObserverSize((switchSizes ? blockSize : inlineSize) || 0, (switchSizes ? inlineSize : blockSize) || 0);
    };

    var zeroBoxes = freeze({
      devicePixelContentBoxSize: size(),
      borderBoxSize: size(),
      contentBoxSize: size(),
      contentRect: new DOMRectReadOnly(0, 0, 0, 0)
    });

    var calculateBoxSizes = function (target, forceRecalculation) {
      if (forceRecalculation === void 0) {
        forceRecalculation = false;
      }

      if (cache.has(target) && !forceRecalculation) {
        return cache.get(target);
      }

      if (isHidden(target)) {
        cache.set(target, zeroBoxes);
        return zeroBoxes;
      }

      var cs = getComputedStyle(target);
      var svg = isSVG(target) && target.ownerSVGElement && target.getBBox();
      var removePadding = !IE && cs.boxSizing === 'border-box';
      var switchSizes = verticalRegexp.test(cs.writingMode || '');
      var canScrollVertically = !svg && scrollRegexp.test(cs.overflowY || '');
      var canScrollHorizontally = !svg && scrollRegexp.test(cs.overflowX || '');
      var paddingTop = svg ? 0 : parseDimension(cs.paddingTop);
      var paddingRight = svg ? 0 : parseDimension(cs.paddingRight);
      var paddingBottom = svg ? 0 : parseDimension(cs.paddingBottom);
      var paddingLeft = svg ? 0 : parseDimension(cs.paddingLeft);
      var borderTop = svg ? 0 : parseDimension(cs.borderTopWidth);
      var borderRight = svg ? 0 : parseDimension(cs.borderRightWidth);
      var borderBottom = svg ? 0 : parseDimension(cs.borderBottomWidth);
      var borderLeft = svg ? 0 : parseDimension(cs.borderLeftWidth);
      var horizontalPadding = paddingLeft + paddingRight;
      var verticalPadding = paddingTop + paddingBottom;
      var horizontalBorderArea = borderLeft + borderRight;
      var verticalBorderArea = borderTop + borderBottom;
      var horizontalScrollbarThickness = !canScrollHorizontally ? 0 : target.offsetHeight - verticalBorderArea - target.clientHeight;
      var verticalScrollbarThickness = !canScrollVertically ? 0 : target.offsetWidth - horizontalBorderArea - target.clientWidth;
      var widthReduction = removePadding ? horizontalPadding + horizontalBorderArea : 0;
      var heightReduction = removePadding ? verticalPadding + verticalBorderArea : 0;
      var contentWidth = svg ? svg.width : parseDimension(cs.width) - widthReduction - verticalScrollbarThickness;
      var contentHeight = svg ? svg.height : parseDimension(cs.height) - heightReduction - horizontalScrollbarThickness;
      var borderBoxWidth = contentWidth + horizontalPadding + verticalScrollbarThickness + horizontalBorderArea;
      var borderBoxHeight = contentHeight + verticalPadding + horizontalScrollbarThickness + verticalBorderArea;
      var boxes = freeze({
        devicePixelContentBoxSize: size(Math.round(contentWidth * devicePixelRatio), Math.round(contentHeight * devicePixelRatio), switchSizes),
        borderBoxSize: size(borderBoxWidth, borderBoxHeight, switchSizes),
        contentBoxSize: size(contentWidth, contentHeight, switchSizes),
        contentRect: new DOMRectReadOnly(paddingLeft, paddingTop, contentWidth, contentHeight)
      });
      cache.set(target, boxes);
      return boxes;
    };

    var calculateBoxSize = function (target, observedBox, forceRecalculation) {
      var _a = calculateBoxSizes(target, forceRecalculation),
          borderBoxSize = _a.borderBoxSize,
          contentBoxSize = _a.contentBoxSize,
          devicePixelContentBoxSize = _a.devicePixelContentBoxSize;

      switch (observedBox) {
        case ResizeObserverBoxOptions.DEVICE_PIXEL_CONTENT_BOX:
          return devicePixelContentBoxSize;

        case ResizeObserverBoxOptions.BORDER_BOX:
          return borderBoxSize;

        default:
          return contentBoxSize;
      }
    };

    var ResizeObserverEntry = function () {
      function ResizeObserverEntry(target) {
        var boxes = calculateBoxSizes(target);
        this.target = target;
        this.contentRect = boxes.contentRect;
        this.borderBoxSize = freeze([boxes.borderBoxSize]);
        this.contentBoxSize = freeze([boxes.contentBoxSize]);
        this.devicePixelContentBoxSize = freeze([boxes.devicePixelContentBoxSize]);
      }

      return ResizeObserverEntry;
    }();

    var calculateDepthForNode = function (node) {
      if (isHidden(node)) {
        return Infinity;
      }

      var depth = 0;
      var parent = node.parentNode;

      while (parent) {
        depth += 1;
        parent = parent.parentNode;
      }

      return depth;
    };

    var broadcastActiveObservations = function () {
      var shallowestDepth = Infinity;
      var callbacks = [];
      resizeObservers.forEach(function processObserver(ro) {
        if (ro.activeTargets.length === 0) {
          return;
        }

        var entries = [];
        ro.activeTargets.forEach(function processTarget(ot) {
          var entry = new ResizeObserverEntry(ot.target);
          var targetDepth = calculateDepthForNode(ot.target);
          entries.push(entry);
          ot.lastReportedSize = calculateBoxSize(ot.target, ot.observedBox);

          if (targetDepth < shallowestDepth) {
            shallowestDepth = targetDepth;
          }
        });
        callbacks.push(function resizeObserverCallback() {
          ro.callback.call(ro.observer, entries, ro.observer);
        });
        ro.activeTargets.splice(0, ro.activeTargets.length);
      });

      for (var _i = 0, callbacks_1 = callbacks; _i < callbacks_1.length; _i++) {
        var callback = callbacks_1[_i];
        callback();
      }

      return shallowestDepth;
    };

    var gatherActiveObservationsAtDepth = function (depth) {
      resizeObservers.forEach(function processObserver(ro) {
        ro.activeTargets.splice(0, ro.activeTargets.length);
        ro.skippedTargets.splice(0, ro.skippedTargets.length);
        ro.observationTargets.forEach(function processTarget(ot) {
          if (ot.isActive()) {
            if (calculateDepthForNode(ot.target) > depth) {
              ro.activeTargets.push(ot);
            } else {
              ro.skippedTargets.push(ot);
            }
          }
        });
      });
    };

    var process$1 = function () {
      var depth = 0;
      gatherActiveObservationsAtDepth(depth);

      while (hasActiveObservations()) {
        depth = broadcastActiveObservations();
        gatherActiveObservationsAtDepth(depth);
      }

      if (hasSkippedObservations()) {
        deliverResizeLoopError();
      }

      return depth > 0;
    };

    var trigger;
    var callbacks = [];

    var notify = function () {
      return callbacks.splice(0).forEach(function (cb) {
        return cb();
      });
    };

    var queueMicroTask = function (callback) {
      if (!trigger) {
        var toggle_1 = 0;
        var el_1 = document.createTextNode('');
        var config = {
          characterData: true
        };
        new MutationObserver(function () {
          return notify();
        }).observe(el_1, config);

        trigger = function () {
          el_1.textContent = "".concat(toggle_1 ? toggle_1-- : toggle_1++);
        };
      }

      callbacks.push(callback);
      trigger();
    };

    var queueResizeObserver = function (cb) {
      queueMicroTask(function ResizeObserver() {
        requestAnimationFrame(cb);
      });
    };

    var watching = 0;

    var isWatching = function () {
      return !!watching;
    };

    var CATCH_PERIOD = 250;
    var observerConfig = {
      attributes: true,
      characterData: true,
      childList: true,
      subtree: true
    };
    var events = ['resize', 'load', 'transitionend', 'animationend', 'animationstart', 'animationiteration', 'keyup', 'keydown', 'mouseup', 'mousedown', 'mouseover', 'mouseout', 'blur', 'focus'];

    var time$1 = function (timeout) {
      if (timeout === void 0) {
        timeout = 0;
      }

      return Date.now() + timeout;
    };

    var scheduled = false;

    var Scheduler = function () {
      function Scheduler() {
        var _this = this;

        this.stopped = true;

        this.listener = function () {
          return _this.schedule();
        };
      }

      Scheduler.prototype.run = function (timeout) {
        var _this = this;

        if (timeout === void 0) {
          timeout = CATCH_PERIOD;
        }

        if (scheduled) {
          return;
        }

        scheduled = true;
        var until = time$1(timeout);
        queueResizeObserver(function () {
          var elementsHaveResized = false;

          try {
            elementsHaveResized = process$1();
          } finally {
            scheduled = false;
            timeout = until - time$1();

            if (!isWatching()) {
              return;
            }

            if (elementsHaveResized) {
              _this.run(1000);
            } else if (timeout > 0) {
              _this.run(timeout);
            } else {
              _this.start();
            }
          }
        });
      };

      Scheduler.prototype.schedule = function () {
        this.stop();
        this.run();
      };

      Scheduler.prototype.observe = function () {
        var _this = this;

        var cb = function () {
          return _this.observer && _this.observer.observe(document.body, observerConfig);
        };

        document.body ? cb() : global$1.addEventListener('DOMContentLoaded', cb);
      };

      Scheduler.prototype.start = function () {
        var _this = this;

        if (this.stopped) {
          this.stopped = false;
          this.observer = new MutationObserver(this.listener);
          this.observe();
          events.forEach(function (name) {
            return global$1.addEventListener(name, _this.listener, true);
          });
        }
      };

      Scheduler.prototype.stop = function () {
        var _this = this;

        if (!this.stopped) {
          this.observer && this.observer.disconnect();
          events.forEach(function (name) {
            return global$1.removeEventListener(name, _this.listener, true);
          });
          this.stopped = true;
        }
      };

      return Scheduler;
    }();

    var scheduler = new Scheduler();

    var updateCount = function (n) {
      !watching && n > 0 && scheduler.start();
      watching += n;
      !watching && scheduler.stop();
    };

    var skipNotifyOnElement = function (target) {
      return !isSVG(target) && !isReplacedElement(target) && getComputedStyle(target).display === 'inline';
    };

    var ResizeObservation = function () {
      function ResizeObservation(target, observedBox) {
        this.target = target;
        this.observedBox = observedBox || ResizeObserverBoxOptions.CONTENT_BOX;
        this.lastReportedSize = {
          inlineSize: 0,
          blockSize: 0
        };
      }

      ResizeObservation.prototype.isActive = function () {
        var size = calculateBoxSize(this.target, this.observedBox, true);

        if (skipNotifyOnElement(this.target)) {
          this.lastReportedSize = size;
        }

        if (this.lastReportedSize.inlineSize !== size.inlineSize || this.lastReportedSize.blockSize !== size.blockSize) {
          return true;
        }

        return false;
      };

      return ResizeObservation;
    }();

    var ResizeObserverDetail = function () {
      function ResizeObserverDetail(resizeObserver, callback) {
        this.activeTargets = [];
        this.skippedTargets = [];
        this.observationTargets = [];
        this.observer = resizeObserver;
        this.callback = callback;
      }

      return ResizeObserverDetail;
    }();

    var observerMap = new WeakMap();

    var getObservationIndex = function (observationTargets, target) {
      for (var i = 0; i < observationTargets.length; i += 1) {
        if (observationTargets[i].target === target) {
          return i;
        }
      }

      return -1;
    };

    var ResizeObserverController = function () {
      function ResizeObserverController() {}

      ResizeObserverController.connect = function (resizeObserver, callback) {
        var detail = new ResizeObserverDetail(resizeObserver, callback);
        observerMap.set(resizeObserver, detail);
      };

      ResizeObserverController.observe = function (resizeObserver, target, options) {
        var detail = observerMap.get(resizeObserver);
        var firstObservation = detail.observationTargets.length === 0;

        if (getObservationIndex(detail.observationTargets, target) < 0) {
          firstObservation && resizeObservers.push(detail);
          detail.observationTargets.push(new ResizeObservation(target, options && options.box));
          updateCount(1);
          scheduler.schedule();
        }
      };

      ResizeObserverController.unobserve = function (resizeObserver, target) {
        var detail = observerMap.get(resizeObserver);
        var index = getObservationIndex(detail.observationTargets, target);
        var lastObservation = detail.observationTargets.length === 1;

        if (index >= 0) {
          lastObservation && resizeObservers.splice(resizeObservers.indexOf(detail), 1);
          detail.observationTargets.splice(index, 1);
          updateCount(-1);
        }
      };

      ResizeObserverController.disconnect = function (resizeObserver) {
        var _this = this;

        var detail = observerMap.get(resizeObserver);
        detail.observationTargets.slice().forEach(function (ot) {
          return _this.unobserve(resizeObserver, ot.target);
        });
        detail.activeTargets.splice(0, detail.activeTargets.length);
      };

      return ResizeObserverController;
    }();

    var ResizeObserver = function () {
      function ResizeObserver(callback) {
        if (arguments.length === 0) {
          throw new TypeError("Failed to construct 'ResizeObserver': 1 argument required, but only 0 present.");
        }

        if (typeof callback !== 'function') {
          throw new TypeError("Failed to construct 'ResizeObserver': The callback provided as parameter 1 is not a function.");
        }

        ResizeObserverController.connect(this, callback);
      }

      ResizeObserver.prototype.observe = function (target, options) {
        if (arguments.length === 0) {
          throw new TypeError("Failed to execute 'observe' on 'ResizeObserver': 1 argument required, but only 0 present.");
        }

        if (!isElement(target)) {
          throw new TypeError("Failed to execute 'observe' on 'ResizeObserver': parameter 1 is not of type 'Element");
        }

        ResizeObserverController.observe(this, target, options);
      };

      ResizeObserver.prototype.unobserve = function (target) {
        if (arguments.length === 0) {
          throw new TypeError("Failed to execute 'unobserve' on 'ResizeObserver': 1 argument required, but only 0 present.");
        }

        if (!isElement(target)) {
          throw new TypeError("Failed to execute 'unobserve' on 'ResizeObserver': parameter 1 is not of type 'Element");
        }

        ResizeObserverController.unobserve(this, target);
      };

      ResizeObserver.prototype.disconnect = function () {
        ResizeObserverController.disconnect(this);
      };

      ResizeObserver.toString = function () {
        return 'function ResizeObserver () { [polyfill code] }';
      };

      return ResizeObserver;
    }();

    class ResizeObserverDelegate {
      constructor() {
        this.handleResize = this.handleResize.bind(this);
        this.observer = new ResizeObserver(this.handleResize);
        this.elHandlersMap = new Map();
      }

      handleResize(entries) {
        for (const entry of entries) {
          const handler = this.elHandlersMap.get(entry.target);

          if (handler !== undefined) {
            handler(entry);
          }
        }
      }

      registerHandler(el, handler) {
        this.elHandlersMap.set(el, handler);
        this.observer.observe(el);
      }

      unregisterHandler(el) {
        if (!this.elHandlersMap.has(el)) {
          return;
        }

        this.elHandlersMap.delete(el);
        this.observer.unobserve(el);
      }

    }

    var resizeObserverManager = new ResizeObserverDelegate();

    var VResizeObserver = vue.defineComponent({
      name: 'ResizeObserver',
      props: {
        onResize: Function
      },

      setup(props) {
        let registered = false; // eslint-disable-next-line @typescript-eslint/no-non-null-assertion

        const proxy = vue.getCurrentInstance().proxy;

        function handleResize(entry) {
          const {
            onResize
          } = props;
          if (onResize !== undefined) onResize(entry);
        }

        vue.onMounted(() => {
          const el = proxy.$el;

          if (el === undefined) {
            warn('resize-observer', '$el does not exist.');
            return;
          }

          if (el.nextElementSibling !== el.nextSibling) {
            if (el.nodeType === 3 && el.nodeValue !== '') {
              warn('resize-observer', '$el can not be observed (it may be a text node).');
              return;
            }
          }

          if (el.nextElementSibling !== null) {
            resizeObserverManager.registerHandler(el.nextElementSibling, handleResize);
            registered = true;
          }
        });
        vue.onBeforeUnmount(() => {
          if (registered) {
            resizeObserverManager.unregisterHandler(proxy.$el.nextElementSibling);
          }
        });
      },

      render() {
        return vue.renderSlot(this.$slots, 'default');
      }

    });

    let maybeTouch;
    function ensureMaybeTouch() {
      if (maybeTouch === undefined) {
        if ('matchMedia' in window) {
          maybeTouch = window.matchMedia('(pointer:coarse)').matches;
        } else {
          maybeTouch = false;
        }
      }

      return maybeTouch;
    }
    let wheelScale;
    function ensureWheelScale() {
      if (wheelScale === undefined) {
        wheelScale = 'chrome' in window ? window.devicePixelRatio : 1;
      }

      return wheelScale;
    }

    /* eslint-disable no-void */
    const styles$1 = c('.v-vl', {
      maxHeight: 'inherit',
      height: '100%',
      overflow: 'auto',
      minWidth: '1px' // a zero width container won't be scrollable

    }, [c('&:not(.v-vl--show-scrollbar)', {
      scrollbarWidth: 'none'
    }, [c('&::-webkit-scrollbar, &::-webkit-scrollbar-track-piece, &::-webkit-scrollbar-thumb', {
      width: 0,
      height: 0,
      display: 'none'
    })])]);
    var VVirtualList = vue.defineComponent({
      name: 'VirtualList',
      inheritAttrs: false,
      props: {
        showScrollbar: {
          type: Boolean,
          default: true
        },
        items: {
          type: Array,
          default: () => []
        },
        // it is suppose to be the min height
        itemSize: {
          type: Number,
          required: true
        },
        itemResizable: Boolean,
        itemsStyle: [String, Object],
        visibleItemsTag: {
          type: [String, Object],
          default: 'div'
        },
        visibleItemsProps: Object,
        ignoreItemResize: Boolean,
        onScroll: Function,
        onWheel: Function,
        onResize: Function,
        defaultScrollKey: [Number, String],
        defaultScrollIndex: Number,
        keyField: {
          type: String,
          default: 'key'
        },
        // Whether it is a good API?
        // ResizeObserver + footer & header is not enough.
        // Too complex for simple case
        paddingTop: {
          type: [Number, String],
          default: 0
        },
        paddingBottom: {
          type: [Number, String],
          default: 0
        }
      },

      setup(props) {
        const ssrAdapter = useSsrAdapter();
        styles$1.mount({
          id: 'vueuc/virtual-list',
          head: true,
          anchorMetaName: cssrAnchorMetaName$1,
          ssr: ssrAdapter
        });
        vue.onMounted(() => {
          const {
            defaultScrollIndex,
            defaultScrollKey
          } = props;

          if (defaultScrollIndex !== undefined && defaultScrollIndex !== null) {
            scrollTo({
              index: defaultScrollIndex
            });
          } else if (defaultScrollKey !== undefined && defaultScrollKey !== null) {
            scrollTo({
              key: defaultScrollKey
            });
          }
        });
        let isDeactivated = false;
        let activateStateInitialized = false;
        vue.onActivated(() => {
          isDeactivated = false;

          if (!activateStateInitialized) {
            activateStateInitialized = true;
            return;
          } // remount


          scrollTo({
            top: scrollTopRef.value,
            left: scrollLeft
          });
        });
        vue.onDeactivated(() => {
          isDeactivated = true;

          if (!activateStateInitialized) {
            activateStateInitialized = true;
          }
        });
        const keyIndexMapRef = vue.computed(() => {
          const map = new Map();
          const {
            keyField
          } = props;
          props.items.forEach((item, index) => {
            map.set(item[keyField], index);
          });
          return map;
        });
        const listElRef = vue.ref(null);
        const listHeightRef = vue.ref(undefined);
        const keyToHeightOffset = new Map();
        const finweckTreeRef = vue.computed(() => {
          const {
            items,
            itemSize,
            keyField
          } = props;
          const ft = new FinweckTree(items.length, itemSize);
          items.forEach((item, index) => {
            const key = item[keyField];
            const heightOffset = keyToHeightOffset.get(key);

            if (heightOffset !== undefined) {
              ft.add(index, heightOffset);
            }
          });
          return ft;
        });
        const finweckTreeUpdateTrigger = vue.ref(0);
        let scrollLeft = 0;
        const scrollTopRef = vue.ref(0);
        const startIndexRef = useMemo(() => {
          return Math.max(finweckTreeRef.value.getBound(scrollTopRef.value - depx(props.paddingTop)) - 1, 0);
        });
        const viewportItemsRef = vue.computed(() => {
          const {
            value: listHeight
          } = listHeightRef;
          if (listHeight === undefined) return [];
          const {
            items,
            itemSize
          } = props;
          const startIndex = startIndexRef.value;
          const endIndex = Math.min(startIndex + Math.ceil(listHeight / itemSize + 1), items.length - 1);
          const viewportItems = [];

          for (let i = startIndex; i <= endIndex; ++i) {
            viewportItems.push(items[i]);
          }

          return viewportItems;
        });

        const scrollTo = (options, y) => {
          if (typeof options === 'number') {
            scrollToPosition(options, y, 'auto');
            return;
          }

          const {
            left,
            top,
            index,
            key,
            position,
            behavior,
            debounce = true
          } = options;

          if (left !== undefined || top !== undefined) {
            scrollToPosition(left, top, behavior);
          } else if (index !== undefined) {
            scrollToIndex(index, behavior, debounce);
          } else if (key !== undefined) {
            const toIndex = keyIndexMapRef.value.get(key);
            if (toIndex !== undefined) scrollToIndex(toIndex, behavior, debounce);
          } else if (position === 'bottom') {
            scrollToPosition(0, Number.MAX_SAFE_INTEGER, behavior);
          } else if (position === 'top') {
            scrollToPosition(0, 0, behavior);
          }
        };

        let anchorIndex;
        let anchorTimerId = null;

        function scrollToIndex(index, behavior, debounce) {
          const {
            value: ft
          } = finweckTreeRef;
          const targetTop = ft.sum(index) + depx(props.paddingTop);

          if (!debounce) {
            listElRef.value.scrollTo({
              left: 0,
              top: targetTop,
              behavior
            });
          } else {
            anchorIndex = index;

            if (anchorTimerId !== null) {
              window.clearTimeout(anchorTimerId);
            }

            anchorTimerId = window.setTimeout(() => {
              anchorIndex = undefined;
              anchorTimerId = null;
            }, 16); // use 0 ms may be ealier than resize callback...

            const {
              scrollTop,
              offsetHeight
            } = listElRef.value;

            if (targetTop > scrollTop) {
              const itemSize = ft.get(index);

              if (targetTop + itemSize <= scrollTop + offsetHeight) ; else {
                listElRef.value.scrollTo({
                  left: 0,
                  top: targetTop + itemSize - offsetHeight,
                  behavior
                });
              }
            } else {
              listElRef.value.scrollTo({
                left: 0,
                top: targetTop,
                behavior
              });
            }
          }
        }

        function scrollToPosition(left, top, behavior) {
          listElRef.value.scrollTo({
            left,
            top,
            behavior
          });
        }

        function handleItemResize(key, entry) {
          var _a, _b, _c;

          if (isDeactivated) return;
          if (props.ignoreItemResize) return;
          if (isHideByVShow(entry.target)) return;
          const {
            value: ft
          } = finweckTreeRef;
          const index = keyIndexMapRef.value.get(key);
          const previousHeight = ft.get(index);
          const height = (_c = (_b = (_a = entry.borderBoxSize) === null || _a === void 0 ? void 0 : _a[0]) === null || _b === void 0 ? void 0 : _b.blockSize) !== null && _c !== void 0 ? _c : entry.contentRect.height;
          if (height === previousHeight) return; // height offset based on itemSize
          // used when rebuild the finweck tree

          const offset = height - props.itemSize;

          if (offset === 0) {
            keyToHeightOffset.delete(key);
          } else {
            keyToHeightOffset.set(key, height - props.itemSize);
          } // delta height based on finweck tree data


          const delta = height - previousHeight;
          if (delta === 0) return;
          ft.add(index, delta);
          const listEl = listElRef.value;

          if (listEl != null) {
            if (anchorIndex === undefined) {
              const previousHeightSum = ft.sum(index);

              if (listEl.scrollTop > previousHeightSum) {
                listEl.scrollBy(0, delta);
              }
            } else {
              if (index < anchorIndex) {
                listEl.scrollBy(0, delta);
              } else if (index === anchorIndex) {
                const previousHeightSum = ft.sum(index);

                if (height + previousHeightSum > // Note, listEl shouldn't have border, nor offsetHeight won't be
                // correct
                listEl.scrollTop + listEl.offsetHeight) {
                  listEl.scrollBy(0, delta);
                }
              }
            }

            syncViewport();
          }

          finweckTreeUpdateTrigger.value++;
        }

        const mayUseWheel = !ensureMaybeTouch();
        let wheelCatched = false;

        function handleListScroll(e) {
          var _a;

          (_a = props.onScroll) === null || _a === void 0 ? void 0 : _a.call(props, e);

          if (!mayUseWheel || !wheelCatched) {
            syncViewport();
          }
        }

        function handleListWheel(e) {
          var _a;

          (_a = props.onWheel) === null || _a === void 0 ? void 0 : _a.call(props, e);

          if (mayUseWheel) {
            const listEl = listElRef.value;

            if (listEl != null) {
              if (e.deltaX === 0) {
                if (listEl.scrollTop === 0 && e.deltaY <= 0) {
                  return;
                }

                if (listEl.scrollTop + listEl.offsetHeight >= listEl.scrollHeight && e.deltaY >= 0) {
                  return;
                }
              }

              e.preventDefault();
              listEl.scrollTop += e.deltaY / ensureWheelScale();
              listEl.scrollLeft += e.deltaX / ensureWheelScale();
              syncViewport();
              wheelCatched = true;
              beforeNextFrameOnce(() => {
                wheelCatched = false;
              });
            }
          }
        }

        function handleListResize(entry) {
          if (isDeactivated) return; // List is HTMLElement

          if (isHideByVShow(entry.target)) return; // If height is same, return

          if (entry.contentRect.height === listHeightRef.value) return;
          listHeightRef.value = entry.contentRect.height;
          const {
            onResize
          } = props;
          if (onResize !== undefined) onResize(entry);
        }

        function syncViewport() {
          const {
            value: listEl
          } = listElRef; // sometime ref el can be null
          // https://github.com/TuSimple/naive-ui/issues/811

          if (listEl == null) return;
          scrollTopRef.value = listEl.scrollTop;
          scrollLeft = listEl.scrollLeft;
        }

        function isHideByVShow(el) {
          let cursor = el;

          while (cursor !== null) {
            if (cursor.style.display === 'none') return true;
            cursor = cursor.parentElement;
          }

          return false;
        }

        return {
          listHeight: listHeightRef,
          listStyle: {
            overflow: 'auto'
          },
          keyToIndex: keyIndexMapRef,
          itemsStyle: vue.computed(() => {
            const {
              itemResizable
            } = props;
            const height = pxfy(finweckTreeRef.value.sum()); // eslint-disable-next-line @typescript-eslint/no-unused-expressions

            finweckTreeUpdateTrigger.value;
            return [props.itemsStyle, {
              boxSizing: 'content-box',
              height: itemResizable ? '' : height,
              minHeight: itemResizable ? height : '',
              paddingTop: pxfy(props.paddingTop),
              paddingBottom: pxfy(props.paddingBottom)
            }];
          }),
          visibleItemsStyle: vue.computed(() => {
            // eslint-disable-next-line @typescript-eslint/no-unused-expressions
            finweckTreeUpdateTrigger.value;
            return {
              transform: `translateY(${pxfy(finweckTreeRef.value.sum(startIndexRef.value))})`
            };
          }),
          viewportItems: viewportItemsRef,
          listElRef,
          itemsElRef: vue.ref(null),
          scrollTo,
          handleListResize,
          handleListScroll,
          handleListWheel,
          handleItemResize
        };
      },

      render() {
        const {
          itemResizable,
          keyField,
          keyToIndex,
          visibleItemsTag
        } = this;
        return vue.h(VResizeObserver, {
          onResize: this.handleListResize
        }, {
          default: () => {
            var _a, _b;

            return vue.h('div', vue.mergeProps(this.$attrs, {
              class: ['v-vl', this.showScrollbar && 'v-vl--show-scrollbar'],
              onScroll: this.handleListScroll,
              onWheel: this.handleListWheel,
              ref: 'listElRef'
            }), [this.items.length !== 0 ? vue.h('div', {
              ref: 'itemsElRef',
              class: 'v-vl-items',
              style: this.itemsStyle
            }, [vue.h(visibleItemsTag, Object.assign({
              class: 'v-vl-visible-items',
              style: this.visibleItemsStyle
            }, this.visibleItemsProps), {
              default: () => this.viewportItems.map(item => {
                const key = item[keyField];
                const index = keyToIndex.get(key);
                const itemVNode = this.$slots.default({
                  item,
                  index
                })[0];

                if (itemResizable) {
                  return vue.h(VResizeObserver, {
                    key,
                    onResize: entry => this.handleItemResize(key, entry)
                  }, {
                    default: () => itemVNode
                  });
                }

                itemVNode.key = key;
                return itemVNode;
              })
            })]) : (_b = (_a = this.$slots).empty) === null || _b === void 0 ? void 0 : _b.call(_a)]);
          }
        });
      }

    });

    const styles = c('.v-x-scroll', {
      overflow: 'auto',
      scrollbarWidth: 'none'
    }, [c('&::-webkit-scrollbar', {
      width: 0,
      height: 0
    })]);
    var VXScroll = vue.defineComponent({
      name: 'XScroll',
      props: {
        disabled: Boolean,
        onScroll: Function
      },

      setup() {
        const selfRef = vue.ref(null);

        function handleWheel(e) {
          const preventYWheel = e.currentTarget.offsetWidth < e.currentTarget.scrollWidth;
          if (!preventYWheel || e.deltaY === 0) return;
          e.currentTarget.scrollLeft += e.deltaY + e.deltaX;
          e.preventDefault();
        }

        const ssrAdapter = useSsrAdapter();
        styles.mount({
          id: 'vueuc/x-scroll',
          head: true,
          anchorMetaName: cssrAnchorMetaName$1,
          ssr: ssrAdapter
        });
        const exposedMethods = {
          scrollTo() {
            var _a;

            (_a = selfRef.value) === null || _a === void 0 ? void 0 : _a.scrollTo(...arguments);
          }

        };
        return Object.assign({
          selfRef,
          handleWheel
        }, exposedMethods);
      },

      render() {
        return vue.h('div', {
          ref: 'selfRef',
          onScroll: this.onScroll,
          onWheel: this.disabled ? undefined : this.handleWheel,
          class: 'v-x-scroll'
        }, this.$slots);
      }

    });

    /* eslint-disable @typescript-eslint/strict-boolean-expressions */
    const hiddenAttr = 'v-hidden';
    const style$1A = c('[v-hidden]', {
      display: 'none!important'
    });
    var VOverflow = vue.defineComponent({
      name: 'Overflow',
      props: {
        getCounter: Function,
        getTail: Function,
        updateCounter: Function,
        onUpdateOverflow: Function
      },

      setup(props, _ref) {
        let {
          slots
        } = _ref;
        const selfRef = vue.ref(null);
        const counterRef = vue.ref(null);

        function deriveCounter() {
          const {
            value: self
          } = selfRef;
          const {
            getCounter,
            getTail
          } = props;
          let counter;
          if (getCounter !== undefined) counter = getCounter();else {
            counter = counterRef.value;
          }
          if (!self || !counter) return;

          if (counter.hasAttribute(hiddenAttr)) {
            counter.removeAttribute(hiddenAttr);
          }

          const {
            children
          } = self;
          const containerWidth = self.offsetWidth;
          const childWidths = [];
          const tail = slots.tail ? getTail === null || getTail === void 0 ? void 0 : getTail() : null;
          let childWidthSum = tail ? tail.offsetWidth : 0;
          let overflow = false;
          const len = self.children.length - (slots.tail ? 1 : 0);

          for (let i = 0; i < len - 1; ++i) {
            if (i < 0) continue;
            const child = children[i];

            if (overflow) {
              if (!child.hasAttribute(hiddenAttr)) {
                child.setAttribute(hiddenAttr, '');
              }

              continue;
            } else if (child.hasAttribute(hiddenAttr)) {
              child.removeAttribute(hiddenAttr);
            }

            const childWidth = child.offsetWidth;
            childWidthSum += childWidth;
            childWidths[i] = childWidth;

            if (childWidthSum > containerWidth) {
              const {
                updateCounter
              } = props;

              for (let j = i; j >= 0; --j) {
                const restCount = len - 1 - j;

                if (updateCounter !== undefined) {
                  updateCounter(restCount);
                } else {
                  counter.textContent = `${restCount}`;
                }

                const counterWidth = counter.offsetWidth;
                childWidthSum -= childWidths[j];

                if (childWidthSum + counterWidth <= containerWidth || j === 0) {
                  overflow = true;
                  i = j - 1;

                  if (tail) {
                    // tail too long or 1st element too long
                    // we only consider tail now
                    if (i === -1) {
                      tail.style.maxWidth = `${containerWidth - counterWidth}px`;
                      tail.style.boxSizing = 'border-box';
                    } else {
                      tail.style.maxWidth = '';
                    }
                  }

                  break;
                }
              }
            }
          }

          const {
            onUpdateOverflow
          } = props;

          if (!overflow) {
            if (onUpdateOverflow !== undefined) {
              onUpdateOverflow(false);
            }

            counter.setAttribute(hiddenAttr, '');
          } else {
            if (onUpdateOverflow !== undefined) {
              onUpdateOverflow(true);
            }
          }
        }

        const ssrAdapter = useSsrAdapter();
        style$1A.mount({
          id: 'vueuc/overflow',
          head: true,
          anchorMetaName: cssrAnchorMetaName$1,
          ssr: ssrAdapter
        });
        vue.onMounted(deriveCounter); // besides onMounted, other case should be manually triggered, or we shoud watch items

        return {
          selfRef,
          counterRef,
          sync: deriveCounter
        };
      },

      render() {
        const {
          $slots
        } = this; // eslint-disable-next-line @typescript-eslint/no-floating-promises

        vue.nextTick(this.sync); // It shouldn't have border

        return vue.h('div', {
          class: 'v-overflow',
          ref: 'selfRef'
        }, [vue.renderSlot($slots, 'default'), // $slots.counter should only has 1 element
        $slots.counter ? $slots.counter() : vue.h('span', {
          style: {
            display: 'inline-block'
          },
          ref: 'counterRef'
        }), // $slots.tail should only has 1 element
        $slots.tail ? $slots.tail() : null]);
      }

    });

    /* eslint-disable @typescript-eslint/strict-boolean-expressions */
    // ref https://www.w3.org/TR/wai-aria-practices-1.1/examples/dialog-modal/js/dialog.js
    function isHTMLElement(node) {
      return node instanceof HTMLElement;
    }

    function focusFirstDescendant(node) {
      for (let i = 0; i < node.childNodes.length; i++) {
        const child = node.childNodes[i];

        if (isHTMLElement(child)) {
          if (attemptFocus(child) || focusFirstDescendant(child)) {
            return true;
          }
        }
      }

      return false;
    }
    function focusLastDescendant(element) {
      for (let i = element.childNodes.length - 1; i >= 0; i--) {
        const child = element.childNodes[i];

        if (isHTMLElement(child)) {
          if (attemptFocus(child) || focusLastDescendant(child)) {
            return true;
          }
        }
      }

      return false;
    }

    function attemptFocus(element) {
      if (!isFocusable(element)) {
        return false;
      }

      try {
        element.focus({
          preventScroll: true
        });
      } catch (e) {}

      return document.activeElement === element;
    }

    function isFocusable(element) {
      if (element.tabIndex > 0 || element.tabIndex === 0 && element.getAttribute('tabIndex') !== null) {
        return true;
      }

      if (element.getAttribute('disabled')) {
        return false;
      }

      switch (element.nodeName) {
        case 'A':
          return !!element.href && element.rel !== 'ignore';

        case 'INPUT':
          return element.type !== 'hidden' && element.type !== 'file';

        case 'BUTTON':
        case 'SELECT':
        case 'TEXTAREA':
          return true;

        default:
          return false;
      }
    }

    let stack = [];
    const FocusTrap = vue.defineComponent({
      name: 'FocusTrap',
      props: {
        disabled: Boolean,
        active: Boolean,
        autoFocus: {
          type: Boolean,
          default: true
        },
        onEsc: Function,
        initialFocusTo: String,
        finalFocusTo: String,
        returnFocusOnDeactivated: {
          type: Boolean,
          default: true
        }
      },

      setup(props) {
        const id = createId();
        const focusableStartRef = vue.ref(null);
        const focusableEndRef = vue.ref(null);
        let activated = false;
        let ignoreInternalFocusChange = false;
        const lastFocusedElement = document.activeElement;

        function isCurrentActive() {
          const currentActiveId = stack[stack.length - 1];
          return currentActiveId === id;
        }

        function handleDocumentKeydown(e) {
          var _a;

          if (e.code === 'Escape') {
            if (isCurrentActive()) {
              (_a = props.onEsc) === null || _a === void 0 ? void 0 : _a.call(props, e);
            }
          }
        }

        vue.onMounted(() => {
          vue.watch(() => props.active, value => {
            if (value) {
              activate();
              on('keydown', document, handleDocumentKeydown);
            } else {
              off('keydown', document, handleDocumentKeydown);

              if (activated) {
                deactivate();
              }
            }
          }, {
            immediate: true
          });
        });
        vue.onBeforeUnmount(() => {
          off('keydown', document, handleDocumentKeydown);
          if (activated) deactivate();
        });

        function handleDocumentFocus(e) {
          if (ignoreInternalFocusChange) return;

          if (isCurrentActive()) {
            const mainEl = getMainEl();
            if (mainEl === null) return;
            if (mainEl.contains(getPreciseEventTarget(e))) return; // I don't handle shift + tab status since it's too tricky to handle
            // Not impossible but I need to sleep

            resetFocusTo('first');
          }
        }

        function getMainEl() {
          const focusableStartEl = focusableStartRef.value;
          if (focusableStartEl === null) return null;
          let mainEl = focusableStartEl;

          while (true) {
            mainEl = mainEl.nextSibling;
            if (mainEl === null) break;

            if (mainEl instanceof Element && mainEl.tagName === 'DIV') {
              break;
            }
          }

          return mainEl;
        }

        function activate() {
          var _a;

          if (props.disabled) return;
          stack.push(id);

          if (props.autoFocus) {
            const {
              initialFocusTo
            } = props;

            if (initialFocusTo === undefined) {
              resetFocusTo('first');
            } else {
              (_a = resolveTo(initialFocusTo)) === null || _a === void 0 ? void 0 : _a.focus({
                preventScroll: true
              });
            }
          }

          activated = true;
          document.addEventListener('focus', handleDocumentFocus, true);
        }

        function deactivate() {
          var _a;

          if (props.disabled) return;
          document.removeEventListener('focus', handleDocumentFocus, true);
          stack = stack.filter(idInStack => idInStack !== id);
          if (isCurrentActive()) return;
          const {
            finalFocusTo
          } = props;

          if (finalFocusTo !== undefined) {
            (_a = resolveTo(finalFocusTo)) === null || _a === void 0 ? void 0 : _a.focus({
              preventScroll: true
            });
          } else if (props.returnFocusOnDeactivated) {
            if (lastFocusedElement instanceof HTMLElement) {
              ignoreInternalFocusChange = true;
              lastFocusedElement.focus({
                preventScroll: true
              });
              ignoreInternalFocusChange = false;
            }
          }
        }

        function resetFocusTo(target) {
          if (!isCurrentActive()) return;

          if (props.active) {
            const focusableStartEl = focusableStartRef.value;
            const focusableEndEl = focusableEndRef.value;

            if (focusableStartEl !== null && focusableEndEl !== null) {
              const mainEl = getMainEl();

              if (mainEl == null || mainEl === focusableEndEl) {
                ignoreInternalFocusChange = true;
                focusableStartEl.focus({
                  preventScroll: true
                });
                ignoreInternalFocusChange = false;
                return;
              }

              ignoreInternalFocusChange = true;
              const focused = target === 'first' ? focusFirstDescendant(mainEl) : focusLastDescendant(mainEl);
              ignoreInternalFocusChange = false;

              if (!focused) {
                ignoreInternalFocusChange = true;
                focusableStartEl.focus({
                  preventScroll: true
                });
                ignoreInternalFocusChange = false;
              }
            }
          }
        }

        function handleStartFocus(e) {
          if (ignoreInternalFocusChange) return;
          const mainEl = getMainEl();
          if (mainEl === null) return;

          if (e.relatedTarget !== null && mainEl.contains(e.relatedTarget)) {
            // if it comes from inner, focus last
            resetFocusTo('last');
          } else {
            // otherwise focus first
            resetFocusTo('first');
          }
        }

        function handleEndFocus(e) {
          if (ignoreInternalFocusChange) return;

          if (e.relatedTarget !== null && e.relatedTarget === focusableStartRef.value) {
            // if it comes from first, focus last
            resetFocusTo('last');
          } else {
            // otherwise focus first
            resetFocusTo('first');
          }
        }

        return {
          focusableStartRef,
          focusableEndRef,
          focusableStyle: 'position: absolute; height: 0; width: 0;',
          handleStartFocus,
          handleEndFocus
        };
      },

      render() {
        const {
          default: defaultSlot
        } = this.$slots;
        if (defaultSlot === undefined) return null;
        if (this.disabled) return defaultSlot();
        const {
          active,
          focusableStyle
        } = this;
        return vue.h(vue.Fragment, null, [vue.h('div', {
          'aria-hidden': 'true',
          tabindex: active ? '0' : '-1',
          ref: 'focusableStartRef',
          style: focusableStyle,
          onFocus: this.handleStartFocus
        }), defaultSlot(), vue.h('div', {
          'aria-hidden': 'true',
          style: focusableStyle,
          ref: 'focusableEndRef',
          tabindex: active ? '0' : '-1',
          onFocus: this.handleEndFocus
        })]);
      }

    });

    function useOnResize(elRef, onResize) {
      if (onResize) {
        vue.onMounted(() => {
          const {
            value: el
          } = elRef;

          if (el) {
            resizeObserverManager.registerHandler(el, onResize);
          }
        });
        vue.onBeforeUnmount(() => {
          const {
            value: el
          } = elRef;

          if (el) {
            resizeObserverManager.unregisterHandler(el);
          }
        });
      }
    }

    let lockCount = 0;
    let originalMarginRight = "";
    let originalOverflow = "";
    let originalOverflowX = "";
    let originalOverflowY = "";
    const lockHtmlScrollRightCompensationRef = vue.ref("0px");
    function useLockHtmlScroll(lockRef) {
      if (typeof document === "undefined") return;
      const el = document.documentElement;
      let watchStopHandle;
      let activated = false;

      const unlock = () => {
        el.style.marginRight = originalMarginRight;
        el.style.overflow = originalOverflow;
        el.style.overflowX = originalOverflowX;
        el.style.overflowY = originalOverflowY;
        lockHtmlScrollRightCompensationRef.value = "0px";
      };

      vue.onMounted(() => {
        watchStopHandle = vue.watch(lockRef, value => {
          if (value) {
            if (!lockCount) {
              const scrollbarWidth = window.innerWidth - el.offsetWidth;

              if (scrollbarWidth > 0) {
                originalMarginRight = el.style.marginRight;
                el.style.marginRight = `${scrollbarWidth}px`;
                lockHtmlScrollRightCompensationRef.value = `${scrollbarWidth}px`;
              }

              originalOverflow = el.style.overflow;
              originalOverflowX = el.style.overflowX;
              originalOverflowY = el.style.overflowY;
              el.style.overflow = "hidden";
              el.style.overflowX = "hidden";
              el.style.overflowY = "hidden";
            }

            activated = true;
            lockCount++;
          } else {
            lockCount--;

            if (!lockCount) {
              unlock();
            }

            activated = false;
          }
        }, {
          immediate: true
        });
      });
      vue.onBeforeUnmount(() => {
        var _watchStopHandle;

        (_watchStopHandle = watchStopHandle) === null || _watchStopHandle === void 0 ? void 0 : _watchStopHandle();

        if (activated) {
          lockCount--;

          if (!lockCount) {
            unlock();
          }

          activated = false;
        }
      });
    }

    const isComposingRef = vue.ref(false);

    const compositionStartHandler = () => {
      isComposingRef.value = true;
    };

    const compositionEndHandler = () => {
      isComposingRef.value = false;
    };

    let mountedCount = 0;
    const useIsComposing = () => {
      if (isBrowser$2) {
        vue.onBeforeMount(() => {
          if (!mountedCount) {
            window.addEventListener("compositionstart", compositionStartHandler);
            window.addEventListener("compositionend", compositionEndHandler);
          }

          mountedCount++;
        });
        vue.onBeforeUnmount(() => {
          if (mountedCount <= 1) {
            window.removeEventListener("compositionstart", compositionStartHandler);
            window.removeEventListener("compositionend", compositionEndHandler);
            mountedCount = 0;
          } else {
            mountedCount--;
          }
        });
      }

      return isComposingRef;
    };

    function useReactivated(callback) {
      const isDeactivatedRef = {
        isDeactivated: false
      };
      let activateStateInitialized = false;
      vue.onActivated(() => {
        isDeactivatedRef.isDeactivated = false;

        if (!activateStateInitialized) {
          activateStateInitialized = true;
          return;
        }

        callback();
      });
      vue.onDeactivated(() => {
        isDeactivatedRef.isDeactivated = true;

        if (!activateStateInitialized) {
          activateStateInitialized = true;
        }
      });
      return isDeactivatedRef;
    }

    function isDocument(node) {
      return node.nodeName === "#document";
    }

    const formItemInjectionKey = createInjectionKey("n-form-item");
    function useFormItem(props) {
      let {
        defaultSize = "medium",
        mergedSize,
        mergedDisabled
      } = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      const NFormItem = vue.inject(formItemInjectionKey, null);
      vue.provide(formItemInjectionKey, null);
      const mergedSizeRef = vue.computed(mergedSize ? () => mergedSize(NFormItem) : () => {
        const {
          size
        } = props;
        if (size) return size;

        if (NFormItem) {
          const {
            mergedSize: mergedSize2
          } = NFormItem;

          if (mergedSize2.value !== void 0) {
            return mergedSize2.value;
          }
        }

        return defaultSize;
      });
      const mergedDisabledRef = vue.computed(mergedDisabled ? () => mergedDisabled(NFormItem) : () => {
        const {
          disabled
        } = props;

        if (disabled !== void 0) {
          return disabled;
        }

        if (NFormItem) {
          return NFormItem.disabled.value;
        }

        return false;
      });
      const mergedStatusRef = vue.computed(() => {
        const {
          status
        } = props;
        if (status) return status;
        return NFormItem === null || NFormItem === void 0 ? void 0 : NFormItem.mergedValidationStatus.value;
      });
      vue.onBeforeUnmount(() => {
        if (NFormItem) {
          NFormItem.restoreValidation();
        }
      });
      return {
        mergedSizeRef,
        mergedDisabledRef,
        mergedStatusRef,

        nTriggerFormBlur() {
          if (NFormItem) {
            NFormItem.handleContentBlur();
          }
        },

        nTriggerFormChange() {
          if (NFormItem) {
            NFormItem.handleContentChange();
          }
        },

        nTriggerFormFocus() {
          if (NFormItem) {
            NFormItem.handleContentFocus();
          }
        },

        nTriggerFormInput() {
          if (NFormItem) {
            NFormItem.handleContentInput();
          }
        }

      };
    }

    var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

    function getDefaultExportFromCjs (x) {
    	return x && x.__esModule && Object.prototype.hasOwnProperty.call(x, 'default') ? x['default'] : x;
    }

    var lodash = {exports: {}};

    /**
     * @license
     * Lodash <https://lodash.com/>
     * Copyright OpenJS Foundation and other contributors <https://openjsf.org/>
     * Released under MIT license <https://lodash.com/license>
     * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>
     * Copyright Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
     */

    (function (module, exports) {
    (function(){/** Used as a safe reference for `undefined` in pre-ES5 environments. */var undefined$1;/** Used as the semantic version number. */var VERSION='4.17.21';/** Used as the size to enable large array optimizations. */var LARGE_ARRAY_SIZE=200;/** Error message constants. */var CORE_ERROR_TEXT='Unsupported core-js use. Try https://npms.io/search?q=ponyfill.',FUNC_ERROR_TEXT='Expected a function',INVALID_TEMPL_VAR_ERROR_TEXT='Invalid `variable` option passed into `_.template`';/** Used to stand-in for `undefined` hash values. */var HASH_UNDEFINED='__lodash_hash_undefined__';/** Used as the maximum memoize cache size. */var MAX_MEMOIZE_SIZE=500;/** Used as the internal argument placeholder. */var PLACEHOLDER='__lodash_placeholder__';/** Used to compose bitmasks for cloning. */var CLONE_DEEP_FLAG=1,CLONE_FLAT_FLAG=2,CLONE_SYMBOLS_FLAG=4;/** Used to compose bitmasks for value comparisons. */var COMPARE_PARTIAL_FLAG=1,COMPARE_UNORDERED_FLAG=2;/** Used to compose bitmasks for function metadata. */var WRAP_BIND_FLAG=1,WRAP_BIND_KEY_FLAG=2,WRAP_CURRY_BOUND_FLAG=4,WRAP_CURRY_FLAG=8,WRAP_CURRY_RIGHT_FLAG=16,WRAP_PARTIAL_FLAG=32,WRAP_PARTIAL_RIGHT_FLAG=64,WRAP_ARY_FLAG=128,WRAP_REARG_FLAG=256,WRAP_FLIP_FLAG=512;/** Used as default options for `_.truncate`. */var DEFAULT_TRUNC_LENGTH=30,DEFAULT_TRUNC_OMISSION='...';/** Used to detect hot functions by number of calls within a span of milliseconds. */var HOT_COUNT=800,HOT_SPAN=16;/** Used to indicate the type of lazy iteratees. */var LAZY_FILTER_FLAG=1,LAZY_MAP_FLAG=2,LAZY_WHILE_FLAG=3;/** Used as references for various `Number` constants. */var INFINITY=1/0,MAX_SAFE_INTEGER=9007199254740991,MAX_INTEGER=1.7976931348623157e+308,NAN=0/0;/** Used as references for the maximum length and index of an array. */var MAX_ARRAY_LENGTH=4294967295,MAX_ARRAY_INDEX=MAX_ARRAY_LENGTH-1,HALF_MAX_ARRAY_LENGTH=MAX_ARRAY_LENGTH>>>1;/** Used to associate wrap methods with their bit flags. */var wrapFlags=[['ary',WRAP_ARY_FLAG],['bind',WRAP_BIND_FLAG],['bindKey',WRAP_BIND_KEY_FLAG],['curry',WRAP_CURRY_FLAG],['curryRight',WRAP_CURRY_RIGHT_FLAG],['flip',WRAP_FLIP_FLAG],['partial',WRAP_PARTIAL_FLAG],['partialRight',WRAP_PARTIAL_RIGHT_FLAG],['rearg',WRAP_REARG_FLAG]];/** `Object#toString` result references. */var argsTag='[object Arguments]',arrayTag='[object Array]',asyncTag='[object AsyncFunction]',boolTag='[object Boolean]',dateTag='[object Date]',domExcTag='[object DOMException]',errorTag='[object Error]',funcTag='[object Function]',genTag='[object GeneratorFunction]',mapTag='[object Map]',numberTag='[object Number]',nullTag='[object Null]',objectTag='[object Object]',promiseTag='[object Promise]',proxyTag='[object Proxy]',regexpTag='[object RegExp]',setTag='[object Set]',stringTag='[object String]',symbolTag='[object Symbol]',undefinedTag='[object Undefined]',weakMapTag='[object WeakMap]',weakSetTag='[object WeakSet]';var arrayBufferTag='[object ArrayBuffer]',dataViewTag='[object DataView]',float32Tag='[object Float32Array]',float64Tag='[object Float64Array]',int8Tag='[object Int8Array]',int16Tag='[object Int16Array]',int32Tag='[object Int32Array]',uint8Tag='[object Uint8Array]',uint8ClampedTag='[object Uint8ClampedArray]',uint16Tag='[object Uint16Array]',uint32Tag='[object Uint32Array]';/** Used to match empty string literals in compiled template source. */var reEmptyStringLeading=/\b__p \+= '';/g,reEmptyStringMiddle=/\b(__p \+=) '' \+/g,reEmptyStringTrailing=/(__e\(.*?\)|\b__t\)) \+\n'';/g;/** Used to match HTML entities and HTML characters. */var reEscapedHtml=/&(?:amp|lt|gt|quot|#39);/g,reUnescapedHtml=/[&<>"']/g,reHasEscapedHtml=RegExp(reEscapedHtml.source),reHasUnescapedHtml=RegExp(reUnescapedHtml.source);/** Used to match template delimiters. */var reEscape=/<%-([\s\S]+?)%>/g,reEvaluate=/<%([\s\S]+?)%>/g,reInterpolate=/<%=([\s\S]+?)%>/g;/** Used to match property names within property paths. */var reIsDeepProp=/\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/,reIsPlainProp=/^\w*$/,rePropName=/[^.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]|(?=(?:\.|\[\])(?:\.|\[\]|$))/g;/**
    	   * Used to match `RegExp`
    	   * [syntax characters](http://ecma-international.org/ecma-262/7.0/#sec-patterns).
    	   */var reRegExpChar=/[\\^$.*+?()[\]{}|]/g,reHasRegExpChar=RegExp(reRegExpChar.source);/** Used to match leading whitespace. */var reTrimStart=/^\s+/;/** Used to match a single whitespace character. */var reWhitespace=/\s/;/** Used to match wrap detail comments. */var reWrapComment=/\{(?:\n\/\* \[wrapped with .+\] \*\/)?\n?/,reWrapDetails=/\{\n\/\* \[wrapped with (.+)\] \*/,reSplitDetails=/,? & /;/** Used to match words composed of alphanumeric characters. */var reAsciiWord=/[^\x00-\x2f\x3a-\x40\x5b-\x60\x7b-\x7f]+/g;/**
    	   * Used to validate the `validate` option in `_.template` variable.
    	   *
    	   * Forbids characters which could potentially change the meaning of the function argument definition:
    	   * - "()," (modification of function parameters)
    	   * - "=" (default value)
    	   * - "[]{}" (destructuring of function parameters)
    	   * - "/" (beginning of a comment)
    	   * - whitespace
    	   */var reForbiddenIdentifierChars=/[()=,{}\[\]\/\s]/;/** Used to match backslashes in property paths. */var reEscapeChar=/\\(\\)?/g;/**
    	   * Used to match
    	   * [ES template delimiters](http://ecma-international.org/ecma-262/7.0/#sec-template-literal-lexical-components).
    	   */var reEsTemplate=/\$\{([^\\}]*(?:\\.[^\\}]*)*)\}/g;/** Used to match `RegExp` flags from their coerced string values. */var reFlags=/\w*$/;/** Used to detect bad signed hexadecimal string values. */var reIsBadHex=/^[-+]0x[0-9a-f]+$/i;/** Used to detect binary string values. */var reIsBinary=/^0b[01]+$/i;/** Used to detect host constructors (Safari). */var reIsHostCtor=/^\[object .+?Constructor\]$/;/** Used to detect octal string values. */var reIsOctal=/^0o[0-7]+$/i;/** Used to detect unsigned integer values. */var reIsUint=/^(?:0|[1-9]\d*)$/;/** Used to match Latin Unicode letters (excluding mathematical operators). */var reLatin=/[\xc0-\xd6\xd8-\xf6\xf8-\xff\u0100-\u017f]/g;/** Used to ensure capturing order of template delimiters. */var reNoMatch=/($^)/;/** Used to match unescaped characters in compiled string literals. */var reUnescapedString=/['\n\r\u2028\u2029\\]/g;/** Used to compose unicode character classes. */var rsAstralRange='\\ud800-\\udfff',rsComboMarksRange='\\u0300-\\u036f',reComboHalfMarksRange='\\ufe20-\\ufe2f',rsComboSymbolsRange='\\u20d0-\\u20ff',rsComboRange=rsComboMarksRange+reComboHalfMarksRange+rsComboSymbolsRange,rsDingbatRange='\\u2700-\\u27bf',rsLowerRange='a-z\\xdf-\\xf6\\xf8-\\xff',rsMathOpRange='\\xac\\xb1\\xd7\\xf7',rsNonCharRange='\\x00-\\x2f\\x3a-\\x40\\x5b-\\x60\\x7b-\\xbf',rsPunctuationRange='\\u2000-\\u206f',rsSpaceRange=' \\t\\x0b\\f\\xa0\\ufeff\\n\\r\\u2028\\u2029\\u1680\\u180e\\u2000\\u2001\\u2002\\u2003\\u2004\\u2005\\u2006\\u2007\\u2008\\u2009\\u200a\\u202f\\u205f\\u3000',rsUpperRange='A-Z\\xc0-\\xd6\\xd8-\\xde',rsVarRange='\\ufe0e\\ufe0f',rsBreakRange=rsMathOpRange+rsNonCharRange+rsPunctuationRange+rsSpaceRange;/** Used to compose unicode capture groups. */var rsApos="['\u2019]",rsAstral='['+rsAstralRange+']',rsBreak='['+rsBreakRange+']',rsCombo='['+rsComboRange+']',rsDigits='\\d+',rsDingbat='['+rsDingbatRange+']',rsLower='['+rsLowerRange+']',rsMisc='[^'+rsAstralRange+rsBreakRange+rsDigits+rsDingbatRange+rsLowerRange+rsUpperRange+']',rsFitz='\\ud83c[\\udffb-\\udfff]',rsModifier='(?:'+rsCombo+'|'+rsFitz+')',rsNonAstral='[^'+rsAstralRange+']',rsRegional='(?:\\ud83c[\\udde6-\\uddff]){2}',rsSurrPair='[\\ud800-\\udbff][\\udc00-\\udfff]',rsUpper='['+rsUpperRange+']',rsZWJ='\\u200d';/** Used to compose unicode regexes. */var rsMiscLower='(?:'+rsLower+'|'+rsMisc+')',rsMiscUpper='(?:'+rsUpper+'|'+rsMisc+')',rsOptContrLower='(?:'+rsApos+'(?:d|ll|m|re|s|t|ve))?',rsOptContrUpper='(?:'+rsApos+'(?:D|LL|M|RE|S|T|VE))?',reOptMod=rsModifier+'?',rsOptVar='['+rsVarRange+']?',rsOptJoin='(?:'+rsZWJ+'(?:'+[rsNonAstral,rsRegional,rsSurrPair].join('|')+')'+rsOptVar+reOptMod+')*',rsOrdLower='\\d*(?:1st|2nd|3rd|(?![123])\\dth)(?=\\b|[A-Z_])',rsOrdUpper='\\d*(?:1ST|2ND|3RD|(?![123])\\dTH)(?=\\b|[a-z_])',rsSeq=rsOptVar+reOptMod+rsOptJoin,rsEmoji='(?:'+[rsDingbat,rsRegional,rsSurrPair].join('|')+')'+rsSeq,rsSymbol='(?:'+[rsNonAstral+rsCombo+'?',rsCombo,rsRegional,rsSurrPair,rsAstral].join('|')+')';/** Used to match apostrophes. */var reApos=RegExp(rsApos,'g');/**
    	   * Used to match [combining diacritical marks](https://en.wikipedia.org/wiki/Combining_Diacritical_Marks) and
    	   * [combining diacritical marks for symbols](https://en.wikipedia.org/wiki/Combining_Diacritical_Marks_for_Symbols).
    	   */var reComboMark=RegExp(rsCombo,'g');/** Used to match [string symbols](https://mathiasbynens.be/notes/javascript-unicode). */var reUnicode=RegExp(rsFitz+'(?='+rsFitz+')|'+rsSymbol+rsSeq,'g');/** Used to match complex or compound words. */var reUnicodeWord=RegExp([rsUpper+'?'+rsLower+'+'+rsOptContrLower+'(?='+[rsBreak,rsUpper,'$'].join('|')+')',rsMiscUpper+'+'+rsOptContrUpper+'(?='+[rsBreak,rsUpper+rsMiscLower,'$'].join('|')+')',rsUpper+'?'+rsMiscLower+'+'+rsOptContrLower,rsUpper+'+'+rsOptContrUpper,rsOrdUpper,rsOrdLower,rsDigits,rsEmoji].join('|'),'g');/** Used to detect strings with [zero-width joiners or code points from the astral planes](http://eev.ee/blog/2015/09/12/dark-corners-of-unicode/). */var reHasUnicode=RegExp('['+rsZWJ+rsAstralRange+rsComboRange+rsVarRange+']');/** Used to detect strings that need a more robust regexp to match words. */var reHasUnicodeWord=/[a-z][A-Z]|[A-Z]{2}[a-z]|[0-9][a-zA-Z]|[a-zA-Z][0-9]|[^a-zA-Z0-9 ]/;/** Used to assign default `context` object properties. */var contextProps=['Array','Buffer','DataView','Date','Error','Float32Array','Float64Array','Function','Int8Array','Int16Array','Int32Array','Map','Math','Object','Promise','RegExp','Set','String','Symbol','TypeError','Uint8Array','Uint8ClampedArray','Uint16Array','Uint32Array','WeakMap','_','clearTimeout','isFinite','parseInt','setTimeout'];/** Used to make template sourceURLs easier to identify. */var templateCounter=-1;/** Used to identify `toStringTag` values of typed arrays. */var typedArrayTags={};typedArrayTags[float32Tag]=typedArrayTags[float64Tag]=typedArrayTags[int8Tag]=typedArrayTags[int16Tag]=typedArrayTags[int32Tag]=typedArrayTags[uint8Tag]=typedArrayTags[uint8ClampedTag]=typedArrayTags[uint16Tag]=typedArrayTags[uint32Tag]=true;typedArrayTags[argsTag]=typedArrayTags[arrayTag]=typedArrayTags[arrayBufferTag]=typedArrayTags[boolTag]=typedArrayTags[dataViewTag]=typedArrayTags[dateTag]=typedArrayTags[errorTag]=typedArrayTags[funcTag]=typedArrayTags[mapTag]=typedArrayTags[numberTag]=typedArrayTags[objectTag]=typedArrayTags[regexpTag]=typedArrayTags[setTag]=typedArrayTags[stringTag]=typedArrayTags[weakMapTag]=false;/** Used to identify `toStringTag` values supported by `_.clone`. */var cloneableTags={};cloneableTags[argsTag]=cloneableTags[arrayTag]=cloneableTags[arrayBufferTag]=cloneableTags[dataViewTag]=cloneableTags[boolTag]=cloneableTags[dateTag]=cloneableTags[float32Tag]=cloneableTags[float64Tag]=cloneableTags[int8Tag]=cloneableTags[int16Tag]=cloneableTags[int32Tag]=cloneableTags[mapTag]=cloneableTags[numberTag]=cloneableTags[objectTag]=cloneableTags[regexpTag]=cloneableTags[setTag]=cloneableTags[stringTag]=cloneableTags[symbolTag]=cloneableTags[uint8Tag]=cloneableTags[uint8ClampedTag]=cloneableTags[uint16Tag]=cloneableTags[uint32Tag]=true;cloneableTags[errorTag]=cloneableTags[funcTag]=cloneableTags[weakMapTag]=false;/** Used to map Latin Unicode letters to basic Latin letters. */var deburredLetters={// Latin-1 Supplement block.
    	'\xc0':'A','\xc1':'A','\xc2':'A','\xc3':'A','\xc4':'A','\xc5':'A','\xe0':'a','\xe1':'a','\xe2':'a','\xe3':'a','\xe4':'a','\xe5':'a','\xc7':'C','\xe7':'c','\xd0':'D','\xf0':'d','\xc8':'E','\xc9':'E','\xca':'E','\xcb':'E','\xe8':'e','\xe9':'e','\xea':'e','\xeb':'e','\xcc':'I','\xcd':'I','\xce':'I','\xcf':'I','\xec':'i','\xed':'i','\xee':'i','\xef':'i','\xd1':'N','\xf1':'n','\xd2':'O','\xd3':'O','\xd4':'O','\xd5':'O','\xd6':'O','\xd8':'O','\xf2':'o','\xf3':'o','\xf4':'o','\xf5':'o','\xf6':'o','\xf8':'o','\xd9':'U','\xda':'U','\xdb':'U','\xdc':'U','\xf9':'u','\xfa':'u','\xfb':'u','\xfc':'u','\xdd':'Y','\xfd':'y','\xff':'y','\xc6':'Ae','\xe6':'ae','\xde':'Th','\xfe':'th','\xdf':'ss',// Latin Extended-A block.
    	'\u0100':'A','\u0102':'A','\u0104':'A','\u0101':'a','\u0103':'a','\u0105':'a','\u0106':'C','\u0108':'C','\u010a':'C','\u010c':'C','\u0107':'c','\u0109':'c','\u010b':'c','\u010d':'c','\u010e':'D','\u0110':'D','\u010f':'d','\u0111':'d','\u0112':'E','\u0114':'E','\u0116':'E','\u0118':'E','\u011a':'E','\u0113':'e','\u0115':'e','\u0117':'e','\u0119':'e','\u011b':'e','\u011c':'G','\u011e':'G','\u0120':'G','\u0122':'G','\u011d':'g','\u011f':'g','\u0121':'g','\u0123':'g','\u0124':'H','\u0126':'H','\u0125':'h','\u0127':'h','\u0128':'I','\u012a':'I','\u012c':'I','\u012e':'I','\u0130':'I','\u0129':'i','\u012b':'i','\u012d':'i','\u012f':'i','\u0131':'i','\u0134':'J','\u0135':'j','\u0136':'K','\u0137':'k','\u0138':'k','\u0139':'L','\u013b':'L','\u013d':'L','\u013f':'L','\u0141':'L','\u013a':'l','\u013c':'l','\u013e':'l','\u0140':'l','\u0142':'l','\u0143':'N','\u0145':'N','\u0147':'N','\u014a':'N','\u0144':'n','\u0146':'n','\u0148':'n','\u014b':'n','\u014c':'O','\u014e':'O','\u0150':'O','\u014d':'o','\u014f':'o','\u0151':'o','\u0154':'R','\u0156':'R','\u0158':'R','\u0155':'r','\u0157':'r','\u0159':'r','\u015a':'S','\u015c':'S','\u015e':'S','\u0160':'S','\u015b':'s','\u015d':'s','\u015f':'s','\u0161':'s','\u0162':'T','\u0164':'T','\u0166':'T','\u0163':'t','\u0165':'t','\u0167':'t','\u0168':'U','\u016a':'U','\u016c':'U','\u016e':'U','\u0170':'U','\u0172':'U','\u0169':'u','\u016b':'u','\u016d':'u','\u016f':'u','\u0171':'u','\u0173':'u','\u0174':'W','\u0175':'w','\u0176':'Y','\u0177':'y','\u0178':'Y','\u0179':'Z','\u017b':'Z','\u017d':'Z','\u017a':'z','\u017c':'z','\u017e':'z','\u0132':'IJ','\u0133':'ij','\u0152':'Oe','\u0153':'oe','\u0149':"'n",'\u017f':'s'};/** Used to map characters to HTML entities. */var htmlEscapes={'&':'&amp;','<':'&lt;','>':'&gt;','"':'&quot;',"'":'&#39;'};/** Used to map HTML entities to characters. */var htmlUnescapes={'&amp;':'&','&lt;':'<','&gt;':'>','&quot;':'"','&#39;':"'"};/** Used to escape characters for inclusion in compiled string literals. */var stringEscapes={'\\':'\\',"'":"'",'\n':'n','\r':'r','\u2028':'u2028','\u2029':'u2029'};/** Built-in method references without a dependency on `root`. */var freeParseFloat=parseFloat,freeParseInt=parseInt;/** Detect free variable `global` from Node.js. */var freeGlobal=typeof commonjsGlobal=='object'&&commonjsGlobal&&commonjsGlobal.Object===Object&&commonjsGlobal;/** Detect free variable `self`. */var freeSelf=typeof self=='object'&&self&&self.Object===Object&&self;/** Used as a reference to the global object. */var root=freeGlobal||freeSelf||Function('return this')();/** Detect free variable `exports`. */var freeExports=exports&&!exports.nodeType&&exports;/** Detect free variable `module`. */var freeModule=freeExports&&'object'=='object'&&module&&!module.nodeType&&module;/** Detect the popular CommonJS extension `module.exports`. */var moduleExports=freeModule&&freeModule.exports===freeExports;/** Detect free variable `process` from Node.js. */var freeProcess=moduleExports&&freeGlobal.process;/** Used to access faster Node.js helpers. */var nodeUtil=function(){try{// Use `util.types` for Node.js 10+.
    	var types=freeModule&&freeModule.require&&freeModule.require('util').types;if(types){return types;}// Legacy `process.binding('util')` for Node.js < 10.
    	return freeProcess&&freeProcess.binding&&freeProcess.binding('util');}catch(e){}}();/* Node.js helper references. */var nodeIsArrayBuffer=nodeUtil&&nodeUtil.isArrayBuffer,nodeIsDate=nodeUtil&&nodeUtil.isDate,nodeIsMap=nodeUtil&&nodeUtil.isMap,nodeIsRegExp=nodeUtil&&nodeUtil.isRegExp,nodeIsSet=nodeUtil&&nodeUtil.isSet,nodeIsTypedArray=nodeUtil&&nodeUtil.isTypedArray;/*--------------------------------------------------------------------------*/ /**
    	   * A faster alternative to `Function#apply`, this function invokes `func`
    	   * with the `this` binding of `thisArg` and the arguments of `args`.
    	   *
    	   * @private
    	   * @param {Function} func The function to invoke.
    	   * @param {*} thisArg The `this` binding of `func`.
    	   * @param {Array} args The arguments to invoke `func` with.
    	   * @returns {*} Returns the result of `func`.
    	   */function apply(func,thisArg,args){switch(args.length){case 0:return func.call(thisArg);case 1:return func.call(thisArg,args[0]);case 2:return func.call(thisArg,args[0],args[1]);case 3:return func.call(thisArg,args[0],args[1],args[2]);}return func.apply(thisArg,args);}/**
    	   * A specialized version of `baseAggregator` for arrays.
    	   *
    	   * @private
    	   * @param {Array} [array] The array to iterate over.
    	   * @param {Function} setter The function to set `accumulator` values.
    	   * @param {Function} iteratee The iteratee to transform keys.
    	   * @param {Object} accumulator The initial aggregated object.
    	   * @returns {Function} Returns `accumulator`.
    	   */function arrayAggregator(array,setter,iteratee,accumulator){var index=-1,length=array==null?0:array.length;while(++index<length){var value=array[index];setter(accumulator,value,iteratee(value),array);}return accumulator;}/**
    	   * A specialized version of `_.forEach` for arrays without support for
    	   * iteratee shorthands.
    	   *
    	   * @private
    	   * @param {Array} [array] The array to iterate over.
    	   * @param {Function} iteratee The function invoked per iteration.
    	   * @returns {Array} Returns `array`.
    	   */function arrayEach(array,iteratee){var index=-1,length=array==null?0:array.length;while(++index<length){if(iteratee(array[index],index,array)===false){break;}}return array;}/**
    	   * A specialized version of `_.forEachRight` for arrays without support for
    	   * iteratee shorthands.
    	   *
    	   * @private
    	   * @param {Array} [array] The array to iterate over.
    	   * @param {Function} iteratee The function invoked per iteration.
    	   * @returns {Array} Returns `array`.
    	   */function arrayEachRight(array,iteratee){var length=array==null?0:array.length;while(length--){if(iteratee(array[length],length,array)===false){break;}}return array;}/**
    	   * A specialized version of `_.every` for arrays without support for
    	   * iteratee shorthands.
    	   *
    	   * @private
    	   * @param {Array} [array] The array to iterate over.
    	   * @param {Function} predicate The function invoked per iteration.
    	   * @returns {boolean} Returns `true` if all elements pass the predicate check,
    	   *  else `false`.
    	   */function arrayEvery(array,predicate){var index=-1,length=array==null?0:array.length;while(++index<length){if(!predicate(array[index],index,array)){return false;}}return true;}/**
    	   * A specialized version of `_.filter` for arrays without support for
    	   * iteratee shorthands.
    	   *
    	   * @private
    	   * @param {Array} [array] The array to iterate over.
    	   * @param {Function} predicate The function invoked per iteration.
    	   * @returns {Array} Returns the new filtered array.
    	   */function arrayFilter(array,predicate){var index=-1,length=array==null?0:array.length,resIndex=0,result=[];while(++index<length){var value=array[index];if(predicate(value,index,array)){result[resIndex++]=value;}}return result;}/**
    	   * A specialized version of `_.includes` for arrays without support for
    	   * specifying an index to search from.
    	   *
    	   * @private
    	   * @param {Array} [array] The array to inspect.
    	   * @param {*} target The value to search for.
    	   * @returns {boolean} Returns `true` if `target` is found, else `false`.
    	   */function arrayIncludes(array,value){var length=array==null?0:array.length;return !!length&&baseIndexOf(array,value,0)>-1;}/**
    	   * This function is like `arrayIncludes` except that it accepts a comparator.
    	   *
    	   * @private
    	   * @param {Array} [array] The array to inspect.
    	   * @param {*} target The value to search for.
    	   * @param {Function} comparator The comparator invoked per element.
    	   * @returns {boolean} Returns `true` if `target` is found, else `false`.
    	   */function arrayIncludesWith(array,value,comparator){var index=-1,length=array==null?0:array.length;while(++index<length){if(comparator(value,array[index])){return true;}}return false;}/**
    	   * A specialized version of `_.map` for arrays without support for iteratee
    	   * shorthands.
    	   *
    	   * @private
    	   * @param {Array} [array] The array to iterate over.
    	   * @param {Function} iteratee The function invoked per iteration.
    	   * @returns {Array} Returns the new mapped array.
    	   */function arrayMap(array,iteratee){var index=-1,length=array==null?0:array.length,result=Array(length);while(++index<length){result[index]=iteratee(array[index],index,array);}return result;}/**
    	   * Appends the elements of `values` to `array`.
    	   *
    	   * @private
    	   * @param {Array} array The array to modify.
    	   * @param {Array} values The values to append.
    	   * @returns {Array} Returns `array`.
    	   */function arrayPush(array,values){var index=-1,length=values.length,offset=array.length;while(++index<length){array[offset+index]=values[index];}return array;}/**
    	   * A specialized version of `_.reduce` for arrays without support for
    	   * iteratee shorthands.
    	   *
    	   * @private
    	   * @param {Array} [array] The array to iterate over.
    	   * @param {Function} iteratee The function invoked per iteration.
    	   * @param {*} [accumulator] The initial value.
    	   * @param {boolean} [initAccum] Specify using the first element of `array` as
    	   *  the initial value.
    	   * @returns {*} Returns the accumulated value.
    	   */function arrayReduce(array,iteratee,accumulator,initAccum){var index=-1,length=array==null?0:array.length;if(initAccum&&length){accumulator=array[++index];}while(++index<length){accumulator=iteratee(accumulator,array[index],index,array);}return accumulator;}/**
    	   * A specialized version of `_.reduceRight` for arrays without support for
    	   * iteratee shorthands.
    	   *
    	   * @private
    	   * @param {Array} [array] The array to iterate over.
    	   * @param {Function} iteratee The function invoked per iteration.
    	   * @param {*} [accumulator] The initial value.
    	   * @param {boolean} [initAccum] Specify using the last element of `array` as
    	   *  the initial value.
    	   * @returns {*} Returns the accumulated value.
    	   */function arrayReduceRight(array,iteratee,accumulator,initAccum){var length=array==null?0:array.length;if(initAccum&&length){accumulator=array[--length];}while(length--){accumulator=iteratee(accumulator,array[length],length,array);}return accumulator;}/**
    	   * A specialized version of `_.some` for arrays without support for iteratee
    	   * shorthands.
    	   *
    	   * @private
    	   * @param {Array} [array] The array to iterate over.
    	   * @param {Function} predicate The function invoked per iteration.
    	   * @returns {boolean} Returns `true` if any element passes the predicate check,
    	   *  else `false`.
    	   */function arraySome(array,predicate){var index=-1,length=array==null?0:array.length;while(++index<length){if(predicate(array[index],index,array)){return true;}}return false;}/**
    	   * Gets the size of an ASCII `string`.
    	   *
    	   * @private
    	   * @param {string} string The string inspect.
    	   * @returns {number} Returns the string size.
    	   */var asciiSize=baseProperty('length');/**
    	   * Converts an ASCII `string` to an array.
    	   *
    	   * @private
    	   * @param {string} string The string to convert.
    	   * @returns {Array} Returns the converted array.
    	   */function asciiToArray(string){return string.split('');}/**
    	   * Splits an ASCII `string` into an array of its words.
    	   *
    	   * @private
    	   * @param {string} The string to inspect.
    	   * @returns {Array} Returns the words of `string`.
    	   */function asciiWords(string){return string.match(reAsciiWord)||[];}/**
    	   * The base implementation of methods like `_.findKey` and `_.findLastKey`,
    	   * without support for iteratee shorthands, which iterates over `collection`
    	   * using `eachFunc`.
    	   *
    	   * @private
    	   * @param {Array|Object} collection The collection to inspect.
    	   * @param {Function} predicate The function invoked per iteration.
    	   * @param {Function} eachFunc The function to iterate over `collection`.
    	   * @returns {*} Returns the found element or its key, else `undefined`.
    	   */function baseFindKey(collection,predicate,eachFunc){var result;eachFunc(collection,function(value,key,collection){if(predicate(value,key,collection)){result=key;return false;}});return result;}/**
    	   * The base implementation of `_.findIndex` and `_.findLastIndex` without
    	   * support for iteratee shorthands.
    	   *
    	   * @private
    	   * @param {Array} array The array to inspect.
    	   * @param {Function} predicate The function invoked per iteration.
    	   * @param {number} fromIndex The index to search from.
    	   * @param {boolean} [fromRight] Specify iterating from right to left.
    	   * @returns {number} Returns the index of the matched value, else `-1`.
    	   */function baseFindIndex(array,predicate,fromIndex,fromRight){var length=array.length,index=fromIndex+(fromRight?1:-1);while(fromRight?index--:++index<length){if(predicate(array[index],index,array)){return index;}}return -1;}/**
    	   * The base implementation of `_.indexOf` without `fromIndex` bounds checks.
    	   *
    	   * @private
    	   * @param {Array} array The array to inspect.
    	   * @param {*} value The value to search for.
    	   * @param {number} fromIndex The index to search from.
    	   * @returns {number} Returns the index of the matched value, else `-1`.
    	   */function baseIndexOf(array,value,fromIndex){return value===value?strictIndexOf(array,value,fromIndex):baseFindIndex(array,baseIsNaN,fromIndex);}/**
    	   * This function is like `baseIndexOf` except that it accepts a comparator.
    	   *
    	   * @private
    	   * @param {Array} array The array to inspect.
    	   * @param {*} value The value to search for.
    	   * @param {number} fromIndex The index to search from.
    	   * @param {Function} comparator The comparator invoked per element.
    	   * @returns {number} Returns the index of the matched value, else `-1`.
    	   */function baseIndexOfWith(array,value,fromIndex,comparator){var index=fromIndex-1,length=array.length;while(++index<length){if(comparator(array[index],value)){return index;}}return -1;}/**
    	   * The base implementation of `_.isNaN` without support for number objects.
    	   *
    	   * @private
    	   * @param {*} value The value to check.
    	   * @returns {boolean} Returns `true` if `value` is `NaN`, else `false`.
    	   */function baseIsNaN(value){return value!==value;}/**
    	   * The base implementation of `_.mean` and `_.meanBy` without support for
    	   * iteratee shorthands.
    	   *
    	   * @private
    	   * @param {Array} array The array to iterate over.
    	   * @param {Function} iteratee The function invoked per iteration.
    	   * @returns {number} Returns the mean.
    	   */function baseMean(array,iteratee){var length=array==null?0:array.length;return length?baseSum(array,iteratee)/length:NAN;}/**
    	   * The base implementation of `_.property` without support for deep paths.
    	   *
    	   * @private
    	   * @param {string} key The key of the property to get.
    	   * @returns {Function} Returns the new accessor function.
    	   */function baseProperty(key){return function(object){return object==null?undefined$1:object[key];};}/**
    	   * The base implementation of `_.propertyOf` without support for deep paths.
    	   *
    	   * @private
    	   * @param {Object} object The object to query.
    	   * @returns {Function} Returns the new accessor function.
    	   */function basePropertyOf(object){return function(key){return object==null?undefined$1:object[key];};}/**
    	   * The base implementation of `_.reduce` and `_.reduceRight`, without support
    	   * for iteratee shorthands, which iterates over `collection` using `eachFunc`.
    	   *
    	   * @private
    	   * @param {Array|Object} collection The collection to iterate over.
    	   * @param {Function} iteratee The function invoked per iteration.
    	   * @param {*} accumulator The initial value.
    	   * @param {boolean} initAccum Specify using the first or last element of
    	   *  `collection` as the initial value.
    	   * @param {Function} eachFunc The function to iterate over `collection`.
    	   * @returns {*} Returns the accumulated value.
    	   */function baseReduce(collection,iteratee,accumulator,initAccum,eachFunc){eachFunc(collection,function(value,index,collection){accumulator=initAccum?(initAccum=false,value):iteratee(accumulator,value,index,collection);});return accumulator;}/**
    	   * The base implementation of `_.sortBy` which uses `comparer` to define the
    	   * sort order of `array` and replaces criteria objects with their corresponding
    	   * values.
    	   *
    	   * @private
    	   * @param {Array} array The array to sort.
    	   * @param {Function} comparer The function to define sort order.
    	   * @returns {Array} Returns `array`.
    	   */function baseSortBy(array,comparer){var length=array.length;array.sort(comparer);while(length--){array[length]=array[length].value;}return array;}/**
    	   * The base implementation of `_.sum` and `_.sumBy` without support for
    	   * iteratee shorthands.
    	   *
    	   * @private
    	   * @param {Array} array The array to iterate over.
    	   * @param {Function} iteratee The function invoked per iteration.
    	   * @returns {number} Returns the sum.
    	   */function baseSum(array,iteratee){var result,index=-1,length=array.length;while(++index<length){var current=iteratee(array[index]);if(current!==undefined$1){result=result===undefined$1?current:result+current;}}return result;}/**
    	   * The base implementation of `_.times` without support for iteratee shorthands
    	   * or max array length checks.
    	   *
    	   * @private
    	   * @param {number} n The number of times to invoke `iteratee`.
    	   * @param {Function} iteratee The function invoked per iteration.
    	   * @returns {Array} Returns the array of results.
    	   */function baseTimes(n,iteratee){var index=-1,result=Array(n);while(++index<n){result[index]=iteratee(index);}return result;}/**
    	   * The base implementation of `_.toPairs` and `_.toPairsIn` which creates an array
    	   * of key-value pairs for `object` corresponding to the property names of `props`.
    	   *
    	   * @private
    	   * @param {Object} object The object to query.
    	   * @param {Array} props The property names to get values for.
    	   * @returns {Object} Returns the key-value pairs.
    	   */function baseToPairs(object,props){return arrayMap(props,function(key){return [key,object[key]];});}/**
    	   * The base implementation of `_.trim`.
    	   *
    	   * @private
    	   * @param {string} string The string to trim.
    	   * @returns {string} Returns the trimmed string.
    	   */function baseTrim(string){return string?string.slice(0,trimmedEndIndex(string)+1).replace(reTrimStart,''):string;}/**
    	   * The base implementation of `_.unary` without support for storing metadata.
    	   *
    	   * @private
    	   * @param {Function} func The function to cap arguments for.
    	   * @returns {Function} Returns the new capped function.
    	   */function baseUnary(func){return function(value){return func(value);};}/**
    	   * The base implementation of `_.values` and `_.valuesIn` which creates an
    	   * array of `object` property values corresponding to the property names
    	   * of `props`.
    	   *
    	   * @private
    	   * @param {Object} object The object to query.
    	   * @param {Array} props The property names to get values for.
    	   * @returns {Object} Returns the array of property values.
    	   */function baseValues(object,props){return arrayMap(props,function(key){return object[key];});}/**
    	   * Checks if a `cache` value for `key` exists.
    	   *
    	   * @private
    	   * @param {Object} cache The cache to query.
    	   * @param {string} key The key of the entry to check.
    	   * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
    	   */function cacheHas(cache,key){return cache.has(key);}/**
    	   * Used by `_.trim` and `_.trimStart` to get the index of the first string symbol
    	   * that is not found in the character symbols.
    	   *
    	   * @private
    	   * @param {Array} strSymbols The string symbols to inspect.
    	   * @param {Array} chrSymbols The character symbols to find.
    	   * @returns {number} Returns the index of the first unmatched string symbol.
    	   */function charsStartIndex(strSymbols,chrSymbols){var index=-1,length=strSymbols.length;while(++index<length&&baseIndexOf(chrSymbols,strSymbols[index],0)>-1){}return index;}/**
    	   * Used by `_.trim` and `_.trimEnd` to get the index of the last string symbol
    	   * that is not found in the character symbols.
    	   *
    	   * @private
    	   * @param {Array} strSymbols The string symbols to inspect.
    	   * @param {Array} chrSymbols The character symbols to find.
    	   * @returns {number} Returns the index of the last unmatched string symbol.
    	   */function charsEndIndex(strSymbols,chrSymbols){var index=strSymbols.length;while(index--&&baseIndexOf(chrSymbols,strSymbols[index],0)>-1){}return index;}/**
    	   * Gets the number of `placeholder` occurrences in `array`.
    	   *
    	   * @private
    	   * @param {Array} array The array to inspect.
    	   * @param {*} placeholder The placeholder to search for.
    	   * @returns {number} Returns the placeholder count.
    	   */function countHolders(array,placeholder){var length=array.length,result=0;while(length--){if(array[length]===placeholder){++result;}}return result;}/**
    	   * Used by `_.deburr` to convert Latin-1 Supplement and Latin Extended-A
    	   * letters to basic Latin letters.
    	   *
    	   * @private
    	   * @param {string} letter The matched letter to deburr.
    	   * @returns {string} Returns the deburred letter.
    	   */var deburrLetter=basePropertyOf(deburredLetters);/**
    	   * Used by `_.escape` to convert characters to HTML entities.
    	   *
    	   * @private
    	   * @param {string} chr The matched character to escape.
    	   * @returns {string} Returns the escaped character.
    	   */var escapeHtmlChar=basePropertyOf(htmlEscapes);/**
    	   * Used by `_.template` to escape characters for inclusion in compiled string literals.
    	   *
    	   * @private
    	   * @param {string} chr The matched character to escape.
    	   * @returns {string} Returns the escaped character.
    	   */function escapeStringChar(chr){return '\\'+stringEscapes[chr];}/**
    	   * Gets the value at `key` of `object`.
    	   *
    	   * @private
    	   * @param {Object} [object] The object to query.
    	   * @param {string} key The key of the property to get.
    	   * @returns {*} Returns the property value.
    	   */function getValue(object,key){return object==null?undefined$1:object[key];}/**
    	   * Checks if `string` contains Unicode symbols.
    	   *
    	   * @private
    	   * @param {string} string The string to inspect.
    	   * @returns {boolean} Returns `true` if a symbol is found, else `false`.
    	   */function hasUnicode(string){return reHasUnicode.test(string);}/**
    	   * Checks if `string` contains a word composed of Unicode symbols.
    	   *
    	   * @private
    	   * @param {string} string The string to inspect.
    	   * @returns {boolean} Returns `true` if a word is found, else `false`.
    	   */function hasUnicodeWord(string){return reHasUnicodeWord.test(string);}/**
    	   * Converts `iterator` to an array.
    	   *
    	   * @private
    	   * @param {Object} iterator The iterator to convert.
    	   * @returns {Array} Returns the converted array.
    	   */function iteratorToArray(iterator){var data,result=[];while(!(data=iterator.next()).done){result.push(data.value);}return result;}/**
    	   * Converts `map` to its key-value pairs.
    	   *
    	   * @private
    	   * @param {Object} map The map to convert.
    	   * @returns {Array} Returns the key-value pairs.
    	   */function mapToArray(map){var index=-1,result=Array(map.size);map.forEach(function(value,key){result[++index]=[key,value];});return result;}/**
    	   * Creates a unary function that invokes `func` with its argument transformed.
    	   *
    	   * @private
    	   * @param {Function} func The function to wrap.
    	   * @param {Function} transform The argument transform.
    	   * @returns {Function} Returns the new function.
    	   */function overArg(func,transform){return function(arg){return func(transform(arg));};}/**
    	   * Replaces all `placeholder` elements in `array` with an internal placeholder
    	   * and returns an array of their indexes.
    	   *
    	   * @private
    	   * @param {Array} array The array to modify.
    	   * @param {*} placeholder The placeholder to replace.
    	   * @returns {Array} Returns the new array of placeholder indexes.
    	   */function replaceHolders(array,placeholder){var index=-1,length=array.length,resIndex=0,result=[];while(++index<length){var value=array[index];if(value===placeholder||value===PLACEHOLDER){array[index]=PLACEHOLDER;result[resIndex++]=index;}}return result;}/**
    	   * Converts `set` to an array of its values.
    	   *
    	   * @private
    	   * @param {Object} set The set to convert.
    	   * @returns {Array} Returns the values.
    	   */function setToArray(set){var index=-1,result=Array(set.size);set.forEach(function(value){result[++index]=value;});return result;}/**
    	   * Converts `set` to its value-value pairs.
    	   *
    	   * @private
    	   * @param {Object} set The set to convert.
    	   * @returns {Array} Returns the value-value pairs.
    	   */function setToPairs(set){var index=-1,result=Array(set.size);set.forEach(function(value){result[++index]=[value,value];});return result;}/**
    	   * A specialized version of `_.indexOf` which performs strict equality
    	   * comparisons of values, i.e. `===`.
    	   *
    	   * @private
    	   * @param {Array} array The array to inspect.
    	   * @param {*} value The value to search for.
    	   * @param {number} fromIndex The index to search from.
    	   * @returns {number} Returns the index of the matched value, else `-1`.
    	   */function strictIndexOf(array,value,fromIndex){var index=fromIndex-1,length=array.length;while(++index<length){if(array[index]===value){return index;}}return -1;}/**
    	   * A specialized version of `_.lastIndexOf` which performs strict equality
    	   * comparisons of values, i.e. `===`.
    	   *
    	   * @private
    	   * @param {Array} array The array to inspect.
    	   * @param {*} value The value to search for.
    	   * @param {number} fromIndex The index to search from.
    	   * @returns {number} Returns the index of the matched value, else `-1`.
    	   */function strictLastIndexOf(array,value,fromIndex){var index=fromIndex+1;while(index--){if(array[index]===value){return index;}}return index;}/**
    	   * Gets the number of symbols in `string`.
    	   *
    	   * @private
    	   * @param {string} string The string to inspect.
    	   * @returns {number} Returns the string size.
    	   */function stringSize(string){return hasUnicode(string)?unicodeSize(string):asciiSize(string);}/**
    	   * Converts `string` to an array.
    	   *
    	   * @private
    	   * @param {string} string The string to convert.
    	   * @returns {Array} Returns the converted array.
    	   */function stringToArray(string){return hasUnicode(string)?unicodeToArray(string):asciiToArray(string);}/**
    	   * Used by `_.trim` and `_.trimEnd` to get the index of the last non-whitespace
    	   * character of `string`.
    	   *
    	   * @private
    	   * @param {string} string The string to inspect.
    	   * @returns {number} Returns the index of the last non-whitespace character.
    	   */function trimmedEndIndex(string){var index=string.length;while(index--&&reWhitespace.test(string.charAt(index))){}return index;}/**
    	   * Used by `_.unescape` to convert HTML entities to characters.
    	   *
    	   * @private
    	   * @param {string} chr The matched character to unescape.
    	   * @returns {string} Returns the unescaped character.
    	   */var unescapeHtmlChar=basePropertyOf(htmlUnescapes);/**
    	   * Gets the size of a Unicode `string`.
    	   *
    	   * @private
    	   * @param {string} string The string inspect.
    	   * @returns {number} Returns the string size.
    	   */function unicodeSize(string){var result=reUnicode.lastIndex=0;while(reUnicode.test(string)){++result;}return result;}/**
    	   * Converts a Unicode `string` to an array.
    	   *
    	   * @private
    	   * @param {string} string The string to convert.
    	   * @returns {Array} Returns the converted array.
    	   */function unicodeToArray(string){return string.match(reUnicode)||[];}/**
    	   * Splits a Unicode `string` into an array of its words.
    	   *
    	   * @private
    	   * @param {string} The string to inspect.
    	   * @returns {Array} Returns the words of `string`.
    	   */function unicodeWords(string){return string.match(reUnicodeWord)||[];}/*--------------------------------------------------------------------------*/ /**
    	   * Create a new pristine `lodash` function using the `context` object.
    	   *
    	   * @static
    	   * @memberOf _
    	   * @since 1.1.0
    	   * @category Util
    	   * @param {Object} [context=root] The context object.
    	   * @returns {Function} Returns a new `lodash` function.
    	   * @example
    	   *
    	   * _.mixin({ 'foo': _.constant('foo') });
    	   *
    	   * var lodash = _.runInContext();
    	   * lodash.mixin({ 'bar': lodash.constant('bar') });
    	   *
    	   * _.isFunction(_.foo);
    	   * // => true
    	   * _.isFunction(_.bar);
    	   * // => false
    	   *
    	   * lodash.isFunction(lodash.foo);
    	   * // => false
    	   * lodash.isFunction(lodash.bar);
    	   * // => true
    	   *
    	   * // Create a suped-up `defer` in Node.js.
    	   * var defer = _.runInContext({ 'setTimeout': setImmediate }).defer;
    	   */var runInContext=function runInContext(context){context=context==null?root:_.defaults(root.Object(),context,_.pick(root,contextProps));/** Built-in constructor references. */var Array=context.Array,Date=context.Date,Error=context.Error,Function=context.Function,Math=context.Math,Object=context.Object,RegExp=context.RegExp,String=context.String,TypeError=context.TypeError;/** Used for built-in method references. */var arrayProto=Array.prototype,funcProto=Function.prototype,objectProto=Object.prototype;/** Used to detect overreaching core-js shims. */var coreJsData=context['__core-js_shared__'];/** Used to resolve the decompiled source of functions. */var funcToString=funcProto.toString;/** Used to check objects for own properties. */var hasOwnProperty=objectProto.hasOwnProperty;/** Used to generate unique IDs. */var idCounter=0;/** Used to detect methods masquerading as native. */var maskSrcKey=function(){var uid=/[^.]+$/.exec(coreJsData&&coreJsData.keys&&coreJsData.keys.IE_PROTO||'');return uid?'Symbol(src)_1.'+uid:'';}();/**
    	     * Used to resolve the
    	     * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)
    	     * of values.
    	     */var nativeObjectToString=objectProto.toString;/** Used to infer the `Object` constructor. */var objectCtorString=funcToString.call(Object);/** Used to restore the original `_` reference in `_.noConflict`. */var oldDash=root._;/** Used to detect if a method is native. */var reIsNative=RegExp('^'+funcToString.call(hasOwnProperty).replace(reRegExpChar,'\\$&').replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g,'$1.*?')+'$');/** Built-in value references. */var Buffer=moduleExports?context.Buffer:undefined$1,Symbol=context.Symbol,Uint8Array=context.Uint8Array,allocUnsafe=Buffer?Buffer.allocUnsafe:undefined$1,getPrototype=overArg(Object.getPrototypeOf,Object),objectCreate=Object.create,propertyIsEnumerable=objectProto.propertyIsEnumerable,splice=arrayProto.splice,spreadableSymbol=Symbol?Symbol.isConcatSpreadable:undefined$1,symIterator=Symbol?Symbol.iterator:undefined$1,symToStringTag=Symbol?Symbol.toStringTag:undefined$1;var defineProperty=function(){try{var func=getNative(Object,'defineProperty');func({},'',{});return func;}catch(e){}}();/** Mocked built-ins. */var ctxClearTimeout=context.clearTimeout!==root.clearTimeout&&context.clearTimeout,ctxNow=Date&&Date.now!==root.Date.now&&Date.now,ctxSetTimeout=context.setTimeout!==root.setTimeout&&context.setTimeout;/* Built-in method references for those with the same name as other `lodash` methods. */var nativeCeil=Math.ceil,nativeFloor=Math.floor,nativeGetSymbols=Object.getOwnPropertySymbols,nativeIsBuffer=Buffer?Buffer.isBuffer:undefined$1,nativeIsFinite=context.isFinite,nativeJoin=arrayProto.join,nativeKeys=overArg(Object.keys,Object),nativeMax=Math.max,nativeMin=Math.min,nativeNow=Date.now,nativeParseInt=context.parseInt,nativeRandom=Math.random,nativeReverse=arrayProto.reverse;/* Built-in method references that are verified to be native. */var DataView=getNative(context,'DataView'),Map=getNative(context,'Map'),Promise=getNative(context,'Promise'),Set=getNative(context,'Set'),WeakMap=getNative(context,'WeakMap'),nativeCreate=getNative(Object,'create');/** Used to store function metadata. */var metaMap=WeakMap&&new WeakMap();/** Used to lookup unminified function names. */var realNames={};/** Used to detect maps, sets, and weakmaps. */var dataViewCtorString=toSource(DataView),mapCtorString=toSource(Map),promiseCtorString=toSource(Promise),setCtorString=toSource(Set),weakMapCtorString=toSource(WeakMap);/** Used to convert symbols to primitives and strings. */var symbolProto=Symbol?Symbol.prototype:undefined$1,symbolValueOf=symbolProto?symbolProto.valueOf:undefined$1,symbolToString=symbolProto?symbolProto.toString:undefined$1;/*------------------------------------------------------------------------*/ /**
    	     * Creates a `lodash` object which wraps `value` to enable implicit method
    	     * chain sequences. Methods that operate on and return arrays, collections,
    	     * and functions can be chained together. Methods that retrieve a single value
    	     * or may return a primitive value will automatically end the chain sequence
    	     * and return the unwrapped value. Otherwise, the value must be unwrapped
    	     * with `_#value`.
    	     *
    	     * Explicit chain sequences, which must be unwrapped with `_#value`, may be
    	     * enabled using `_.chain`.
    	     *
    	     * The execution of chained methods is lazy, that is, it's deferred until
    	     * `_#value` is implicitly or explicitly called.
    	     *
    	     * Lazy evaluation allows several methods to support shortcut fusion.
    	     * Shortcut fusion is an optimization to merge iteratee calls; this avoids
    	     * the creation of intermediate arrays and can greatly reduce the number of
    	     * iteratee executions. Sections of a chain sequence qualify for shortcut
    	     * fusion if the section is applied to an array and iteratees accept only
    	     * one argument. The heuristic for whether a section qualifies for shortcut
    	     * fusion is subject to change.
    	     *
    	     * Chaining is supported in custom builds as long as the `_#value` method is
    	     * directly or indirectly included in the build.
    	     *
    	     * In addition to lodash methods, wrappers have `Array` and `String` methods.
    	     *
    	     * The wrapper `Array` methods are:
    	     * `concat`, `join`, `pop`, `push`, `shift`, `sort`, `splice`, and `unshift`
    	     *
    	     * The wrapper `String` methods are:
    	     * `replace` and `split`
    	     *
    	     * The wrapper methods that support shortcut fusion are:
    	     * `at`, `compact`, `drop`, `dropRight`, `dropWhile`, `filter`, `find`,
    	     * `findLast`, `head`, `initial`, `last`, `map`, `reject`, `reverse`, `slice`,
    	     * `tail`, `take`, `takeRight`, `takeRightWhile`, `takeWhile`, and `toArray`
    	     *
    	     * The chainable wrapper methods are:
    	     * `after`, `ary`, `assign`, `assignIn`, `assignInWith`, `assignWith`, `at`,
    	     * `before`, `bind`, `bindAll`, `bindKey`, `castArray`, `chain`, `chunk`,
    	     * `commit`, `compact`, `concat`, `conforms`, `constant`, `countBy`, `create`,
    	     * `curry`, `debounce`, `defaults`, `defaultsDeep`, `defer`, `delay`,
    	     * `difference`, `differenceBy`, `differenceWith`, `drop`, `dropRight`,
    	     * `dropRightWhile`, `dropWhile`, `extend`, `extendWith`, `fill`, `filter`,
    	     * `flatMap`, `flatMapDeep`, `flatMapDepth`, `flatten`, `flattenDeep`,
    	     * `flattenDepth`, `flip`, `flow`, `flowRight`, `fromPairs`, `functions`,
    	     * `functionsIn`, `groupBy`, `initial`, `intersection`, `intersectionBy`,
    	     * `intersectionWith`, `invert`, `invertBy`, `invokeMap`, `iteratee`, `keyBy`,
    	     * `keys`, `keysIn`, `map`, `mapKeys`, `mapValues`, `matches`, `matchesProperty`,
    	     * `memoize`, `merge`, `mergeWith`, `method`, `methodOf`, `mixin`, `negate`,
    	     * `nthArg`, `omit`, `omitBy`, `once`, `orderBy`, `over`, `overArgs`,
    	     * `overEvery`, `overSome`, `partial`, `partialRight`, `partition`, `pick`,
    	     * `pickBy`, `plant`, `property`, `propertyOf`, `pull`, `pullAll`, `pullAllBy`,
    	     * `pullAllWith`, `pullAt`, `push`, `range`, `rangeRight`, `rearg`, `reject`,
    	     * `remove`, `rest`, `reverse`, `sampleSize`, `set`, `setWith`, `shuffle`,
    	     * `slice`, `sort`, `sortBy`, `splice`, `spread`, `tail`, `take`, `takeRight`,
    	     * `takeRightWhile`, `takeWhile`, `tap`, `throttle`, `thru`, `toArray`,
    	     * `toPairs`, `toPairsIn`, `toPath`, `toPlainObject`, `transform`, `unary`,
    	     * `union`, `unionBy`, `unionWith`, `uniq`, `uniqBy`, `uniqWith`, `unset`,
    	     * `unshift`, `unzip`, `unzipWith`, `update`, `updateWith`, `values`,
    	     * `valuesIn`, `without`, `wrap`, `xor`, `xorBy`, `xorWith`, `zip`,
    	     * `zipObject`, `zipObjectDeep`, and `zipWith`
    	     *
    	     * The wrapper methods that are **not** chainable by default are:
    	     * `add`, `attempt`, `camelCase`, `capitalize`, `ceil`, `clamp`, `clone`,
    	     * `cloneDeep`, `cloneDeepWith`, `cloneWith`, `conformsTo`, `deburr`,
    	     * `defaultTo`, `divide`, `each`, `eachRight`, `endsWith`, `eq`, `escape`,
    	     * `escapeRegExp`, `every`, `find`, `findIndex`, `findKey`, `findLast`,
    	     * `findLastIndex`, `findLastKey`, `first`, `floor`, `forEach`, `forEachRight`,
    	     * `forIn`, `forInRight`, `forOwn`, `forOwnRight`, `get`, `gt`, `gte`, `has`,
    	     * `hasIn`, `head`, `identity`, `includes`, `indexOf`, `inRange`, `invoke`,
    	     * `isArguments`, `isArray`, `isArrayBuffer`, `isArrayLike`, `isArrayLikeObject`,
    	     * `isBoolean`, `isBuffer`, `isDate`, `isElement`, `isEmpty`, `isEqual`,
    	     * `isEqualWith`, `isError`, `isFinite`, `isFunction`, `isInteger`, `isLength`,
    	     * `isMap`, `isMatch`, `isMatchWith`, `isNaN`, `isNative`, `isNil`, `isNull`,
    	     * `isNumber`, `isObject`, `isObjectLike`, `isPlainObject`, `isRegExp`,
    	     * `isSafeInteger`, `isSet`, `isString`, `isUndefined`, `isTypedArray`,
    	     * `isWeakMap`, `isWeakSet`, `join`, `kebabCase`, `last`, `lastIndexOf`,
    	     * `lowerCase`, `lowerFirst`, `lt`, `lte`, `max`, `maxBy`, `mean`, `meanBy`,
    	     * `min`, `minBy`, `multiply`, `noConflict`, `noop`, `now`, `nth`, `pad`,
    	     * `padEnd`, `padStart`, `parseInt`, `pop`, `random`, `reduce`, `reduceRight`,
    	     * `repeat`, `result`, `round`, `runInContext`, `sample`, `shift`, `size`,
    	     * `snakeCase`, `some`, `sortedIndex`, `sortedIndexBy`, `sortedLastIndex`,
    	     * `sortedLastIndexBy`, `startCase`, `startsWith`, `stubArray`, `stubFalse`,
    	     * `stubObject`, `stubString`, `stubTrue`, `subtract`, `sum`, `sumBy`,
    	     * `template`, `times`, `toFinite`, `toInteger`, `toJSON`, `toLength`,
    	     * `toLower`, `toNumber`, `toSafeInteger`, `toString`, `toUpper`, `trim`,
    	     * `trimEnd`, `trimStart`, `truncate`, `unescape`, `uniqueId`, `upperCase`,
    	     * `upperFirst`, `value`, and `words`
    	     *
    	     * @name _
    	     * @constructor
    	     * @category Seq
    	     * @param {*} value The value to wrap in a `lodash` instance.
    	     * @returns {Object} Returns the new `lodash` wrapper instance.
    	     * @example
    	     *
    	     * function square(n) {
    	     *   return n * n;
    	     * }
    	     *
    	     * var wrapped = _([1, 2, 3]);
    	     *
    	     * // Returns an unwrapped value.
    	     * wrapped.reduce(_.add);
    	     * // => 6
    	     *
    	     * // Returns a wrapped value.
    	     * var squares = wrapped.map(square);
    	     *
    	     * _.isArray(squares);
    	     * // => false
    	     *
    	     * _.isArray(squares.value());
    	     * // => true
    	     */function lodash(value){if(isObjectLike(value)&&!isArray(value)&&!(value instanceof LazyWrapper)){if(value instanceof LodashWrapper){return value;}if(hasOwnProperty.call(value,'__wrapped__')){return wrapperClone(value);}}return new LodashWrapper(value);}/**
    	     * The base implementation of `_.create` without support for assigning
    	     * properties to the created object.
    	     *
    	     * @private
    	     * @param {Object} proto The object to inherit from.
    	     * @returns {Object} Returns the new object.
    	     */var baseCreate=function(){function object(){}return function(proto){if(!isObject(proto)){return {};}if(objectCreate){return objectCreate(proto);}object.prototype=proto;var result=new object();object.prototype=undefined$1;return result;};}();/**
    	     * The function whose prototype chain sequence wrappers inherit from.
    	     *
    	     * @private
    	     */function baseLodash(){// No operation performed.
    	}/**
    	     * The base constructor for creating `lodash` wrapper objects.
    	     *
    	     * @private
    	     * @param {*} value The value to wrap.
    	     * @param {boolean} [chainAll] Enable explicit method chain sequences.
    	     */function LodashWrapper(value,chainAll){this.__wrapped__=value;this.__actions__=[];this.__chain__=!!chainAll;this.__index__=0;this.__values__=undefined$1;}/**
    	     * By default, the template delimiters used by lodash are like those in
    	     * embedded Ruby (ERB) as well as ES2015 template strings. Change the
    	     * following template settings to use alternative delimiters.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @type {Object}
    	     */lodash.templateSettings={/**
    	       * Used to detect `data` property values to be HTML-escaped.
    	       *
    	       * @memberOf _.templateSettings
    	       * @type {RegExp}
    	       */'escape':reEscape,/**
    	       * Used to detect code to be evaluated.
    	       *
    	       * @memberOf _.templateSettings
    	       * @type {RegExp}
    	       */'evaluate':reEvaluate,/**
    	       * Used to detect `data` property values to inject.
    	       *
    	       * @memberOf _.templateSettings
    	       * @type {RegExp}
    	       */'interpolate':reInterpolate,/**
    	       * Used to reference the data object in the template text.
    	       *
    	       * @memberOf _.templateSettings
    	       * @type {string}
    	       */'variable':'',/**
    	       * Used to import variables into the compiled template.
    	       *
    	       * @memberOf _.templateSettings
    	       * @type {Object}
    	       */'imports':{/**
    	         * A reference to the `lodash` function.
    	         *
    	         * @memberOf _.templateSettings.imports
    	         * @type {Function}
    	         */'_':lodash}};// Ensure wrappers are instances of `baseLodash`.
    	lodash.prototype=baseLodash.prototype;lodash.prototype.constructor=lodash;LodashWrapper.prototype=baseCreate(baseLodash.prototype);LodashWrapper.prototype.constructor=LodashWrapper;/*------------------------------------------------------------------------*/ /**
    	     * Creates a lazy wrapper object which wraps `value` to enable lazy evaluation.
    	     *
    	     * @private
    	     * @constructor
    	     * @param {*} value The value to wrap.
    	     */function LazyWrapper(value){this.__wrapped__=value;this.__actions__=[];this.__dir__=1;this.__filtered__=false;this.__iteratees__=[];this.__takeCount__=MAX_ARRAY_LENGTH;this.__views__=[];}/**
    	     * Creates a clone of the lazy wrapper object.
    	     *
    	     * @private
    	     * @name clone
    	     * @memberOf LazyWrapper
    	     * @returns {Object} Returns the cloned `LazyWrapper` object.
    	     */function lazyClone(){var result=new LazyWrapper(this.__wrapped__);result.__actions__=copyArray(this.__actions__);result.__dir__=this.__dir__;result.__filtered__=this.__filtered__;result.__iteratees__=copyArray(this.__iteratees__);result.__takeCount__=this.__takeCount__;result.__views__=copyArray(this.__views__);return result;}/**
    	     * Reverses the direction of lazy iteration.
    	     *
    	     * @private
    	     * @name reverse
    	     * @memberOf LazyWrapper
    	     * @returns {Object} Returns the new reversed `LazyWrapper` object.
    	     */function lazyReverse(){if(this.__filtered__){var result=new LazyWrapper(this);result.__dir__=-1;result.__filtered__=true;}else {result=this.clone();result.__dir__*=-1;}return result;}/**
    	     * Extracts the unwrapped value from its lazy wrapper.
    	     *
    	     * @private
    	     * @name value
    	     * @memberOf LazyWrapper
    	     * @returns {*} Returns the unwrapped value.
    	     */function lazyValue(){var array=this.__wrapped__.value(),dir=this.__dir__,isArr=isArray(array),isRight=dir<0,arrLength=isArr?array.length:0,view=getView(0,arrLength,this.__views__),start=view.start,end=view.end,length=end-start,index=isRight?end:start-1,iteratees=this.__iteratees__,iterLength=iteratees.length,resIndex=0,takeCount=nativeMin(length,this.__takeCount__);if(!isArr||!isRight&&arrLength==length&&takeCount==length){return baseWrapperValue(array,this.__actions__);}var result=[];outer:while(length--&&resIndex<takeCount){index+=dir;var iterIndex=-1,value=array[index];while(++iterIndex<iterLength){var data=iteratees[iterIndex],iteratee=data.iteratee,type=data.type,computed=iteratee(value);if(type==LAZY_MAP_FLAG){value=computed;}else if(!computed){if(type==LAZY_FILTER_FLAG){continue outer;}else {break outer;}}}result[resIndex++]=value;}return result;}// Ensure `LazyWrapper` is an instance of `baseLodash`.
    	LazyWrapper.prototype=baseCreate(baseLodash.prototype);LazyWrapper.prototype.constructor=LazyWrapper;/*------------------------------------------------------------------------*/ /**
    	     * Creates a hash object.
    	     *
    	     * @private
    	     * @constructor
    	     * @param {Array} [entries] The key-value pairs to cache.
    	     */function Hash(entries){var index=-1,length=entries==null?0:entries.length;this.clear();while(++index<length){var entry=entries[index];this.set(entry[0],entry[1]);}}/**
    	     * Removes all key-value entries from the hash.
    	     *
    	     * @private
    	     * @name clear
    	     * @memberOf Hash
    	     */function hashClear(){this.__data__=nativeCreate?nativeCreate(null):{};this.size=0;}/**
    	     * Removes `key` and its value from the hash.
    	     *
    	     * @private
    	     * @name delete
    	     * @memberOf Hash
    	     * @param {Object} hash The hash to modify.
    	     * @param {string} key The key of the value to remove.
    	     * @returns {boolean} Returns `true` if the entry was removed, else `false`.
    	     */function hashDelete(key){var result=this.has(key)&&delete this.__data__[key];this.size-=result?1:0;return result;}/**
    	     * Gets the hash value for `key`.
    	     *
    	     * @private
    	     * @name get
    	     * @memberOf Hash
    	     * @param {string} key The key of the value to get.
    	     * @returns {*} Returns the entry value.
    	     */function hashGet(key){var data=this.__data__;if(nativeCreate){var result=data[key];return result===HASH_UNDEFINED?undefined$1:result;}return hasOwnProperty.call(data,key)?data[key]:undefined$1;}/**
    	     * Checks if a hash value for `key` exists.
    	     *
    	     * @private
    	     * @name has
    	     * @memberOf Hash
    	     * @param {string} key The key of the entry to check.
    	     * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
    	     */function hashHas(key){var data=this.__data__;return nativeCreate?data[key]!==undefined$1:hasOwnProperty.call(data,key);}/**
    	     * Sets the hash `key` to `value`.
    	     *
    	     * @private
    	     * @name set
    	     * @memberOf Hash
    	     * @param {string} key The key of the value to set.
    	     * @param {*} value The value to set.
    	     * @returns {Object} Returns the hash instance.
    	     */function hashSet(key,value){var data=this.__data__;this.size+=this.has(key)?0:1;data[key]=nativeCreate&&value===undefined$1?HASH_UNDEFINED:value;return this;}// Add methods to `Hash`.
    	Hash.prototype.clear=hashClear;Hash.prototype['delete']=hashDelete;Hash.prototype.get=hashGet;Hash.prototype.has=hashHas;Hash.prototype.set=hashSet;/*------------------------------------------------------------------------*/ /**
    	     * Creates an list cache object.
    	     *
    	     * @private
    	     * @constructor
    	     * @param {Array} [entries] The key-value pairs to cache.
    	     */function ListCache(entries){var index=-1,length=entries==null?0:entries.length;this.clear();while(++index<length){var entry=entries[index];this.set(entry[0],entry[1]);}}/**
    	     * Removes all key-value entries from the list cache.
    	     *
    	     * @private
    	     * @name clear
    	     * @memberOf ListCache
    	     */function listCacheClear(){this.__data__=[];this.size=0;}/**
    	     * Removes `key` and its value from the list cache.
    	     *
    	     * @private
    	     * @name delete
    	     * @memberOf ListCache
    	     * @param {string} key The key of the value to remove.
    	     * @returns {boolean} Returns `true` if the entry was removed, else `false`.
    	     */function listCacheDelete(key){var data=this.__data__,index=assocIndexOf(data,key);if(index<0){return false;}var lastIndex=data.length-1;if(index==lastIndex){data.pop();}else {splice.call(data,index,1);}--this.size;return true;}/**
    	     * Gets the list cache value for `key`.
    	     *
    	     * @private
    	     * @name get
    	     * @memberOf ListCache
    	     * @param {string} key The key of the value to get.
    	     * @returns {*} Returns the entry value.
    	     */function listCacheGet(key){var data=this.__data__,index=assocIndexOf(data,key);return index<0?undefined$1:data[index][1];}/**
    	     * Checks if a list cache value for `key` exists.
    	     *
    	     * @private
    	     * @name has
    	     * @memberOf ListCache
    	     * @param {string} key The key of the entry to check.
    	     * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
    	     */function listCacheHas(key){return assocIndexOf(this.__data__,key)>-1;}/**
    	     * Sets the list cache `key` to `value`.
    	     *
    	     * @private
    	     * @name set
    	     * @memberOf ListCache
    	     * @param {string} key The key of the value to set.
    	     * @param {*} value The value to set.
    	     * @returns {Object} Returns the list cache instance.
    	     */function listCacheSet(key,value){var data=this.__data__,index=assocIndexOf(data,key);if(index<0){++this.size;data.push([key,value]);}else {data[index][1]=value;}return this;}// Add methods to `ListCache`.
    	ListCache.prototype.clear=listCacheClear;ListCache.prototype['delete']=listCacheDelete;ListCache.prototype.get=listCacheGet;ListCache.prototype.has=listCacheHas;ListCache.prototype.set=listCacheSet;/*------------------------------------------------------------------------*/ /**
    	     * Creates a map cache object to store key-value pairs.
    	     *
    	     * @private
    	     * @constructor
    	     * @param {Array} [entries] The key-value pairs to cache.
    	     */function MapCache(entries){var index=-1,length=entries==null?0:entries.length;this.clear();while(++index<length){var entry=entries[index];this.set(entry[0],entry[1]);}}/**
    	     * Removes all key-value entries from the map.
    	     *
    	     * @private
    	     * @name clear
    	     * @memberOf MapCache
    	     */function mapCacheClear(){this.size=0;this.__data__={'hash':new Hash(),'map':new(Map||ListCache)(),'string':new Hash()};}/**
    	     * Removes `key` and its value from the map.
    	     *
    	     * @private
    	     * @name delete
    	     * @memberOf MapCache
    	     * @param {string} key The key of the value to remove.
    	     * @returns {boolean} Returns `true` if the entry was removed, else `false`.
    	     */function mapCacheDelete(key){var result=getMapData(this,key)['delete'](key);this.size-=result?1:0;return result;}/**
    	     * Gets the map value for `key`.
    	     *
    	     * @private
    	     * @name get
    	     * @memberOf MapCache
    	     * @param {string} key The key of the value to get.
    	     * @returns {*} Returns the entry value.
    	     */function mapCacheGet(key){return getMapData(this,key).get(key);}/**
    	     * Checks if a map value for `key` exists.
    	     *
    	     * @private
    	     * @name has
    	     * @memberOf MapCache
    	     * @param {string} key The key of the entry to check.
    	     * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
    	     */function mapCacheHas(key){return getMapData(this,key).has(key);}/**
    	     * Sets the map `key` to `value`.
    	     *
    	     * @private
    	     * @name set
    	     * @memberOf MapCache
    	     * @param {string} key The key of the value to set.
    	     * @param {*} value The value to set.
    	     * @returns {Object} Returns the map cache instance.
    	     */function mapCacheSet(key,value){var data=getMapData(this,key),size=data.size;data.set(key,value);this.size+=data.size==size?0:1;return this;}// Add methods to `MapCache`.
    	MapCache.prototype.clear=mapCacheClear;MapCache.prototype['delete']=mapCacheDelete;MapCache.prototype.get=mapCacheGet;MapCache.prototype.has=mapCacheHas;MapCache.prototype.set=mapCacheSet;/*------------------------------------------------------------------------*/ /**
    	     *
    	     * Creates an array cache object to store unique values.
    	     *
    	     * @private
    	     * @constructor
    	     * @param {Array} [values] The values to cache.
    	     */function SetCache(values){var index=-1,length=values==null?0:values.length;this.__data__=new MapCache();while(++index<length){this.add(values[index]);}}/**
    	     * Adds `value` to the array cache.
    	     *
    	     * @private
    	     * @name add
    	     * @memberOf SetCache
    	     * @alias push
    	     * @param {*} value The value to cache.
    	     * @returns {Object} Returns the cache instance.
    	     */function setCacheAdd(value){this.__data__.set(value,HASH_UNDEFINED);return this;}/**
    	     * Checks if `value` is in the array cache.
    	     *
    	     * @private
    	     * @name has
    	     * @memberOf SetCache
    	     * @param {*} value The value to search for.
    	     * @returns {number} Returns `true` if `value` is found, else `false`.
    	     */function setCacheHas(value){return this.__data__.has(value);}// Add methods to `SetCache`.
    	SetCache.prototype.add=SetCache.prototype.push=setCacheAdd;SetCache.prototype.has=setCacheHas;/*------------------------------------------------------------------------*/ /**
    	     * Creates a stack cache object to store key-value pairs.
    	     *
    	     * @private
    	     * @constructor
    	     * @param {Array} [entries] The key-value pairs to cache.
    	     */function Stack(entries){var data=this.__data__=new ListCache(entries);this.size=data.size;}/**
    	     * Removes all key-value entries from the stack.
    	     *
    	     * @private
    	     * @name clear
    	     * @memberOf Stack
    	     */function stackClear(){this.__data__=new ListCache();this.size=0;}/**
    	     * Removes `key` and its value from the stack.
    	     *
    	     * @private
    	     * @name delete
    	     * @memberOf Stack
    	     * @param {string} key The key of the value to remove.
    	     * @returns {boolean} Returns `true` if the entry was removed, else `false`.
    	     */function stackDelete(key){var data=this.__data__,result=data['delete'](key);this.size=data.size;return result;}/**
    	     * Gets the stack value for `key`.
    	     *
    	     * @private
    	     * @name get
    	     * @memberOf Stack
    	     * @param {string} key The key of the value to get.
    	     * @returns {*} Returns the entry value.
    	     */function stackGet(key){return this.__data__.get(key);}/**
    	     * Checks if a stack value for `key` exists.
    	     *
    	     * @private
    	     * @name has
    	     * @memberOf Stack
    	     * @param {string} key The key of the entry to check.
    	     * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
    	     */function stackHas(key){return this.__data__.has(key);}/**
    	     * Sets the stack `key` to `value`.
    	     *
    	     * @private
    	     * @name set
    	     * @memberOf Stack
    	     * @param {string} key The key of the value to set.
    	     * @param {*} value The value to set.
    	     * @returns {Object} Returns the stack cache instance.
    	     */function stackSet(key,value){var data=this.__data__;if(data instanceof ListCache){var pairs=data.__data__;if(!Map||pairs.length<LARGE_ARRAY_SIZE-1){pairs.push([key,value]);this.size=++data.size;return this;}data=this.__data__=new MapCache(pairs);}data.set(key,value);this.size=data.size;return this;}// Add methods to `Stack`.
    	Stack.prototype.clear=stackClear;Stack.prototype['delete']=stackDelete;Stack.prototype.get=stackGet;Stack.prototype.has=stackHas;Stack.prototype.set=stackSet;/*------------------------------------------------------------------------*/ /**
    	     * Creates an array of the enumerable property names of the array-like `value`.
    	     *
    	     * @private
    	     * @param {*} value The value to query.
    	     * @param {boolean} inherited Specify returning inherited property names.
    	     * @returns {Array} Returns the array of property names.
    	     */function arrayLikeKeys(value,inherited){var isArr=isArray(value),isArg=!isArr&&isArguments(value),isBuff=!isArr&&!isArg&&isBuffer(value),isType=!isArr&&!isArg&&!isBuff&&isTypedArray(value),skipIndexes=isArr||isArg||isBuff||isType,result=skipIndexes?baseTimes(value.length,String):[],length=result.length;for(var key in value){if((inherited||hasOwnProperty.call(value,key))&&!(skipIndexes&&(// Safari 9 has enumerable `arguments.length` in strict mode.
    	key=='length'||// Node.js 0.10 has enumerable non-index properties on buffers.
    	isBuff&&(key=='offset'||key=='parent')||// PhantomJS 2 has enumerable non-index properties on typed arrays.
    	isType&&(key=='buffer'||key=='byteLength'||key=='byteOffset')||// Skip index properties.
    	isIndex(key,length)))){result.push(key);}}return result;}/**
    	     * A specialized version of `_.sample` for arrays.
    	     *
    	     * @private
    	     * @param {Array} array The array to sample.
    	     * @returns {*} Returns the random element.
    	     */function arraySample(array){var length=array.length;return length?array[baseRandom(0,length-1)]:undefined$1;}/**
    	     * A specialized version of `_.sampleSize` for arrays.
    	     *
    	     * @private
    	     * @param {Array} array The array to sample.
    	     * @param {number} n The number of elements to sample.
    	     * @returns {Array} Returns the random elements.
    	     */function arraySampleSize(array,n){return shuffleSelf(copyArray(array),baseClamp(n,0,array.length));}/**
    	     * A specialized version of `_.shuffle` for arrays.
    	     *
    	     * @private
    	     * @param {Array} array The array to shuffle.
    	     * @returns {Array} Returns the new shuffled array.
    	     */function arrayShuffle(array){return shuffleSelf(copyArray(array));}/**
    	     * This function is like `assignValue` except that it doesn't assign
    	     * `undefined` values.
    	     *
    	     * @private
    	     * @param {Object} object The object to modify.
    	     * @param {string} key The key of the property to assign.
    	     * @param {*} value The value to assign.
    	     */function assignMergeValue(object,key,value){if(value!==undefined$1&&!eq(object[key],value)||value===undefined$1&&!(key in object)){baseAssignValue(object,key,value);}}/**
    	     * Assigns `value` to `key` of `object` if the existing value is not equivalent
    	     * using [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
    	     * for equality comparisons.
    	     *
    	     * @private
    	     * @param {Object} object The object to modify.
    	     * @param {string} key The key of the property to assign.
    	     * @param {*} value The value to assign.
    	     */function assignValue(object,key,value){var objValue=object[key];if(!(hasOwnProperty.call(object,key)&&eq(objValue,value))||value===undefined$1&&!(key in object)){baseAssignValue(object,key,value);}}/**
    	     * Gets the index at which the `key` is found in `array` of key-value pairs.
    	     *
    	     * @private
    	     * @param {Array} array The array to inspect.
    	     * @param {*} key The key to search for.
    	     * @returns {number} Returns the index of the matched value, else `-1`.
    	     */function assocIndexOf(array,key){var length=array.length;while(length--){if(eq(array[length][0],key)){return length;}}return -1;}/**
    	     * Aggregates elements of `collection` on `accumulator` with keys transformed
    	     * by `iteratee` and values set by `setter`.
    	     *
    	     * @private
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Function} setter The function to set `accumulator` values.
    	     * @param {Function} iteratee The iteratee to transform keys.
    	     * @param {Object} accumulator The initial aggregated object.
    	     * @returns {Function} Returns `accumulator`.
    	     */function baseAggregator(collection,setter,iteratee,accumulator){baseEach(collection,function(value,key,collection){setter(accumulator,value,iteratee(value),collection);});return accumulator;}/**
    	     * The base implementation of `_.assign` without support for multiple sources
    	     * or `customizer` functions.
    	     *
    	     * @private
    	     * @param {Object} object The destination object.
    	     * @param {Object} source The source object.
    	     * @returns {Object} Returns `object`.
    	     */function baseAssign(object,source){return object&&copyObject(source,keys(source),object);}/**
    	     * The base implementation of `_.assignIn` without support for multiple sources
    	     * or `customizer` functions.
    	     *
    	     * @private
    	     * @param {Object} object The destination object.
    	     * @param {Object} source The source object.
    	     * @returns {Object} Returns `object`.
    	     */function baseAssignIn(object,source){return object&&copyObject(source,keysIn(source),object);}/**
    	     * The base implementation of `assignValue` and `assignMergeValue` without
    	     * value checks.
    	     *
    	     * @private
    	     * @param {Object} object The object to modify.
    	     * @param {string} key The key of the property to assign.
    	     * @param {*} value The value to assign.
    	     */function baseAssignValue(object,key,value){if(key=='__proto__'&&defineProperty){defineProperty(object,key,{'configurable':true,'enumerable':true,'value':value,'writable':true});}else {object[key]=value;}}/**
    	     * The base implementation of `_.at` without support for individual paths.
    	     *
    	     * @private
    	     * @param {Object} object The object to iterate over.
    	     * @param {string[]} paths The property paths to pick.
    	     * @returns {Array} Returns the picked elements.
    	     */function baseAt(object,paths){var index=-1,length=paths.length,result=Array(length),skip=object==null;while(++index<length){result[index]=skip?undefined$1:get(object,paths[index]);}return result;}/**
    	     * The base implementation of `_.clamp` which doesn't coerce arguments.
    	     *
    	     * @private
    	     * @param {number} number The number to clamp.
    	     * @param {number} [lower] The lower bound.
    	     * @param {number} upper The upper bound.
    	     * @returns {number} Returns the clamped number.
    	     */function baseClamp(number,lower,upper){if(number===number){if(upper!==undefined$1){number=number<=upper?number:upper;}if(lower!==undefined$1){number=number>=lower?number:lower;}}return number;}/**
    	     * The base implementation of `_.clone` and `_.cloneDeep` which tracks
    	     * traversed objects.
    	     *
    	     * @private
    	     * @param {*} value The value to clone.
    	     * @param {boolean} bitmask The bitmask flags.
    	     *  1 - Deep clone
    	     *  2 - Flatten inherited properties
    	     *  4 - Clone symbols
    	     * @param {Function} [customizer] The function to customize cloning.
    	     * @param {string} [key] The key of `value`.
    	     * @param {Object} [object] The parent object of `value`.
    	     * @param {Object} [stack] Tracks traversed objects and their clone counterparts.
    	     * @returns {*} Returns the cloned value.
    	     */function baseClone(value,bitmask,customizer,key,object,stack){var result,isDeep=bitmask&CLONE_DEEP_FLAG,isFlat=bitmask&CLONE_FLAT_FLAG,isFull=bitmask&CLONE_SYMBOLS_FLAG;if(customizer){result=object?customizer(value,key,object,stack):customizer(value);}if(result!==undefined$1){return result;}if(!isObject(value)){return value;}var isArr=isArray(value);if(isArr){result=initCloneArray(value);if(!isDeep){return copyArray(value,result);}}else {var tag=getTag(value),isFunc=tag==funcTag||tag==genTag;if(isBuffer(value)){return cloneBuffer(value,isDeep);}if(tag==objectTag||tag==argsTag||isFunc&&!object){result=isFlat||isFunc?{}:initCloneObject(value);if(!isDeep){return isFlat?copySymbolsIn(value,baseAssignIn(result,value)):copySymbols(value,baseAssign(result,value));}}else {if(!cloneableTags[tag]){return object?value:{};}result=initCloneByTag(value,tag,isDeep);}}// Check for circular references and return its corresponding clone.
    	stack||(stack=new Stack());var stacked=stack.get(value);if(stacked){return stacked;}stack.set(value,result);if(isSet(value)){value.forEach(function(subValue){result.add(baseClone(subValue,bitmask,customizer,subValue,value,stack));});}else if(isMap(value)){value.forEach(function(subValue,key){result.set(key,baseClone(subValue,bitmask,customizer,key,value,stack));});}var keysFunc=isFull?isFlat?getAllKeysIn:getAllKeys:isFlat?keysIn:keys;var props=isArr?undefined$1:keysFunc(value);arrayEach(props||value,function(subValue,key){if(props){key=subValue;subValue=value[key];}// Recursively populate clone (susceptible to call stack limits).
    	assignValue(result,key,baseClone(subValue,bitmask,customizer,key,value,stack));});return result;}/**
    	     * The base implementation of `_.conforms` which doesn't clone `source`.
    	     *
    	     * @private
    	     * @param {Object} source The object of property predicates to conform to.
    	     * @returns {Function} Returns the new spec function.
    	     */function baseConforms(source){var props=keys(source);return function(object){return baseConformsTo(object,source,props);};}/**
    	     * The base implementation of `_.conformsTo` which accepts `props` to check.
    	     *
    	     * @private
    	     * @param {Object} object The object to inspect.
    	     * @param {Object} source The object of property predicates to conform to.
    	     * @returns {boolean} Returns `true` if `object` conforms, else `false`.
    	     */function baseConformsTo(object,source,props){var length=props.length;if(object==null){return !length;}object=Object(object);while(length--){var key=props[length],predicate=source[key],value=object[key];if(value===undefined$1&&!(key in object)||!predicate(value)){return false;}}return true;}/**
    	     * The base implementation of `_.delay` and `_.defer` which accepts `args`
    	     * to provide to `func`.
    	     *
    	     * @private
    	     * @param {Function} func The function to delay.
    	     * @param {number} wait The number of milliseconds to delay invocation.
    	     * @param {Array} args The arguments to provide to `func`.
    	     * @returns {number|Object} Returns the timer id or timeout object.
    	     */function baseDelay(func,wait,args){if(typeof func!='function'){throw new TypeError(FUNC_ERROR_TEXT);}return setTimeout(function(){func.apply(undefined$1,args);},wait);}/**
    	     * The base implementation of methods like `_.difference` without support
    	     * for excluding multiple arrays or iteratee shorthands.
    	     *
    	     * @private
    	     * @param {Array} array The array to inspect.
    	     * @param {Array} values The values to exclude.
    	     * @param {Function} [iteratee] The iteratee invoked per element.
    	     * @param {Function} [comparator] The comparator invoked per element.
    	     * @returns {Array} Returns the new array of filtered values.
    	     */function baseDifference(array,values,iteratee,comparator){var index=-1,includes=arrayIncludes,isCommon=true,length=array.length,result=[],valuesLength=values.length;if(!length){return result;}if(iteratee){values=arrayMap(values,baseUnary(iteratee));}if(comparator){includes=arrayIncludesWith;isCommon=false;}else if(values.length>=LARGE_ARRAY_SIZE){includes=cacheHas;isCommon=false;values=new SetCache(values);}outer:while(++index<length){var value=array[index],computed=iteratee==null?value:iteratee(value);value=comparator||value!==0?value:0;if(isCommon&&computed===computed){var valuesIndex=valuesLength;while(valuesIndex--){if(values[valuesIndex]===computed){continue outer;}}result.push(value);}else if(!includes(values,computed,comparator)){result.push(value);}}return result;}/**
    	     * The base implementation of `_.forEach` without support for iteratee shorthands.
    	     *
    	     * @private
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Function} iteratee The function invoked per iteration.
    	     * @returns {Array|Object} Returns `collection`.
    	     */var baseEach=createBaseEach(baseForOwn);/**
    	     * The base implementation of `_.forEachRight` without support for iteratee shorthands.
    	     *
    	     * @private
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Function} iteratee The function invoked per iteration.
    	     * @returns {Array|Object} Returns `collection`.
    	     */var baseEachRight=createBaseEach(baseForOwnRight,true);/**
    	     * The base implementation of `_.every` without support for iteratee shorthands.
    	     *
    	     * @private
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Function} predicate The function invoked per iteration.
    	     * @returns {boolean} Returns `true` if all elements pass the predicate check,
    	     *  else `false`
    	     */function baseEvery(collection,predicate){var result=true;baseEach(collection,function(value,index,collection){result=!!predicate(value,index,collection);return result;});return result;}/**
    	     * The base implementation of methods like `_.max` and `_.min` which accepts a
    	     * `comparator` to determine the extremum value.
    	     *
    	     * @private
    	     * @param {Array} array The array to iterate over.
    	     * @param {Function} iteratee The iteratee invoked per iteration.
    	     * @param {Function} comparator The comparator used to compare values.
    	     * @returns {*} Returns the extremum value.
    	     */function baseExtremum(array,iteratee,comparator){var index=-1,length=array.length;while(++index<length){var value=array[index],current=iteratee(value);if(current!=null&&(computed===undefined$1?current===current&&!isSymbol(current):comparator(current,computed))){var computed=current,result=value;}}return result;}/**
    	     * The base implementation of `_.fill` without an iteratee call guard.
    	     *
    	     * @private
    	     * @param {Array} array The array to fill.
    	     * @param {*} value The value to fill `array` with.
    	     * @param {number} [start=0] The start position.
    	     * @param {number} [end=array.length] The end position.
    	     * @returns {Array} Returns `array`.
    	     */function baseFill(array,value,start,end){var length=array.length;start=toInteger(start);if(start<0){start=-start>length?0:length+start;}end=end===undefined$1||end>length?length:toInteger(end);if(end<0){end+=length;}end=start>end?0:toLength(end);while(start<end){array[start++]=value;}return array;}/**
    	     * The base implementation of `_.filter` without support for iteratee shorthands.
    	     *
    	     * @private
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Function} predicate The function invoked per iteration.
    	     * @returns {Array} Returns the new filtered array.
    	     */function baseFilter(collection,predicate){var result=[];baseEach(collection,function(value,index,collection){if(predicate(value,index,collection)){result.push(value);}});return result;}/**
    	     * The base implementation of `_.flatten` with support for restricting flattening.
    	     *
    	     * @private
    	     * @param {Array} array The array to flatten.
    	     * @param {number} depth The maximum recursion depth.
    	     * @param {boolean} [predicate=isFlattenable] The function invoked per iteration.
    	     * @param {boolean} [isStrict] Restrict to values that pass `predicate` checks.
    	     * @param {Array} [result=[]] The initial result value.
    	     * @returns {Array} Returns the new flattened array.
    	     */function baseFlatten(array,depth,predicate,isStrict,result){var index=-1,length=array.length;predicate||(predicate=isFlattenable);result||(result=[]);while(++index<length){var value=array[index];if(depth>0&&predicate(value)){if(depth>1){// Recursively flatten arrays (susceptible to call stack limits).
    	baseFlatten(value,depth-1,predicate,isStrict,result);}else {arrayPush(result,value);}}else if(!isStrict){result[result.length]=value;}}return result;}/**
    	     * The base implementation of `baseForOwn` which iterates over `object`
    	     * properties returned by `keysFunc` and invokes `iteratee` for each property.
    	     * Iteratee functions may exit iteration early by explicitly returning `false`.
    	     *
    	     * @private
    	     * @param {Object} object The object to iterate over.
    	     * @param {Function} iteratee The function invoked per iteration.
    	     * @param {Function} keysFunc The function to get the keys of `object`.
    	     * @returns {Object} Returns `object`.
    	     */var baseFor=createBaseFor();/**
    	     * This function is like `baseFor` except that it iterates over properties
    	     * in the opposite order.
    	     *
    	     * @private
    	     * @param {Object} object The object to iterate over.
    	     * @param {Function} iteratee The function invoked per iteration.
    	     * @param {Function} keysFunc The function to get the keys of `object`.
    	     * @returns {Object} Returns `object`.
    	     */var baseForRight=createBaseFor(true);/**
    	     * The base implementation of `_.forOwn` without support for iteratee shorthands.
    	     *
    	     * @private
    	     * @param {Object} object The object to iterate over.
    	     * @param {Function} iteratee The function invoked per iteration.
    	     * @returns {Object} Returns `object`.
    	     */function baseForOwn(object,iteratee){return object&&baseFor(object,iteratee,keys);}/**
    	     * The base implementation of `_.forOwnRight` without support for iteratee shorthands.
    	     *
    	     * @private
    	     * @param {Object} object The object to iterate over.
    	     * @param {Function} iteratee The function invoked per iteration.
    	     * @returns {Object} Returns `object`.
    	     */function baseForOwnRight(object,iteratee){return object&&baseForRight(object,iteratee,keys);}/**
    	     * The base implementation of `_.functions` which creates an array of
    	     * `object` function property names filtered from `props`.
    	     *
    	     * @private
    	     * @param {Object} object The object to inspect.
    	     * @param {Array} props The property names to filter.
    	     * @returns {Array} Returns the function names.
    	     */function baseFunctions(object,props){return arrayFilter(props,function(key){return isFunction(object[key]);});}/**
    	     * The base implementation of `_.get` without support for default values.
    	     *
    	     * @private
    	     * @param {Object} object The object to query.
    	     * @param {Array|string} path The path of the property to get.
    	     * @returns {*} Returns the resolved value.
    	     */function baseGet(object,path){path=castPath(path,object);var index=0,length=path.length;while(object!=null&&index<length){object=object[toKey(path[index++])];}return index&&index==length?object:undefined$1;}/**
    	     * The base implementation of `getAllKeys` and `getAllKeysIn` which uses
    	     * `keysFunc` and `symbolsFunc` to get the enumerable property names and
    	     * symbols of `object`.
    	     *
    	     * @private
    	     * @param {Object} object The object to query.
    	     * @param {Function} keysFunc The function to get the keys of `object`.
    	     * @param {Function} symbolsFunc The function to get the symbols of `object`.
    	     * @returns {Array} Returns the array of property names and symbols.
    	     */function baseGetAllKeys(object,keysFunc,symbolsFunc){var result=keysFunc(object);return isArray(object)?result:arrayPush(result,symbolsFunc(object));}/**
    	     * The base implementation of `getTag` without fallbacks for buggy environments.
    	     *
    	     * @private
    	     * @param {*} value The value to query.
    	     * @returns {string} Returns the `toStringTag`.
    	     */function baseGetTag(value){if(value==null){return value===undefined$1?undefinedTag:nullTag;}return symToStringTag&&symToStringTag in Object(value)?getRawTag(value):objectToString(value);}/**
    	     * The base implementation of `_.gt` which doesn't coerce arguments.
    	     *
    	     * @private
    	     * @param {*} value The value to compare.
    	     * @param {*} other The other value to compare.
    	     * @returns {boolean} Returns `true` if `value` is greater than `other`,
    	     *  else `false`.
    	     */function baseGt(value,other){return value>other;}/**
    	     * The base implementation of `_.has` without support for deep paths.
    	     *
    	     * @private
    	     * @param {Object} [object] The object to query.
    	     * @param {Array|string} key The key to check.
    	     * @returns {boolean} Returns `true` if `key` exists, else `false`.
    	     */function baseHas(object,key){return object!=null&&hasOwnProperty.call(object,key);}/**
    	     * The base implementation of `_.hasIn` without support for deep paths.
    	     *
    	     * @private
    	     * @param {Object} [object] The object to query.
    	     * @param {Array|string} key The key to check.
    	     * @returns {boolean} Returns `true` if `key` exists, else `false`.
    	     */function baseHasIn(object,key){return object!=null&&key in Object(object);}/**
    	     * The base implementation of `_.inRange` which doesn't coerce arguments.
    	     *
    	     * @private
    	     * @param {number} number The number to check.
    	     * @param {number} start The start of the range.
    	     * @param {number} end The end of the range.
    	     * @returns {boolean} Returns `true` if `number` is in the range, else `false`.
    	     */function baseInRange(number,start,end){return number>=nativeMin(start,end)&&number<nativeMax(start,end);}/**
    	     * The base implementation of methods like `_.intersection`, without support
    	     * for iteratee shorthands, that accepts an array of arrays to inspect.
    	     *
    	     * @private
    	     * @param {Array} arrays The arrays to inspect.
    	     * @param {Function} [iteratee] The iteratee invoked per element.
    	     * @param {Function} [comparator] The comparator invoked per element.
    	     * @returns {Array} Returns the new array of shared values.
    	     */function baseIntersection(arrays,iteratee,comparator){var includes=comparator?arrayIncludesWith:arrayIncludes,length=arrays[0].length,othLength=arrays.length,othIndex=othLength,caches=Array(othLength),maxLength=Infinity,result=[];while(othIndex--){var array=arrays[othIndex];if(othIndex&&iteratee){array=arrayMap(array,baseUnary(iteratee));}maxLength=nativeMin(array.length,maxLength);caches[othIndex]=!comparator&&(iteratee||length>=120&&array.length>=120)?new SetCache(othIndex&&array):undefined$1;}array=arrays[0];var index=-1,seen=caches[0];outer:while(++index<length&&result.length<maxLength){var value=array[index],computed=iteratee?iteratee(value):value;value=comparator||value!==0?value:0;if(!(seen?cacheHas(seen,computed):includes(result,computed,comparator))){othIndex=othLength;while(--othIndex){var cache=caches[othIndex];if(!(cache?cacheHas(cache,computed):includes(arrays[othIndex],computed,comparator))){continue outer;}}if(seen){seen.push(computed);}result.push(value);}}return result;}/**
    	     * The base implementation of `_.invert` and `_.invertBy` which inverts
    	     * `object` with values transformed by `iteratee` and set by `setter`.
    	     *
    	     * @private
    	     * @param {Object} object The object to iterate over.
    	     * @param {Function} setter The function to set `accumulator` values.
    	     * @param {Function} iteratee The iteratee to transform values.
    	     * @param {Object} accumulator The initial inverted object.
    	     * @returns {Function} Returns `accumulator`.
    	     */function baseInverter(object,setter,iteratee,accumulator){baseForOwn(object,function(value,key,object){setter(accumulator,iteratee(value),key,object);});return accumulator;}/**
    	     * The base implementation of `_.invoke` without support for individual
    	     * method arguments.
    	     *
    	     * @private
    	     * @param {Object} object The object to query.
    	     * @param {Array|string} path The path of the method to invoke.
    	     * @param {Array} args The arguments to invoke the method with.
    	     * @returns {*} Returns the result of the invoked method.
    	     */function baseInvoke(object,path,args){path=castPath(path,object);object=parent(object,path);var func=object==null?object:object[toKey(last(path))];return func==null?undefined$1:apply(func,object,args);}/**
    	     * The base implementation of `_.isArguments`.
    	     *
    	     * @private
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is an `arguments` object,
    	     */function baseIsArguments(value){return isObjectLike(value)&&baseGetTag(value)==argsTag;}/**
    	     * The base implementation of `_.isArrayBuffer` without Node.js optimizations.
    	     *
    	     * @private
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is an array buffer, else `false`.
    	     */function baseIsArrayBuffer(value){return isObjectLike(value)&&baseGetTag(value)==arrayBufferTag;}/**
    	     * The base implementation of `_.isDate` without Node.js optimizations.
    	     *
    	     * @private
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a date object, else `false`.
    	     */function baseIsDate(value){return isObjectLike(value)&&baseGetTag(value)==dateTag;}/**
    	     * The base implementation of `_.isEqual` which supports partial comparisons
    	     * and tracks traversed objects.
    	     *
    	     * @private
    	     * @param {*} value The value to compare.
    	     * @param {*} other The other value to compare.
    	     * @param {boolean} bitmask The bitmask flags.
    	     *  1 - Unordered comparison
    	     *  2 - Partial comparison
    	     * @param {Function} [customizer] The function to customize comparisons.
    	     * @param {Object} [stack] Tracks traversed `value` and `other` objects.
    	     * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
    	     */function baseIsEqual(value,other,bitmask,customizer,stack){if(value===other){return true;}if(value==null||other==null||!isObjectLike(value)&&!isObjectLike(other)){return value!==value&&other!==other;}return baseIsEqualDeep(value,other,bitmask,customizer,baseIsEqual,stack);}/**
    	     * A specialized version of `baseIsEqual` for arrays and objects which performs
    	     * deep comparisons and tracks traversed objects enabling objects with circular
    	     * references to be compared.
    	     *
    	     * @private
    	     * @param {Object} object The object to compare.
    	     * @param {Object} other The other object to compare.
    	     * @param {number} bitmask The bitmask flags. See `baseIsEqual` for more details.
    	     * @param {Function} customizer The function to customize comparisons.
    	     * @param {Function} equalFunc The function to determine equivalents of values.
    	     * @param {Object} [stack] Tracks traversed `object` and `other` objects.
    	     * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
    	     */function baseIsEqualDeep(object,other,bitmask,customizer,equalFunc,stack){var objIsArr=isArray(object),othIsArr=isArray(other),objTag=objIsArr?arrayTag:getTag(object),othTag=othIsArr?arrayTag:getTag(other);objTag=objTag==argsTag?objectTag:objTag;othTag=othTag==argsTag?objectTag:othTag;var objIsObj=objTag==objectTag,othIsObj=othTag==objectTag,isSameTag=objTag==othTag;if(isSameTag&&isBuffer(object)){if(!isBuffer(other)){return false;}objIsArr=true;objIsObj=false;}if(isSameTag&&!objIsObj){stack||(stack=new Stack());return objIsArr||isTypedArray(object)?equalArrays(object,other,bitmask,customizer,equalFunc,stack):equalByTag(object,other,objTag,bitmask,customizer,equalFunc,stack);}if(!(bitmask&COMPARE_PARTIAL_FLAG)){var objIsWrapped=objIsObj&&hasOwnProperty.call(object,'__wrapped__'),othIsWrapped=othIsObj&&hasOwnProperty.call(other,'__wrapped__');if(objIsWrapped||othIsWrapped){var objUnwrapped=objIsWrapped?object.value():object,othUnwrapped=othIsWrapped?other.value():other;stack||(stack=new Stack());return equalFunc(objUnwrapped,othUnwrapped,bitmask,customizer,stack);}}if(!isSameTag){return false;}stack||(stack=new Stack());return equalObjects(object,other,bitmask,customizer,equalFunc,stack);}/**
    	     * The base implementation of `_.isMap` without Node.js optimizations.
    	     *
    	     * @private
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a map, else `false`.
    	     */function baseIsMap(value){return isObjectLike(value)&&getTag(value)==mapTag;}/**
    	     * The base implementation of `_.isMatch` without support for iteratee shorthands.
    	     *
    	     * @private
    	     * @param {Object} object The object to inspect.
    	     * @param {Object} source The object of property values to match.
    	     * @param {Array} matchData The property names, values, and compare flags to match.
    	     * @param {Function} [customizer] The function to customize comparisons.
    	     * @returns {boolean} Returns `true` if `object` is a match, else `false`.
    	     */function baseIsMatch(object,source,matchData,customizer){var index=matchData.length,length=index,noCustomizer=!customizer;if(object==null){return !length;}object=Object(object);while(index--){var data=matchData[index];if(noCustomizer&&data[2]?data[1]!==object[data[0]]:!(data[0]in object)){return false;}}while(++index<length){data=matchData[index];var key=data[0],objValue=object[key],srcValue=data[1];if(noCustomizer&&data[2]){if(objValue===undefined$1&&!(key in object)){return false;}}else {var stack=new Stack();if(customizer){var result=customizer(objValue,srcValue,key,object,source,stack);}if(!(result===undefined$1?baseIsEqual(srcValue,objValue,COMPARE_PARTIAL_FLAG|COMPARE_UNORDERED_FLAG,customizer,stack):result)){return false;}}}return true;}/**
    	     * The base implementation of `_.isNative` without bad shim checks.
    	     *
    	     * @private
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a native function,
    	     *  else `false`.
    	     */function baseIsNative(value){if(!isObject(value)||isMasked(value)){return false;}var pattern=isFunction(value)?reIsNative:reIsHostCtor;return pattern.test(toSource(value));}/**
    	     * The base implementation of `_.isRegExp` without Node.js optimizations.
    	     *
    	     * @private
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a regexp, else `false`.
    	     */function baseIsRegExp(value){return isObjectLike(value)&&baseGetTag(value)==regexpTag;}/**
    	     * The base implementation of `_.isSet` without Node.js optimizations.
    	     *
    	     * @private
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a set, else `false`.
    	     */function baseIsSet(value){return isObjectLike(value)&&getTag(value)==setTag;}/**
    	     * The base implementation of `_.isTypedArray` without Node.js optimizations.
    	     *
    	     * @private
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a typed array, else `false`.
    	     */function baseIsTypedArray(value){return isObjectLike(value)&&isLength(value.length)&&!!typedArrayTags[baseGetTag(value)];}/**
    	     * The base implementation of `_.iteratee`.
    	     *
    	     * @private
    	     * @param {*} [value=_.identity] The value to convert to an iteratee.
    	     * @returns {Function} Returns the iteratee.
    	     */function baseIteratee(value){// Don't store the `typeof` result in a variable to avoid a JIT bug in Safari 9.
    	// See https://bugs.webkit.org/show_bug.cgi?id=156034 for more details.
    	if(typeof value=='function'){return value;}if(value==null){return identity;}if(typeof value=='object'){return isArray(value)?baseMatchesProperty(value[0],value[1]):baseMatches(value);}return property(value);}/**
    	     * The base implementation of `_.keys` which doesn't treat sparse arrays as dense.
    	     *
    	     * @private
    	     * @param {Object} object The object to query.
    	     * @returns {Array} Returns the array of property names.
    	     */function baseKeys(object){if(!isPrototype(object)){return nativeKeys(object);}var result=[];for(var key in Object(object)){if(hasOwnProperty.call(object,key)&&key!='constructor'){result.push(key);}}return result;}/**
    	     * The base implementation of `_.keysIn` which doesn't treat sparse arrays as dense.
    	     *
    	     * @private
    	     * @param {Object} object The object to query.
    	     * @returns {Array} Returns the array of property names.
    	     */function baseKeysIn(object){if(!isObject(object)){return nativeKeysIn(object);}var isProto=isPrototype(object),result=[];for(var key in object){if(!(key=='constructor'&&(isProto||!hasOwnProperty.call(object,key)))){result.push(key);}}return result;}/**
    	     * The base implementation of `_.lt` which doesn't coerce arguments.
    	     *
    	     * @private
    	     * @param {*} value The value to compare.
    	     * @param {*} other The other value to compare.
    	     * @returns {boolean} Returns `true` if `value` is less than `other`,
    	     *  else `false`.
    	     */function baseLt(value,other){return value<other;}/**
    	     * The base implementation of `_.map` without support for iteratee shorthands.
    	     *
    	     * @private
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Function} iteratee The function invoked per iteration.
    	     * @returns {Array} Returns the new mapped array.
    	     */function baseMap(collection,iteratee){var index=-1,result=isArrayLike(collection)?Array(collection.length):[];baseEach(collection,function(value,key,collection){result[++index]=iteratee(value,key,collection);});return result;}/**
    	     * The base implementation of `_.matches` which doesn't clone `source`.
    	     *
    	     * @private
    	     * @param {Object} source The object of property values to match.
    	     * @returns {Function} Returns the new spec function.
    	     */function baseMatches(source){var matchData=getMatchData(source);if(matchData.length==1&&matchData[0][2]){return matchesStrictComparable(matchData[0][0],matchData[0][1]);}return function(object){return object===source||baseIsMatch(object,source,matchData);};}/**
    	     * The base implementation of `_.matchesProperty` which doesn't clone `srcValue`.
    	     *
    	     * @private
    	     * @param {string} path The path of the property to get.
    	     * @param {*} srcValue The value to match.
    	     * @returns {Function} Returns the new spec function.
    	     */function baseMatchesProperty(path,srcValue){if(isKey(path)&&isStrictComparable(srcValue)){return matchesStrictComparable(toKey(path),srcValue);}return function(object){var objValue=get(object,path);return objValue===undefined$1&&objValue===srcValue?hasIn(object,path):baseIsEqual(srcValue,objValue,COMPARE_PARTIAL_FLAG|COMPARE_UNORDERED_FLAG);};}/**
    	     * The base implementation of `_.merge` without support for multiple sources.
    	     *
    	     * @private
    	     * @param {Object} object The destination object.
    	     * @param {Object} source The source object.
    	     * @param {number} srcIndex The index of `source`.
    	     * @param {Function} [customizer] The function to customize merged values.
    	     * @param {Object} [stack] Tracks traversed source values and their merged
    	     *  counterparts.
    	     */function baseMerge(object,source,srcIndex,customizer,stack){if(object===source){return;}baseFor(source,function(srcValue,key){stack||(stack=new Stack());if(isObject(srcValue)){baseMergeDeep(object,source,key,srcIndex,baseMerge,customizer,stack);}else {var newValue=customizer?customizer(safeGet(object,key),srcValue,key+'',object,source,stack):undefined$1;if(newValue===undefined$1){newValue=srcValue;}assignMergeValue(object,key,newValue);}},keysIn);}/**
    	     * A specialized version of `baseMerge` for arrays and objects which performs
    	     * deep merges and tracks traversed objects enabling objects with circular
    	     * references to be merged.
    	     *
    	     * @private
    	     * @param {Object} object The destination object.
    	     * @param {Object} source The source object.
    	     * @param {string} key The key of the value to merge.
    	     * @param {number} srcIndex The index of `source`.
    	     * @param {Function} mergeFunc The function to merge values.
    	     * @param {Function} [customizer] The function to customize assigned values.
    	     * @param {Object} [stack] Tracks traversed source values and their merged
    	     *  counterparts.
    	     */function baseMergeDeep(object,source,key,srcIndex,mergeFunc,customizer,stack){var objValue=safeGet(object,key),srcValue=safeGet(source,key),stacked=stack.get(srcValue);if(stacked){assignMergeValue(object,key,stacked);return;}var newValue=customizer?customizer(objValue,srcValue,key+'',object,source,stack):undefined$1;var isCommon=newValue===undefined$1;if(isCommon){var isArr=isArray(srcValue),isBuff=!isArr&&isBuffer(srcValue),isTyped=!isArr&&!isBuff&&isTypedArray(srcValue);newValue=srcValue;if(isArr||isBuff||isTyped){if(isArray(objValue)){newValue=objValue;}else if(isArrayLikeObject(objValue)){newValue=copyArray(objValue);}else if(isBuff){isCommon=false;newValue=cloneBuffer(srcValue,true);}else if(isTyped){isCommon=false;newValue=cloneTypedArray(srcValue,true);}else {newValue=[];}}else if(isPlainObject(srcValue)||isArguments(srcValue)){newValue=objValue;if(isArguments(objValue)){newValue=toPlainObject(objValue);}else if(!isObject(objValue)||isFunction(objValue)){newValue=initCloneObject(srcValue);}}else {isCommon=false;}}if(isCommon){// Recursively merge objects and arrays (susceptible to call stack limits).
    	stack.set(srcValue,newValue);mergeFunc(newValue,srcValue,srcIndex,customizer,stack);stack['delete'](srcValue);}assignMergeValue(object,key,newValue);}/**
    	     * The base implementation of `_.nth` which doesn't coerce arguments.
    	     *
    	     * @private
    	     * @param {Array} array The array to query.
    	     * @param {number} n The index of the element to return.
    	     * @returns {*} Returns the nth element of `array`.
    	     */function baseNth(array,n){var length=array.length;if(!length){return;}n+=n<0?length:0;return isIndex(n,length)?array[n]:undefined$1;}/**
    	     * The base implementation of `_.orderBy` without param guards.
    	     *
    	     * @private
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Function[]|Object[]|string[]} iteratees The iteratees to sort by.
    	     * @param {string[]} orders The sort orders of `iteratees`.
    	     * @returns {Array} Returns the new sorted array.
    	     */function baseOrderBy(collection,iteratees,orders){if(iteratees.length){iteratees=arrayMap(iteratees,function(iteratee){if(isArray(iteratee)){return function(value){return baseGet(value,iteratee.length===1?iteratee[0]:iteratee);};}return iteratee;});}else {iteratees=[identity];}var index=-1;iteratees=arrayMap(iteratees,baseUnary(getIteratee()));var result=baseMap(collection,function(value,key,collection){var criteria=arrayMap(iteratees,function(iteratee){return iteratee(value);});return {'criteria':criteria,'index':++index,'value':value};});return baseSortBy(result,function(object,other){return compareMultiple(object,other,orders);});}/**
    	     * The base implementation of `_.pick` without support for individual
    	     * property identifiers.
    	     *
    	     * @private
    	     * @param {Object} object The source object.
    	     * @param {string[]} paths The property paths to pick.
    	     * @returns {Object} Returns the new object.
    	     */function basePick(object,paths){return basePickBy(object,paths,function(value,path){return hasIn(object,path);});}/**
    	     * The base implementation of  `_.pickBy` without support for iteratee shorthands.
    	     *
    	     * @private
    	     * @param {Object} object The source object.
    	     * @param {string[]} paths The property paths to pick.
    	     * @param {Function} predicate The function invoked per property.
    	     * @returns {Object} Returns the new object.
    	     */function basePickBy(object,paths,predicate){var index=-1,length=paths.length,result={};while(++index<length){var path=paths[index],value=baseGet(object,path);if(predicate(value,path)){baseSet(result,castPath(path,object),value);}}return result;}/**
    	     * A specialized version of `baseProperty` which supports deep paths.
    	     *
    	     * @private
    	     * @param {Array|string} path The path of the property to get.
    	     * @returns {Function} Returns the new accessor function.
    	     */function basePropertyDeep(path){return function(object){return baseGet(object,path);};}/**
    	     * The base implementation of `_.pullAllBy` without support for iteratee
    	     * shorthands.
    	     *
    	     * @private
    	     * @param {Array} array The array to modify.
    	     * @param {Array} values The values to remove.
    	     * @param {Function} [iteratee] The iteratee invoked per element.
    	     * @param {Function} [comparator] The comparator invoked per element.
    	     * @returns {Array} Returns `array`.
    	     */function basePullAll(array,values,iteratee,comparator){var indexOf=comparator?baseIndexOfWith:baseIndexOf,index=-1,length=values.length,seen=array;if(array===values){values=copyArray(values);}if(iteratee){seen=arrayMap(array,baseUnary(iteratee));}while(++index<length){var fromIndex=0,value=values[index],computed=iteratee?iteratee(value):value;while((fromIndex=indexOf(seen,computed,fromIndex,comparator))>-1){if(seen!==array){splice.call(seen,fromIndex,1);}splice.call(array,fromIndex,1);}}return array;}/**
    	     * The base implementation of `_.pullAt` without support for individual
    	     * indexes or capturing the removed elements.
    	     *
    	     * @private
    	     * @param {Array} array The array to modify.
    	     * @param {number[]} indexes The indexes of elements to remove.
    	     * @returns {Array} Returns `array`.
    	     */function basePullAt(array,indexes){var length=array?indexes.length:0,lastIndex=length-1;while(length--){var index=indexes[length];if(length==lastIndex||index!==previous){var previous=index;if(isIndex(index)){splice.call(array,index,1);}else {baseUnset(array,index);}}}return array;}/**
    	     * The base implementation of `_.random` without support for returning
    	     * floating-point numbers.
    	     *
    	     * @private
    	     * @param {number} lower The lower bound.
    	     * @param {number} upper The upper bound.
    	     * @returns {number} Returns the random number.
    	     */function baseRandom(lower,upper){return lower+nativeFloor(nativeRandom()*(upper-lower+1));}/**
    	     * The base implementation of `_.range` and `_.rangeRight` which doesn't
    	     * coerce arguments.
    	     *
    	     * @private
    	     * @param {number} start The start of the range.
    	     * @param {number} end The end of the range.
    	     * @param {number} step The value to increment or decrement by.
    	     * @param {boolean} [fromRight] Specify iterating from right to left.
    	     * @returns {Array} Returns the range of numbers.
    	     */function baseRange(start,end,step,fromRight){var index=-1,length=nativeMax(nativeCeil((end-start)/(step||1)),0),result=Array(length);while(length--){result[fromRight?length:++index]=start;start+=step;}return result;}/**
    	     * The base implementation of `_.repeat` which doesn't coerce arguments.
    	     *
    	     * @private
    	     * @param {string} string The string to repeat.
    	     * @param {number} n The number of times to repeat the string.
    	     * @returns {string} Returns the repeated string.
    	     */function baseRepeat(string,n){var result='';if(!string||n<1||n>MAX_SAFE_INTEGER){return result;}// Leverage the exponentiation by squaring algorithm for a faster repeat.
    	// See https://en.wikipedia.org/wiki/Exponentiation_by_squaring for more details.
    	do{if(n%2){result+=string;}n=nativeFloor(n/2);if(n){string+=string;}}while(n);return result;}/**
    	     * The base implementation of `_.rest` which doesn't validate or coerce arguments.
    	     *
    	     * @private
    	     * @param {Function} func The function to apply a rest parameter to.
    	     * @param {number} [start=func.length-1] The start position of the rest parameter.
    	     * @returns {Function} Returns the new function.
    	     */function baseRest(func,start){return setToString(overRest(func,start,identity),func+'');}/**
    	     * The base implementation of `_.sample`.
    	     *
    	     * @private
    	     * @param {Array|Object} collection The collection to sample.
    	     * @returns {*} Returns the random element.
    	     */function baseSample(collection){return arraySample(values(collection));}/**
    	     * The base implementation of `_.sampleSize` without param guards.
    	     *
    	     * @private
    	     * @param {Array|Object} collection The collection to sample.
    	     * @param {number} n The number of elements to sample.
    	     * @returns {Array} Returns the random elements.
    	     */function baseSampleSize(collection,n){var array=values(collection);return shuffleSelf(array,baseClamp(n,0,array.length));}/**
    	     * The base implementation of `_.set`.
    	     *
    	     * @private
    	     * @param {Object} object The object to modify.
    	     * @param {Array|string} path The path of the property to set.
    	     * @param {*} value The value to set.
    	     * @param {Function} [customizer] The function to customize path creation.
    	     * @returns {Object} Returns `object`.
    	     */function baseSet(object,path,value,customizer){if(!isObject(object)){return object;}path=castPath(path,object);var index=-1,length=path.length,lastIndex=length-1,nested=object;while(nested!=null&&++index<length){var key=toKey(path[index]),newValue=value;if(key==='__proto__'||key==='constructor'||key==='prototype'){return object;}if(index!=lastIndex){var objValue=nested[key];newValue=customizer?customizer(objValue,key,nested):undefined$1;if(newValue===undefined$1){newValue=isObject(objValue)?objValue:isIndex(path[index+1])?[]:{};}}assignValue(nested,key,newValue);nested=nested[key];}return object;}/**
    	     * The base implementation of `setData` without support for hot loop shorting.
    	     *
    	     * @private
    	     * @param {Function} func The function to associate metadata with.
    	     * @param {*} data The metadata.
    	     * @returns {Function} Returns `func`.
    	     */var baseSetData=!metaMap?identity:function(func,data){metaMap.set(func,data);return func;};/**
    	     * The base implementation of `setToString` without support for hot loop shorting.
    	     *
    	     * @private
    	     * @param {Function} func The function to modify.
    	     * @param {Function} string The `toString` result.
    	     * @returns {Function} Returns `func`.
    	     */var baseSetToString=!defineProperty?identity:function(func,string){return defineProperty(func,'toString',{'configurable':true,'enumerable':false,'value':constant(string),'writable':true});};/**
    	     * The base implementation of `_.shuffle`.
    	     *
    	     * @private
    	     * @param {Array|Object} collection The collection to shuffle.
    	     * @returns {Array} Returns the new shuffled array.
    	     */function baseShuffle(collection){return shuffleSelf(values(collection));}/**
    	     * The base implementation of `_.slice` without an iteratee call guard.
    	     *
    	     * @private
    	     * @param {Array} array The array to slice.
    	     * @param {number} [start=0] The start position.
    	     * @param {number} [end=array.length] The end position.
    	     * @returns {Array} Returns the slice of `array`.
    	     */function baseSlice(array,start,end){var index=-1,length=array.length;if(start<0){start=-start>length?0:length+start;}end=end>length?length:end;if(end<0){end+=length;}length=start>end?0:end-start>>>0;start>>>=0;var result=Array(length);while(++index<length){result[index]=array[index+start];}return result;}/**
    	     * The base implementation of `_.some` without support for iteratee shorthands.
    	     *
    	     * @private
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Function} predicate The function invoked per iteration.
    	     * @returns {boolean} Returns `true` if any element passes the predicate check,
    	     *  else `false`.
    	     */function baseSome(collection,predicate){var result;baseEach(collection,function(value,index,collection){result=predicate(value,index,collection);return !result;});return !!result;}/**
    	     * The base implementation of `_.sortedIndex` and `_.sortedLastIndex` which
    	     * performs a binary search of `array` to determine the index at which `value`
    	     * should be inserted into `array` in order to maintain its sort order.
    	     *
    	     * @private
    	     * @param {Array} array The sorted array to inspect.
    	     * @param {*} value The value to evaluate.
    	     * @param {boolean} [retHighest] Specify returning the highest qualified index.
    	     * @returns {number} Returns the index at which `value` should be inserted
    	     *  into `array`.
    	     */function baseSortedIndex(array,value,retHighest){var low=0,high=array==null?low:array.length;if(typeof value=='number'&&value===value&&high<=HALF_MAX_ARRAY_LENGTH){while(low<high){var mid=low+high>>>1,computed=array[mid];if(computed!==null&&!isSymbol(computed)&&(retHighest?computed<=value:computed<value)){low=mid+1;}else {high=mid;}}return high;}return baseSortedIndexBy(array,value,identity,retHighest);}/**
    	     * The base implementation of `_.sortedIndexBy` and `_.sortedLastIndexBy`
    	     * which invokes `iteratee` for `value` and each element of `array` to compute
    	     * their sort ranking. The iteratee is invoked with one argument; (value).
    	     *
    	     * @private
    	     * @param {Array} array The sorted array to inspect.
    	     * @param {*} value The value to evaluate.
    	     * @param {Function} iteratee The iteratee invoked per element.
    	     * @param {boolean} [retHighest] Specify returning the highest qualified index.
    	     * @returns {number} Returns the index at which `value` should be inserted
    	     *  into `array`.
    	     */function baseSortedIndexBy(array,value,iteratee,retHighest){var low=0,high=array==null?0:array.length;if(high===0){return 0;}value=iteratee(value);var valIsNaN=value!==value,valIsNull=value===null,valIsSymbol=isSymbol(value),valIsUndefined=value===undefined$1;while(low<high){var mid=nativeFloor((low+high)/2),computed=iteratee(array[mid]),othIsDefined=computed!==undefined$1,othIsNull=computed===null,othIsReflexive=computed===computed,othIsSymbol=isSymbol(computed);if(valIsNaN){var setLow=retHighest||othIsReflexive;}else if(valIsUndefined){setLow=othIsReflexive&&(retHighest||othIsDefined);}else if(valIsNull){setLow=othIsReflexive&&othIsDefined&&(retHighest||!othIsNull);}else if(valIsSymbol){setLow=othIsReflexive&&othIsDefined&&!othIsNull&&(retHighest||!othIsSymbol);}else if(othIsNull||othIsSymbol){setLow=false;}else {setLow=retHighest?computed<=value:computed<value;}if(setLow){low=mid+1;}else {high=mid;}}return nativeMin(high,MAX_ARRAY_INDEX);}/**
    	     * The base implementation of `_.sortedUniq` and `_.sortedUniqBy` without
    	     * support for iteratee shorthands.
    	     *
    	     * @private
    	     * @param {Array} array The array to inspect.
    	     * @param {Function} [iteratee] The iteratee invoked per element.
    	     * @returns {Array} Returns the new duplicate free array.
    	     */function baseSortedUniq(array,iteratee){var index=-1,length=array.length,resIndex=0,result=[];while(++index<length){var value=array[index],computed=iteratee?iteratee(value):value;if(!index||!eq(computed,seen)){var seen=computed;result[resIndex++]=value===0?0:value;}}return result;}/**
    	     * The base implementation of `_.toNumber` which doesn't ensure correct
    	     * conversions of binary, hexadecimal, or octal string values.
    	     *
    	     * @private
    	     * @param {*} value The value to process.
    	     * @returns {number} Returns the number.
    	     */function baseToNumber(value){if(typeof value=='number'){return value;}if(isSymbol(value)){return NAN;}return +value;}/**
    	     * The base implementation of `_.toString` which doesn't convert nullish
    	     * values to empty strings.
    	     *
    	     * @private
    	     * @param {*} value The value to process.
    	     * @returns {string} Returns the string.
    	     */function baseToString(value){// Exit early for strings to avoid a performance hit in some environments.
    	if(typeof value=='string'){return value;}if(isArray(value)){// Recursively convert values (susceptible to call stack limits).
    	return arrayMap(value,baseToString)+'';}if(isSymbol(value)){return symbolToString?symbolToString.call(value):'';}var result=value+'';return result=='0'&&1/value==-INFINITY?'-0':result;}/**
    	     * The base implementation of `_.uniqBy` without support for iteratee shorthands.
    	     *
    	     * @private
    	     * @param {Array} array The array to inspect.
    	     * @param {Function} [iteratee] The iteratee invoked per element.
    	     * @param {Function} [comparator] The comparator invoked per element.
    	     * @returns {Array} Returns the new duplicate free array.
    	     */function baseUniq(array,iteratee,comparator){var index=-1,includes=arrayIncludes,length=array.length,isCommon=true,result=[],seen=result;if(comparator){isCommon=false;includes=arrayIncludesWith;}else if(length>=LARGE_ARRAY_SIZE){var set=iteratee?null:createSet(array);if(set){return setToArray(set);}isCommon=false;includes=cacheHas;seen=new SetCache();}else {seen=iteratee?[]:result;}outer:while(++index<length){var value=array[index],computed=iteratee?iteratee(value):value;value=comparator||value!==0?value:0;if(isCommon&&computed===computed){var seenIndex=seen.length;while(seenIndex--){if(seen[seenIndex]===computed){continue outer;}}if(iteratee){seen.push(computed);}result.push(value);}else if(!includes(seen,computed,comparator)){if(seen!==result){seen.push(computed);}result.push(value);}}return result;}/**
    	     * The base implementation of `_.unset`.
    	     *
    	     * @private
    	     * @param {Object} object The object to modify.
    	     * @param {Array|string} path The property path to unset.
    	     * @returns {boolean} Returns `true` if the property is deleted, else `false`.
    	     */function baseUnset(object,path){path=castPath(path,object);object=parent(object,path);return object==null||delete object[toKey(last(path))];}/**
    	     * The base implementation of `_.update`.
    	     *
    	     * @private
    	     * @param {Object} object The object to modify.
    	     * @param {Array|string} path The path of the property to update.
    	     * @param {Function} updater The function to produce the updated value.
    	     * @param {Function} [customizer] The function to customize path creation.
    	     * @returns {Object} Returns `object`.
    	     */function baseUpdate(object,path,updater,customizer){return baseSet(object,path,updater(baseGet(object,path)),customizer);}/**
    	     * The base implementation of methods like `_.dropWhile` and `_.takeWhile`
    	     * without support for iteratee shorthands.
    	     *
    	     * @private
    	     * @param {Array} array The array to query.
    	     * @param {Function} predicate The function invoked per iteration.
    	     * @param {boolean} [isDrop] Specify dropping elements instead of taking them.
    	     * @param {boolean} [fromRight] Specify iterating from right to left.
    	     * @returns {Array} Returns the slice of `array`.
    	     */function baseWhile(array,predicate,isDrop,fromRight){var length=array.length,index=fromRight?length:-1;while((fromRight?index--:++index<length)&&predicate(array[index],index,array)){}return isDrop?baseSlice(array,fromRight?0:index,fromRight?index+1:length):baseSlice(array,fromRight?index+1:0,fromRight?length:index);}/**
    	     * The base implementation of `wrapperValue` which returns the result of
    	     * performing a sequence of actions on the unwrapped `value`, where each
    	     * successive action is supplied the return value of the previous.
    	     *
    	     * @private
    	     * @param {*} value The unwrapped value.
    	     * @param {Array} actions Actions to perform to resolve the unwrapped value.
    	     * @returns {*} Returns the resolved value.
    	     */function baseWrapperValue(value,actions){var result=value;if(result instanceof LazyWrapper){result=result.value();}return arrayReduce(actions,function(result,action){return action.func.apply(action.thisArg,arrayPush([result],action.args));},result);}/**
    	     * The base implementation of methods like `_.xor`, without support for
    	     * iteratee shorthands, that accepts an array of arrays to inspect.
    	     *
    	     * @private
    	     * @param {Array} arrays The arrays to inspect.
    	     * @param {Function} [iteratee] The iteratee invoked per element.
    	     * @param {Function} [comparator] The comparator invoked per element.
    	     * @returns {Array} Returns the new array of values.
    	     */function baseXor(arrays,iteratee,comparator){var length=arrays.length;if(length<2){return length?baseUniq(arrays[0]):[];}var index=-1,result=Array(length);while(++index<length){var array=arrays[index],othIndex=-1;while(++othIndex<length){if(othIndex!=index){result[index]=baseDifference(result[index]||array,arrays[othIndex],iteratee,comparator);}}}return baseUniq(baseFlatten(result,1),iteratee,comparator);}/**
    	     * This base implementation of `_.zipObject` which assigns values using `assignFunc`.
    	     *
    	     * @private
    	     * @param {Array} props The property identifiers.
    	     * @param {Array} values The property values.
    	     * @param {Function} assignFunc The function to assign values.
    	     * @returns {Object} Returns the new object.
    	     */function baseZipObject(props,values,assignFunc){var index=-1,length=props.length,valsLength=values.length,result={};while(++index<length){var value=index<valsLength?values[index]:undefined$1;assignFunc(result,props[index],value);}return result;}/**
    	     * Casts `value` to an empty array if it's not an array like object.
    	     *
    	     * @private
    	     * @param {*} value The value to inspect.
    	     * @returns {Array|Object} Returns the cast array-like object.
    	     */function castArrayLikeObject(value){return isArrayLikeObject(value)?value:[];}/**
    	     * Casts `value` to `identity` if it's not a function.
    	     *
    	     * @private
    	     * @param {*} value The value to inspect.
    	     * @returns {Function} Returns cast function.
    	     */function castFunction(value){return typeof value=='function'?value:identity;}/**
    	     * Casts `value` to a path array if it's not one.
    	     *
    	     * @private
    	     * @param {*} value The value to inspect.
    	     * @param {Object} [object] The object to query keys on.
    	     * @returns {Array} Returns the cast property path array.
    	     */function castPath(value,object){if(isArray(value)){return value;}return isKey(value,object)?[value]:stringToPath(toString(value));}/**
    	     * A `baseRest` alias which can be replaced with `identity` by module
    	     * replacement plugins.
    	     *
    	     * @private
    	     * @type {Function}
    	     * @param {Function} func The function to apply a rest parameter to.
    	     * @returns {Function} Returns the new function.
    	     */var castRest=baseRest;/**
    	     * Casts `array` to a slice if it's needed.
    	     *
    	     * @private
    	     * @param {Array} array The array to inspect.
    	     * @param {number} start The start position.
    	     * @param {number} [end=array.length] The end position.
    	     * @returns {Array} Returns the cast slice.
    	     */function castSlice(array,start,end){var length=array.length;end=end===undefined$1?length:end;return !start&&end>=length?array:baseSlice(array,start,end);}/**
    	     * A simple wrapper around the global [`clearTimeout`](https://mdn.io/clearTimeout).
    	     *
    	     * @private
    	     * @param {number|Object} id The timer id or timeout object of the timer to clear.
    	     */var clearTimeout=ctxClearTimeout||function(id){return root.clearTimeout(id);};/**
    	     * Creates a clone of  `buffer`.
    	     *
    	     * @private
    	     * @param {Buffer} buffer The buffer to clone.
    	     * @param {boolean} [isDeep] Specify a deep clone.
    	     * @returns {Buffer} Returns the cloned buffer.
    	     */function cloneBuffer(buffer,isDeep){if(isDeep){return buffer.slice();}var length=buffer.length,result=allocUnsafe?allocUnsafe(length):new buffer.constructor(length);buffer.copy(result);return result;}/**
    	     * Creates a clone of `arrayBuffer`.
    	     *
    	     * @private
    	     * @param {ArrayBuffer} arrayBuffer The array buffer to clone.
    	     * @returns {ArrayBuffer} Returns the cloned array buffer.
    	     */function cloneArrayBuffer(arrayBuffer){var result=new arrayBuffer.constructor(arrayBuffer.byteLength);new Uint8Array(result).set(new Uint8Array(arrayBuffer));return result;}/**
    	     * Creates a clone of `dataView`.
    	     *
    	     * @private
    	     * @param {Object} dataView The data view to clone.
    	     * @param {boolean} [isDeep] Specify a deep clone.
    	     * @returns {Object} Returns the cloned data view.
    	     */function cloneDataView(dataView,isDeep){var buffer=isDeep?cloneArrayBuffer(dataView.buffer):dataView.buffer;return new dataView.constructor(buffer,dataView.byteOffset,dataView.byteLength);}/**
    	     * Creates a clone of `regexp`.
    	     *
    	     * @private
    	     * @param {Object} regexp The regexp to clone.
    	     * @returns {Object} Returns the cloned regexp.
    	     */function cloneRegExp(regexp){var result=new regexp.constructor(regexp.source,reFlags.exec(regexp));result.lastIndex=regexp.lastIndex;return result;}/**
    	     * Creates a clone of the `symbol` object.
    	     *
    	     * @private
    	     * @param {Object} symbol The symbol object to clone.
    	     * @returns {Object} Returns the cloned symbol object.
    	     */function cloneSymbol(symbol){return symbolValueOf?Object(symbolValueOf.call(symbol)):{};}/**
    	     * Creates a clone of `typedArray`.
    	     *
    	     * @private
    	     * @param {Object} typedArray The typed array to clone.
    	     * @param {boolean} [isDeep] Specify a deep clone.
    	     * @returns {Object} Returns the cloned typed array.
    	     */function cloneTypedArray(typedArray,isDeep){var buffer=isDeep?cloneArrayBuffer(typedArray.buffer):typedArray.buffer;return new typedArray.constructor(buffer,typedArray.byteOffset,typedArray.length);}/**
    	     * Compares values to sort them in ascending order.
    	     *
    	     * @private
    	     * @param {*} value The value to compare.
    	     * @param {*} other The other value to compare.
    	     * @returns {number} Returns the sort order indicator for `value`.
    	     */function compareAscending(value,other){if(value!==other){var valIsDefined=value!==undefined$1,valIsNull=value===null,valIsReflexive=value===value,valIsSymbol=isSymbol(value);var othIsDefined=other!==undefined$1,othIsNull=other===null,othIsReflexive=other===other,othIsSymbol=isSymbol(other);if(!othIsNull&&!othIsSymbol&&!valIsSymbol&&value>other||valIsSymbol&&othIsDefined&&othIsReflexive&&!othIsNull&&!othIsSymbol||valIsNull&&othIsDefined&&othIsReflexive||!valIsDefined&&othIsReflexive||!valIsReflexive){return 1;}if(!valIsNull&&!valIsSymbol&&!othIsSymbol&&value<other||othIsSymbol&&valIsDefined&&valIsReflexive&&!valIsNull&&!valIsSymbol||othIsNull&&valIsDefined&&valIsReflexive||!othIsDefined&&valIsReflexive||!othIsReflexive){return -1;}}return 0;}/**
    	     * Used by `_.orderBy` to compare multiple properties of a value to another
    	     * and stable sort them.
    	     *
    	     * If `orders` is unspecified, all values are sorted in ascending order. Otherwise,
    	     * specify an order of "desc" for descending or "asc" for ascending sort order
    	     * of corresponding values.
    	     *
    	     * @private
    	     * @param {Object} object The object to compare.
    	     * @param {Object} other The other object to compare.
    	     * @param {boolean[]|string[]} orders The order to sort by for each property.
    	     * @returns {number} Returns the sort order indicator for `object`.
    	     */function compareMultiple(object,other,orders){var index=-1,objCriteria=object.criteria,othCriteria=other.criteria,length=objCriteria.length,ordersLength=orders.length;while(++index<length){var result=compareAscending(objCriteria[index],othCriteria[index]);if(result){if(index>=ordersLength){return result;}var order=orders[index];return result*(order=='desc'?-1:1);}}// Fixes an `Array#sort` bug in the JS engine embedded in Adobe applications
    	// that causes it, under certain circumstances, to provide the same value for
    	// `object` and `other`. See https://github.com/jashkenas/underscore/pull/1247
    	// for more details.
    	//
    	// This also ensures a stable sort in V8 and other engines.
    	// See https://bugs.chromium.org/p/v8/issues/detail?id=90 for more details.
    	return object.index-other.index;}/**
    	     * Creates an array that is the composition of partially applied arguments,
    	     * placeholders, and provided arguments into a single array of arguments.
    	     *
    	     * @private
    	     * @param {Array} args The provided arguments.
    	     * @param {Array} partials The arguments to prepend to those provided.
    	     * @param {Array} holders The `partials` placeholder indexes.
    	     * @params {boolean} [isCurried] Specify composing for a curried function.
    	     * @returns {Array} Returns the new array of composed arguments.
    	     */function composeArgs(args,partials,holders,isCurried){var argsIndex=-1,argsLength=args.length,holdersLength=holders.length,leftIndex=-1,leftLength=partials.length,rangeLength=nativeMax(argsLength-holdersLength,0),result=Array(leftLength+rangeLength),isUncurried=!isCurried;while(++leftIndex<leftLength){result[leftIndex]=partials[leftIndex];}while(++argsIndex<holdersLength){if(isUncurried||argsIndex<argsLength){result[holders[argsIndex]]=args[argsIndex];}}while(rangeLength--){result[leftIndex++]=args[argsIndex++];}return result;}/**
    	     * This function is like `composeArgs` except that the arguments composition
    	     * is tailored for `_.partialRight`.
    	     *
    	     * @private
    	     * @param {Array} args The provided arguments.
    	     * @param {Array} partials The arguments to append to those provided.
    	     * @param {Array} holders The `partials` placeholder indexes.
    	     * @params {boolean} [isCurried] Specify composing for a curried function.
    	     * @returns {Array} Returns the new array of composed arguments.
    	     */function composeArgsRight(args,partials,holders,isCurried){var argsIndex=-1,argsLength=args.length,holdersIndex=-1,holdersLength=holders.length,rightIndex=-1,rightLength=partials.length,rangeLength=nativeMax(argsLength-holdersLength,0),result=Array(rangeLength+rightLength),isUncurried=!isCurried;while(++argsIndex<rangeLength){result[argsIndex]=args[argsIndex];}var offset=argsIndex;while(++rightIndex<rightLength){result[offset+rightIndex]=partials[rightIndex];}while(++holdersIndex<holdersLength){if(isUncurried||argsIndex<argsLength){result[offset+holders[holdersIndex]]=args[argsIndex++];}}return result;}/**
    	     * Copies the values of `source` to `array`.
    	     *
    	     * @private
    	     * @param {Array} source The array to copy values from.
    	     * @param {Array} [array=[]] The array to copy values to.
    	     * @returns {Array} Returns `array`.
    	     */function copyArray(source,array){var index=-1,length=source.length;array||(array=Array(length));while(++index<length){array[index]=source[index];}return array;}/**
    	     * Copies properties of `source` to `object`.
    	     *
    	     * @private
    	     * @param {Object} source The object to copy properties from.
    	     * @param {Array} props The property identifiers to copy.
    	     * @param {Object} [object={}] The object to copy properties to.
    	     * @param {Function} [customizer] The function to customize copied values.
    	     * @returns {Object} Returns `object`.
    	     */function copyObject(source,props,object,customizer){var isNew=!object;object||(object={});var index=-1,length=props.length;while(++index<length){var key=props[index];var newValue=customizer?customizer(object[key],source[key],key,object,source):undefined$1;if(newValue===undefined$1){newValue=source[key];}if(isNew){baseAssignValue(object,key,newValue);}else {assignValue(object,key,newValue);}}return object;}/**
    	     * Copies own symbols of `source` to `object`.
    	     *
    	     * @private
    	     * @param {Object} source The object to copy symbols from.
    	     * @param {Object} [object={}] The object to copy symbols to.
    	     * @returns {Object} Returns `object`.
    	     */function copySymbols(source,object){return copyObject(source,getSymbols(source),object);}/**
    	     * Copies own and inherited symbols of `source` to `object`.
    	     *
    	     * @private
    	     * @param {Object} source The object to copy symbols from.
    	     * @param {Object} [object={}] The object to copy symbols to.
    	     * @returns {Object} Returns `object`.
    	     */function copySymbolsIn(source,object){return copyObject(source,getSymbolsIn(source),object);}/**
    	     * Creates a function like `_.groupBy`.
    	     *
    	     * @private
    	     * @param {Function} setter The function to set accumulator values.
    	     * @param {Function} [initializer] The accumulator object initializer.
    	     * @returns {Function} Returns the new aggregator function.
    	     */function createAggregator(setter,initializer){return function(collection,iteratee){var func=isArray(collection)?arrayAggregator:baseAggregator,accumulator=initializer?initializer():{};return func(collection,setter,getIteratee(iteratee,2),accumulator);};}/**
    	     * Creates a function like `_.assign`.
    	     *
    	     * @private
    	     * @param {Function} assigner The function to assign values.
    	     * @returns {Function} Returns the new assigner function.
    	     */function createAssigner(assigner){return baseRest(function(object,sources){var index=-1,length=sources.length,customizer=length>1?sources[length-1]:undefined$1,guard=length>2?sources[2]:undefined$1;customizer=assigner.length>3&&typeof customizer=='function'?(length--,customizer):undefined$1;if(guard&&isIterateeCall(sources[0],sources[1],guard)){customizer=length<3?undefined$1:customizer;length=1;}object=Object(object);while(++index<length){var source=sources[index];if(source){assigner(object,source,index,customizer);}}return object;});}/**
    	     * Creates a `baseEach` or `baseEachRight` function.
    	     *
    	     * @private
    	     * @param {Function} eachFunc The function to iterate over a collection.
    	     * @param {boolean} [fromRight] Specify iterating from right to left.
    	     * @returns {Function} Returns the new base function.
    	     */function createBaseEach(eachFunc,fromRight){return function(collection,iteratee){if(collection==null){return collection;}if(!isArrayLike(collection)){return eachFunc(collection,iteratee);}var length=collection.length,index=fromRight?length:-1,iterable=Object(collection);while(fromRight?index--:++index<length){if(iteratee(iterable[index],index,iterable)===false){break;}}return collection;};}/**
    	     * Creates a base function for methods like `_.forIn` and `_.forOwn`.
    	     *
    	     * @private
    	     * @param {boolean} [fromRight] Specify iterating from right to left.
    	     * @returns {Function} Returns the new base function.
    	     */function createBaseFor(fromRight){return function(object,iteratee,keysFunc){var index=-1,iterable=Object(object),props=keysFunc(object),length=props.length;while(length--){var key=props[fromRight?length:++index];if(iteratee(iterable[key],key,iterable)===false){break;}}return object;};}/**
    	     * Creates a function that wraps `func` to invoke it with the optional `this`
    	     * binding of `thisArg`.
    	     *
    	     * @private
    	     * @param {Function} func The function to wrap.
    	     * @param {number} bitmask The bitmask flags. See `createWrap` for more details.
    	     * @param {*} [thisArg] The `this` binding of `func`.
    	     * @returns {Function} Returns the new wrapped function.
    	     */function createBind(func,bitmask,thisArg){var isBind=bitmask&WRAP_BIND_FLAG,Ctor=createCtor(func);function wrapper(){var fn=this&&this!==root&&this instanceof wrapper?Ctor:func;return fn.apply(isBind?thisArg:this,arguments);}return wrapper;}/**
    	     * Creates a function like `_.lowerFirst`.
    	     *
    	     * @private
    	     * @param {string} methodName The name of the `String` case method to use.
    	     * @returns {Function} Returns the new case function.
    	     */function createCaseFirst(methodName){return function(string){string=toString(string);var strSymbols=hasUnicode(string)?stringToArray(string):undefined$1;var chr=strSymbols?strSymbols[0]:string.charAt(0);var trailing=strSymbols?castSlice(strSymbols,1).join(''):string.slice(1);return chr[methodName]()+trailing;};}/**
    	     * Creates a function like `_.camelCase`.
    	     *
    	     * @private
    	     * @param {Function} callback The function to combine each word.
    	     * @returns {Function} Returns the new compounder function.
    	     */function createCompounder(callback){return function(string){return arrayReduce(words(deburr(string).replace(reApos,'')),callback,'');};}/**
    	     * Creates a function that produces an instance of `Ctor` regardless of
    	     * whether it was invoked as part of a `new` expression or by `call` or `apply`.
    	     *
    	     * @private
    	     * @param {Function} Ctor The constructor to wrap.
    	     * @returns {Function} Returns the new wrapped function.
    	     */function createCtor(Ctor){return function(){// Use a `switch` statement to work with class constructors. See
    	// http://ecma-international.org/ecma-262/7.0/#sec-ecmascript-function-objects-call-thisargument-argumentslist
    	// for more details.
    	var args=arguments;switch(args.length){case 0:return new Ctor();case 1:return new Ctor(args[0]);case 2:return new Ctor(args[0],args[1]);case 3:return new Ctor(args[0],args[1],args[2]);case 4:return new Ctor(args[0],args[1],args[2],args[3]);case 5:return new Ctor(args[0],args[1],args[2],args[3],args[4]);case 6:return new Ctor(args[0],args[1],args[2],args[3],args[4],args[5]);case 7:return new Ctor(args[0],args[1],args[2],args[3],args[4],args[5],args[6]);}var thisBinding=baseCreate(Ctor.prototype),result=Ctor.apply(thisBinding,args);// Mimic the constructor's `return` behavior.
    	// See https://es5.github.io/#x13.2.2 for more details.
    	return isObject(result)?result:thisBinding;};}/**
    	     * Creates a function that wraps `func` to enable currying.
    	     *
    	     * @private
    	     * @param {Function} func The function to wrap.
    	     * @param {number} bitmask The bitmask flags. See `createWrap` for more details.
    	     * @param {number} arity The arity of `func`.
    	     * @returns {Function} Returns the new wrapped function.
    	     */function createCurry(func,bitmask,arity){var Ctor=createCtor(func);function wrapper(){var length=arguments.length,args=Array(length),index=length,placeholder=getHolder(wrapper);while(index--){args[index]=arguments[index];}var holders=length<3&&args[0]!==placeholder&&args[length-1]!==placeholder?[]:replaceHolders(args,placeholder);length-=holders.length;if(length<arity){return createRecurry(func,bitmask,createHybrid,wrapper.placeholder,undefined$1,args,holders,undefined$1,undefined$1,arity-length);}var fn=this&&this!==root&&this instanceof wrapper?Ctor:func;return apply(fn,this,args);}return wrapper;}/**
    	     * Creates a `_.find` or `_.findLast` function.
    	     *
    	     * @private
    	     * @param {Function} findIndexFunc The function to find the collection index.
    	     * @returns {Function} Returns the new find function.
    	     */function createFind(findIndexFunc){return function(collection,predicate,fromIndex){var iterable=Object(collection);if(!isArrayLike(collection)){var iteratee=getIteratee(predicate,3);collection=keys(collection);predicate=function(key){return iteratee(iterable[key],key,iterable);};}var index=findIndexFunc(collection,predicate,fromIndex);return index>-1?iterable[iteratee?collection[index]:index]:undefined$1;};}/**
    	     * Creates a `_.flow` or `_.flowRight` function.
    	     *
    	     * @private
    	     * @param {boolean} [fromRight] Specify iterating from right to left.
    	     * @returns {Function} Returns the new flow function.
    	     */function createFlow(fromRight){return flatRest(function(funcs){var length=funcs.length,index=length,prereq=LodashWrapper.prototype.thru;if(fromRight){funcs.reverse();}while(index--){var func=funcs[index];if(typeof func!='function'){throw new TypeError(FUNC_ERROR_TEXT);}if(prereq&&!wrapper&&getFuncName(func)=='wrapper'){var wrapper=new LodashWrapper([],true);}}index=wrapper?index:length;while(++index<length){func=funcs[index];var funcName=getFuncName(func),data=funcName=='wrapper'?getData(func):undefined$1;if(data&&isLaziable(data[0])&&data[1]==(WRAP_ARY_FLAG|WRAP_CURRY_FLAG|WRAP_PARTIAL_FLAG|WRAP_REARG_FLAG)&&!data[4].length&&data[9]==1){wrapper=wrapper[getFuncName(data[0])].apply(wrapper,data[3]);}else {wrapper=func.length==1&&isLaziable(func)?wrapper[funcName]():wrapper.thru(func);}}return function(){var args=arguments,value=args[0];if(wrapper&&args.length==1&&isArray(value)){return wrapper.plant(value).value();}var index=0,result=length?funcs[index].apply(this,args):value;while(++index<length){result=funcs[index].call(this,result);}return result;};});}/**
    	     * Creates a function that wraps `func` to invoke it with optional `this`
    	     * binding of `thisArg`, partial application, and currying.
    	     *
    	     * @private
    	     * @param {Function|string} func The function or method name to wrap.
    	     * @param {number} bitmask The bitmask flags. See `createWrap` for more details.
    	     * @param {*} [thisArg] The `this` binding of `func`.
    	     * @param {Array} [partials] The arguments to prepend to those provided to
    	     *  the new function.
    	     * @param {Array} [holders] The `partials` placeholder indexes.
    	     * @param {Array} [partialsRight] The arguments to append to those provided
    	     *  to the new function.
    	     * @param {Array} [holdersRight] The `partialsRight` placeholder indexes.
    	     * @param {Array} [argPos] The argument positions of the new function.
    	     * @param {number} [ary] The arity cap of `func`.
    	     * @param {number} [arity] The arity of `func`.
    	     * @returns {Function} Returns the new wrapped function.
    	     */function createHybrid(func,bitmask,thisArg,partials,holders,partialsRight,holdersRight,argPos,ary,arity){var isAry=bitmask&WRAP_ARY_FLAG,isBind=bitmask&WRAP_BIND_FLAG,isBindKey=bitmask&WRAP_BIND_KEY_FLAG,isCurried=bitmask&(WRAP_CURRY_FLAG|WRAP_CURRY_RIGHT_FLAG),isFlip=bitmask&WRAP_FLIP_FLAG,Ctor=isBindKey?undefined$1:createCtor(func);function wrapper(){var length=arguments.length,args=Array(length),index=length;while(index--){args[index]=arguments[index];}if(isCurried){var placeholder=getHolder(wrapper),holdersCount=countHolders(args,placeholder);}if(partials){args=composeArgs(args,partials,holders,isCurried);}if(partialsRight){args=composeArgsRight(args,partialsRight,holdersRight,isCurried);}length-=holdersCount;if(isCurried&&length<arity){var newHolders=replaceHolders(args,placeholder);return createRecurry(func,bitmask,createHybrid,wrapper.placeholder,thisArg,args,newHolders,argPos,ary,arity-length);}var thisBinding=isBind?thisArg:this,fn=isBindKey?thisBinding[func]:func;length=args.length;if(argPos){args=reorder(args,argPos);}else if(isFlip&&length>1){args.reverse();}if(isAry&&ary<length){args.length=ary;}if(this&&this!==root&&this instanceof wrapper){fn=Ctor||createCtor(fn);}return fn.apply(thisBinding,args);}return wrapper;}/**
    	     * Creates a function like `_.invertBy`.
    	     *
    	     * @private
    	     * @param {Function} setter The function to set accumulator values.
    	     * @param {Function} toIteratee The function to resolve iteratees.
    	     * @returns {Function} Returns the new inverter function.
    	     */function createInverter(setter,toIteratee){return function(object,iteratee){return baseInverter(object,setter,toIteratee(iteratee),{});};}/**
    	     * Creates a function that performs a mathematical operation on two values.
    	     *
    	     * @private
    	     * @param {Function} operator The function to perform the operation.
    	     * @param {number} [defaultValue] The value used for `undefined` arguments.
    	     * @returns {Function} Returns the new mathematical operation function.
    	     */function createMathOperation(operator,defaultValue){return function(value,other){var result;if(value===undefined$1&&other===undefined$1){return defaultValue;}if(value!==undefined$1){result=value;}if(other!==undefined$1){if(result===undefined$1){return other;}if(typeof value=='string'||typeof other=='string'){value=baseToString(value);other=baseToString(other);}else {value=baseToNumber(value);other=baseToNumber(other);}result=operator(value,other);}return result;};}/**
    	     * Creates a function like `_.over`.
    	     *
    	     * @private
    	     * @param {Function} arrayFunc The function to iterate over iteratees.
    	     * @returns {Function} Returns the new over function.
    	     */function createOver(arrayFunc){return flatRest(function(iteratees){iteratees=arrayMap(iteratees,baseUnary(getIteratee()));return baseRest(function(args){var thisArg=this;return arrayFunc(iteratees,function(iteratee){return apply(iteratee,thisArg,args);});});});}/**
    	     * Creates the padding for `string` based on `length`. The `chars` string
    	     * is truncated if the number of characters exceeds `length`.
    	     *
    	     * @private
    	     * @param {number} length The padding length.
    	     * @param {string} [chars=' '] The string used as padding.
    	     * @returns {string} Returns the padding for `string`.
    	     */function createPadding(length,chars){chars=chars===undefined$1?' ':baseToString(chars);var charsLength=chars.length;if(charsLength<2){return charsLength?baseRepeat(chars,length):chars;}var result=baseRepeat(chars,nativeCeil(length/stringSize(chars)));return hasUnicode(chars)?castSlice(stringToArray(result),0,length).join(''):result.slice(0,length);}/**
    	     * Creates a function that wraps `func` to invoke it with the `this` binding
    	     * of `thisArg` and `partials` prepended to the arguments it receives.
    	     *
    	     * @private
    	     * @param {Function} func The function to wrap.
    	     * @param {number} bitmask The bitmask flags. See `createWrap` for more details.
    	     * @param {*} thisArg The `this` binding of `func`.
    	     * @param {Array} partials The arguments to prepend to those provided to
    	     *  the new function.
    	     * @returns {Function} Returns the new wrapped function.
    	     */function createPartial(func,bitmask,thisArg,partials){var isBind=bitmask&WRAP_BIND_FLAG,Ctor=createCtor(func);function wrapper(){var argsIndex=-1,argsLength=arguments.length,leftIndex=-1,leftLength=partials.length,args=Array(leftLength+argsLength),fn=this&&this!==root&&this instanceof wrapper?Ctor:func;while(++leftIndex<leftLength){args[leftIndex]=partials[leftIndex];}while(argsLength--){args[leftIndex++]=arguments[++argsIndex];}return apply(fn,isBind?thisArg:this,args);}return wrapper;}/**
    	     * Creates a `_.range` or `_.rangeRight` function.
    	     *
    	     * @private
    	     * @param {boolean} [fromRight] Specify iterating from right to left.
    	     * @returns {Function} Returns the new range function.
    	     */function createRange(fromRight){return function(start,end,step){if(step&&typeof step!='number'&&isIterateeCall(start,end,step)){end=step=undefined$1;}// Ensure the sign of `-0` is preserved.
    	start=toFinite(start);if(end===undefined$1){end=start;start=0;}else {end=toFinite(end);}step=step===undefined$1?start<end?1:-1:toFinite(step);return baseRange(start,end,step,fromRight);};}/**
    	     * Creates a function that performs a relational operation on two values.
    	     *
    	     * @private
    	     * @param {Function} operator The function to perform the operation.
    	     * @returns {Function} Returns the new relational operation function.
    	     */function createRelationalOperation(operator){return function(value,other){if(!(typeof value=='string'&&typeof other=='string')){value=toNumber(value);other=toNumber(other);}return operator(value,other);};}/**
    	     * Creates a function that wraps `func` to continue currying.
    	     *
    	     * @private
    	     * @param {Function} func The function to wrap.
    	     * @param {number} bitmask The bitmask flags. See `createWrap` for more details.
    	     * @param {Function} wrapFunc The function to create the `func` wrapper.
    	     * @param {*} placeholder The placeholder value.
    	     * @param {*} [thisArg] The `this` binding of `func`.
    	     * @param {Array} [partials] The arguments to prepend to those provided to
    	     *  the new function.
    	     * @param {Array} [holders] The `partials` placeholder indexes.
    	     * @param {Array} [argPos] The argument positions of the new function.
    	     * @param {number} [ary] The arity cap of `func`.
    	     * @param {number} [arity] The arity of `func`.
    	     * @returns {Function} Returns the new wrapped function.
    	     */function createRecurry(func,bitmask,wrapFunc,placeholder,thisArg,partials,holders,argPos,ary,arity){var isCurry=bitmask&WRAP_CURRY_FLAG,newHolders=isCurry?holders:undefined$1,newHoldersRight=isCurry?undefined$1:holders,newPartials=isCurry?partials:undefined$1,newPartialsRight=isCurry?undefined$1:partials;bitmask|=isCurry?WRAP_PARTIAL_FLAG:WRAP_PARTIAL_RIGHT_FLAG;bitmask&=~(isCurry?WRAP_PARTIAL_RIGHT_FLAG:WRAP_PARTIAL_FLAG);if(!(bitmask&WRAP_CURRY_BOUND_FLAG)){bitmask&=~(WRAP_BIND_FLAG|WRAP_BIND_KEY_FLAG);}var newData=[func,bitmask,thisArg,newPartials,newHolders,newPartialsRight,newHoldersRight,argPos,ary,arity];var result=wrapFunc.apply(undefined$1,newData);if(isLaziable(func)){setData(result,newData);}result.placeholder=placeholder;return setWrapToString(result,func,bitmask);}/**
    	     * Creates a function like `_.round`.
    	     *
    	     * @private
    	     * @param {string} methodName The name of the `Math` method to use when rounding.
    	     * @returns {Function} Returns the new round function.
    	     */function createRound(methodName){var func=Math[methodName];return function(number,precision){number=toNumber(number);precision=precision==null?0:nativeMin(toInteger(precision),292);if(precision&&nativeIsFinite(number)){// Shift with exponential notation to avoid floating-point issues.
    	// See [MDN](https://mdn.io/round#Examples) for more details.
    	var pair=(toString(number)+'e').split('e'),value=func(pair[0]+'e'+(+pair[1]+precision));pair=(toString(value)+'e').split('e');return +(pair[0]+'e'+(+pair[1]-precision));}return func(number);};}/**
    	     * Creates a set object of `values`.
    	     *
    	     * @private
    	     * @param {Array} values The values to add to the set.
    	     * @returns {Object} Returns the new set.
    	     */var createSet=!(Set&&1/setToArray(new Set([,-0]))[1]==INFINITY)?noop:function(values){return new Set(values);};/**
    	     * Creates a `_.toPairs` or `_.toPairsIn` function.
    	     *
    	     * @private
    	     * @param {Function} keysFunc The function to get the keys of a given object.
    	     * @returns {Function} Returns the new pairs function.
    	     */function createToPairs(keysFunc){return function(object){var tag=getTag(object);if(tag==mapTag){return mapToArray(object);}if(tag==setTag){return setToPairs(object);}return baseToPairs(object,keysFunc(object));};}/**
    	     * Creates a function that either curries or invokes `func` with optional
    	     * `this` binding and partially applied arguments.
    	     *
    	     * @private
    	     * @param {Function|string} func The function or method name to wrap.
    	     * @param {number} bitmask The bitmask flags.
    	     *    1 - `_.bind`
    	     *    2 - `_.bindKey`
    	     *    4 - `_.curry` or `_.curryRight` of a bound function
    	     *    8 - `_.curry`
    	     *   16 - `_.curryRight`
    	     *   32 - `_.partial`
    	     *   64 - `_.partialRight`
    	     *  128 - `_.rearg`
    	     *  256 - `_.ary`
    	     *  512 - `_.flip`
    	     * @param {*} [thisArg] The `this` binding of `func`.
    	     * @param {Array} [partials] The arguments to be partially applied.
    	     * @param {Array} [holders] The `partials` placeholder indexes.
    	     * @param {Array} [argPos] The argument positions of the new function.
    	     * @param {number} [ary] The arity cap of `func`.
    	     * @param {number} [arity] The arity of `func`.
    	     * @returns {Function} Returns the new wrapped function.
    	     */function createWrap(func,bitmask,thisArg,partials,holders,argPos,ary,arity){var isBindKey=bitmask&WRAP_BIND_KEY_FLAG;if(!isBindKey&&typeof func!='function'){throw new TypeError(FUNC_ERROR_TEXT);}var length=partials?partials.length:0;if(!length){bitmask&=~(WRAP_PARTIAL_FLAG|WRAP_PARTIAL_RIGHT_FLAG);partials=holders=undefined$1;}ary=ary===undefined$1?ary:nativeMax(toInteger(ary),0);arity=arity===undefined$1?arity:toInteger(arity);length-=holders?holders.length:0;if(bitmask&WRAP_PARTIAL_RIGHT_FLAG){var partialsRight=partials,holdersRight=holders;partials=holders=undefined$1;}var data=isBindKey?undefined$1:getData(func);var newData=[func,bitmask,thisArg,partials,holders,partialsRight,holdersRight,argPos,ary,arity];if(data){mergeData(newData,data);}func=newData[0];bitmask=newData[1];thisArg=newData[2];partials=newData[3];holders=newData[4];arity=newData[9]=newData[9]===undefined$1?isBindKey?0:func.length:nativeMax(newData[9]-length,0);if(!arity&&bitmask&(WRAP_CURRY_FLAG|WRAP_CURRY_RIGHT_FLAG)){bitmask&=~(WRAP_CURRY_FLAG|WRAP_CURRY_RIGHT_FLAG);}if(!bitmask||bitmask==WRAP_BIND_FLAG){var result=createBind(func,bitmask,thisArg);}else if(bitmask==WRAP_CURRY_FLAG||bitmask==WRAP_CURRY_RIGHT_FLAG){result=createCurry(func,bitmask,arity);}else if((bitmask==WRAP_PARTIAL_FLAG||bitmask==(WRAP_BIND_FLAG|WRAP_PARTIAL_FLAG))&&!holders.length){result=createPartial(func,bitmask,thisArg,partials);}else {result=createHybrid.apply(undefined$1,newData);}var setter=data?baseSetData:setData;return setWrapToString(setter(result,newData),func,bitmask);}/**
    	     * Used by `_.defaults` to customize its `_.assignIn` use to assign properties
    	     * of source objects to the destination object for all destination properties
    	     * that resolve to `undefined`.
    	     *
    	     * @private
    	     * @param {*} objValue The destination value.
    	     * @param {*} srcValue The source value.
    	     * @param {string} key The key of the property to assign.
    	     * @param {Object} object The parent object of `objValue`.
    	     * @returns {*} Returns the value to assign.
    	     */function customDefaultsAssignIn(objValue,srcValue,key,object){if(objValue===undefined$1||eq(objValue,objectProto[key])&&!hasOwnProperty.call(object,key)){return srcValue;}return objValue;}/**
    	     * Used by `_.defaultsDeep` to customize its `_.merge` use to merge source
    	     * objects into destination objects that are passed thru.
    	     *
    	     * @private
    	     * @param {*} objValue The destination value.
    	     * @param {*} srcValue The source value.
    	     * @param {string} key The key of the property to merge.
    	     * @param {Object} object The parent object of `objValue`.
    	     * @param {Object} source The parent object of `srcValue`.
    	     * @param {Object} [stack] Tracks traversed source values and their merged
    	     *  counterparts.
    	     * @returns {*} Returns the value to assign.
    	     */function customDefaultsMerge(objValue,srcValue,key,object,source,stack){if(isObject(objValue)&&isObject(srcValue)){// Recursively merge objects and arrays (susceptible to call stack limits).
    	stack.set(srcValue,objValue);baseMerge(objValue,srcValue,undefined$1,customDefaultsMerge,stack);stack['delete'](srcValue);}return objValue;}/**
    	     * Used by `_.omit` to customize its `_.cloneDeep` use to only clone plain
    	     * objects.
    	     *
    	     * @private
    	     * @param {*} value The value to inspect.
    	     * @param {string} key The key of the property to inspect.
    	     * @returns {*} Returns the uncloned value or `undefined` to defer cloning to `_.cloneDeep`.
    	     */function customOmitClone(value){return isPlainObject(value)?undefined$1:value;}/**
    	     * A specialized version of `baseIsEqualDeep` for arrays with support for
    	     * partial deep comparisons.
    	     *
    	     * @private
    	     * @param {Array} array The array to compare.
    	     * @param {Array} other The other array to compare.
    	     * @param {number} bitmask The bitmask flags. See `baseIsEqual` for more details.
    	     * @param {Function} customizer The function to customize comparisons.
    	     * @param {Function} equalFunc The function to determine equivalents of values.
    	     * @param {Object} stack Tracks traversed `array` and `other` objects.
    	     * @returns {boolean} Returns `true` if the arrays are equivalent, else `false`.
    	     */function equalArrays(array,other,bitmask,customizer,equalFunc,stack){var isPartial=bitmask&COMPARE_PARTIAL_FLAG,arrLength=array.length,othLength=other.length;if(arrLength!=othLength&&!(isPartial&&othLength>arrLength)){return false;}// Check that cyclic values are equal.
    	var arrStacked=stack.get(array);var othStacked=stack.get(other);if(arrStacked&&othStacked){return arrStacked==other&&othStacked==array;}var index=-1,result=true,seen=bitmask&COMPARE_UNORDERED_FLAG?new SetCache():undefined$1;stack.set(array,other);stack.set(other,array);// Ignore non-index properties.
    	while(++index<arrLength){var arrValue=array[index],othValue=other[index];if(customizer){var compared=isPartial?customizer(othValue,arrValue,index,other,array,stack):customizer(arrValue,othValue,index,array,other,stack);}if(compared!==undefined$1){if(compared){continue;}result=false;break;}// Recursively compare arrays (susceptible to call stack limits).
    	if(seen){if(!arraySome(other,function(othValue,othIndex){if(!cacheHas(seen,othIndex)&&(arrValue===othValue||equalFunc(arrValue,othValue,bitmask,customizer,stack))){return seen.push(othIndex);}})){result=false;break;}}else if(!(arrValue===othValue||equalFunc(arrValue,othValue,bitmask,customizer,stack))){result=false;break;}}stack['delete'](array);stack['delete'](other);return result;}/**
    	     * A specialized version of `baseIsEqualDeep` for comparing objects of
    	     * the same `toStringTag`.
    	     *
    	     * **Note:** This function only supports comparing values with tags of
    	     * `Boolean`, `Date`, `Error`, `Number`, `RegExp`, or `String`.
    	     *
    	     * @private
    	     * @param {Object} object The object to compare.
    	     * @param {Object} other The other object to compare.
    	     * @param {string} tag The `toStringTag` of the objects to compare.
    	     * @param {number} bitmask The bitmask flags. See `baseIsEqual` for more details.
    	     * @param {Function} customizer The function to customize comparisons.
    	     * @param {Function} equalFunc The function to determine equivalents of values.
    	     * @param {Object} stack Tracks traversed `object` and `other` objects.
    	     * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
    	     */function equalByTag(object,other,tag,bitmask,customizer,equalFunc,stack){switch(tag){case dataViewTag:if(object.byteLength!=other.byteLength||object.byteOffset!=other.byteOffset){return false;}object=object.buffer;other=other.buffer;case arrayBufferTag:if(object.byteLength!=other.byteLength||!equalFunc(new Uint8Array(object),new Uint8Array(other))){return false;}return true;case boolTag:case dateTag:case numberTag:// Coerce booleans to `1` or `0` and dates to milliseconds.
    	// Invalid dates are coerced to `NaN`.
    	return eq(+object,+other);case errorTag:return object.name==other.name&&object.message==other.message;case regexpTag:case stringTag:// Coerce regexes to strings and treat strings, primitives and objects,
    	// as equal. See http://www.ecma-international.org/ecma-262/7.0/#sec-regexp.prototype.tostring
    	// for more details.
    	return object==other+'';case mapTag:var convert=mapToArray;case setTag:var isPartial=bitmask&COMPARE_PARTIAL_FLAG;convert||(convert=setToArray);if(object.size!=other.size&&!isPartial){return false;}// Assume cyclic values are equal.
    	var stacked=stack.get(object);if(stacked){return stacked==other;}bitmask|=COMPARE_UNORDERED_FLAG;// Recursively compare objects (susceptible to call stack limits).
    	stack.set(object,other);var result=equalArrays(convert(object),convert(other),bitmask,customizer,equalFunc,stack);stack['delete'](object);return result;case symbolTag:if(symbolValueOf){return symbolValueOf.call(object)==symbolValueOf.call(other);}}return false;}/**
    	     * A specialized version of `baseIsEqualDeep` for objects with support for
    	     * partial deep comparisons.
    	     *
    	     * @private
    	     * @param {Object} object The object to compare.
    	     * @param {Object} other The other object to compare.
    	     * @param {number} bitmask The bitmask flags. See `baseIsEqual` for more details.
    	     * @param {Function} customizer The function to customize comparisons.
    	     * @param {Function} equalFunc The function to determine equivalents of values.
    	     * @param {Object} stack Tracks traversed `object` and `other` objects.
    	     * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
    	     */function equalObjects(object,other,bitmask,customizer,equalFunc,stack){var isPartial=bitmask&COMPARE_PARTIAL_FLAG,objProps=getAllKeys(object),objLength=objProps.length,othProps=getAllKeys(other),othLength=othProps.length;if(objLength!=othLength&&!isPartial){return false;}var index=objLength;while(index--){var key=objProps[index];if(!(isPartial?key in other:hasOwnProperty.call(other,key))){return false;}}// Check that cyclic values are equal.
    	var objStacked=stack.get(object);var othStacked=stack.get(other);if(objStacked&&othStacked){return objStacked==other&&othStacked==object;}var result=true;stack.set(object,other);stack.set(other,object);var skipCtor=isPartial;while(++index<objLength){key=objProps[index];var objValue=object[key],othValue=other[key];if(customizer){var compared=isPartial?customizer(othValue,objValue,key,other,object,stack):customizer(objValue,othValue,key,object,other,stack);}// Recursively compare objects (susceptible to call stack limits).
    	if(!(compared===undefined$1?objValue===othValue||equalFunc(objValue,othValue,bitmask,customizer,stack):compared)){result=false;break;}skipCtor||(skipCtor=key=='constructor');}if(result&&!skipCtor){var objCtor=object.constructor,othCtor=other.constructor;// Non `Object` object instances with different constructors are not equal.
    	if(objCtor!=othCtor&&'constructor'in object&&'constructor'in other&&!(typeof objCtor=='function'&&objCtor instanceof objCtor&&typeof othCtor=='function'&&othCtor instanceof othCtor)){result=false;}}stack['delete'](object);stack['delete'](other);return result;}/**
    	     * A specialized version of `baseRest` which flattens the rest array.
    	     *
    	     * @private
    	     * @param {Function} func The function to apply a rest parameter to.
    	     * @returns {Function} Returns the new function.
    	     */function flatRest(func){return setToString(overRest(func,undefined$1,flatten),func+'');}/**
    	     * Creates an array of own enumerable property names and symbols of `object`.
    	     *
    	     * @private
    	     * @param {Object} object The object to query.
    	     * @returns {Array} Returns the array of property names and symbols.
    	     */function getAllKeys(object){return baseGetAllKeys(object,keys,getSymbols);}/**
    	     * Creates an array of own and inherited enumerable property names and
    	     * symbols of `object`.
    	     *
    	     * @private
    	     * @param {Object} object The object to query.
    	     * @returns {Array} Returns the array of property names and symbols.
    	     */function getAllKeysIn(object){return baseGetAllKeys(object,keysIn,getSymbolsIn);}/**
    	     * Gets metadata for `func`.
    	     *
    	     * @private
    	     * @param {Function} func The function to query.
    	     * @returns {*} Returns the metadata for `func`.
    	     */var getData=!metaMap?noop:function(func){return metaMap.get(func);};/**
    	     * Gets the name of `func`.
    	     *
    	     * @private
    	     * @param {Function} func The function to query.
    	     * @returns {string} Returns the function name.
    	     */function getFuncName(func){var result=func.name+'',array=realNames[result],length=hasOwnProperty.call(realNames,result)?array.length:0;while(length--){var data=array[length],otherFunc=data.func;if(otherFunc==null||otherFunc==func){return data.name;}}return result;}/**
    	     * Gets the argument placeholder value for `func`.
    	     *
    	     * @private
    	     * @param {Function} func The function to inspect.
    	     * @returns {*} Returns the placeholder value.
    	     */function getHolder(func){var object=hasOwnProperty.call(lodash,'placeholder')?lodash:func;return object.placeholder;}/**
    	     * Gets the appropriate "iteratee" function. If `_.iteratee` is customized,
    	     * this function returns the custom method, otherwise it returns `baseIteratee`.
    	     * If arguments are provided, the chosen function is invoked with them and
    	     * its result is returned.
    	     *
    	     * @private
    	     * @param {*} [value] The value to convert to an iteratee.
    	     * @param {number} [arity] The arity of the created iteratee.
    	     * @returns {Function} Returns the chosen function or its result.
    	     */function getIteratee(){var result=lodash.iteratee||iteratee;result=result===iteratee?baseIteratee:result;return arguments.length?result(arguments[0],arguments[1]):result;}/**
    	     * Gets the data for `map`.
    	     *
    	     * @private
    	     * @param {Object} map The map to query.
    	     * @param {string} key The reference key.
    	     * @returns {*} Returns the map data.
    	     */function getMapData(map,key){var data=map.__data__;return isKeyable(key)?data[typeof key=='string'?'string':'hash']:data.map;}/**
    	     * Gets the property names, values, and compare flags of `object`.
    	     *
    	     * @private
    	     * @param {Object} object The object to query.
    	     * @returns {Array} Returns the match data of `object`.
    	     */function getMatchData(object){var result=keys(object),length=result.length;while(length--){var key=result[length],value=object[key];result[length]=[key,value,isStrictComparable(value)];}return result;}/**
    	     * Gets the native function at `key` of `object`.
    	     *
    	     * @private
    	     * @param {Object} object The object to query.
    	     * @param {string} key The key of the method to get.
    	     * @returns {*} Returns the function if it's native, else `undefined`.
    	     */function getNative(object,key){var value=getValue(object,key);return baseIsNative(value)?value:undefined$1;}/**
    	     * A specialized version of `baseGetTag` which ignores `Symbol.toStringTag` values.
    	     *
    	     * @private
    	     * @param {*} value The value to query.
    	     * @returns {string} Returns the raw `toStringTag`.
    	     */function getRawTag(value){var isOwn=hasOwnProperty.call(value,symToStringTag),tag=value[symToStringTag];try{value[symToStringTag]=undefined$1;var unmasked=true;}catch(e){}var result=nativeObjectToString.call(value);if(unmasked){if(isOwn){value[symToStringTag]=tag;}else {delete value[symToStringTag];}}return result;}/**
    	     * Creates an array of the own enumerable symbols of `object`.
    	     *
    	     * @private
    	     * @param {Object} object The object to query.
    	     * @returns {Array} Returns the array of symbols.
    	     */var getSymbols=!nativeGetSymbols?stubArray:function(object){if(object==null){return [];}object=Object(object);return arrayFilter(nativeGetSymbols(object),function(symbol){return propertyIsEnumerable.call(object,symbol);});};/**
    	     * Creates an array of the own and inherited enumerable symbols of `object`.
    	     *
    	     * @private
    	     * @param {Object} object The object to query.
    	     * @returns {Array} Returns the array of symbols.
    	     */var getSymbolsIn=!nativeGetSymbols?stubArray:function(object){var result=[];while(object){arrayPush(result,getSymbols(object));object=getPrototype(object);}return result;};/**
    	     * Gets the `toStringTag` of `value`.
    	     *
    	     * @private
    	     * @param {*} value The value to query.
    	     * @returns {string} Returns the `toStringTag`.
    	     */var getTag=baseGetTag;// Fallback for data views, maps, sets, and weak maps in IE 11 and promises in Node.js < 6.
    	if(DataView&&getTag(new DataView(new ArrayBuffer(1)))!=dataViewTag||Map&&getTag(new Map())!=mapTag||Promise&&getTag(Promise.resolve())!=promiseTag||Set&&getTag(new Set())!=setTag||WeakMap&&getTag(new WeakMap())!=weakMapTag){getTag=function(value){var result=baseGetTag(value),Ctor=result==objectTag?value.constructor:undefined$1,ctorString=Ctor?toSource(Ctor):'';if(ctorString){switch(ctorString){case dataViewCtorString:return dataViewTag;case mapCtorString:return mapTag;case promiseCtorString:return promiseTag;case setCtorString:return setTag;case weakMapCtorString:return weakMapTag;}}return result;};}/**
    	     * Gets the view, applying any `transforms` to the `start` and `end` positions.
    	     *
    	     * @private
    	     * @param {number} start The start of the view.
    	     * @param {number} end The end of the view.
    	     * @param {Array} transforms The transformations to apply to the view.
    	     * @returns {Object} Returns an object containing the `start` and `end`
    	     *  positions of the view.
    	     */function getView(start,end,transforms){var index=-1,length=transforms.length;while(++index<length){var data=transforms[index],size=data.size;switch(data.type){case'drop':start+=size;break;case'dropRight':end-=size;break;case'take':end=nativeMin(end,start+size);break;case'takeRight':start=nativeMax(start,end-size);break;}}return {'start':start,'end':end};}/**
    	     * Extracts wrapper details from the `source` body comment.
    	     *
    	     * @private
    	     * @param {string} source The source to inspect.
    	     * @returns {Array} Returns the wrapper details.
    	     */function getWrapDetails(source){var match=source.match(reWrapDetails);return match?match[1].split(reSplitDetails):[];}/**
    	     * Checks if `path` exists on `object`.
    	     *
    	     * @private
    	     * @param {Object} object The object to query.
    	     * @param {Array|string} path The path to check.
    	     * @param {Function} hasFunc The function to check properties.
    	     * @returns {boolean} Returns `true` if `path` exists, else `false`.
    	     */function hasPath(object,path,hasFunc){path=castPath(path,object);var index=-1,length=path.length,result=false;while(++index<length){var key=toKey(path[index]);if(!(result=object!=null&&hasFunc(object,key))){break;}object=object[key];}if(result||++index!=length){return result;}length=object==null?0:object.length;return !!length&&isLength(length)&&isIndex(key,length)&&(isArray(object)||isArguments(object));}/**
    	     * Initializes an array clone.
    	     *
    	     * @private
    	     * @param {Array} array The array to clone.
    	     * @returns {Array} Returns the initialized clone.
    	     */function initCloneArray(array){var length=array.length,result=new array.constructor(length);// Add properties assigned by `RegExp#exec`.
    	if(length&&typeof array[0]=='string'&&hasOwnProperty.call(array,'index')){result.index=array.index;result.input=array.input;}return result;}/**
    	     * Initializes an object clone.
    	     *
    	     * @private
    	     * @param {Object} object The object to clone.
    	     * @returns {Object} Returns the initialized clone.
    	     */function initCloneObject(object){return typeof object.constructor=='function'&&!isPrototype(object)?baseCreate(getPrototype(object)):{};}/**
    	     * Initializes an object clone based on its `toStringTag`.
    	     *
    	     * **Note:** This function only supports cloning values with tags of
    	     * `Boolean`, `Date`, `Error`, `Map`, `Number`, `RegExp`, `Set`, or `String`.
    	     *
    	     * @private
    	     * @param {Object} object The object to clone.
    	     * @param {string} tag The `toStringTag` of the object to clone.
    	     * @param {boolean} [isDeep] Specify a deep clone.
    	     * @returns {Object} Returns the initialized clone.
    	     */function initCloneByTag(object,tag,isDeep){var Ctor=object.constructor;switch(tag){case arrayBufferTag:return cloneArrayBuffer(object);case boolTag:case dateTag:return new Ctor(+object);case dataViewTag:return cloneDataView(object,isDeep);case float32Tag:case float64Tag:case int8Tag:case int16Tag:case int32Tag:case uint8Tag:case uint8ClampedTag:case uint16Tag:case uint32Tag:return cloneTypedArray(object,isDeep);case mapTag:return new Ctor();case numberTag:case stringTag:return new Ctor(object);case regexpTag:return cloneRegExp(object);case setTag:return new Ctor();case symbolTag:return cloneSymbol(object);}}/**
    	     * Inserts wrapper `details` in a comment at the top of the `source` body.
    	     *
    	     * @private
    	     * @param {string} source The source to modify.
    	     * @returns {Array} details The details to insert.
    	     * @returns {string} Returns the modified source.
    	     */function insertWrapDetails(source,details){var length=details.length;if(!length){return source;}var lastIndex=length-1;details[lastIndex]=(length>1?'& ':'')+details[lastIndex];details=details.join(length>2?', ':' ');return source.replace(reWrapComment,'{\n/* [wrapped with '+details+'] */\n');}/**
    	     * Checks if `value` is a flattenable `arguments` object or array.
    	     *
    	     * @private
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is flattenable, else `false`.
    	     */function isFlattenable(value){return isArray(value)||isArguments(value)||!!(spreadableSymbol&&value&&value[spreadableSymbol]);}/**
    	     * Checks if `value` is a valid array-like index.
    	     *
    	     * @private
    	     * @param {*} value The value to check.
    	     * @param {number} [length=MAX_SAFE_INTEGER] The upper bounds of a valid index.
    	     * @returns {boolean} Returns `true` if `value` is a valid index, else `false`.
    	     */function isIndex(value,length){var type=typeof value;length=length==null?MAX_SAFE_INTEGER:length;return !!length&&(type=='number'||type!='symbol'&&reIsUint.test(value))&&value>-1&&value%1==0&&value<length;}/**
    	     * Checks if the given arguments are from an iteratee call.
    	     *
    	     * @private
    	     * @param {*} value The potential iteratee value argument.
    	     * @param {*} index The potential iteratee index or key argument.
    	     * @param {*} object The potential iteratee object argument.
    	     * @returns {boolean} Returns `true` if the arguments are from an iteratee call,
    	     *  else `false`.
    	     */function isIterateeCall(value,index,object){if(!isObject(object)){return false;}var type=typeof index;if(type=='number'?isArrayLike(object)&&isIndex(index,object.length):type=='string'&&index in object){return eq(object[index],value);}return false;}/**
    	     * Checks if `value` is a property name and not a property path.
    	     *
    	     * @private
    	     * @param {*} value The value to check.
    	     * @param {Object} [object] The object to query keys on.
    	     * @returns {boolean} Returns `true` if `value` is a property name, else `false`.
    	     */function isKey(value,object){if(isArray(value)){return false;}var type=typeof value;if(type=='number'||type=='symbol'||type=='boolean'||value==null||isSymbol(value)){return true;}return reIsPlainProp.test(value)||!reIsDeepProp.test(value)||object!=null&&value in Object(object);}/**
    	     * Checks if `value` is suitable for use as unique object key.
    	     *
    	     * @private
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is suitable, else `false`.
    	     */function isKeyable(value){var type=typeof value;return type=='string'||type=='number'||type=='symbol'||type=='boolean'?value!=='__proto__':value===null;}/**
    	     * Checks if `func` has a lazy counterpart.
    	     *
    	     * @private
    	     * @param {Function} func The function to check.
    	     * @returns {boolean} Returns `true` if `func` has a lazy counterpart,
    	     *  else `false`.
    	     */function isLaziable(func){var funcName=getFuncName(func),other=lodash[funcName];if(typeof other!='function'||!(funcName in LazyWrapper.prototype)){return false;}if(func===other){return true;}var data=getData(other);return !!data&&func===data[0];}/**
    	     * Checks if `func` has its source masked.
    	     *
    	     * @private
    	     * @param {Function} func The function to check.
    	     * @returns {boolean} Returns `true` if `func` is masked, else `false`.
    	     */function isMasked(func){return !!maskSrcKey&&maskSrcKey in func;}/**
    	     * Checks if `func` is capable of being masked.
    	     *
    	     * @private
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `func` is maskable, else `false`.
    	     */var isMaskable=coreJsData?isFunction:stubFalse;/**
    	     * Checks if `value` is likely a prototype object.
    	     *
    	     * @private
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a prototype, else `false`.
    	     */function isPrototype(value){var Ctor=value&&value.constructor,proto=typeof Ctor=='function'&&Ctor.prototype||objectProto;return value===proto;}/**
    	     * Checks if `value` is suitable for strict equality comparisons, i.e. `===`.
    	     *
    	     * @private
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` if suitable for strict
    	     *  equality comparisons, else `false`.
    	     */function isStrictComparable(value){return value===value&&!isObject(value);}/**
    	     * A specialized version of `matchesProperty` for source values suitable
    	     * for strict equality comparisons, i.e. `===`.
    	     *
    	     * @private
    	     * @param {string} key The key of the property to get.
    	     * @param {*} srcValue The value to match.
    	     * @returns {Function} Returns the new spec function.
    	     */function matchesStrictComparable(key,srcValue){return function(object){if(object==null){return false;}return object[key]===srcValue&&(srcValue!==undefined$1||key in Object(object));};}/**
    	     * A specialized version of `_.memoize` which clears the memoized function's
    	     * cache when it exceeds `MAX_MEMOIZE_SIZE`.
    	     *
    	     * @private
    	     * @param {Function} func The function to have its output memoized.
    	     * @returns {Function} Returns the new memoized function.
    	     */function memoizeCapped(func){var result=memoize(func,function(key){if(cache.size===MAX_MEMOIZE_SIZE){cache.clear();}return key;});var cache=result.cache;return result;}/**
    	     * Merges the function metadata of `source` into `data`.
    	     *
    	     * Merging metadata reduces the number of wrappers used to invoke a function.
    	     * This is possible because methods like `_.bind`, `_.curry`, and `_.partial`
    	     * may be applied regardless of execution order. Methods like `_.ary` and
    	     * `_.rearg` modify function arguments, making the order in which they are
    	     * executed important, preventing the merging of metadata. However, we make
    	     * an exception for a safe combined case where curried functions have `_.ary`
    	     * and or `_.rearg` applied.
    	     *
    	     * @private
    	     * @param {Array} data The destination metadata.
    	     * @param {Array} source The source metadata.
    	     * @returns {Array} Returns `data`.
    	     */function mergeData(data,source){var bitmask=data[1],srcBitmask=source[1],newBitmask=bitmask|srcBitmask,isCommon=newBitmask<(WRAP_BIND_FLAG|WRAP_BIND_KEY_FLAG|WRAP_ARY_FLAG);var isCombo=srcBitmask==WRAP_ARY_FLAG&&bitmask==WRAP_CURRY_FLAG||srcBitmask==WRAP_ARY_FLAG&&bitmask==WRAP_REARG_FLAG&&data[7].length<=source[8]||srcBitmask==(WRAP_ARY_FLAG|WRAP_REARG_FLAG)&&source[7].length<=source[8]&&bitmask==WRAP_CURRY_FLAG;// Exit early if metadata can't be merged.
    	if(!(isCommon||isCombo)){return data;}// Use source `thisArg` if available.
    	if(srcBitmask&WRAP_BIND_FLAG){data[2]=source[2];// Set when currying a bound function.
    	newBitmask|=bitmask&WRAP_BIND_FLAG?0:WRAP_CURRY_BOUND_FLAG;}// Compose partial arguments.
    	var value=source[3];if(value){var partials=data[3];data[3]=partials?composeArgs(partials,value,source[4]):value;data[4]=partials?replaceHolders(data[3],PLACEHOLDER):source[4];}// Compose partial right arguments.
    	value=source[5];if(value){partials=data[5];data[5]=partials?composeArgsRight(partials,value,source[6]):value;data[6]=partials?replaceHolders(data[5],PLACEHOLDER):source[6];}// Use source `argPos` if available.
    	value=source[7];if(value){data[7]=value;}// Use source `ary` if it's smaller.
    	if(srcBitmask&WRAP_ARY_FLAG){data[8]=data[8]==null?source[8]:nativeMin(data[8],source[8]);}// Use source `arity` if one is not provided.
    	if(data[9]==null){data[9]=source[9];}// Use source `func` and merge bitmasks.
    	data[0]=source[0];data[1]=newBitmask;return data;}/**
    	     * This function is like
    	     * [`Object.keys`](http://ecma-international.org/ecma-262/7.0/#sec-object.keys)
    	     * except that it includes inherited enumerable properties.
    	     *
    	     * @private
    	     * @param {Object} object The object to query.
    	     * @returns {Array} Returns the array of property names.
    	     */function nativeKeysIn(object){var result=[];if(object!=null){for(var key in Object(object)){result.push(key);}}return result;}/**
    	     * Converts `value` to a string using `Object.prototype.toString`.
    	     *
    	     * @private
    	     * @param {*} value The value to convert.
    	     * @returns {string} Returns the converted string.
    	     */function objectToString(value){return nativeObjectToString.call(value);}/**
    	     * A specialized version of `baseRest` which transforms the rest array.
    	     *
    	     * @private
    	     * @param {Function} func The function to apply a rest parameter to.
    	     * @param {number} [start=func.length-1] The start position of the rest parameter.
    	     * @param {Function} transform The rest array transform.
    	     * @returns {Function} Returns the new function.
    	     */function overRest(func,start,transform){start=nativeMax(start===undefined$1?func.length-1:start,0);return function(){var args=arguments,index=-1,length=nativeMax(args.length-start,0),array=Array(length);while(++index<length){array[index]=args[start+index];}index=-1;var otherArgs=Array(start+1);while(++index<start){otherArgs[index]=args[index];}otherArgs[start]=transform(array);return apply(func,this,otherArgs);};}/**
    	     * Gets the parent value at `path` of `object`.
    	     *
    	     * @private
    	     * @param {Object} object The object to query.
    	     * @param {Array} path The path to get the parent value of.
    	     * @returns {*} Returns the parent value.
    	     */function parent(object,path){return path.length<2?object:baseGet(object,baseSlice(path,0,-1));}/**
    	     * Reorder `array` according to the specified indexes where the element at
    	     * the first index is assigned as the first element, the element at
    	     * the second index is assigned as the second element, and so on.
    	     *
    	     * @private
    	     * @param {Array} array The array to reorder.
    	     * @param {Array} indexes The arranged array indexes.
    	     * @returns {Array} Returns `array`.
    	     */function reorder(array,indexes){var arrLength=array.length,length=nativeMin(indexes.length,arrLength),oldArray=copyArray(array);while(length--){var index=indexes[length];array[length]=isIndex(index,arrLength)?oldArray[index]:undefined$1;}return array;}/**
    	     * Gets the value at `key`, unless `key` is "__proto__" or "constructor".
    	     *
    	     * @private
    	     * @param {Object} object The object to query.
    	     * @param {string} key The key of the property to get.
    	     * @returns {*} Returns the property value.
    	     */function safeGet(object,key){if(key==='constructor'&&typeof object[key]==='function'){return;}if(key=='__proto__'){return;}return object[key];}/**
    	     * Sets metadata for `func`.
    	     *
    	     * **Note:** If this function becomes hot, i.e. is invoked a lot in a short
    	     * period of time, it will trip its breaker and transition to an identity
    	     * function to avoid garbage collection pauses in V8. See
    	     * [V8 issue 2070](https://bugs.chromium.org/p/v8/issues/detail?id=2070)
    	     * for more details.
    	     *
    	     * @private
    	     * @param {Function} func The function to associate metadata with.
    	     * @param {*} data The metadata.
    	     * @returns {Function} Returns `func`.
    	     */var setData=shortOut(baseSetData);/**
    	     * A simple wrapper around the global [`setTimeout`](https://mdn.io/setTimeout).
    	     *
    	     * @private
    	     * @param {Function} func The function to delay.
    	     * @param {number} wait The number of milliseconds to delay invocation.
    	     * @returns {number|Object} Returns the timer id or timeout object.
    	     */var setTimeout=ctxSetTimeout||function(func,wait){return root.setTimeout(func,wait);};/**
    	     * Sets the `toString` method of `func` to return `string`.
    	     *
    	     * @private
    	     * @param {Function} func The function to modify.
    	     * @param {Function} string The `toString` result.
    	     * @returns {Function} Returns `func`.
    	     */var setToString=shortOut(baseSetToString);/**
    	     * Sets the `toString` method of `wrapper` to mimic the source of `reference`
    	     * with wrapper details in a comment at the top of the source body.
    	     *
    	     * @private
    	     * @param {Function} wrapper The function to modify.
    	     * @param {Function} reference The reference function.
    	     * @param {number} bitmask The bitmask flags. See `createWrap` for more details.
    	     * @returns {Function} Returns `wrapper`.
    	     */function setWrapToString(wrapper,reference,bitmask){var source=reference+'';return setToString(wrapper,insertWrapDetails(source,updateWrapDetails(getWrapDetails(source),bitmask)));}/**
    	     * Creates a function that'll short out and invoke `identity` instead
    	     * of `func` when it's called `HOT_COUNT` or more times in `HOT_SPAN`
    	     * milliseconds.
    	     *
    	     * @private
    	     * @param {Function} func The function to restrict.
    	     * @returns {Function} Returns the new shortable function.
    	     */function shortOut(func){var count=0,lastCalled=0;return function(){var stamp=nativeNow(),remaining=HOT_SPAN-(stamp-lastCalled);lastCalled=stamp;if(remaining>0){if(++count>=HOT_COUNT){return arguments[0];}}else {count=0;}return func.apply(undefined$1,arguments);};}/**
    	     * A specialized version of `_.shuffle` which mutates and sets the size of `array`.
    	     *
    	     * @private
    	     * @param {Array} array The array to shuffle.
    	     * @param {number} [size=array.length] The size of `array`.
    	     * @returns {Array} Returns `array`.
    	     */function shuffleSelf(array,size){var index=-1,length=array.length,lastIndex=length-1;size=size===undefined$1?length:size;while(++index<size){var rand=baseRandom(index,lastIndex),value=array[rand];array[rand]=array[index];array[index]=value;}array.length=size;return array;}/**
    	     * Converts `string` to a property path array.
    	     *
    	     * @private
    	     * @param {string} string The string to convert.
    	     * @returns {Array} Returns the property path array.
    	     */var stringToPath=memoizeCapped(function(string){var result=[];if(string.charCodeAt(0)===46/* . */){result.push('');}string.replace(rePropName,function(match,number,quote,subString){result.push(quote?subString.replace(reEscapeChar,'$1'):number||match);});return result;});/**
    	     * Converts `value` to a string key if it's not a string or symbol.
    	     *
    	     * @private
    	     * @param {*} value The value to inspect.
    	     * @returns {string|symbol} Returns the key.
    	     */function toKey(value){if(typeof value=='string'||isSymbol(value)){return value;}var result=value+'';return result=='0'&&1/value==-INFINITY?'-0':result;}/**
    	     * Converts `func` to its source code.
    	     *
    	     * @private
    	     * @param {Function} func The function to convert.
    	     * @returns {string} Returns the source code.
    	     */function toSource(func){if(func!=null){try{return funcToString.call(func);}catch(e){}try{return func+'';}catch(e){}}return '';}/**
    	     * Updates wrapper `details` based on `bitmask` flags.
    	     *
    	     * @private
    	     * @returns {Array} details The details to modify.
    	     * @param {number} bitmask The bitmask flags. See `createWrap` for more details.
    	     * @returns {Array} Returns `details`.
    	     */function updateWrapDetails(details,bitmask){arrayEach(wrapFlags,function(pair){var value='_.'+pair[0];if(bitmask&pair[1]&&!arrayIncludes(details,value)){details.push(value);}});return details.sort();}/**
    	     * Creates a clone of `wrapper`.
    	     *
    	     * @private
    	     * @param {Object} wrapper The wrapper to clone.
    	     * @returns {Object} Returns the cloned wrapper.
    	     */function wrapperClone(wrapper){if(wrapper instanceof LazyWrapper){return wrapper.clone();}var result=new LodashWrapper(wrapper.__wrapped__,wrapper.__chain__);result.__actions__=copyArray(wrapper.__actions__);result.__index__=wrapper.__index__;result.__values__=wrapper.__values__;return result;}/*------------------------------------------------------------------------*/ /**
    	     * Creates an array of elements split into groups the length of `size`.
    	     * If `array` can't be split evenly, the final chunk will be the remaining
    	     * elements.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Array
    	     * @param {Array} array The array to process.
    	     * @param {number} [size=1] The length of each chunk
    	     * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
    	     * @returns {Array} Returns the new array of chunks.
    	     * @example
    	     *
    	     * _.chunk(['a', 'b', 'c', 'd'], 2);
    	     * // => [['a', 'b'], ['c', 'd']]
    	     *
    	     * _.chunk(['a', 'b', 'c', 'd'], 3);
    	     * // => [['a', 'b', 'c'], ['d']]
    	     */function chunk(array,size,guard){if(guard?isIterateeCall(array,size,guard):size===undefined$1){size=1;}else {size=nativeMax(toInteger(size),0);}var length=array==null?0:array.length;if(!length||size<1){return [];}var index=0,resIndex=0,result=Array(nativeCeil(length/size));while(index<length){result[resIndex++]=baseSlice(array,index,index+=size);}return result;}/**
    	     * Creates an array with all falsey values removed. The values `false`, `null`,
    	     * `0`, `""`, `undefined`, and `NaN` are falsey.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Array
    	     * @param {Array} array The array to compact.
    	     * @returns {Array} Returns the new array of filtered values.
    	     * @example
    	     *
    	     * _.compact([0, 1, false, 2, '', 3]);
    	     * // => [1, 2, 3]
    	     */function compact(array){var index=-1,length=array==null?0:array.length,resIndex=0,result=[];while(++index<length){var value=array[index];if(value){result[resIndex++]=value;}}return result;}/**
    	     * Creates a new array concatenating `array` with any additional arrays
    	     * and/or values.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Array
    	     * @param {Array} array The array to concatenate.
    	     * @param {...*} [values] The values to concatenate.
    	     * @returns {Array} Returns the new concatenated array.
    	     * @example
    	     *
    	     * var array = [1];
    	     * var other = _.concat(array, 2, [3], [[4]]);
    	     *
    	     * console.log(other);
    	     * // => [1, 2, 3, [4]]
    	     *
    	     * console.log(array);
    	     * // => [1]
    	     */function concat(){var length=arguments.length;if(!length){return [];}var args=Array(length-1),array=arguments[0],index=length;while(index--){args[index-1]=arguments[index];}return arrayPush(isArray(array)?copyArray(array):[array],baseFlatten(args,1));}/**
    	     * Creates an array of `array` values not included in the other given arrays
    	     * using [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
    	     * for equality comparisons. The order and references of result values are
    	     * determined by the first array.
    	     *
    	     * **Note:** Unlike `_.pullAll`, this method returns a new array.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Array
    	     * @param {Array} array The array to inspect.
    	     * @param {...Array} [values] The values to exclude.
    	     * @returns {Array} Returns the new array of filtered values.
    	     * @see _.without, _.xor
    	     * @example
    	     *
    	     * _.difference([2, 1], [2, 3]);
    	     * // => [1]
    	     */var difference=baseRest(function(array,values){return isArrayLikeObject(array)?baseDifference(array,baseFlatten(values,1,isArrayLikeObject,true)):[];});/**
    	     * This method is like `_.difference` except that it accepts `iteratee` which
    	     * is invoked for each element of `array` and `values` to generate the criterion
    	     * by which they're compared. The order and references of result values are
    	     * determined by the first array. The iteratee is invoked with one argument:
    	     * (value).
    	     *
    	     * **Note:** Unlike `_.pullAllBy`, this method returns a new array.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Array
    	     * @param {Array} array The array to inspect.
    	     * @param {...Array} [values] The values to exclude.
    	     * @param {Function} [iteratee=_.identity] The iteratee invoked per element.
    	     * @returns {Array} Returns the new array of filtered values.
    	     * @example
    	     *
    	     * _.differenceBy([2.1, 1.2], [2.3, 3.4], Math.floor);
    	     * // => [1.2]
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.differenceBy([{ 'x': 2 }, { 'x': 1 }], [{ 'x': 1 }], 'x');
    	     * // => [{ 'x': 2 }]
    	     */var differenceBy=baseRest(function(array,values){var iteratee=last(values);if(isArrayLikeObject(iteratee)){iteratee=undefined$1;}return isArrayLikeObject(array)?baseDifference(array,baseFlatten(values,1,isArrayLikeObject,true),getIteratee(iteratee,2)):[];});/**
    	     * This method is like `_.difference` except that it accepts `comparator`
    	     * which is invoked to compare elements of `array` to `values`. The order and
    	     * references of result values are determined by the first array. The comparator
    	     * is invoked with two arguments: (arrVal, othVal).
    	     *
    	     * **Note:** Unlike `_.pullAllWith`, this method returns a new array.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Array
    	     * @param {Array} array The array to inspect.
    	     * @param {...Array} [values] The values to exclude.
    	     * @param {Function} [comparator] The comparator invoked per element.
    	     * @returns {Array} Returns the new array of filtered values.
    	     * @example
    	     *
    	     * var objects = [{ 'x': 1, 'y': 2 }, { 'x': 2, 'y': 1 }];
    	     *
    	     * _.differenceWith(objects, [{ 'x': 1, 'y': 2 }], _.isEqual);
    	     * // => [{ 'x': 2, 'y': 1 }]
    	     */var differenceWith=baseRest(function(array,values){var comparator=last(values);if(isArrayLikeObject(comparator)){comparator=undefined$1;}return isArrayLikeObject(array)?baseDifference(array,baseFlatten(values,1,isArrayLikeObject,true),undefined$1,comparator):[];});/**
    	     * Creates a slice of `array` with `n` elements dropped from the beginning.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.5.0
    	     * @category Array
    	     * @param {Array} array The array to query.
    	     * @param {number} [n=1] The number of elements to drop.
    	     * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
    	     * @returns {Array} Returns the slice of `array`.
    	     * @example
    	     *
    	     * _.drop([1, 2, 3]);
    	     * // => [2, 3]
    	     *
    	     * _.drop([1, 2, 3], 2);
    	     * // => [3]
    	     *
    	     * _.drop([1, 2, 3], 5);
    	     * // => []
    	     *
    	     * _.drop([1, 2, 3], 0);
    	     * // => [1, 2, 3]
    	     */function drop(array,n,guard){var length=array==null?0:array.length;if(!length){return [];}n=guard||n===undefined$1?1:toInteger(n);return baseSlice(array,n<0?0:n,length);}/**
    	     * Creates a slice of `array` with `n` elements dropped from the end.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Array
    	     * @param {Array} array The array to query.
    	     * @param {number} [n=1] The number of elements to drop.
    	     * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
    	     * @returns {Array} Returns the slice of `array`.
    	     * @example
    	     *
    	     * _.dropRight([1, 2, 3]);
    	     * // => [1, 2]
    	     *
    	     * _.dropRight([1, 2, 3], 2);
    	     * // => [1]
    	     *
    	     * _.dropRight([1, 2, 3], 5);
    	     * // => []
    	     *
    	     * _.dropRight([1, 2, 3], 0);
    	     * // => [1, 2, 3]
    	     */function dropRight(array,n,guard){var length=array==null?0:array.length;if(!length){return [];}n=guard||n===undefined$1?1:toInteger(n);n=length-n;return baseSlice(array,0,n<0?0:n);}/**
    	     * Creates a slice of `array` excluding elements dropped from the end.
    	     * Elements are dropped until `predicate` returns falsey. The predicate is
    	     * invoked with three arguments: (value, index, array).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Array
    	     * @param {Array} array The array to query.
    	     * @param {Function} [predicate=_.identity] The function invoked per iteration.
    	     * @returns {Array} Returns the slice of `array`.
    	     * @example
    	     *
    	     * var users = [
    	     *   { 'user': 'barney',  'active': true },
    	     *   { 'user': 'fred',    'active': false },
    	     *   { 'user': 'pebbles', 'active': false }
    	     * ];
    	     *
    	     * _.dropRightWhile(users, function(o) { return !o.active; });
    	     * // => objects for ['barney']
    	     *
    	     * // The `_.matches` iteratee shorthand.
    	     * _.dropRightWhile(users, { 'user': 'pebbles', 'active': false });
    	     * // => objects for ['barney', 'fred']
    	     *
    	     * // The `_.matchesProperty` iteratee shorthand.
    	     * _.dropRightWhile(users, ['active', false]);
    	     * // => objects for ['barney']
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.dropRightWhile(users, 'active');
    	     * // => objects for ['barney', 'fred', 'pebbles']
    	     */function dropRightWhile(array,predicate){return array&&array.length?baseWhile(array,getIteratee(predicate,3),true,true):[];}/**
    	     * Creates a slice of `array` excluding elements dropped from the beginning.
    	     * Elements are dropped until `predicate` returns falsey. The predicate is
    	     * invoked with three arguments: (value, index, array).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Array
    	     * @param {Array} array The array to query.
    	     * @param {Function} [predicate=_.identity] The function invoked per iteration.
    	     * @returns {Array} Returns the slice of `array`.
    	     * @example
    	     *
    	     * var users = [
    	     *   { 'user': 'barney',  'active': false },
    	     *   { 'user': 'fred',    'active': false },
    	     *   { 'user': 'pebbles', 'active': true }
    	     * ];
    	     *
    	     * _.dropWhile(users, function(o) { return !o.active; });
    	     * // => objects for ['pebbles']
    	     *
    	     * // The `_.matches` iteratee shorthand.
    	     * _.dropWhile(users, { 'user': 'barney', 'active': false });
    	     * // => objects for ['fred', 'pebbles']
    	     *
    	     * // The `_.matchesProperty` iteratee shorthand.
    	     * _.dropWhile(users, ['active', false]);
    	     * // => objects for ['pebbles']
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.dropWhile(users, 'active');
    	     * // => objects for ['barney', 'fred', 'pebbles']
    	     */function dropWhile(array,predicate){return array&&array.length?baseWhile(array,getIteratee(predicate,3),true):[];}/**
    	     * Fills elements of `array` with `value` from `start` up to, but not
    	     * including, `end`.
    	     *
    	     * **Note:** This method mutates `array`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.2.0
    	     * @category Array
    	     * @param {Array} array The array to fill.
    	     * @param {*} value The value to fill `array` with.
    	     * @param {number} [start=0] The start position.
    	     * @param {number} [end=array.length] The end position.
    	     * @returns {Array} Returns `array`.
    	     * @example
    	     *
    	     * var array = [1, 2, 3];
    	     *
    	     * _.fill(array, 'a');
    	     * console.log(array);
    	     * // => ['a', 'a', 'a']
    	     *
    	     * _.fill(Array(3), 2);
    	     * // => [2, 2, 2]
    	     *
    	     * _.fill([4, 6, 8, 10], '*', 1, 3);
    	     * // => [4, '*', '*', 10]
    	     */function fill(array,value,start,end){var length=array==null?0:array.length;if(!length){return [];}if(start&&typeof start!='number'&&isIterateeCall(array,value,start)){start=0;end=length;}return baseFill(array,value,start,end);}/**
    	     * This method is like `_.find` except that it returns the index of the first
    	     * element `predicate` returns truthy for instead of the element itself.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 1.1.0
    	     * @category Array
    	     * @param {Array} array The array to inspect.
    	     * @param {Function} [predicate=_.identity] The function invoked per iteration.
    	     * @param {number} [fromIndex=0] The index to search from.
    	     * @returns {number} Returns the index of the found element, else `-1`.
    	     * @example
    	     *
    	     * var users = [
    	     *   { 'user': 'barney',  'active': false },
    	     *   { 'user': 'fred',    'active': false },
    	     *   { 'user': 'pebbles', 'active': true }
    	     * ];
    	     *
    	     * _.findIndex(users, function(o) { return o.user == 'barney'; });
    	     * // => 0
    	     *
    	     * // The `_.matches` iteratee shorthand.
    	     * _.findIndex(users, { 'user': 'fred', 'active': false });
    	     * // => 1
    	     *
    	     * // The `_.matchesProperty` iteratee shorthand.
    	     * _.findIndex(users, ['active', false]);
    	     * // => 0
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.findIndex(users, 'active');
    	     * // => 2
    	     */function findIndex(array,predicate,fromIndex){var length=array==null?0:array.length;if(!length){return -1;}var index=fromIndex==null?0:toInteger(fromIndex);if(index<0){index=nativeMax(length+index,0);}return baseFindIndex(array,getIteratee(predicate,3),index);}/**
    	     * This method is like `_.findIndex` except that it iterates over elements
    	     * of `collection` from right to left.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 2.0.0
    	     * @category Array
    	     * @param {Array} array The array to inspect.
    	     * @param {Function} [predicate=_.identity] The function invoked per iteration.
    	     * @param {number} [fromIndex=array.length-1] The index to search from.
    	     * @returns {number} Returns the index of the found element, else `-1`.
    	     * @example
    	     *
    	     * var users = [
    	     *   { 'user': 'barney',  'active': true },
    	     *   { 'user': 'fred',    'active': false },
    	     *   { 'user': 'pebbles', 'active': false }
    	     * ];
    	     *
    	     * _.findLastIndex(users, function(o) { return o.user == 'pebbles'; });
    	     * // => 2
    	     *
    	     * // The `_.matches` iteratee shorthand.
    	     * _.findLastIndex(users, { 'user': 'barney', 'active': true });
    	     * // => 0
    	     *
    	     * // The `_.matchesProperty` iteratee shorthand.
    	     * _.findLastIndex(users, ['active', false]);
    	     * // => 2
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.findLastIndex(users, 'active');
    	     * // => 0
    	     */function findLastIndex(array,predicate,fromIndex){var length=array==null?0:array.length;if(!length){return -1;}var index=length-1;if(fromIndex!==undefined$1){index=toInteger(fromIndex);index=fromIndex<0?nativeMax(length+index,0):nativeMin(index,length-1);}return baseFindIndex(array,getIteratee(predicate,3),index,true);}/**
    	     * Flattens `array` a single level deep.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Array
    	     * @param {Array} array The array to flatten.
    	     * @returns {Array} Returns the new flattened array.
    	     * @example
    	     *
    	     * _.flatten([1, [2, [3, [4]], 5]]);
    	     * // => [1, 2, [3, [4]], 5]
    	     */function flatten(array){var length=array==null?0:array.length;return length?baseFlatten(array,1):[];}/**
    	     * Recursively flattens `array`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Array
    	     * @param {Array} array The array to flatten.
    	     * @returns {Array} Returns the new flattened array.
    	     * @example
    	     *
    	     * _.flattenDeep([1, [2, [3, [4]], 5]]);
    	     * // => [1, 2, 3, 4, 5]
    	     */function flattenDeep(array){var length=array==null?0:array.length;return length?baseFlatten(array,INFINITY):[];}/**
    	     * Recursively flatten `array` up to `depth` times.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.4.0
    	     * @category Array
    	     * @param {Array} array The array to flatten.
    	     * @param {number} [depth=1] The maximum recursion depth.
    	     * @returns {Array} Returns the new flattened array.
    	     * @example
    	     *
    	     * var array = [1, [2, [3, [4]], 5]];
    	     *
    	     * _.flattenDepth(array, 1);
    	     * // => [1, 2, [3, [4]], 5]
    	     *
    	     * _.flattenDepth(array, 2);
    	     * // => [1, 2, 3, [4], 5]
    	     */function flattenDepth(array,depth){var length=array==null?0:array.length;if(!length){return [];}depth=depth===undefined$1?1:toInteger(depth);return baseFlatten(array,depth);}/**
    	     * The inverse of `_.toPairs`; this method returns an object composed
    	     * from key-value `pairs`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Array
    	     * @param {Array} pairs The key-value pairs.
    	     * @returns {Object} Returns the new object.
    	     * @example
    	     *
    	     * _.fromPairs([['a', 1], ['b', 2]]);
    	     * // => { 'a': 1, 'b': 2 }
    	     */function fromPairs(pairs){var index=-1,length=pairs==null?0:pairs.length,result={};while(++index<length){var pair=pairs[index];result[pair[0]]=pair[1];}return result;}/**
    	     * Gets the first element of `array`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @alias first
    	     * @category Array
    	     * @param {Array} array The array to query.
    	     * @returns {*} Returns the first element of `array`.
    	     * @example
    	     *
    	     * _.head([1, 2, 3]);
    	     * // => 1
    	     *
    	     * _.head([]);
    	     * // => undefined
    	     */function head(array){return array&&array.length?array[0]:undefined$1;}/**
    	     * Gets the index at which the first occurrence of `value` is found in `array`
    	     * using [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
    	     * for equality comparisons. If `fromIndex` is negative, it's used as the
    	     * offset from the end of `array`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Array
    	     * @param {Array} array The array to inspect.
    	     * @param {*} value The value to search for.
    	     * @param {number} [fromIndex=0] The index to search from.
    	     * @returns {number} Returns the index of the matched value, else `-1`.
    	     * @example
    	     *
    	     * _.indexOf([1, 2, 1, 2], 2);
    	     * // => 1
    	     *
    	     * // Search from the `fromIndex`.
    	     * _.indexOf([1, 2, 1, 2], 2, 2);
    	     * // => 3
    	     */function indexOf(array,value,fromIndex){var length=array==null?0:array.length;if(!length){return -1;}var index=fromIndex==null?0:toInteger(fromIndex);if(index<0){index=nativeMax(length+index,0);}return baseIndexOf(array,value,index);}/**
    	     * Gets all but the last element of `array`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Array
    	     * @param {Array} array The array to query.
    	     * @returns {Array} Returns the slice of `array`.
    	     * @example
    	     *
    	     * _.initial([1, 2, 3]);
    	     * // => [1, 2]
    	     */function initial(array){var length=array==null?0:array.length;return length?baseSlice(array,0,-1):[];}/**
    	     * Creates an array of unique values that are included in all given arrays
    	     * using [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
    	     * for equality comparisons. The order and references of result values are
    	     * determined by the first array.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Array
    	     * @param {...Array} [arrays] The arrays to inspect.
    	     * @returns {Array} Returns the new array of intersecting values.
    	     * @example
    	     *
    	     * _.intersection([2, 1], [2, 3]);
    	     * // => [2]
    	     */var intersection=baseRest(function(arrays){var mapped=arrayMap(arrays,castArrayLikeObject);return mapped.length&&mapped[0]===arrays[0]?baseIntersection(mapped):[];});/**
    	     * This method is like `_.intersection` except that it accepts `iteratee`
    	     * which is invoked for each element of each `arrays` to generate the criterion
    	     * by which they're compared. The order and references of result values are
    	     * determined by the first array. The iteratee is invoked with one argument:
    	     * (value).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Array
    	     * @param {...Array} [arrays] The arrays to inspect.
    	     * @param {Function} [iteratee=_.identity] The iteratee invoked per element.
    	     * @returns {Array} Returns the new array of intersecting values.
    	     * @example
    	     *
    	     * _.intersectionBy([2.1, 1.2], [2.3, 3.4], Math.floor);
    	     * // => [2.1]
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.intersectionBy([{ 'x': 1 }], [{ 'x': 2 }, { 'x': 1 }], 'x');
    	     * // => [{ 'x': 1 }]
    	     */var intersectionBy=baseRest(function(arrays){var iteratee=last(arrays),mapped=arrayMap(arrays,castArrayLikeObject);if(iteratee===last(mapped)){iteratee=undefined$1;}else {mapped.pop();}return mapped.length&&mapped[0]===arrays[0]?baseIntersection(mapped,getIteratee(iteratee,2)):[];});/**
    	     * This method is like `_.intersection` except that it accepts `comparator`
    	     * which is invoked to compare elements of `arrays`. The order and references
    	     * of result values are determined by the first array. The comparator is
    	     * invoked with two arguments: (arrVal, othVal).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Array
    	     * @param {...Array} [arrays] The arrays to inspect.
    	     * @param {Function} [comparator] The comparator invoked per element.
    	     * @returns {Array} Returns the new array of intersecting values.
    	     * @example
    	     *
    	     * var objects = [{ 'x': 1, 'y': 2 }, { 'x': 2, 'y': 1 }];
    	     * var others = [{ 'x': 1, 'y': 1 }, { 'x': 1, 'y': 2 }];
    	     *
    	     * _.intersectionWith(objects, others, _.isEqual);
    	     * // => [{ 'x': 1, 'y': 2 }]
    	     */var intersectionWith=baseRest(function(arrays){var comparator=last(arrays),mapped=arrayMap(arrays,castArrayLikeObject);comparator=typeof comparator=='function'?comparator:undefined$1;if(comparator){mapped.pop();}return mapped.length&&mapped[0]===arrays[0]?baseIntersection(mapped,undefined$1,comparator):[];});/**
    	     * Converts all elements in `array` into a string separated by `separator`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Array
    	     * @param {Array} array The array to convert.
    	     * @param {string} [separator=','] The element separator.
    	     * @returns {string} Returns the joined string.
    	     * @example
    	     *
    	     * _.join(['a', 'b', 'c'], '~');
    	     * // => 'a~b~c'
    	     */function join(array,separator){return array==null?'':nativeJoin.call(array,separator);}/**
    	     * Gets the last element of `array`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Array
    	     * @param {Array} array The array to query.
    	     * @returns {*} Returns the last element of `array`.
    	     * @example
    	     *
    	     * _.last([1, 2, 3]);
    	     * // => 3
    	     */function last(array){var length=array==null?0:array.length;return length?array[length-1]:undefined$1;}/**
    	     * This method is like `_.indexOf` except that it iterates over elements of
    	     * `array` from right to left.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Array
    	     * @param {Array} array The array to inspect.
    	     * @param {*} value The value to search for.
    	     * @param {number} [fromIndex=array.length-1] The index to search from.
    	     * @returns {number} Returns the index of the matched value, else `-1`.
    	     * @example
    	     *
    	     * _.lastIndexOf([1, 2, 1, 2], 2);
    	     * // => 3
    	     *
    	     * // Search from the `fromIndex`.
    	     * _.lastIndexOf([1, 2, 1, 2], 2, 2);
    	     * // => 1
    	     */function lastIndexOf(array,value,fromIndex){var length=array==null?0:array.length;if(!length){return -1;}var index=length;if(fromIndex!==undefined$1){index=toInteger(fromIndex);index=index<0?nativeMax(length+index,0):nativeMin(index,length-1);}return value===value?strictLastIndexOf(array,value,index):baseFindIndex(array,baseIsNaN,index,true);}/**
    	     * Gets the element at index `n` of `array`. If `n` is negative, the nth
    	     * element from the end is returned.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.11.0
    	     * @category Array
    	     * @param {Array} array The array to query.
    	     * @param {number} [n=0] The index of the element to return.
    	     * @returns {*} Returns the nth element of `array`.
    	     * @example
    	     *
    	     * var array = ['a', 'b', 'c', 'd'];
    	     *
    	     * _.nth(array, 1);
    	     * // => 'b'
    	     *
    	     * _.nth(array, -2);
    	     * // => 'c';
    	     */function nth(array,n){return array&&array.length?baseNth(array,toInteger(n)):undefined$1;}/**
    	     * Removes all given values from `array` using
    	     * [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
    	     * for equality comparisons.
    	     *
    	     * **Note:** Unlike `_.without`, this method mutates `array`. Use `_.remove`
    	     * to remove elements from an array by predicate.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 2.0.0
    	     * @category Array
    	     * @param {Array} array The array to modify.
    	     * @param {...*} [values] The values to remove.
    	     * @returns {Array} Returns `array`.
    	     * @example
    	     *
    	     * var array = ['a', 'b', 'c', 'a', 'b', 'c'];
    	     *
    	     * _.pull(array, 'a', 'c');
    	     * console.log(array);
    	     * // => ['b', 'b']
    	     */var pull=baseRest(pullAll);/**
    	     * This method is like `_.pull` except that it accepts an array of values to remove.
    	     *
    	     * **Note:** Unlike `_.difference`, this method mutates `array`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Array
    	     * @param {Array} array The array to modify.
    	     * @param {Array} values The values to remove.
    	     * @returns {Array} Returns `array`.
    	     * @example
    	     *
    	     * var array = ['a', 'b', 'c', 'a', 'b', 'c'];
    	     *
    	     * _.pullAll(array, ['a', 'c']);
    	     * console.log(array);
    	     * // => ['b', 'b']
    	     */function pullAll(array,values){return array&&array.length&&values&&values.length?basePullAll(array,values):array;}/**
    	     * This method is like `_.pullAll` except that it accepts `iteratee` which is
    	     * invoked for each element of `array` and `values` to generate the criterion
    	     * by which they're compared. The iteratee is invoked with one argument: (value).
    	     *
    	     * **Note:** Unlike `_.differenceBy`, this method mutates `array`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Array
    	     * @param {Array} array The array to modify.
    	     * @param {Array} values The values to remove.
    	     * @param {Function} [iteratee=_.identity] The iteratee invoked per element.
    	     * @returns {Array} Returns `array`.
    	     * @example
    	     *
    	     * var array = [{ 'x': 1 }, { 'x': 2 }, { 'x': 3 }, { 'x': 1 }];
    	     *
    	     * _.pullAllBy(array, [{ 'x': 1 }, { 'x': 3 }], 'x');
    	     * console.log(array);
    	     * // => [{ 'x': 2 }]
    	     */function pullAllBy(array,values,iteratee){return array&&array.length&&values&&values.length?basePullAll(array,values,getIteratee(iteratee,2)):array;}/**
    	     * This method is like `_.pullAll` except that it accepts `comparator` which
    	     * is invoked to compare elements of `array` to `values`. The comparator is
    	     * invoked with two arguments: (arrVal, othVal).
    	     *
    	     * **Note:** Unlike `_.differenceWith`, this method mutates `array`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.6.0
    	     * @category Array
    	     * @param {Array} array The array to modify.
    	     * @param {Array} values The values to remove.
    	     * @param {Function} [comparator] The comparator invoked per element.
    	     * @returns {Array} Returns `array`.
    	     * @example
    	     *
    	     * var array = [{ 'x': 1, 'y': 2 }, { 'x': 3, 'y': 4 }, { 'x': 5, 'y': 6 }];
    	     *
    	     * _.pullAllWith(array, [{ 'x': 3, 'y': 4 }], _.isEqual);
    	     * console.log(array);
    	     * // => [{ 'x': 1, 'y': 2 }, { 'x': 5, 'y': 6 }]
    	     */function pullAllWith(array,values,comparator){return array&&array.length&&values&&values.length?basePullAll(array,values,undefined$1,comparator):array;}/**
    	     * Removes elements from `array` corresponding to `indexes` and returns an
    	     * array of removed elements.
    	     *
    	     * **Note:** Unlike `_.at`, this method mutates `array`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Array
    	     * @param {Array} array The array to modify.
    	     * @param {...(number|number[])} [indexes] The indexes of elements to remove.
    	     * @returns {Array} Returns the new array of removed elements.
    	     * @example
    	     *
    	     * var array = ['a', 'b', 'c', 'd'];
    	     * var pulled = _.pullAt(array, [1, 3]);
    	     *
    	     * console.log(array);
    	     * // => ['a', 'c']
    	     *
    	     * console.log(pulled);
    	     * // => ['b', 'd']
    	     */var pullAt=flatRest(function(array,indexes){var length=array==null?0:array.length,result=baseAt(array,indexes);basePullAt(array,arrayMap(indexes,function(index){return isIndex(index,length)?+index:index;}).sort(compareAscending));return result;});/**
    	     * Removes all elements from `array` that `predicate` returns truthy for
    	     * and returns an array of the removed elements. The predicate is invoked
    	     * with three arguments: (value, index, array).
    	     *
    	     * **Note:** Unlike `_.filter`, this method mutates `array`. Use `_.pull`
    	     * to pull elements from an array by value.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 2.0.0
    	     * @category Array
    	     * @param {Array} array The array to modify.
    	     * @param {Function} [predicate=_.identity] The function invoked per iteration.
    	     * @returns {Array} Returns the new array of removed elements.
    	     * @example
    	     *
    	     * var array = [1, 2, 3, 4];
    	     * var evens = _.remove(array, function(n) {
    	     *   return n % 2 == 0;
    	     * });
    	     *
    	     * console.log(array);
    	     * // => [1, 3]
    	     *
    	     * console.log(evens);
    	     * // => [2, 4]
    	     */function remove(array,predicate){var result=[];if(!(array&&array.length)){return result;}var index=-1,indexes=[],length=array.length;predicate=getIteratee(predicate,3);while(++index<length){var value=array[index];if(predicate(value,index,array)){result.push(value);indexes.push(index);}}basePullAt(array,indexes);return result;}/**
    	     * Reverses `array` so that the first element becomes the last, the second
    	     * element becomes the second to last, and so on.
    	     *
    	     * **Note:** This method mutates `array` and is based on
    	     * [`Array#reverse`](https://mdn.io/Array/reverse).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Array
    	     * @param {Array} array The array to modify.
    	     * @returns {Array} Returns `array`.
    	     * @example
    	     *
    	     * var array = [1, 2, 3];
    	     *
    	     * _.reverse(array);
    	     * // => [3, 2, 1]
    	     *
    	     * console.log(array);
    	     * // => [3, 2, 1]
    	     */function reverse(array){return array==null?array:nativeReverse.call(array);}/**
    	     * Creates a slice of `array` from `start` up to, but not including, `end`.
    	     *
    	     * **Note:** This method is used instead of
    	     * [`Array#slice`](https://mdn.io/Array/slice) to ensure dense arrays are
    	     * returned.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Array
    	     * @param {Array} array The array to slice.
    	     * @param {number} [start=0] The start position.
    	     * @param {number} [end=array.length] The end position.
    	     * @returns {Array} Returns the slice of `array`.
    	     */function slice(array,start,end){var length=array==null?0:array.length;if(!length){return [];}if(end&&typeof end!='number'&&isIterateeCall(array,start,end)){start=0;end=length;}else {start=start==null?0:toInteger(start);end=end===undefined$1?length:toInteger(end);}return baseSlice(array,start,end);}/**
    	     * Uses a binary search to determine the lowest index at which `value`
    	     * should be inserted into `array` in order to maintain its sort order.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Array
    	     * @param {Array} array The sorted array to inspect.
    	     * @param {*} value The value to evaluate.
    	     * @returns {number} Returns the index at which `value` should be inserted
    	     *  into `array`.
    	     * @example
    	     *
    	     * _.sortedIndex([30, 50], 40);
    	     * // => 1
    	     */function sortedIndex(array,value){return baseSortedIndex(array,value);}/**
    	     * This method is like `_.sortedIndex` except that it accepts `iteratee`
    	     * which is invoked for `value` and each element of `array` to compute their
    	     * sort ranking. The iteratee is invoked with one argument: (value).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Array
    	     * @param {Array} array The sorted array to inspect.
    	     * @param {*} value The value to evaluate.
    	     * @param {Function} [iteratee=_.identity] The iteratee invoked per element.
    	     * @returns {number} Returns the index at which `value` should be inserted
    	     *  into `array`.
    	     * @example
    	     *
    	     * var objects = [{ 'x': 4 }, { 'x': 5 }];
    	     *
    	     * _.sortedIndexBy(objects, { 'x': 4 }, function(o) { return o.x; });
    	     * // => 0
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.sortedIndexBy(objects, { 'x': 4 }, 'x');
    	     * // => 0
    	     */function sortedIndexBy(array,value,iteratee){return baseSortedIndexBy(array,value,getIteratee(iteratee,2));}/**
    	     * This method is like `_.indexOf` except that it performs a binary
    	     * search on a sorted `array`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Array
    	     * @param {Array} array The array to inspect.
    	     * @param {*} value The value to search for.
    	     * @returns {number} Returns the index of the matched value, else `-1`.
    	     * @example
    	     *
    	     * _.sortedIndexOf([4, 5, 5, 5, 6], 5);
    	     * // => 1
    	     */function sortedIndexOf(array,value){var length=array==null?0:array.length;if(length){var index=baseSortedIndex(array,value);if(index<length&&eq(array[index],value)){return index;}}return -1;}/**
    	     * This method is like `_.sortedIndex` except that it returns the highest
    	     * index at which `value` should be inserted into `array` in order to
    	     * maintain its sort order.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Array
    	     * @param {Array} array The sorted array to inspect.
    	     * @param {*} value The value to evaluate.
    	     * @returns {number} Returns the index at which `value` should be inserted
    	     *  into `array`.
    	     * @example
    	     *
    	     * _.sortedLastIndex([4, 5, 5, 5, 6], 5);
    	     * // => 4
    	     */function sortedLastIndex(array,value){return baseSortedIndex(array,value,true);}/**
    	     * This method is like `_.sortedLastIndex` except that it accepts `iteratee`
    	     * which is invoked for `value` and each element of `array` to compute their
    	     * sort ranking. The iteratee is invoked with one argument: (value).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Array
    	     * @param {Array} array The sorted array to inspect.
    	     * @param {*} value The value to evaluate.
    	     * @param {Function} [iteratee=_.identity] The iteratee invoked per element.
    	     * @returns {number} Returns the index at which `value` should be inserted
    	     *  into `array`.
    	     * @example
    	     *
    	     * var objects = [{ 'x': 4 }, { 'x': 5 }];
    	     *
    	     * _.sortedLastIndexBy(objects, { 'x': 4 }, function(o) { return o.x; });
    	     * // => 1
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.sortedLastIndexBy(objects, { 'x': 4 }, 'x');
    	     * // => 1
    	     */function sortedLastIndexBy(array,value,iteratee){return baseSortedIndexBy(array,value,getIteratee(iteratee,2),true);}/**
    	     * This method is like `_.lastIndexOf` except that it performs a binary
    	     * search on a sorted `array`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Array
    	     * @param {Array} array The array to inspect.
    	     * @param {*} value The value to search for.
    	     * @returns {number} Returns the index of the matched value, else `-1`.
    	     * @example
    	     *
    	     * _.sortedLastIndexOf([4, 5, 5, 5, 6], 5);
    	     * // => 3
    	     */function sortedLastIndexOf(array,value){var length=array==null?0:array.length;if(length){var index=baseSortedIndex(array,value,true)-1;if(eq(array[index],value)){return index;}}return -1;}/**
    	     * This method is like `_.uniq` except that it's designed and optimized
    	     * for sorted arrays.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Array
    	     * @param {Array} array The array to inspect.
    	     * @returns {Array} Returns the new duplicate free array.
    	     * @example
    	     *
    	     * _.sortedUniq([1, 1, 2]);
    	     * // => [1, 2]
    	     */function sortedUniq(array){return array&&array.length?baseSortedUniq(array):[];}/**
    	     * This method is like `_.uniqBy` except that it's designed and optimized
    	     * for sorted arrays.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Array
    	     * @param {Array} array The array to inspect.
    	     * @param {Function} [iteratee] The iteratee invoked per element.
    	     * @returns {Array} Returns the new duplicate free array.
    	     * @example
    	     *
    	     * _.sortedUniqBy([1.1, 1.2, 2.3, 2.4], Math.floor);
    	     * // => [1.1, 2.3]
    	     */function sortedUniqBy(array,iteratee){return array&&array.length?baseSortedUniq(array,getIteratee(iteratee,2)):[];}/**
    	     * Gets all but the first element of `array`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Array
    	     * @param {Array} array The array to query.
    	     * @returns {Array} Returns the slice of `array`.
    	     * @example
    	     *
    	     * _.tail([1, 2, 3]);
    	     * // => [2, 3]
    	     */function tail(array){var length=array==null?0:array.length;return length?baseSlice(array,1,length):[];}/**
    	     * Creates a slice of `array` with `n` elements taken from the beginning.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Array
    	     * @param {Array} array The array to query.
    	     * @param {number} [n=1] The number of elements to take.
    	     * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
    	     * @returns {Array} Returns the slice of `array`.
    	     * @example
    	     *
    	     * _.take([1, 2, 3]);
    	     * // => [1]
    	     *
    	     * _.take([1, 2, 3], 2);
    	     * // => [1, 2]
    	     *
    	     * _.take([1, 2, 3], 5);
    	     * // => [1, 2, 3]
    	     *
    	     * _.take([1, 2, 3], 0);
    	     * // => []
    	     */function take(array,n,guard){if(!(array&&array.length)){return [];}n=guard||n===undefined$1?1:toInteger(n);return baseSlice(array,0,n<0?0:n);}/**
    	     * Creates a slice of `array` with `n` elements taken from the end.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Array
    	     * @param {Array} array The array to query.
    	     * @param {number} [n=1] The number of elements to take.
    	     * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
    	     * @returns {Array} Returns the slice of `array`.
    	     * @example
    	     *
    	     * _.takeRight([1, 2, 3]);
    	     * // => [3]
    	     *
    	     * _.takeRight([1, 2, 3], 2);
    	     * // => [2, 3]
    	     *
    	     * _.takeRight([1, 2, 3], 5);
    	     * // => [1, 2, 3]
    	     *
    	     * _.takeRight([1, 2, 3], 0);
    	     * // => []
    	     */function takeRight(array,n,guard){var length=array==null?0:array.length;if(!length){return [];}n=guard||n===undefined$1?1:toInteger(n);n=length-n;return baseSlice(array,n<0?0:n,length);}/**
    	     * Creates a slice of `array` with elements taken from the end. Elements are
    	     * taken until `predicate` returns falsey. The predicate is invoked with
    	     * three arguments: (value, index, array).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Array
    	     * @param {Array} array The array to query.
    	     * @param {Function} [predicate=_.identity] The function invoked per iteration.
    	     * @returns {Array} Returns the slice of `array`.
    	     * @example
    	     *
    	     * var users = [
    	     *   { 'user': 'barney',  'active': true },
    	     *   { 'user': 'fred',    'active': false },
    	     *   { 'user': 'pebbles', 'active': false }
    	     * ];
    	     *
    	     * _.takeRightWhile(users, function(o) { return !o.active; });
    	     * // => objects for ['fred', 'pebbles']
    	     *
    	     * // The `_.matches` iteratee shorthand.
    	     * _.takeRightWhile(users, { 'user': 'pebbles', 'active': false });
    	     * // => objects for ['pebbles']
    	     *
    	     * // The `_.matchesProperty` iteratee shorthand.
    	     * _.takeRightWhile(users, ['active', false]);
    	     * // => objects for ['fred', 'pebbles']
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.takeRightWhile(users, 'active');
    	     * // => []
    	     */function takeRightWhile(array,predicate){return array&&array.length?baseWhile(array,getIteratee(predicate,3),false,true):[];}/**
    	     * Creates a slice of `array` with elements taken from the beginning. Elements
    	     * are taken until `predicate` returns falsey. The predicate is invoked with
    	     * three arguments: (value, index, array).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Array
    	     * @param {Array} array The array to query.
    	     * @param {Function} [predicate=_.identity] The function invoked per iteration.
    	     * @returns {Array} Returns the slice of `array`.
    	     * @example
    	     *
    	     * var users = [
    	     *   { 'user': 'barney',  'active': false },
    	     *   { 'user': 'fred',    'active': false },
    	     *   { 'user': 'pebbles', 'active': true }
    	     * ];
    	     *
    	     * _.takeWhile(users, function(o) { return !o.active; });
    	     * // => objects for ['barney', 'fred']
    	     *
    	     * // The `_.matches` iteratee shorthand.
    	     * _.takeWhile(users, { 'user': 'barney', 'active': false });
    	     * // => objects for ['barney']
    	     *
    	     * // The `_.matchesProperty` iteratee shorthand.
    	     * _.takeWhile(users, ['active', false]);
    	     * // => objects for ['barney', 'fred']
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.takeWhile(users, 'active');
    	     * // => []
    	     */function takeWhile(array,predicate){return array&&array.length?baseWhile(array,getIteratee(predicate,3)):[];}/**
    	     * Creates an array of unique values, in order, from all given arrays using
    	     * [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
    	     * for equality comparisons.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Array
    	     * @param {...Array} [arrays] The arrays to inspect.
    	     * @returns {Array} Returns the new array of combined values.
    	     * @example
    	     *
    	     * _.union([2], [1, 2]);
    	     * // => [2, 1]
    	     */var union=baseRest(function(arrays){return baseUniq(baseFlatten(arrays,1,isArrayLikeObject,true));});/**
    	     * This method is like `_.union` except that it accepts `iteratee` which is
    	     * invoked for each element of each `arrays` to generate the criterion by
    	     * which uniqueness is computed. Result values are chosen from the first
    	     * array in which the value occurs. The iteratee is invoked with one argument:
    	     * (value).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Array
    	     * @param {...Array} [arrays] The arrays to inspect.
    	     * @param {Function} [iteratee=_.identity] The iteratee invoked per element.
    	     * @returns {Array} Returns the new array of combined values.
    	     * @example
    	     *
    	     * _.unionBy([2.1], [1.2, 2.3], Math.floor);
    	     * // => [2.1, 1.2]
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.unionBy([{ 'x': 1 }], [{ 'x': 2 }, { 'x': 1 }], 'x');
    	     * // => [{ 'x': 1 }, { 'x': 2 }]
    	     */var unionBy=baseRest(function(arrays){var iteratee=last(arrays);if(isArrayLikeObject(iteratee)){iteratee=undefined$1;}return baseUniq(baseFlatten(arrays,1,isArrayLikeObject,true),getIteratee(iteratee,2));});/**
    	     * This method is like `_.union` except that it accepts `comparator` which
    	     * is invoked to compare elements of `arrays`. Result values are chosen from
    	     * the first array in which the value occurs. The comparator is invoked
    	     * with two arguments: (arrVal, othVal).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Array
    	     * @param {...Array} [arrays] The arrays to inspect.
    	     * @param {Function} [comparator] The comparator invoked per element.
    	     * @returns {Array} Returns the new array of combined values.
    	     * @example
    	     *
    	     * var objects = [{ 'x': 1, 'y': 2 }, { 'x': 2, 'y': 1 }];
    	     * var others = [{ 'x': 1, 'y': 1 }, { 'x': 1, 'y': 2 }];
    	     *
    	     * _.unionWith(objects, others, _.isEqual);
    	     * // => [{ 'x': 1, 'y': 2 }, { 'x': 2, 'y': 1 }, { 'x': 1, 'y': 1 }]
    	     */var unionWith=baseRest(function(arrays){var comparator=last(arrays);comparator=typeof comparator=='function'?comparator:undefined$1;return baseUniq(baseFlatten(arrays,1,isArrayLikeObject,true),undefined$1,comparator);});/**
    	     * Creates a duplicate-free version of an array, using
    	     * [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
    	     * for equality comparisons, in which only the first occurrence of each element
    	     * is kept. The order of result values is determined by the order they occur
    	     * in the array.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Array
    	     * @param {Array} array The array to inspect.
    	     * @returns {Array} Returns the new duplicate free array.
    	     * @example
    	     *
    	     * _.uniq([2, 1, 2]);
    	     * // => [2, 1]
    	     */function uniq(array){return array&&array.length?baseUniq(array):[];}/**
    	     * This method is like `_.uniq` except that it accepts `iteratee` which is
    	     * invoked for each element in `array` to generate the criterion by which
    	     * uniqueness is computed. The order of result values is determined by the
    	     * order they occur in the array. The iteratee is invoked with one argument:
    	     * (value).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Array
    	     * @param {Array} array The array to inspect.
    	     * @param {Function} [iteratee=_.identity] The iteratee invoked per element.
    	     * @returns {Array} Returns the new duplicate free array.
    	     * @example
    	     *
    	     * _.uniqBy([2.1, 1.2, 2.3], Math.floor);
    	     * // => [2.1, 1.2]
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.uniqBy([{ 'x': 1 }, { 'x': 2 }, { 'x': 1 }], 'x');
    	     * // => [{ 'x': 1 }, { 'x': 2 }]
    	     */function uniqBy(array,iteratee){return array&&array.length?baseUniq(array,getIteratee(iteratee,2)):[];}/**
    	     * This method is like `_.uniq` except that it accepts `comparator` which
    	     * is invoked to compare elements of `array`. The order of result values is
    	     * determined by the order they occur in the array.The comparator is invoked
    	     * with two arguments: (arrVal, othVal).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Array
    	     * @param {Array} array The array to inspect.
    	     * @param {Function} [comparator] The comparator invoked per element.
    	     * @returns {Array} Returns the new duplicate free array.
    	     * @example
    	     *
    	     * var objects = [{ 'x': 1, 'y': 2 }, { 'x': 2, 'y': 1 }, { 'x': 1, 'y': 2 }];
    	     *
    	     * _.uniqWith(objects, _.isEqual);
    	     * // => [{ 'x': 1, 'y': 2 }, { 'x': 2, 'y': 1 }]
    	     */function uniqWith(array,comparator){comparator=typeof comparator=='function'?comparator:undefined$1;return array&&array.length?baseUniq(array,undefined$1,comparator):[];}/**
    	     * This method is like `_.zip` except that it accepts an array of grouped
    	     * elements and creates an array regrouping the elements to their pre-zip
    	     * configuration.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 1.2.0
    	     * @category Array
    	     * @param {Array} array The array of grouped elements to process.
    	     * @returns {Array} Returns the new array of regrouped elements.
    	     * @example
    	     *
    	     * var zipped = _.zip(['a', 'b'], [1, 2], [true, false]);
    	     * // => [['a', 1, true], ['b', 2, false]]
    	     *
    	     * _.unzip(zipped);
    	     * // => [['a', 'b'], [1, 2], [true, false]]
    	     */function unzip(array){if(!(array&&array.length)){return [];}var length=0;array=arrayFilter(array,function(group){if(isArrayLikeObject(group)){length=nativeMax(group.length,length);return true;}});return baseTimes(length,function(index){return arrayMap(array,baseProperty(index));});}/**
    	     * This method is like `_.unzip` except that it accepts `iteratee` to specify
    	     * how regrouped values should be combined. The iteratee is invoked with the
    	     * elements of each group: (...group).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.8.0
    	     * @category Array
    	     * @param {Array} array The array of grouped elements to process.
    	     * @param {Function} [iteratee=_.identity] The function to combine
    	     *  regrouped values.
    	     * @returns {Array} Returns the new array of regrouped elements.
    	     * @example
    	     *
    	     * var zipped = _.zip([1, 2], [10, 20], [100, 200]);
    	     * // => [[1, 10, 100], [2, 20, 200]]
    	     *
    	     * _.unzipWith(zipped, _.add);
    	     * // => [3, 30, 300]
    	     */function unzipWith(array,iteratee){if(!(array&&array.length)){return [];}var result=unzip(array);if(iteratee==null){return result;}return arrayMap(result,function(group){return apply(iteratee,undefined$1,group);});}/**
    	     * Creates an array excluding all given values using
    	     * [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
    	     * for equality comparisons.
    	     *
    	     * **Note:** Unlike `_.pull`, this method returns a new array.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Array
    	     * @param {Array} array The array to inspect.
    	     * @param {...*} [values] The values to exclude.
    	     * @returns {Array} Returns the new array of filtered values.
    	     * @see _.difference, _.xor
    	     * @example
    	     *
    	     * _.without([2, 1, 2, 3], 1, 2);
    	     * // => [3]
    	     */var without=baseRest(function(array,values){return isArrayLikeObject(array)?baseDifference(array,values):[];});/**
    	     * Creates an array of unique values that is the
    	     * [symmetric difference](https://en.wikipedia.org/wiki/Symmetric_difference)
    	     * of the given arrays. The order of result values is determined by the order
    	     * they occur in the arrays.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 2.4.0
    	     * @category Array
    	     * @param {...Array} [arrays] The arrays to inspect.
    	     * @returns {Array} Returns the new array of filtered values.
    	     * @see _.difference, _.without
    	     * @example
    	     *
    	     * _.xor([2, 1], [2, 3]);
    	     * // => [1, 3]
    	     */var xor=baseRest(function(arrays){return baseXor(arrayFilter(arrays,isArrayLikeObject));});/**
    	     * This method is like `_.xor` except that it accepts `iteratee` which is
    	     * invoked for each element of each `arrays` to generate the criterion by
    	     * which by which they're compared. The order of result values is determined
    	     * by the order they occur in the arrays. The iteratee is invoked with one
    	     * argument: (value).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Array
    	     * @param {...Array} [arrays] The arrays to inspect.
    	     * @param {Function} [iteratee=_.identity] The iteratee invoked per element.
    	     * @returns {Array} Returns the new array of filtered values.
    	     * @example
    	     *
    	     * _.xorBy([2.1, 1.2], [2.3, 3.4], Math.floor);
    	     * // => [1.2, 3.4]
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.xorBy([{ 'x': 1 }], [{ 'x': 2 }, { 'x': 1 }], 'x');
    	     * // => [{ 'x': 2 }]
    	     */var xorBy=baseRest(function(arrays){var iteratee=last(arrays);if(isArrayLikeObject(iteratee)){iteratee=undefined$1;}return baseXor(arrayFilter(arrays,isArrayLikeObject),getIteratee(iteratee,2));});/**
    	     * This method is like `_.xor` except that it accepts `comparator` which is
    	     * invoked to compare elements of `arrays`. The order of result values is
    	     * determined by the order they occur in the arrays. The comparator is invoked
    	     * with two arguments: (arrVal, othVal).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Array
    	     * @param {...Array} [arrays] The arrays to inspect.
    	     * @param {Function} [comparator] The comparator invoked per element.
    	     * @returns {Array} Returns the new array of filtered values.
    	     * @example
    	     *
    	     * var objects = [{ 'x': 1, 'y': 2 }, { 'x': 2, 'y': 1 }];
    	     * var others = [{ 'x': 1, 'y': 1 }, { 'x': 1, 'y': 2 }];
    	     *
    	     * _.xorWith(objects, others, _.isEqual);
    	     * // => [{ 'x': 2, 'y': 1 }, { 'x': 1, 'y': 1 }]
    	     */var xorWith=baseRest(function(arrays){var comparator=last(arrays);comparator=typeof comparator=='function'?comparator:undefined$1;return baseXor(arrayFilter(arrays,isArrayLikeObject),undefined$1,comparator);});/**
    	     * Creates an array of grouped elements, the first of which contains the
    	     * first elements of the given arrays, the second of which contains the
    	     * second elements of the given arrays, and so on.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Array
    	     * @param {...Array} [arrays] The arrays to process.
    	     * @returns {Array} Returns the new array of grouped elements.
    	     * @example
    	     *
    	     * _.zip(['a', 'b'], [1, 2], [true, false]);
    	     * // => [['a', 1, true], ['b', 2, false]]
    	     */var zip=baseRest(unzip);/**
    	     * This method is like `_.fromPairs` except that it accepts two arrays,
    	     * one of property identifiers and one of corresponding values.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.4.0
    	     * @category Array
    	     * @param {Array} [props=[]] The property identifiers.
    	     * @param {Array} [values=[]] The property values.
    	     * @returns {Object} Returns the new object.
    	     * @example
    	     *
    	     * _.zipObject(['a', 'b'], [1, 2]);
    	     * // => { 'a': 1, 'b': 2 }
    	     */function zipObject(props,values){return baseZipObject(props||[],values||[],assignValue);}/**
    	     * This method is like `_.zipObject` except that it supports property paths.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.1.0
    	     * @category Array
    	     * @param {Array} [props=[]] The property identifiers.
    	     * @param {Array} [values=[]] The property values.
    	     * @returns {Object} Returns the new object.
    	     * @example
    	     *
    	     * _.zipObjectDeep(['a.b[0].c', 'a.b[1].d'], [1, 2]);
    	     * // => { 'a': { 'b': [{ 'c': 1 }, { 'd': 2 }] } }
    	     */function zipObjectDeep(props,values){return baseZipObject(props||[],values||[],baseSet);}/**
    	     * This method is like `_.zip` except that it accepts `iteratee` to specify
    	     * how grouped values should be combined. The iteratee is invoked with the
    	     * elements of each group: (...group).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.8.0
    	     * @category Array
    	     * @param {...Array} [arrays] The arrays to process.
    	     * @param {Function} [iteratee=_.identity] The function to combine
    	     *  grouped values.
    	     * @returns {Array} Returns the new array of grouped elements.
    	     * @example
    	     *
    	     * _.zipWith([1, 2], [10, 20], [100, 200], function(a, b, c) {
    	     *   return a + b + c;
    	     * });
    	     * // => [111, 222]
    	     */var zipWith=baseRest(function(arrays){var length=arrays.length,iteratee=length>1?arrays[length-1]:undefined$1;iteratee=typeof iteratee=='function'?(arrays.pop(),iteratee):undefined$1;return unzipWith(arrays,iteratee);});/*------------------------------------------------------------------------*/ /**
    	     * Creates a `lodash` wrapper instance that wraps `value` with explicit method
    	     * chain sequences enabled. The result of such sequences must be unwrapped
    	     * with `_#value`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 1.3.0
    	     * @category Seq
    	     * @param {*} value The value to wrap.
    	     * @returns {Object} Returns the new `lodash` wrapper instance.
    	     * @example
    	     *
    	     * var users = [
    	     *   { 'user': 'barney',  'age': 36 },
    	     *   { 'user': 'fred',    'age': 40 },
    	     *   { 'user': 'pebbles', 'age': 1 }
    	     * ];
    	     *
    	     * var youngest = _
    	     *   .chain(users)
    	     *   .sortBy('age')
    	     *   .map(function(o) {
    	     *     return o.user + ' is ' + o.age;
    	     *   })
    	     *   .head()
    	     *   .value();
    	     * // => 'pebbles is 1'
    	     */function chain(value){var result=lodash(value);result.__chain__=true;return result;}/**
    	     * This method invokes `interceptor` and returns `value`. The interceptor
    	     * is invoked with one argument; (value). The purpose of this method is to
    	     * "tap into" a method chain sequence in order to modify intermediate results.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Seq
    	     * @param {*} value The value to provide to `interceptor`.
    	     * @param {Function} interceptor The function to invoke.
    	     * @returns {*} Returns `value`.
    	     * @example
    	     *
    	     * _([1, 2, 3])
    	     *  .tap(function(array) {
    	     *    // Mutate input array.
    	     *    array.pop();
    	     *  })
    	     *  .reverse()
    	     *  .value();
    	     * // => [2, 1]
    	     */function tap(value,interceptor){interceptor(value);return value;}/**
    	     * This method is like `_.tap` except that it returns the result of `interceptor`.
    	     * The purpose of this method is to "pass thru" values replacing intermediate
    	     * results in a method chain sequence.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Seq
    	     * @param {*} value The value to provide to `interceptor`.
    	     * @param {Function} interceptor The function to invoke.
    	     * @returns {*} Returns the result of `interceptor`.
    	     * @example
    	     *
    	     * _('  abc  ')
    	     *  .chain()
    	     *  .trim()
    	     *  .thru(function(value) {
    	     *    return [value];
    	     *  })
    	     *  .value();
    	     * // => ['abc']
    	     */function thru(value,interceptor){return interceptor(value);}/**
    	     * This method is the wrapper version of `_.at`.
    	     *
    	     * @name at
    	     * @memberOf _
    	     * @since 1.0.0
    	     * @category Seq
    	     * @param {...(string|string[])} [paths] The property paths to pick.
    	     * @returns {Object} Returns the new `lodash` wrapper instance.
    	     * @example
    	     *
    	     * var object = { 'a': [{ 'b': { 'c': 3 } }, 4] };
    	     *
    	     * _(object).at(['a[0].b.c', 'a[1]']).value();
    	     * // => [3, 4]
    	     */var wrapperAt=flatRest(function(paths){var length=paths.length,start=length?paths[0]:0,value=this.__wrapped__,interceptor=function(object){return baseAt(object,paths);};if(length>1||this.__actions__.length||!(value instanceof LazyWrapper)||!isIndex(start)){return this.thru(interceptor);}value=value.slice(start,+start+(length?1:0));value.__actions__.push({'func':thru,'args':[interceptor],'thisArg':undefined$1});return new LodashWrapper(value,this.__chain__).thru(function(array){if(length&&!array.length){array.push(undefined$1);}return array;});});/**
    	     * Creates a `lodash` wrapper instance with explicit method chain sequences enabled.
    	     *
    	     * @name chain
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Seq
    	     * @returns {Object} Returns the new `lodash` wrapper instance.
    	     * @example
    	     *
    	     * var users = [
    	     *   { 'user': 'barney', 'age': 36 },
    	     *   { 'user': 'fred',   'age': 40 }
    	     * ];
    	     *
    	     * // A sequence without explicit chaining.
    	     * _(users).head();
    	     * // => { 'user': 'barney', 'age': 36 }
    	     *
    	     * // A sequence with explicit chaining.
    	     * _(users)
    	     *   .chain()
    	     *   .head()
    	     *   .pick('user')
    	     *   .value();
    	     * // => { 'user': 'barney' }
    	     */function wrapperChain(){return chain(this);}/**
    	     * Executes the chain sequence and returns the wrapped result.
    	     *
    	     * @name commit
    	     * @memberOf _
    	     * @since 3.2.0
    	     * @category Seq
    	     * @returns {Object} Returns the new `lodash` wrapper instance.
    	     * @example
    	     *
    	     * var array = [1, 2];
    	     * var wrapped = _(array).push(3);
    	     *
    	     * console.log(array);
    	     * // => [1, 2]
    	     *
    	     * wrapped = wrapped.commit();
    	     * console.log(array);
    	     * // => [1, 2, 3]
    	     *
    	     * wrapped.last();
    	     * // => 3
    	     *
    	     * console.log(array);
    	     * // => [1, 2, 3]
    	     */function wrapperCommit(){return new LodashWrapper(this.value(),this.__chain__);}/**
    	     * Gets the next value on a wrapped object following the
    	     * [iterator protocol](https://mdn.io/iteration_protocols#iterator).
    	     *
    	     * @name next
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Seq
    	     * @returns {Object} Returns the next iterator value.
    	     * @example
    	     *
    	     * var wrapped = _([1, 2]);
    	     *
    	     * wrapped.next();
    	     * // => { 'done': false, 'value': 1 }
    	     *
    	     * wrapped.next();
    	     * // => { 'done': false, 'value': 2 }
    	     *
    	     * wrapped.next();
    	     * // => { 'done': true, 'value': undefined }
    	     */function wrapperNext(){if(this.__values__===undefined$1){this.__values__=toArray(this.value());}var done=this.__index__>=this.__values__.length,value=done?undefined$1:this.__values__[this.__index__++];return {'done':done,'value':value};}/**
    	     * Enables the wrapper to be iterable.
    	     *
    	     * @name Symbol.iterator
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Seq
    	     * @returns {Object} Returns the wrapper object.
    	     * @example
    	     *
    	     * var wrapped = _([1, 2]);
    	     *
    	     * wrapped[Symbol.iterator]() === wrapped;
    	     * // => true
    	     *
    	     * Array.from(wrapped);
    	     * // => [1, 2]
    	     */function wrapperToIterator(){return this;}/**
    	     * Creates a clone of the chain sequence planting `value` as the wrapped value.
    	     *
    	     * @name plant
    	     * @memberOf _
    	     * @since 3.2.0
    	     * @category Seq
    	     * @param {*} value The value to plant.
    	     * @returns {Object} Returns the new `lodash` wrapper instance.
    	     * @example
    	     *
    	     * function square(n) {
    	     *   return n * n;
    	     * }
    	     *
    	     * var wrapped = _([1, 2]).map(square);
    	     * var other = wrapped.plant([3, 4]);
    	     *
    	     * other.value();
    	     * // => [9, 16]
    	     *
    	     * wrapped.value();
    	     * // => [1, 4]
    	     */function wrapperPlant(value){var result,parent=this;while(parent instanceof baseLodash){var clone=wrapperClone(parent);clone.__index__=0;clone.__values__=undefined$1;if(result){previous.__wrapped__=clone;}else {result=clone;}var previous=clone;parent=parent.__wrapped__;}previous.__wrapped__=value;return result;}/**
    	     * This method is the wrapper version of `_.reverse`.
    	     *
    	     * **Note:** This method mutates the wrapped array.
    	     *
    	     * @name reverse
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Seq
    	     * @returns {Object} Returns the new `lodash` wrapper instance.
    	     * @example
    	     *
    	     * var array = [1, 2, 3];
    	     *
    	     * _(array).reverse().value()
    	     * // => [3, 2, 1]
    	     *
    	     * console.log(array);
    	     * // => [3, 2, 1]
    	     */function wrapperReverse(){var value=this.__wrapped__;if(value instanceof LazyWrapper){var wrapped=value;if(this.__actions__.length){wrapped=new LazyWrapper(this);}wrapped=wrapped.reverse();wrapped.__actions__.push({'func':thru,'args':[reverse],'thisArg':undefined$1});return new LodashWrapper(wrapped,this.__chain__);}return this.thru(reverse);}/**
    	     * Executes the chain sequence to resolve the unwrapped value.
    	     *
    	     * @name value
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @alias toJSON, valueOf
    	     * @category Seq
    	     * @returns {*} Returns the resolved unwrapped value.
    	     * @example
    	     *
    	     * _([1, 2, 3]).value();
    	     * // => [1, 2, 3]
    	     */function wrapperValue(){return baseWrapperValue(this.__wrapped__,this.__actions__);}/*------------------------------------------------------------------------*/ /**
    	     * Creates an object composed of keys generated from the results of running
    	     * each element of `collection` thru `iteratee`. The corresponding value of
    	     * each key is the number of times the key was returned by `iteratee`. The
    	     * iteratee is invoked with one argument: (value).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.5.0
    	     * @category Collection
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Function} [iteratee=_.identity] The iteratee to transform keys.
    	     * @returns {Object} Returns the composed aggregate object.
    	     * @example
    	     *
    	     * _.countBy([6.1, 4.2, 6.3], Math.floor);
    	     * // => { '4': 1, '6': 2 }
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.countBy(['one', 'two', 'three'], 'length');
    	     * // => { '3': 2, '5': 1 }
    	     */var countBy=createAggregator(function(result,value,key){if(hasOwnProperty.call(result,key)){++result[key];}else {baseAssignValue(result,key,1);}});/**
    	     * Checks if `predicate` returns truthy for **all** elements of `collection`.
    	     * Iteration is stopped once `predicate` returns falsey. The predicate is
    	     * invoked with three arguments: (value, index|key, collection).
    	     *
    	     * **Note:** This method returns `true` for
    	     * [empty collections](https://en.wikipedia.org/wiki/Empty_set) because
    	     * [everything is true](https://en.wikipedia.org/wiki/Vacuous_truth) of
    	     * elements of empty collections.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Collection
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Function} [predicate=_.identity] The function invoked per iteration.
    	     * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
    	     * @returns {boolean} Returns `true` if all elements pass the predicate check,
    	     *  else `false`.
    	     * @example
    	     *
    	     * _.every([true, 1, null, 'yes'], Boolean);
    	     * // => false
    	     *
    	     * var users = [
    	     *   { 'user': 'barney', 'age': 36, 'active': false },
    	     *   { 'user': 'fred',   'age': 40, 'active': false }
    	     * ];
    	     *
    	     * // The `_.matches` iteratee shorthand.
    	     * _.every(users, { 'user': 'barney', 'active': false });
    	     * // => false
    	     *
    	     * // The `_.matchesProperty` iteratee shorthand.
    	     * _.every(users, ['active', false]);
    	     * // => true
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.every(users, 'active');
    	     * // => false
    	     */function every(collection,predicate,guard){var func=isArray(collection)?arrayEvery:baseEvery;if(guard&&isIterateeCall(collection,predicate,guard)){predicate=undefined$1;}return func(collection,getIteratee(predicate,3));}/**
    	     * Iterates over elements of `collection`, returning an array of all elements
    	     * `predicate` returns truthy for. The predicate is invoked with three
    	     * arguments: (value, index|key, collection).
    	     *
    	     * **Note:** Unlike `_.remove`, this method returns a new array.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Collection
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Function} [predicate=_.identity] The function invoked per iteration.
    	     * @returns {Array} Returns the new filtered array.
    	     * @see _.reject
    	     * @example
    	     *
    	     * var users = [
    	     *   { 'user': 'barney', 'age': 36, 'active': true },
    	     *   { 'user': 'fred',   'age': 40, 'active': false }
    	     * ];
    	     *
    	     * _.filter(users, function(o) { return !o.active; });
    	     * // => objects for ['fred']
    	     *
    	     * // The `_.matches` iteratee shorthand.
    	     * _.filter(users, { 'age': 36, 'active': true });
    	     * // => objects for ['barney']
    	     *
    	     * // The `_.matchesProperty` iteratee shorthand.
    	     * _.filter(users, ['active', false]);
    	     * // => objects for ['fred']
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.filter(users, 'active');
    	     * // => objects for ['barney']
    	     *
    	     * // Combining several predicates using `_.overEvery` or `_.overSome`.
    	     * _.filter(users, _.overSome([{ 'age': 36 }, ['age', 40]]));
    	     * // => objects for ['fred', 'barney']
    	     */function filter(collection,predicate){var func=isArray(collection)?arrayFilter:baseFilter;return func(collection,getIteratee(predicate,3));}/**
    	     * Iterates over elements of `collection`, returning the first element
    	     * `predicate` returns truthy for. The predicate is invoked with three
    	     * arguments: (value, index|key, collection).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Collection
    	     * @param {Array|Object} collection The collection to inspect.
    	     * @param {Function} [predicate=_.identity] The function invoked per iteration.
    	     * @param {number} [fromIndex=0] The index to search from.
    	     * @returns {*} Returns the matched element, else `undefined`.
    	     * @example
    	     *
    	     * var users = [
    	     *   { 'user': 'barney',  'age': 36, 'active': true },
    	     *   { 'user': 'fred',    'age': 40, 'active': false },
    	     *   { 'user': 'pebbles', 'age': 1,  'active': true }
    	     * ];
    	     *
    	     * _.find(users, function(o) { return o.age < 40; });
    	     * // => object for 'barney'
    	     *
    	     * // The `_.matches` iteratee shorthand.
    	     * _.find(users, { 'age': 1, 'active': true });
    	     * // => object for 'pebbles'
    	     *
    	     * // The `_.matchesProperty` iteratee shorthand.
    	     * _.find(users, ['active', false]);
    	     * // => object for 'fred'
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.find(users, 'active');
    	     * // => object for 'barney'
    	     */var find=createFind(findIndex);/**
    	     * This method is like `_.find` except that it iterates over elements of
    	     * `collection` from right to left.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 2.0.0
    	     * @category Collection
    	     * @param {Array|Object} collection The collection to inspect.
    	     * @param {Function} [predicate=_.identity] The function invoked per iteration.
    	     * @param {number} [fromIndex=collection.length-1] The index to search from.
    	     * @returns {*} Returns the matched element, else `undefined`.
    	     * @example
    	     *
    	     * _.findLast([1, 2, 3, 4], function(n) {
    	     *   return n % 2 == 1;
    	     * });
    	     * // => 3
    	     */var findLast=createFind(findLastIndex);/**
    	     * Creates a flattened array of values by running each element in `collection`
    	     * thru `iteratee` and flattening the mapped results. The iteratee is invoked
    	     * with three arguments: (value, index|key, collection).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Collection
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
    	     * @returns {Array} Returns the new flattened array.
    	     * @example
    	     *
    	     * function duplicate(n) {
    	     *   return [n, n];
    	     * }
    	     *
    	     * _.flatMap([1, 2], duplicate);
    	     * // => [1, 1, 2, 2]
    	     */function flatMap(collection,iteratee){return baseFlatten(map(collection,iteratee),1);}/**
    	     * This method is like `_.flatMap` except that it recursively flattens the
    	     * mapped results.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.7.0
    	     * @category Collection
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
    	     * @returns {Array} Returns the new flattened array.
    	     * @example
    	     *
    	     * function duplicate(n) {
    	     *   return [[[n, n]]];
    	     * }
    	     *
    	     * _.flatMapDeep([1, 2], duplicate);
    	     * // => [1, 1, 2, 2]
    	     */function flatMapDeep(collection,iteratee){return baseFlatten(map(collection,iteratee),INFINITY);}/**
    	     * This method is like `_.flatMap` except that it recursively flattens the
    	     * mapped results up to `depth` times.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.7.0
    	     * @category Collection
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
    	     * @param {number} [depth=1] The maximum recursion depth.
    	     * @returns {Array} Returns the new flattened array.
    	     * @example
    	     *
    	     * function duplicate(n) {
    	     *   return [[[n, n]]];
    	     * }
    	     *
    	     * _.flatMapDepth([1, 2], duplicate, 2);
    	     * // => [[1, 1], [2, 2]]
    	     */function flatMapDepth(collection,iteratee,depth){depth=depth===undefined$1?1:toInteger(depth);return baseFlatten(map(collection,iteratee),depth);}/**
    	     * Iterates over elements of `collection` and invokes `iteratee` for each element.
    	     * The iteratee is invoked with three arguments: (value, index|key, collection).
    	     * Iteratee functions may exit iteration early by explicitly returning `false`.
    	     *
    	     * **Note:** As with other "Collections" methods, objects with a "length"
    	     * property are iterated like arrays. To avoid this behavior use `_.forIn`
    	     * or `_.forOwn` for object iteration.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @alias each
    	     * @category Collection
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
    	     * @returns {Array|Object} Returns `collection`.
    	     * @see _.forEachRight
    	     * @example
    	     *
    	     * _.forEach([1, 2], function(value) {
    	     *   console.log(value);
    	     * });
    	     * // => Logs `1` then `2`.
    	     *
    	     * _.forEach({ 'a': 1, 'b': 2 }, function(value, key) {
    	     *   console.log(key);
    	     * });
    	     * // => Logs 'a' then 'b' (iteration order is not guaranteed).
    	     */function forEach(collection,iteratee){var func=isArray(collection)?arrayEach:baseEach;return func(collection,getIteratee(iteratee,3));}/**
    	     * This method is like `_.forEach` except that it iterates over elements of
    	     * `collection` from right to left.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 2.0.0
    	     * @alias eachRight
    	     * @category Collection
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
    	     * @returns {Array|Object} Returns `collection`.
    	     * @see _.forEach
    	     * @example
    	     *
    	     * _.forEachRight([1, 2], function(value) {
    	     *   console.log(value);
    	     * });
    	     * // => Logs `2` then `1`.
    	     */function forEachRight(collection,iteratee){var func=isArray(collection)?arrayEachRight:baseEachRight;return func(collection,getIteratee(iteratee,3));}/**
    	     * Creates an object composed of keys generated from the results of running
    	     * each element of `collection` thru `iteratee`. The order of grouped values
    	     * is determined by the order they occur in `collection`. The corresponding
    	     * value of each key is an array of elements responsible for generating the
    	     * key. The iteratee is invoked with one argument: (value).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Collection
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Function} [iteratee=_.identity] The iteratee to transform keys.
    	     * @returns {Object} Returns the composed aggregate object.
    	     * @example
    	     *
    	     * _.groupBy([6.1, 4.2, 6.3], Math.floor);
    	     * // => { '4': [4.2], '6': [6.1, 6.3] }
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.groupBy(['one', 'two', 'three'], 'length');
    	     * // => { '3': ['one', 'two'], '5': ['three'] }
    	     */var groupBy=createAggregator(function(result,value,key){if(hasOwnProperty.call(result,key)){result[key].push(value);}else {baseAssignValue(result,key,[value]);}});/**
    	     * Checks if `value` is in `collection`. If `collection` is a string, it's
    	     * checked for a substring of `value`, otherwise
    	     * [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
    	     * is used for equality comparisons. If `fromIndex` is negative, it's used as
    	     * the offset from the end of `collection`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Collection
    	     * @param {Array|Object|string} collection The collection to inspect.
    	     * @param {*} value The value to search for.
    	     * @param {number} [fromIndex=0] The index to search from.
    	     * @param- {Object} [guard] Enables use as an iteratee for methods like `_.reduce`.
    	     * @returns {boolean} Returns `true` if `value` is found, else `false`.
    	     * @example
    	     *
    	     * _.includes([1, 2, 3], 1);
    	     * // => true
    	     *
    	     * _.includes([1, 2, 3], 1, 2);
    	     * // => false
    	     *
    	     * _.includes({ 'a': 1, 'b': 2 }, 1);
    	     * // => true
    	     *
    	     * _.includes('abcd', 'bc');
    	     * // => true
    	     */function includes(collection,value,fromIndex,guard){collection=isArrayLike(collection)?collection:values(collection);fromIndex=fromIndex&&!guard?toInteger(fromIndex):0;var length=collection.length;if(fromIndex<0){fromIndex=nativeMax(length+fromIndex,0);}return isString(collection)?fromIndex<=length&&collection.indexOf(value,fromIndex)>-1:!!length&&baseIndexOf(collection,value,fromIndex)>-1;}/**
    	     * Invokes the method at `path` of each element in `collection`, returning
    	     * an array of the results of each invoked method. Any additional arguments
    	     * are provided to each invoked method. If `path` is a function, it's invoked
    	     * for, and `this` bound to, each element in `collection`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Collection
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Array|Function|string} path The path of the method to invoke or
    	     *  the function invoked per iteration.
    	     * @param {...*} [args] The arguments to invoke each method with.
    	     * @returns {Array} Returns the array of results.
    	     * @example
    	     *
    	     * _.invokeMap([[5, 1, 7], [3, 2, 1]], 'sort');
    	     * // => [[1, 5, 7], [1, 2, 3]]
    	     *
    	     * _.invokeMap([123, 456], String.prototype.split, '');
    	     * // => [['1', '2', '3'], ['4', '5', '6']]
    	     */var invokeMap=baseRest(function(collection,path,args){var index=-1,isFunc=typeof path=='function',result=isArrayLike(collection)?Array(collection.length):[];baseEach(collection,function(value){result[++index]=isFunc?apply(path,value,args):baseInvoke(value,path,args);});return result;});/**
    	     * Creates an object composed of keys generated from the results of running
    	     * each element of `collection` thru `iteratee`. The corresponding value of
    	     * each key is the last element responsible for generating the key. The
    	     * iteratee is invoked with one argument: (value).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Collection
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Function} [iteratee=_.identity] The iteratee to transform keys.
    	     * @returns {Object} Returns the composed aggregate object.
    	     * @example
    	     *
    	     * var array = [
    	     *   { 'dir': 'left', 'code': 97 },
    	     *   { 'dir': 'right', 'code': 100 }
    	     * ];
    	     *
    	     * _.keyBy(array, function(o) {
    	     *   return String.fromCharCode(o.code);
    	     * });
    	     * // => { 'a': { 'dir': 'left', 'code': 97 }, 'd': { 'dir': 'right', 'code': 100 } }
    	     *
    	     * _.keyBy(array, 'dir');
    	     * // => { 'left': { 'dir': 'left', 'code': 97 }, 'right': { 'dir': 'right', 'code': 100 } }
    	     */var keyBy=createAggregator(function(result,value,key){baseAssignValue(result,key,value);});/**
    	     * Creates an array of values by running each element in `collection` thru
    	     * `iteratee`. The iteratee is invoked with three arguments:
    	     * (value, index|key, collection).
    	     *
    	     * Many lodash methods are guarded to work as iteratees for methods like
    	     * `_.every`, `_.filter`, `_.map`, `_.mapValues`, `_.reject`, and `_.some`.
    	     *
    	     * The guarded methods are:
    	     * `ary`, `chunk`, `curry`, `curryRight`, `drop`, `dropRight`, `every`,
    	     * `fill`, `invert`, `parseInt`, `random`, `range`, `rangeRight`, `repeat`,
    	     * `sampleSize`, `slice`, `some`, `sortBy`, `split`, `take`, `takeRight`,
    	     * `template`, `trim`, `trimEnd`, `trimStart`, and `words`
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Collection
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
    	     * @returns {Array} Returns the new mapped array.
    	     * @example
    	     *
    	     * function square(n) {
    	     *   return n * n;
    	     * }
    	     *
    	     * _.map([4, 8], square);
    	     * // => [16, 64]
    	     *
    	     * _.map({ 'a': 4, 'b': 8 }, square);
    	     * // => [16, 64] (iteration order is not guaranteed)
    	     *
    	     * var users = [
    	     *   { 'user': 'barney' },
    	     *   { 'user': 'fred' }
    	     * ];
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.map(users, 'user');
    	     * // => ['barney', 'fred']
    	     */function map(collection,iteratee){var func=isArray(collection)?arrayMap:baseMap;return func(collection,getIteratee(iteratee,3));}/**
    	     * This method is like `_.sortBy` except that it allows specifying the sort
    	     * orders of the iteratees to sort by. If `orders` is unspecified, all values
    	     * are sorted in ascending order. Otherwise, specify an order of "desc" for
    	     * descending or "asc" for ascending sort order of corresponding values.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Collection
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Array[]|Function[]|Object[]|string[]} [iteratees=[_.identity]]
    	     *  The iteratees to sort by.
    	     * @param {string[]} [orders] The sort orders of `iteratees`.
    	     * @param- {Object} [guard] Enables use as an iteratee for methods like `_.reduce`.
    	     * @returns {Array} Returns the new sorted array.
    	     * @example
    	     *
    	     * var users = [
    	     *   { 'user': 'fred',   'age': 48 },
    	     *   { 'user': 'barney', 'age': 34 },
    	     *   { 'user': 'fred',   'age': 40 },
    	     *   { 'user': 'barney', 'age': 36 }
    	     * ];
    	     *
    	     * // Sort by `user` in ascending order and by `age` in descending order.
    	     * _.orderBy(users, ['user', 'age'], ['asc', 'desc']);
    	     * // => objects for [['barney', 36], ['barney', 34], ['fred', 48], ['fred', 40]]
    	     */function orderBy(collection,iteratees,orders,guard){if(collection==null){return [];}if(!isArray(iteratees)){iteratees=iteratees==null?[]:[iteratees];}orders=guard?undefined$1:orders;if(!isArray(orders)){orders=orders==null?[]:[orders];}return baseOrderBy(collection,iteratees,orders);}/**
    	     * Creates an array of elements split into two groups, the first of which
    	     * contains elements `predicate` returns truthy for, the second of which
    	     * contains elements `predicate` returns falsey for. The predicate is
    	     * invoked with one argument: (value).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Collection
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Function} [predicate=_.identity] The function invoked per iteration.
    	     * @returns {Array} Returns the array of grouped elements.
    	     * @example
    	     *
    	     * var users = [
    	     *   { 'user': 'barney',  'age': 36, 'active': false },
    	     *   { 'user': 'fred',    'age': 40, 'active': true },
    	     *   { 'user': 'pebbles', 'age': 1,  'active': false }
    	     * ];
    	     *
    	     * _.partition(users, function(o) { return o.active; });
    	     * // => objects for [['fred'], ['barney', 'pebbles']]
    	     *
    	     * // The `_.matches` iteratee shorthand.
    	     * _.partition(users, { 'age': 1, 'active': false });
    	     * // => objects for [['pebbles'], ['barney', 'fred']]
    	     *
    	     * // The `_.matchesProperty` iteratee shorthand.
    	     * _.partition(users, ['active', false]);
    	     * // => objects for [['barney', 'pebbles'], ['fred']]
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.partition(users, 'active');
    	     * // => objects for [['fred'], ['barney', 'pebbles']]
    	     */var partition=createAggregator(function(result,value,key){result[key?0:1].push(value);},function(){return [[],[]];});/**
    	     * Reduces `collection` to a value which is the accumulated result of running
    	     * each element in `collection` thru `iteratee`, where each successive
    	     * invocation is supplied the return value of the previous. If `accumulator`
    	     * is not given, the first element of `collection` is used as the initial
    	     * value. The iteratee is invoked with four arguments:
    	     * (accumulator, value, index|key, collection).
    	     *
    	     * Many lodash methods are guarded to work as iteratees for methods like
    	     * `_.reduce`, `_.reduceRight`, and `_.transform`.
    	     *
    	     * The guarded methods are:
    	     * `assign`, `defaults`, `defaultsDeep`, `includes`, `merge`, `orderBy`,
    	     * and `sortBy`
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Collection
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
    	     * @param {*} [accumulator] The initial value.
    	     * @returns {*} Returns the accumulated value.
    	     * @see _.reduceRight
    	     * @example
    	     *
    	     * _.reduce([1, 2], function(sum, n) {
    	     *   return sum + n;
    	     * }, 0);
    	     * // => 3
    	     *
    	     * _.reduce({ 'a': 1, 'b': 2, 'c': 1 }, function(result, value, key) {
    	     *   (result[value] || (result[value] = [])).push(key);
    	     *   return result;
    	     * }, {});
    	     * // => { '1': ['a', 'c'], '2': ['b'] } (iteration order is not guaranteed)
    	     */function reduce(collection,iteratee,accumulator){var func=isArray(collection)?arrayReduce:baseReduce,initAccum=arguments.length<3;return func(collection,getIteratee(iteratee,4),accumulator,initAccum,baseEach);}/**
    	     * This method is like `_.reduce` except that it iterates over elements of
    	     * `collection` from right to left.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Collection
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
    	     * @param {*} [accumulator] The initial value.
    	     * @returns {*} Returns the accumulated value.
    	     * @see _.reduce
    	     * @example
    	     *
    	     * var array = [[0, 1], [2, 3], [4, 5]];
    	     *
    	     * _.reduceRight(array, function(flattened, other) {
    	     *   return flattened.concat(other);
    	     * }, []);
    	     * // => [4, 5, 2, 3, 0, 1]
    	     */function reduceRight(collection,iteratee,accumulator){var func=isArray(collection)?arrayReduceRight:baseReduce,initAccum=arguments.length<3;return func(collection,getIteratee(iteratee,4),accumulator,initAccum,baseEachRight);}/**
    	     * The opposite of `_.filter`; this method returns the elements of `collection`
    	     * that `predicate` does **not** return truthy for.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Collection
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Function} [predicate=_.identity] The function invoked per iteration.
    	     * @returns {Array} Returns the new filtered array.
    	     * @see _.filter
    	     * @example
    	     *
    	     * var users = [
    	     *   { 'user': 'barney', 'age': 36, 'active': false },
    	     *   { 'user': 'fred',   'age': 40, 'active': true }
    	     * ];
    	     *
    	     * _.reject(users, function(o) { return !o.active; });
    	     * // => objects for ['fred']
    	     *
    	     * // The `_.matches` iteratee shorthand.
    	     * _.reject(users, { 'age': 40, 'active': true });
    	     * // => objects for ['barney']
    	     *
    	     * // The `_.matchesProperty` iteratee shorthand.
    	     * _.reject(users, ['active', false]);
    	     * // => objects for ['fred']
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.reject(users, 'active');
    	     * // => objects for ['barney']
    	     */function reject(collection,predicate){var func=isArray(collection)?arrayFilter:baseFilter;return func(collection,negate(getIteratee(predicate,3)));}/**
    	     * Gets a random element from `collection`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 2.0.0
    	     * @category Collection
    	     * @param {Array|Object} collection The collection to sample.
    	     * @returns {*} Returns the random element.
    	     * @example
    	     *
    	     * _.sample([1, 2, 3, 4]);
    	     * // => 2
    	     */function sample(collection){var func=isArray(collection)?arraySample:baseSample;return func(collection);}/**
    	     * Gets `n` random elements at unique keys from `collection` up to the
    	     * size of `collection`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Collection
    	     * @param {Array|Object} collection The collection to sample.
    	     * @param {number} [n=1] The number of elements to sample.
    	     * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
    	     * @returns {Array} Returns the random elements.
    	     * @example
    	     *
    	     * _.sampleSize([1, 2, 3], 2);
    	     * // => [3, 1]
    	     *
    	     * _.sampleSize([1, 2, 3], 4);
    	     * // => [2, 3, 1]
    	     */function sampleSize(collection,n,guard){if(guard?isIterateeCall(collection,n,guard):n===undefined$1){n=1;}else {n=toInteger(n);}var func=isArray(collection)?arraySampleSize:baseSampleSize;return func(collection,n);}/**
    	     * Creates an array of shuffled values, using a version of the
    	     * [Fisher-Yates shuffle](https://en.wikipedia.org/wiki/Fisher-Yates_shuffle).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Collection
    	     * @param {Array|Object} collection The collection to shuffle.
    	     * @returns {Array} Returns the new shuffled array.
    	     * @example
    	     *
    	     * _.shuffle([1, 2, 3, 4]);
    	     * // => [4, 1, 3, 2]
    	     */function shuffle(collection){var func=isArray(collection)?arrayShuffle:baseShuffle;return func(collection);}/**
    	     * Gets the size of `collection` by returning its length for array-like
    	     * values or the number of own enumerable string keyed properties for objects.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Collection
    	     * @param {Array|Object|string} collection The collection to inspect.
    	     * @returns {number} Returns the collection size.
    	     * @example
    	     *
    	     * _.size([1, 2, 3]);
    	     * // => 3
    	     *
    	     * _.size({ 'a': 1, 'b': 2 });
    	     * // => 2
    	     *
    	     * _.size('pebbles');
    	     * // => 7
    	     */function size(collection){if(collection==null){return 0;}if(isArrayLike(collection)){return isString(collection)?stringSize(collection):collection.length;}var tag=getTag(collection);if(tag==mapTag||tag==setTag){return collection.size;}return baseKeys(collection).length;}/**
    	     * Checks if `predicate` returns truthy for **any** element of `collection`.
    	     * Iteration is stopped once `predicate` returns truthy. The predicate is
    	     * invoked with three arguments: (value, index|key, collection).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Collection
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {Function} [predicate=_.identity] The function invoked per iteration.
    	     * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
    	     * @returns {boolean} Returns `true` if any element passes the predicate check,
    	     *  else `false`.
    	     * @example
    	     *
    	     * _.some([null, 0, 'yes', false], Boolean);
    	     * // => true
    	     *
    	     * var users = [
    	     *   { 'user': 'barney', 'active': true },
    	     *   { 'user': 'fred',   'active': false }
    	     * ];
    	     *
    	     * // The `_.matches` iteratee shorthand.
    	     * _.some(users, { 'user': 'barney', 'active': false });
    	     * // => false
    	     *
    	     * // The `_.matchesProperty` iteratee shorthand.
    	     * _.some(users, ['active', false]);
    	     * // => true
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.some(users, 'active');
    	     * // => true
    	     */function some(collection,predicate,guard){var func=isArray(collection)?arraySome:baseSome;if(guard&&isIterateeCall(collection,predicate,guard)){predicate=undefined$1;}return func(collection,getIteratee(predicate,3));}/**
    	     * Creates an array of elements, sorted in ascending order by the results of
    	     * running each element in a collection thru each iteratee. This method
    	     * performs a stable sort, that is, it preserves the original sort order of
    	     * equal elements. The iteratees are invoked with one argument: (value).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Collection
    	     * @param {Array|Object} collection The collection to iterate over.
    	     * @param {...(Function|Function[])} [iteratees=[_.identity]]
    	     *  The iteratees to sort by.
    	     * @returns {Array} Returns the new sorted array.
    	     * @example
    	     *
    	     * var users = [
    	     *   { 'user': 'fred',   'age': 48 },
    	     *   { 'user': 'barney', 'age': 36 },
    	     *   { 'user': 'fred',   'age': 30 },
    	     *   { 'user': 'barney', 'age': 34 }
    	     * ];
    	     *
    	     * _.sortBy(users, [function(o) { return o.user; }]);
    	     * // => objects for [['barney', 36], ['barney', 34], ['fred', 48], ['fred', 30]]
    	     *
    	     * _.sortBy(users, ['user', 'age']);
    	     * // => objects for [['barney', 34], ['barney', 36], ['fred', 30], ['fred', 48]]
    	     */var sortBy=baseRest(function(collection,iteratees){if(collection==null){return [];}var length=iteratees.length;if(length>1&&isIterateeCall(collection,iteratees[0],iteratees[1])){iteratees=[];}else if(length>2&&isIterateeCall(iteratees[0],iteratees[1],iteratees[2])){iteratees=[iteratees[0]];}return baseOrderBy(collection,baseFlatten(iteratees,1),[]);});/*------------------------------------------------------------------------*/ /**
    	     * Gets the timestamp of the number of milliseconds that have elapsed since
    	     * the Unix epoch (1 January 1970 00:00:00 UTC).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 2.4.0
    	     * @category Date
    	     * @returns {number} Returns the timestamp.
    	     * @example
    	     *
    	     * _.defer(function(stamp) {
    	     *   console.log(_.now() - stamp);
    	     * }, _.now());
    	     * // => Logs the number of milliseconds it took for the deferred invocation.
    	     */var now=ctxNow||function(){return root.Date.now();};/*------------------------------------------------------------------------*/ /**
    	     * The opposite of `_.before`; this method creates a function that invokes
    	     * `func` once it's called `n` or more times.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Function
    	     * @param {number} n The number of calls before `func` is invoked.
    	     * @param {Function} func The function to restrict.
    	     * @returns {Function} Returns the new restricted function.
    	     * @example
    	     *
    	     * var saves = ['profile', 'settings'];
    	     *
    	     * var done = _.after(saves.length, function() {
    	     *   console.log('done saving!');
    	     * });
    	     *
    	     * _.forEach(saves, function(type) {
    	     *   asyncSave({ 'type': type, 'complete': done });
    	     * });
    	     * // => Logs 'done saving!' after the two async saves have completed.
    	     */function after(n,func){if(typeof func!='function'){throw new TypeError(FUNC_ERROR_TEXT);}n=toInteger(n);return function(){if(--n<1){return func.apply(this,arguments);}};}/**
    	     * Creates a function that invokes `func`, with up to `n` arguments,
    	     * ignoring any additional arguments.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Function
    	     * @param {Function} func The function to cap arguments for.
    	     * @param {number} [n=func.length] The arity cap.
    	     * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
    	     * @returns {Function} Returns the new capped function.
    	     * @example
    	     *
    	     * _.map(['6', '8', '10'], _.ary(parseInt, 1));
    	     * // => [6, 8, 10]
    	     */function ary(func,n,guard){n=guard?undefined$1:n;n=func&&n==null?func.length:n;return createWrap(func,WRAP_ARY_FLAG,undefined$1,undefined$1,undefined$1,undefined$1,n);}/**
    	     * Creates a function that invokes `func`, with the `this` binding and arguments
    	     * of the created function, while it's called less than `n` times. Subsequent
    	     * calls to the created function return the result of the last `func` invocation.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Function
    	     * @param {number} n The number of calls at which `func` is no longer invoked.
    	     * @param {Function} func The function to restrict.
    	     * @returns {Function} Returns the new restricted function.
    	     * @example
    	     *
    	     * jQuery(element).on('click', _.before(5, addContactToList));
    	     * // => Allows adding up to 4 contacts to the list.
    	     */function before(n,func){var result;if(typeof func!='function'){throw new TypeError(FUNC_ERROR_TEXT);}n=toInteger(n);return function(){if(--n>0){result=func.apply(this,arguments);}if(n<=1){func=undefined$1;}return result;};}/**
    	     * Creates a function that invokes `func` with the `this` binding of `thisArg`
    	     * and `partials` prepended to the arguments it receives.
    	     *
    	     * The `_.bind.placeholder` value, which defaults to `_` in monolithic builds,
    	     * may be used as a placeholder for partially applied arguments.
    	     *
    	     * **Note:** Unlike native `Function#bind`, this method doesn't set the "length"
    	     * property of bound functions.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Function
    	     * @param {Function} func The function to bind.
    	     * @param {*} thisArg The `this` binding of `func`.
    	     * @param {...*} [partials] The arguments to be partially applied.
    	     * @returns {Function} Returns the new bound function.
    	     * @example
    	     *
    	     * function greet(greeting, punctuation) {
    	     *   return greeting + ' ' + this.user + punctuation;
    	     * }
    	     *
    	     * var object = { 'user': 'fred' };
    	     *
    	     * var bound = _.bind(greet, object, 'hi');
    	     * bound('!');
    	     * // => 'hi fred!'
    	     *
    	     * // Bound with placeholders.
    	     * var bound = _.bind(greet, object, _, '!');
    	     * bound('hi');
    	     * // => 'hi fred!'
    	     */var bind=baseRest(function(func,thisArg,partials){var bitmask=WRAP_BIND_FLAG;if(partials.length){var holders=replaceHolders(partials,getHolder(bind));bitmask|=WRAP_PARTIAL_FLAG;}return createWrap(func,bitmask,thisArg,partials,holders);});/**
    	     * Creates a function that invokes the method at `object[key]` with `partials`
    	     * prepended to the arguments it receives.
    	     *
    	     * This method differs from `_.bind` by allowing bound functions to reference
    	     * methods that may be redefined or don't yet exist. See
    	     * [Peter Michaux's article](http://peter.michaux.ca/articles/lazy-function-definition-pattern)
    	     * for more details.
    	     *
    	     * The `_.bindKey.placeholder` value, which defaults to `_` in monolithic
    	     * builds, may be used as a placeholder for partially applied arguments.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.10.0
    	     * @category Function
    	     * @param {Object} object The object to invoke the method on.
    	     * @param {string} key The key of the method.
    	     * @param {...*} [partials] The arguments to be partially applied.
    	     * @returns {Function} Returns the new bound function.
    	     * @example
    	     *
    	     * var object = {
    	     *   'user': 'fred',
    	     *   'greet': function(greeting, punctuation) {
    	     *     return greeting + ' ' + this.user + punctuation;
    	     *   }
    	     * };
    	     *
    	     * var bound = _.bindKey(object, 'greet', 'hi');
    	     * bound('!');
    	     * // => 'hi fred!'
    	     *
    	     * object.greet = function(greeting, punctuation) {
    	     *   return greeting + 'ya ' + this.user + punctuation;
    	     * };
    	     *
    	     * bound('!');
    	     * // => 'hiya fred!'
    	     *
    	     * // Bound with placeholders.
    	     * var bound = _.bindKey(object, 'greet', _, '!');
    	     * bound('hi');
    	     * // => 'hiya fred!'
    	     */var bindKey=baseRest(function(object,key,partials){var bitmask=WRAP_BIND_FLAG|WRAP_BIND_KEY_FLAG;if(partials.length){var holders=replaceHolders(partials,getHolder(bindKey));bitmask|=WRAP_PARTIAL_FLAG;}return createWrap(key,bitmask,object,partials,holders);});/**
    	     * Creates a function that accepts arguments of `func` and either invokes
    	     * `func` returning its result, if at least `arity` number of arguments have
    	     * been provided, or returns a function that accepts the remaining `func`
    	     * arguments, and so on. The arity of `func` may be specified if `func.length`
    	     * is not sufficient.
    	     *
    	     * The `_.curry.placeholder` value, which defaults to `_` in monolithic builds,
    	     * may be used as a placeholder for provided arguments.
    	     *
    	     * **Note:** This method doesn't set the "length" property of curried functions.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 2.0.0
    	     * @category Function
    	     * @param {Function} func The function to curry.
    	     * @param {number} [arity=func.length] The arity of `func`.
    	     * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
    	     * @returns {Function} Returns the new curried function.
    	     * @example
    	     *
    	     * var abc = function(a, b, c) {
    	     *   return [a, b, c];
    	     * };
    	     *
    	     * var curried = _.curry(abc);
    	     *
    	     * curried(1)(2)(3);
    	     * // => [1, 2, 3]
    	     *
    	     * curried(1, 2)(3);
    	     * // => [1, 2, 3]
    	     *
    	     * curried(1, 2, 3);
    	     * // => [1, 2, 3]
    	     *
    	     * // Curried with placeholders.
    	     * curried(1)(_, 3)(2);
    	     * // => [1, 2, 3]
    	     */function curry(func,arity,guard){arity=guard?undefined$1:arity;var result=createWrap(func,WRAP_CURRY_FLAG,undefined$1,undefined$1,undefined$1,undefined$1,undefined$1,arity);result.placeholder=curry.placeholder;return result;}/**
    	     * This method is like `_.curry` except that arguments are applied to `func`
    	     * in the manner of `_.partialRight` instead of `_.partial`.
    	     *
    	     * The `_.curryRight.placeholder` value, which defaults to `_` in monolithic
    	     * builds, may be used as a placeholder for provided arguments.
    	     *
    	     * **Note:** This method doesn't set the "length" property of curried functions.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Function
    	     * @param {Function} func The function to curry.
    	     * @param {number} [arity=func.length] The arity of `func`.
    	     * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
    	     * @returns {Function} Returns the new curried function.
    	     * @example
    	     *
    	     * var abc = function(a, b, c) {
    	     *   return [a, b, c];
    	     * };
    	     *
    	     * var curried = _.curryRight(abc);
    	     *
    	     * curried(3)(2)(1);
    	     * // => [1, 2, 3]
    	     *
    	     * curried(2, 3)(1);
    	     * // => [1, 2, 3]
    	     *
    	     * curried(1, 2, 3);
    	     * // => [1, 2, 3]
    	     *
    	     * // Curried with placeholders.
    	     * curried(3)(1, _)(2);
    	     * // => [1, 2, 3]
    	     */function curryRight(func,arity,guard){arity=guard?undefined$1:arity;var result=createWrap(func,WRAP_CURRY_RIGHT_FLAG,undefined$1,undefined$1,undefined$1,undefined$1,undefined$1,arity);result.placeholder=curryRight.placeholder;return result;}/**
    	     * Creates a debounced function that delays invoking `func` until after `wait`
    	     * milliseconds have elapsed since the last time the debounced function was
    	     * invoked. The debounced function comes with a `cancel` method to cancel
    	     * delayed `func` invocations and a `flush` method to immediately invoke them.
    	     * Provide `options` to indicate whether `func` should be invoked on the
    	     * leading and/or trailing edge of the `wait` timeout. The `func` is invoked
    	     * with the last arguments provided to the debounced function. Subsequent
    	     * calls to the debounced function return the result of the last `func`
    	     * invocation.
    	     *
    	     * **Note:** If `leading` and `trailing` options are `true`, `func` is
    	     * invoked on the trailing edge of the timeout only if the debounced function
    	     * is invoked more than once during the `wait` timeout.
    	     *
    	     * If `wait` is `0` and `leading` is `false`, `func` invocation is deferred
    	     * until to the next tick, similar to `setTimeout` with a timeout of `0`.
    	     *
    	     * See [David Corbacho's article](https://css-tricks.com/debouncing-throttling-explained-examples/)
    	     * for details over the differences between `_.debounce` and `_.throttle`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Function
    	     * @param {Function} func The function to debounce.
    	     * @param {number} [wait=0] The number of milliseconds to delay.
    	     * @param {Object} [options={}] The options object.
    	     * @param {boolean} [options.leading=false]
    	     *  Specify invoking on the leading edge of the timeout.
    	     * @param {number} [options.maxWait]
    	     *  The maximum time `func` is allowed to be delayed before it's invoked.
    	     * @param {boolean} [options.trailing=true]
    	     *  Specify invoking on the trailing edge of the timeout.
    	     * @returns {Function} Returns the new debounced function.
    	     * @example
    	     *
    	     * // Avoid costly calculations while the window size is in flux.
    	     * jQuery(window).on('resize', _.debounce(calculateLayout, 150));
    	     *
    	     * // Invoke `sendMail` when clicked, debouncing subsequent calls.
    	     * jQuery(element).on('click', _.debounce(sendMail, 300, {
    	     *   'leading': true,
    	     *   'trailing': false
    	     * }));
    	     *
    	     * // Ensure `batchLog` is invoked once after 1 second of debounced calls.
    	     * var debounced = _.debounce(batchLog, 250, { 'maxWait': 1000 });
    	     * var source = new EventSource('/stream');
    	     * jQuery(source).on('message', debounced);
    	     *
    	     * // Cancel the trailing debounced invocation.
    	     * jQuery(window).on('popstate', debounced.cancel);
    	     */function debounce(func,wait,options){var lastArgs,lastThis,maxWait,result,timerId,lastCallTime,lastInvokeTime=0,leading=false,maxing=false,trailing=true;if(typeof func!='function'){throw new TypeError(FUNC_ERROR_TEXT);}wait=toNumber(wait)||0;if(isObject(options)){leading=!!options.leading;maxing='maxWait'in options;maxWait=maxing?nativeMax(toNumber(options.maxWait)||0,wait):maxWait;trailing='trailing'in options?!!options.trailing:trailing;}function invokeFunc(time){var args=lastArgs,thisArg=lastThis;lastArgs=lastThis=undefined$1;lastInvokeTime=time;result=func.apply(thisArg,args);return result;}function leadingEdge(time){// Reset any `maxWait` timer.
    	lastInvokeTime=time;// Start the timer for the trailing edge.
    	timerId=setTimeout(timerExpired,wait);// Invoke the leading edge.
    	return leading?invokeFunc(time):result;}function remainingWait(time){var timeSinceLastCall=time-lastCallTime,timeSinceLastInvoke=time-lastInvokeTime,timeWaiting=wait-timeSinceLastCall;return maxing?nativeMin(timeWaiting,maxWait-timeSinceLastInvoke):timeWaiting;}function shouldInvoke(time){var timeSinceLastCall=time-lastCallTime,timeSinceLastInvoke=time-lastInvokeTime;// Either this is the first call, activity has stopped and we're at the
    	// trailing edge, the system time has gone backwards and we're treating
    	// it as the trailing edge, or we've hit the `maxWait` limit.
    	return lastCallTime===undefined$1||timeSinceLastCall>=wait||timeSinceLastCall<0||maxing&&timeSinceLastInvoke>=maxWait;}function timerExpired(){var time=now();if(shouldInvoke(time)){return trailingEdge(time);}// Restart the timer.
    	timerId=setTimeout(timerExpired,remainingWait(time));}function trailingEdge(time){timerId=undefined$1;// Only invoke if we have `lastArgs` which means `func` has been
    	// debounced at least once.
    	if(trailing&&lastArgs){return invokeFunc(time);}lastArgs=lastThis=undefined$1;return result;}function cancel(){if(timerId!==undefined$1){clearTimeout(timerId);}lastInvokeTime=0;lastArgs=lastCallTime=lastThis=timerId=undefined$1;}function flush(){return timerId===undefined$1?result:trailingEdge(now());}function debounced(){var time=now(),isInvoking=shouldInvoke(time);lastArgs=arguments;lastThis=this;lastCallTime=time;if(isInvoking){if(timerId===undefined$1){return leadingEdge(lastCallTime);}if(maxing){// Handle invocations in a tight loop.
    	clearTimeout(timerId);timerId=setTimeout(timerExpired,wait);return invokeFunc(lastCallTime);}}if(timerId===undefined$1){timerId=setTimeout(timerExpired,wait);}return result;}debounced.cancel=cancel;debounced.flush=flush;return debounced;}/**
    	     * Defers invoking the `func` until the current call stack has cleared. Any
    	     * additional arguments are provided to `func` when it's invoked.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Function
    	     * @param {Function} func The function to defer.
    	     * @param {...*} [args] The arguments to invoke `func` with.
    	     * @returns {number} Returns the timer id.
    	     * @example
    	     *
    	     * _.defer(function(text) {
    	     *   console.log(text);
    	     * }, 'deferred');
    	     * // => Logs 'deferred' after one millisecond.
    	     */var defer=baseRest(function(func,args){return baseDelay(func,1,args);});/**
    	     * Invokes `func` after `wait` milliseconds. Any additional arguments are
    	     * provided to `func` when it's invoked.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Function
    	     * @param {Function} func The function to delay.
    	     * @param {number} wait The number of milliseconds to delay invocation.
    	     * @param {...*} [args] The arguments to invoke `func` with.
    	     * @returns {number} Returns the timer id.
    	     * @example
    	     *
    	     * _.delay(function(text) {
    	     *   console.log(text);
    	     * }, 1000, 'later');
    	     * // => Logs 'later' after one second.
    	     */var delay=baseRest(function(func,wait,args){return baseDelay(func,toNumber(wait)||0,args);});/**
    	     * Creates a function that invokes `func` with arguments reversed.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Function
    	     * @param {Function} func The function to flip arguments for.
    	     * @returns {Function} Returns the new flipped function.
    	     * @example
    	     *
    	     * var flipped = _.flip(function() {
    	     *   return _.toArray(arguments);
    	     * });
    	     *
    	     * flipped('a', 'b', 'c', 'd');
    	     * // => ['d', 'c', 'b', 'a']
    	     */function flip(func){return createWrap(func,WRAP_FLIP_FLAG);}/**
    	     * Creates a function that memoizes the result of `func`. If `resolver` is
    	     * provided, it determines the cache key for storing the result based on the
    	     * arguments provided to the memoized function. By default, the first argument
    	     * provided to the memoized function is used as the map cache key. The `func`
    	     * is invoked with the `this` binding of the memoized function.
    	     *
    	     * **Note:** The cache is exposed as the `cache` property on the memoized
    	     * function. Its creation may be customized by replacing the `_.memoize.Cache`
    	     * constructor with one whose instances implement the
    	     * [`Map`](http://ecma-international.org/ecma-262/7.0/#sec-properties-of-the-map-prototype-object)
    	     * method interface of `clear`, `delete`, `get`, `has`, and `set`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Function
    	     * @param {Function} func The function to have its output memoized.
    	     * @param {Function} [resolver] The function to resolve the cache key.
    	     * @returns {Function} Returns the new memoized function.
    	     * @example
    	     *
    	     * var object = { 'a': 1, 'b': 2 };
    	     * var other = { 'c': 3, 'd': 4 };
    	     *
    	     * var values = _.memoize(_.values);
    	     * values(object);
    	     * // => [1, 2]
    	     *
    	     * values(other);
    	     * // => [3, 4]
    	     *
    	     * object.a = 2;
    	     * values(object);
    	     * // => [1, 2]
    	     *
    	     * // Modify the result cache.
    	     * values.cache.set(object, ['a', 'b']);
    	     * values(object);
    	     * // => ['a', 'b']
    	     *
    	     * // Replace `_.memoize.Cache`.
    	     * _.memoize.Cache = WeakMap;
    	     */function memoize(func,resolver){if(typeof func!='function'||resolver!=null&&typeof resolver!='function'){throw new TypeError(FUNC_ERROR_TEXT);}var memoized=function(){var args=arguments,key=resolver?resolver.apply(this,args):args[0],cache=memoized.cache;if(cache.has(key)){return cache.get(key);}var result=func.apply(this,args);memoized.cache=cache.set(key,result)||cache;return result;};memoized.cache=new(memoize.Cache||MapCache)();return memoized;}// Expose `MapCache`.
    	memoize.Cache=MapCache;/**
    	     * Creates a function that negates the result of the predicate `func`. The
    	     * `func` predicate is invoked with the `this` binding and arguments of the
    	     * created function.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Function
    	     * @param {Function} predicate The predicate to negate.
    	     * @returns {Function} Returns the new negated function.
    	     * @example
    	     *
    	     * function isEven(n) {
    	     *   return n % 2 == 0;
    	     * }
    	     *
    	     * _.filter([1, 2, 3, 4, 5, 6], _.negate(isEven));
    	     * // => [1, 3, 5]
    	     */function negate(predicate){if(typeof predicate!='function'){throw new TypeError(FUNC_ERROR_TEXT);}return function(){var args=arguments;switch(args.length){case 0:return !predicate.call(this);case 1:return !predicate.call(this,args[0]);case 2:return !predicate.call(this,args[0],args[1]);case 3:return !predicate.call(this,args[0],args[1],args[2]);}return !predicate.apply(this,args);};}/**
    	     * Creates a function that is restricted to invoking `func` once. Repeat calls
    	     * to the function return the value of the first invocation. The `func` is
    	     * invoked with the `this` binding and arguments of the created function.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Function
    	     * @param {Function} func The function to restrict.
    	     * @returns {Function} Returns the new restricted function.
    	     * @example
    	     *
    	     * var initialize = _.once(createApplication);
    	     * initialize();
    	     * initialize();
    	     * // => `createApplication` is invoked once
    	     */function once(func){return before(2,func);}/**
    	     * Creates a function that invokes `func` with its arguments transformed.
    	     *
    	     * @static
    	     * @since 4.0.0
    	     * @memberOf _
    	     * @category Function
    	     * @param {Function} func The function to wrap.
    	     * @param {...(Function|Function[])} [transforms=[_.identity]]
    	     *  The argument transforms.
    	     * @returns {Function} Returns the new function.
    	     * @example
    	     *
    	     * function doubled(n) {
    	     *   return n * 2;
    	     * }
    	     *
    	     * function square(n) {
    	     *   return n * n;
    	     * }
    	     *
    	     * var func = _.overArgs(function(x, y) {
    	     *   return [x, y];
    	     * }, [square, doubled]);
    	     *
    	     * func(9, 3);
    	     * // => [81, 6]
    	     *
    	     * func(10, 5);
    	     * // => [100, 10]
    	     */var overArgs=castRest(function(func,transforms){transforms=transforms.length==1&&isArray(transforms[0])?arrayMap(transforms[0],baseUnary(getIteratee())):arrayMap(baseFlatten(transforms,1),baseUnary(getIteratee()));var funcsLength=transforms.length;return baseRest(function(args){var index=-1,length=nativeMin(args.length,funcsLength);while(++index<length){args[index]=transforms[index].call(this,args[index]);}return apply(func,this,args);});});/**
    	     * Creates a function that invokes `func` with `partials` prepended to the
    	     * arguments it receives. This method is like `_.bind` except it does **not**
    	     * alter the `this` binding.
    	     *
    	     * The `_.partial.placeholder` value, which defaults to `_` in monolithic
    	     * builds, may be used as a placeholder for partially applied arguments.
    	     *
    	     * **Note:** This method doesn't set the "length" property of partially
    	     * applied functions.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.2.0
    	     * @category Function
    	     * @param {Function} func The function to partially apply arguments to.
    	     * @param {...*} [partials] The arguments to be partially applied.
    	     * @returns {Function} Returns the new partially applied function.
    	     * @example
    	     *
    	     * function greet(greeting, name) {
    	     *   return greeting + ' ' + name;
    	     * }
    	     *
    	     * var sayHelloTo = _.partial(greet, 'hello');
    	     * sayHelloTo('fred');
    	     * // => 'hello fred'
    	     *
    	     * // Partially applied with placeholders.
    	     * var greetFred = _.partial(greet, _, 'fred');
    	     * greetFred('hi');
    	     * // => 'hi fred'
    	     */var partial=baseRest(function(func,partials){var holders=replaceHolders(partials,getHolder(partial));return createWrap(func,WRAP_PARTIAL_FLAG,undefined$1,partials,holders);});/**
    	     * This method is like `_.partial` except that partially applied arguments
    	     * are appended to the arguments it receives.
    	     *
    	     * The `_.partialRight.placeholder` value, which defaults to `_` in monolithic
    	     * builds, may be used as a placeholder for partially applied arguments.
    	     *
    	     * **Note:** This method doesn't set the "length" property of partially
    	     * applied functions.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 1.0.0
    	     * @category Function
    	     * @param {Function} func The function to partially apply arguments to.
    	     * @param {...*} [partials] The arguments to be partially applied.
    	     * @returns {Function} Returns the new partially applied function.
    	     * @example
    	     *
    	     * function greet(greeting, name) {
    	     *   return greeting + ' ' + name;
    	     * }
    	     *
    	     * var greetFred = _.partialRight(greet, 'fred');
    	     * greetFred('hi');
    	     * // => 'hi fred'
    	     *
    	     * // Partially applied with placeholders.
    	     * var sayHelloTo = _.partialRight(greet, 'hello', _);
    	     * sayHelloTo('fred');
    	     * // => 'hello fred'
    	     */var partialRight=baseRest(function(func,partials){var holders=replaceHolders(partials,getHolder(partialRight));return createWrap(func,WRAP_PARTIAL_RIGHT_FLAG,undefined$1,partials,holders);});/**
    	     * Creates a function that invokes `func` with arguments arranged according
    	     * to the specified `indexes` where the argument value at the first index is
    	     * provided as the first argument, the argument value at the second index is
    	     * provided as the second argument, and so on.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Function
    	     * @param {Function} func The function to rearrange arguments for.
    	     * @param {...(number|number[])} indexes The arranged argument indexes.
    	     * @returns {Function} Returns the new function.
    	     * @example
    	     *
    	     * var rearged = _.rearg(function(a, b, c) {
    	     *   return [a, b, c];
    	     * }, [2, 0, 1]);
    	     *
    	     * rearged('b', 'c', 'a')
    	     * // => ['a', 'b', 'c']
    	     */var rearg=flatRest(function(func,indexes){return createWrap(func,WRAP_REARG_FLAG,undefined$1,undefined$1,undefined$1,indexes);});/**
    	     * Creates a function that invokes `func` with the `this` binding of the
    	     * created function and arguments from `start` and beyond provided as
    	     * an array.
    	     *
    	     * **Note:** This method is based on the
    	     * [rest parameter](https://mdn.io/rest_parameters).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Function
    	     * @param {Function} func The function to apply a rest parameter to.
    	     * @param {number} [start=func.length-1] The start position of the rest parameter.
    	     * @returns {Function} Returns the new function.
    	     * @example
    	     *
    	     * var say = _.rest(function(what, names) {
    	     *   return what + ' ' + _.initial(names).join(', ') +
    	     *     (_.size(names) > 1 ? ', & ' : '') + _.last(names);
    	     * });
    	     *
    	     * say('hello', 'fred', 'barney', 'pebbles');
    	     * // => 'hello fred, barney, & pebbles'
    	     */function rest(func,start){if(typeof func!='function'){throw new TypeError(FUNC_ERROR_TEXT);}start=start===undefined$1?start:toInteger(start);return baseRest(func,start);}/**
    	     * Creates a function that invokes `func` with the `this` binding of the
    	     * create function and an array of arguments much like
    	     * [`Function#apply`](http://www.ecma-international.org/ecma-262/7.0/#sec-function.prototype.apply).
    	     *
    	     * **Note:** This method is based on the
    	     * [spread operator](https://mdn.io/spread_operator).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.2.0
    	     * @category Function
    	     * @param {Function} func The function to spread arguments over.
    	     * @param {number} [start=0] The start position of the spread.
    	     * @returns {Function} Returns the new function.
    	     * @example
    	     *
    	     * var say = _.spread(function(who, what) {
    	     *   return who + ' says ' + what;
    	     * });
    	     *
    	     * say(['fred', 'hello']);
    	     * // => 'fred says hello'
    	     *
    	     * var numbers = Promise.all([
    	     *   Promise.resolve(40),
    	     *   Promise.resolve(36)
    	     * ]);
    	     *
    	     * numbers.then(_.spread(function(x, y) {
    	     *   return x + y;
    	     * }));
    	     * // => a Promise of 76
    	     */function spread(func,start){if(typeof func!='function'){throw new TypeError(FUNC_ERROR_TEXT);}start=start==null?0:nativeMax(toInteger(start),0);return baseRest(function(args){var array=args[start],otherArgs=castSlice(args,0,start);if(array){arrayPush(otherArgs,array);}return apply(func,this,otherArgs);});}/**
    	     * Creates a throttled function that only invokes `func` at most once per
    	     * every `wait` milliseconds. The throttled function comes with a `cancel`
    	     * method to cancel delayed `func` invocations and a `flush` method to
    	     * immediately invoke them. Provide `options` to indicate whether `func`
    	     * should be invoked on the leading and/or trailing edge of the `wait`
    	     * timeout. The `func` is invoked with the last arguments provided to the
    	     * throttled function. Subsequent calls to the throttled function return the
    	     * result of the last `func` invocation.
    	     *
    	     * **Note:** If `leading` and `trailing` options are `true`, `func` is
    	     * invoked on the trailing edge of the timeout only if the throttled function
    	     * is invoked more than once during the `wait` timeout.
    	     *
    	     * If `wait` is `0` and `leading` is `false`, `func` invocation is deferred
    	     * until to the next tick, similar to `setTimeout` with a timeout of `0`.
    	     *
    	     * See [David Corbacho's article](https://css-tricks.com/debouncing-throttling-explained-examples/)
    	     * for details over the differences between `_.throttle` and `_.debounce`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Function
    	     * @param {Function} func The function to throttle.
    	     * @param {number} [wait=0] The number of milliseconds to throttle invocations to.
    	     * @param {Object} [options={}] The options object.
    	     * @param {boolean} [options.leading=true]
    	     *  Specify invoking on the leading edge of the timeout.
    	     * @param {boolean} [options.trailing=true]
    	     *  Specify invoking on the trailing edge of the timeout.
    	     * @returns {Function} Returns the new throttled function.
    	     * @example
    	     *
    	     * // Avoid excessively updating the position while scrolling.
    	     * jQuery(window).on('scroll', _.throttle(updatePosition, 100));
    	     *
    	     * // Invoke `renewToken` when the click event is fired, but not more than once every 5 minutes.
    	     * var throttled = _.throttle(renewToken, 300000, { 'trailing': false });
    	     * jQuery(element).on('click', throttled);
    	     *
    	     * // Cancel the trailing throttled invocation.
    	     * jQuery(window).on('popstate', throttled.cancel);
    	     */function throttle(func,wait,options){var leading=true,trailing=true;if(typeof func!='function'){throw new TypeError(FUNC_ERROR_TEXT);}if(isObject(options)){leading='leading'in options?!!options.leading:leading;trailing='trailing'in options?!!options.trailing:trailing;}return debounce(func,wait,{'leading':leading,'maxWait':wait,'trailing':trailing});}/**
    	     * Creates a function that accepts up to one argument, ignoring any
    	     * additional arguments.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Function
    	     * @param {Function} func The function to cap arguments for.
    	     * @returns {Function} Returns the new capped function.
    	     * @example
    	     *
    	     * _.map(['6', '8', '10'], _.unary(parseInt));
    	     * // => [6, 8, 10]
    	     */function unary(func){return ary(func,1);}/**
    	     * Creates a function that provides `value` to `wrapper` as its first
    	     * argument. Any additional arguments provided to the function are appended
    	     * to those provided to the `wrapper`. The wrapper is invoked with the `this`
    	     * binding of the created function.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Function
    	     * @param {*} value The value to wrap.
    	     * @param {Function} [wrapper=identity] The wrapper function.
    	     * @returns {Function} Returns the new function.
    	     * @example
    	     *
    	     * var p = _.wrap(_.escape, function(func, text) {
    	     *   return '<p>' + func(text) + '</p>';
    	     * });
    	     *
    	     * p('fred, barney, & pebbles');
    	     * // => '<p>fred, barney, &amp; pebbles</p>'
    	     */function wrap(value,wrapper){return partial(castFunction(wrapper),value);}/*------------------------------------------------------------------------*/ /**
    	     * Casts `value` as an array if it's not one.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.4.0
    	     * @category Lang
    	     * @param {*} value The value to inspect.
    	     * @returns {Array} Returns the cast array.
    	     * @example
    	     *
    	     * _.castArray(1);
    	     * // => [1]
    	     *
    	     * _.castArray({ 'a': 1 });
    	     * // => [{ 'a': 1 }]
    	     *
    	     * _.castArray('abc');
    	     * // => ['abc']
    	     *
    	     * _.castArray(null);
    	     * // => [null]
    	     *
    	     * _.castArray(undefined);
    	     * // => [undefined]
    	     *
    	     * _.castArray();
    	     * // => []
    	     *
    	     * var array = [1, 2, 3];
    	     * console.log(_.castArray(array) === array);
    	     * // => true
    	     */function castArray(){if(!arguments.length){return [];}var value=arguments[0];return isArray(value)?value:[value];}/**
    	     * Creates a shallow clone of `value`.
    	     *
    	     * **Note:** This method is loosely based on the
    	     * [structured clone algorithm](https://mdn.io/Structured_clone_algorithm)
    	     * and supports cloning arrays, array buffers, booleans, date objects, maps,
    	     * numbers, `Object` objects, regexes, sets, strings, symbols, and typed
    	     * arrays. The own enumerable properties of `arguments` objects are cloned
    	     * as plain objects. An empty object is returned for uncloneable values such
    	     * as error objects, functions, DOM nodes, and WeakMaps.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Lang
    	     * @param {*} value The value to clone.
    	     * @returns {*} Returns the cloned value.
    	     * @see _.cloneDeep
    	     * @example
    	     *
    	     * var objects = [{ 'a': 1 }, { 'b': 2 }];
    	     *
    	     * var shallow = _.clone(objects);
    	     * console.log(shallow[0] === objects[0]);
    	     * // => true
    	     */function clone(value){return baseClone(value,CLONE_SYMBOLS_FLAG);}/**
    	     * This method is like `_.clone` except that it accepts `customizer` which
    	     * is invoked to produce the cloned value. If `customizer` returns `undefined`,
    	     * cloning is handled by the method instead. The `customizer` is invoked with
    	     * up to four arguments; (value [, index|key, object, stack]).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Lang
    	     * @param {*} value The value to clone.
    	     * @param {Function} [customizer] The function to customize cloning.
    	     * @returns {*} Returns the cloned value.
    	     * @see _.cloneDeepWith
    	     * @example
    	     *
    	     * function customizer(value) {
    	     *   if (_.isElement(value)) {
    	     *     return value.cloneNode(false);
    	     *   }
    	     * }
    	     *
    	     * var el = _.cloneWith(document.body, customizer);
    	     *
    	     * console.log(el === document.body);
    	     * // => false
    	     * console.log(el.nodeName);
    	     * // => 'BODY'
    	     * console.log(el.childNodes.length);
    	     * // => 0
    	     */function cloneWith(value,customizer){customizer=typeof customizer=='function'?customizer:undefined$1;return baseClone(value,CLONE_SYMBOLS_FLAG,customizer);}/**
    	     * This method is like `_.clone` except that it recursively clones `value`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 1.0.0
    	     * @category Lang
    	     * @param {*} value The value to recursively clone.
    	     * @returns {*} Returns the deep cloned value.
    	     * @see _.clone
    	     * @example
    	     *
    	     * var objects = [{ 'a': 1 }, { 'b': 2 }];
    	     *
    	     * var deep = _.cloneDeep(objects);
    	     * console.log(deep[0] === objects[0]);
    	     * // => false
    	     */function cloneDeep(value){return baseClone(value,CLONE_DEEP_FLAG|CLONE_SYMBOLS_FLAG);}/**
    	     * This method is like `_.cloneWith` except that it recursively clones `value`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Lang
    	     * @param {*} value The value to recursively clone.
    	     * @param {Function} [customizer] The function to customize cloning.
    	     * @returns {*} Returns the deep cloned value.
    	     * @see _.cloneWith
    	     * @example
    	     *
    	     * function customizer(value) {
    	     *   if (_.isElement(value)) {
    	     *     return value.cloneNode(true);
    	     *   }
    	     * }
    	     *
    	     * var el = _.cloneDeepWith(document.body, customizer);
    	     *
    	     * console.log(el === document.body);
    	     * // => false
    	     * console.log(el.nodeName);
    	     * // => 'BODY'
    	     * console.log(el.childNodes.length);
    	     * // => 20
    	     */function cloneDeepWith(value,customizer){customizer=typeof customizer=='function'?customizer:undefined$1;return baseClone(value,CLONE_DEEP_FLAG|CLONE_SYMBOLS_FLAG,customizer);}/**
    	     * Checks if `object` conforms to `source` by invoking the predicate
    	     * properties of `source` with the corresponding property values of `object`.
    	     *
    	     * **Note:** This method is equivalent to `_.conforms` when `source` is
    	     * partially applied.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.14.0
    	     * @category Lang
    	     * @param {Object} object The object to inspect.
    	     * @param {Object} source The object of property predicates to conform to.
    	     * @returns {boolean} Returns `true` if `object` conforms, else `false`.
    	     * @example
    	     *
    	     * var object = { 'a': 1, 'b': 2 };
    	     *
    	     * _.conformsTo(object, { 'b': function(n) { return n > 1; } });
    	     * // => true
    	     *
    	     * _.conformsTo(object, { 'b': function(n) { return n > 2; } });
    	     * // => false
    	     */function conformsTo(object,source){return source==null||baseConformsTo(object,source,keys(source));}/**
    	     * Performs a
    	     * [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
    	     * comparison between two values to determine if they are equivalent.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Lang
    	     * @param {*} value The value to compare.
    	     * @param {*} other The other value to compare.
    	     * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
    	     * @example
    	     *
    	     * var object = { 'a': 1 };
    	     * var other = { 'a': 1 };
    	     *
    	     * _.eq(object, object);
    	     * // => true
    	     *
    	     * _.eq(object, other);
    	     * // => false
    	     *
    	     * _.eq('a', 'a');
    	     * // => true
    	     *
    	     * _.eq('a', Object('a'));
    	     * // => false
    	     *
    	     * _.eq(NaN, NaN);
    	     * // => true
    	     */function eq(value,other){return value===other||value!==value&&other!==other;}/**
    	     * Checks if `value` is greater than `other`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.9.0
    	     * @category Lang
    	     * @param {*} value The value to compare.
    	     * @param {*} other The other value to compare.
    	     * @returns {boolean} Returns `true` if `value` is greater than `other`,
    	     *  else `false`.
    	     * @see _.lt
    	     * @example
    	     *
    	     * _.gt(3, 1);
    	     * // => true
    	     *
    	     * _.gt(3, 3);
    	     * // => false
    	     *
    	     * _.gt(1, 3);
    	     * // => false
    	     */var gt=createRelationalOperation(baseGt);/**
    	     * Checks if `value` is greater than or equal to `other`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.9.0
    	     * @category Lang
    	     * @param {*} value The value to compare.
    	     * @param {*} other The other value to compare.
    	     * @returns {boolean} Returns `true` if `value` is greater than or equal to
    	     *  `other`, else `false`.
    	     * @see _.lte
    	     * @example
    	     *
    	     * _.gte(3, 1);
    	     * // => true
    	     *
    	     * _.gte(3, 3);
    	     * // => true
    	     *
    	     * _.gte(1, 3);
    	     * // => false
    	     */var gte=createRelationalOperation(function(value,other){return value>=other;});/**
    	     * Checks if `value` is likely an `arguments` object.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is an `arguments` object,
    	     *  else `false`.
    	     * @example
    	     *
    	     * _.isArguments(function() { return arguments; }());
    	     * // => true
    	     *
    	     * _.isArguments([1, 2, 3]);
    	     * // => false
    	     */var isArguments=baseIsArguments(function(){return arguments;}())?baseIsArguments:function(value){return isObjectLike(value)&&hasOwnProperty.call(value,'callee')&&!propertyIsEnumerable.call(value,'callee');};/**
    	     * Checks if `value` is classified as an `Array` object.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is an array, else `false`.
    	     * @example
    	     *
    	     * _.isArray([1, 2, 3]);
    	     * // => true
    	     *
    	     * _.isArray(document.body.children);
    	     * // => false
    	     *
    	     * _.isArray('abc');
    	     * // => false
    	     *
    	     * _.isArray(_.noop);
    	     * // => false
    	     */var isArray=Array.isArray;/**
    	     * Checks if `value` is classified as an `ArrayBuffer` object.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.3.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is an array buffer, else `false`.
    	     * @example
    	     *
    	     * _.isArrayBuffer(new ArrayBuffer(2));
    	     * // => true
    	     *
    	     * _.isArrayBuffer(new Array(2));
    	     * // => false
    	     */var isArrayBuffer=nodeIsArrayBuffer?baseUnary(nodeIsArrayBuffer):baseIsArrayBuffer;/**
    	     * Checks if `value` is array-like. A value is considered array-like if it's
    	     * not a function and has a `value.length` that's an integer greater than or
    	     * equal to `0` and less than or equal to `Number.MAX_SAFE_INTEGER`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is array-like, else `false`.
    	     * @example
    	     *
    	     * _.isArrayLike([1, 2, 3]);
    	     * // => true
    	     *
    	     * _.isArrayLike(document.body.children);
    	     * // => true
    	     *
    	     * _.isArrayLike('abc');
    	     * // => true
    	     *
    	     * _.isArrayLike(_.noop);
    	     * // => false
    	     */function isArrayLike(value){return value!=null&&isLength(value.length)&&!isFunction(value);}/**
    	     * This method is like `_.isArrayLike` except that it also checks if `value`
    	     * is an object.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is an array-like object,
    	     *  else `false`.
    	     * @example
    	     *
    	     * _.isArrayLikeObject([1, 2, 3]);
    	     * // => true
    	     *
    	     * _.isArrayLikeObject(document.body.children);
    	     * // => true
    	     *
    	     * _.isArrayLikeObject('abc');
    	     * // => false
    	     *
    	     * _.isArrayLikeObject(_.noop);
    	     * // => false
    	     */function isArrayLikeObject(value){return isObjectLike(value)&&isArrayLike(value);}/**
    	     * Checks if `value` is classified as a boolean primitive or object.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a boolean, else `false`.
    	     * @example
    	     *
    	     * _.isBoolean(false);
    	     * // => true
    	     *
    	     * _.isBoolean(null);
    	     * // => false
    	     */function isBoolean(value){return value===true||value===false||isObjectLike(value)&&baseGetTag(value)==boolTag;}/**
    	     * Checks if `value` is a buffer.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.3.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a buffer, else `false`.
    	     * @example
    	     *
    	     * _.isBuffer(new Buffer(2));
    	     * // => true
    	     *
    	     * _.isBuffer(new Uint8Array(2));
    	     * // => false
    	     */var isBuffer=nativeIsBuffer||stubFalse;/**
    	     * Checks if `value` is classified as a `Date` object.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a date object, else `false`.
    	     * @example
    	     *
    	     * _.isDate(new Date);
    	     * // => true
    	     *
    	     * _.isDate('Mon April 23 2012');
    	     * // => false
    	     */var isDate=nodeIsDate?baseUnary(nodeIsDate):baseIsDate;/**
    	     * Checks if `value` is likely a DOM element.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a DOM element, else `false`.
    	     * @example
    	     *
    	     * _.isElement(document.body);
    	     * // => true
    	     *
    	     * _.isElement('<body>');
    	     * // => false
    	     */function isElement(value){return isObjectLike(value)&&value.nodeType===1&&!isPlainObject(value);}/**
    	     * Checks if `value` is an empty object, collection, map, or set.
    	     *
    	     * Objects are considered empty if they have no own enumerable string keyed
    	     * properties.
    	     *
    	     * Array-like values such as `arguments` objects, arrays, buffers, strings, or
    	     * jQuery-like collections are considered empty if they have a `length` of `0`.
    	     * Similarly, maps and sets are considered empty if they have a `size` of `0`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is empty, else `false`.
    	     * @example
    	     *
    	     * _.isEmpty(null);
    	     * // => true
    	     *
    	     * _.isEmpty(true);
    	     * // => true
    	     *
    	     * _.isEmpty(1);
    	     * // => true
    	     *
    	     * _.isEmpty([1, 2, 3]);
    	     * // => false
    	     *
    	     * _.isEmpty({ 'a': 1 });
    	     * // => false
    	     */function isEmpty(value){if(value==null){return true;}if(isArrayLike(value)&&(isArray(value)||typeof value=='string'||typeof value.splice=='function'||isBuffer(value)||isTypedArray(value)||isArguments(value))){return !value.length;}var tag=getTag(value);if(tag==mapTag||tag==setTag){return !value.size;}if(isPrototype(value)){return !baseKeys(value).length;}for(var key in value){if(hasOwnProperty.call(value,key)){return false;}}return true;}/**
    	     * Performs a deep comparison between two values to determine if they are
    	     * equivalent.
    	     *
    	     * **Note:** This method supports comparing arrays, array buffers, booleans,
    	     * date objects, error objects, maps, numbers, `Object` objects, regexes,
    	     * sets, strings, symbols, and typed arrays. `Object` objects are compared
    	     * by their own, not inherited, enumerable properties. Functions and DOM
    	     * nodes are compared by strict equality, i.e. `===`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Lang
    	     * @param {*} value The value to compare.
    	     * @param {*} other The other value to compare.
    	     * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
    	     * @example
    	     *
    	     * var object = { 'a': 1 };
    	     * var other = { 'a': 1 };
    	     *
    	     * _.isEqual(object, other);
    	     * // => true
    	     *
    	     * object === other;
    	     * // => false
    	     */function isEqual(value,other){return baseIsEqual(value,other);}/**
    	     * This method is like `_.isEqual` except that it accepts `customizer` which
    	     * is invoked to compare values. If `customizer` returns `undefined`, comparisons
    	     * are handled by the method instead. The `customizer` is invoked with up to
    	     * six arguments: (objValue, othValue [, index|key, object, other, stack]).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Lang
    	     * @param {*} value The value to compare.
    	     * @param {*} other The other value to compare.
    	     * @param {Function} [customizer] The function to customize comparisons.
    	     * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
    	     * @example
    	     *
    	     * function isGreeting(value) {
    	     *   return /^h(?:i|ello)$/.test(value);
    	     * }
    	     *
    	     * function customizer(objValue, othValue) {
    	     *   if (isGreeting(objValue) && isGreeting(othValue)) {
    	     *     return true;
    	     *   }
    	     * }
    	     *
    	     * var array = ['hello', 'goodbye'];
    	     * var other = ['hi', 'goodbye'];
    	     *
    	     * _.isEqualWith(array, other, customizer);
    	     * // => true
    	     */function isEqualWith(value,other,customizer){customizer=typeof customizer=='function'?customizer:undefined$1;var result=customizer?customizer(value,other):undefined$1;return result===undefined$1?baseIsEqual(value,other,undefined$1,customizer):!!result;}/**
    	     * Checks if `value` is an `Error`, `EvalError`, `RangeError`, `ReferenceError`,
    	     * `SyntaxError`, `TypeError`, or `URIError` object.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is an error object, else `false`.
    	     * @example
    	     *
    	     * _.isError(new Error);
    	     * // => true
    	     *
    	     * _.isError(Error);
    	     * // => false
    	     */function isError(value){if(!isObjectLike(value)){return false;}var tag=baseGetTag(value);return tag==errorTag||tag==domExcTag||typeof value.message=='string'&&typeof value.name=='string'&&!isPlainObject(value);}/**
    	     * Checks if `value` is a finite primitive number.
    	     *
    	     * **Note:** This method is based on
    	     * [`Number.isFinite`](https://mdn.io/Number/isFinite).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a finite number, else `false`.
    	     * @example
    	     *
    	     * _.isFinite(3);
    	     * // => true
    	     *
    	     * _.isFinite(Number.MIN_VALUE);
    	     * // => true
    	     *
    	     * _.isFinite(Infinity);
    	     * // => false
    	     *
    	     * _.isFinite('3');
    	     * // => false
    	     */function isFinite(value){return typeof value=='number'&&nativeIsFinite(value);}/**
    	     * Checks if `value` is classified as a `Function` object.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a function, else `false`.
    	     * @example
    	     *
    	     * _.isFunction(_);
    	     * // => true
    	     *
    	     * _.isFunction(/abc/);
    	     * // => false
    	     */function isFunction(value){if(!isObject(value)){return false;}// The use of `Object#toString` avoids issues with the `typeof` operator
    	// in Safari 9 which returns 'object' for typed arrays and other constructors.
    	var tag=baseGetTag(value);return tag==funcTag||tag==genTag||tag==asyncTag||tag==proxyTag;}/**
    	     * Checks if `value` is an integer.
    	     *
    	     * **Note:** This method is based on
    	     * [`Number.isInteger`](https://mdn.io/Number/isInteger).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is an integer, else `false`.
    	     * @example
    	     *
    	     * _.isInteger(3);
    	     * // => true
    	     *
    	     * _.isInteger(Number.MIN_VALUE);
    	     * // => false
    	     *
    	     * _.isInteger(Infinity);
    	     * // => false
    	     *
    	     * _.isInteger('3');
    	     * // => false
    	     */function isInteger(value){return typeof value=='number'&&value==toInteger(value);}/**
    	     * Checks if `value` is a valid array-like length.
    	     *
    	     * **Note:** This method is loosely based on
    	     * [`ToLength`](http://ecma-international.org/ecma-262/7.0/#sec-tolength).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a valid length, else `false`.
    	     * @example
    	     *
    	     * _.isLength(3);
    	     * // => true
    	     *
    	     * _.isLength(Number.MIN_VALUE);
    	     * // => false
    	     *
    	     * _.isLength(Infinity);
    	     * // => false
    	     *
    	     * _.isLength('3');
    	     * // => false
    	     */function isLength(value){return typeof value=='number'&&value>-1&&value%1==0&&value<=MAX_SAFE_INTEGER;}/**
    	     * Checks if `value` is the
    	     * [language type](http://www.ecma-international.org/ecma-262/7.0/#sec-ecmascript-language-types)
    	     * of `Object`. (e.g. arrays, functions, objects, regexes, `new Number(0)`, and `new String('')`)
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is an object, else `false`.
    	     * @example
    	     *
    	     * _.isObject({});
    	     * // => true
    	     *
    	     * _.isObject([1, 2, 3]);
    	     * // => true
    	     *
    	     * _.isObject(_.noop);
    	     * // => true
    	     *
    	     * _.isObject(null);
    	     * // => false
    	     */function isObject(value){var type=typeof value;return value!=null&&(type=='object'||type=='function');}/**
    	     * Checks if `value` is object-like. A value is object-like if it's not `null`
    	     * and has a `typeof` result of "object".
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is object-like, else `false`.
    	     * @example
    	     *
    	     * _.isObjectLike({});
    	     * // => true
    	     *
    	     * _.isObjectLike([1, 2, 3]);
    	     * // => true
    	     *
    	     * _.isObjectLike(_.noop);
    	     * // => false
    	     *
    	     * _.isObjectLike(null);
    	     * // => false
    	     */function isObjectLike(value){return value!=null&&typeof value=='object';}/**
    	     * Checks if `value` is classified as a `Map` object.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.3.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a map, else `false`.
    	     * @example
    	     *
    	     * _.isMap(new Map);
    	     * // => true
    	     *
    	     * _.isMap(new WeakMap);
    	     * // => false
    	     */var isMap=nodeIsMap?baseUnary(nodeIsMap):baseIsMap;/**
    	     * Performs a partial deep comparison between `object` and `source` to
    	     * determine if `object` contains equivalent property values.
    	     *
    	     * **Note:** This method is equivalent to `_.matches` when `source` is
    	     * partially applied.
    	     *
    	     * Partial comparisons will match empty array and empty object `source`
    	     * values against any array or object value, respectively. See `_.isEqual`
    	     * for a list of supported value comparisons.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Lang
    	     * @param {Object} object The object to inspect.
    	     * @param {Object} source The object of property values to match.
    	     * @returns {boolean} Returns `true` if `object` is a match, else `false`.
    	     * @example
    	     *
    	     * var object = { 'a': 1, 'b': 2 };
    	     *
    	     * _.isMatch(object, { 'b': 2 });
    	     * // => true
    	     *
    	     * _.isMatch(object, { 'b': 1 });
    	     * // => false
    	     */function isMatch(object,source){return object===source||baseIsMatch(object,source,getMatchData(source));}/**
    	     * This method is like `_.isMatch` except that it accepts `customizer` which
    	     * is invoked to compare values. If `customizer` returns `undefined`, comparisons
    	     * are handled by the method instead. The `customizer` is invoked with five
    	     * arguments: (objValue, srcValue, index|key, object, source).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Lang
    	     * @param {Object} object The object to inspect.
    	     * @param {Object} source The object of property values to match.
    	     * @param {Function} [customizer] The function to customize comparisons.
    	     * @returns {boolean} Returns `true` if `object` is a match, else `false`.
    	     * @example
    	     *
    	     * function isGreeting(value) {
    	     *   return /^h(?:i|ello)$/.test(value);
    	     * }
    	     *
    	     * function customizer(objValue, srcValue) {
    	     *   if (isGreeting(objValue) && isGreeting(srcValue)) {
    	     *     return true;
    	     *   }
    	     * }
    	     *
    	     * var object = { 'greeting': 'hello' };
    	     * var source = { 'greeting': 'hi' };
    	     *
    	     * _.isMatchWith(object, source, customizer);
    	     * // => true
    	     */function isMatchWith(object,source,customizer){customizer=typeof customizer=='function'?customizer:undefined$1;return baseIsMatch(object,source,getMatchData(source),customizer);}/**
    	     * Checks if `value` is `NaN`.
    	     *
    	     * **Note:** This method is based on
    	     * [`Number.isNaN`](https://mdn.io/Number/isNaN) and is not the same as
    	     * global [`isNaN`](https://mdn.io/isNaN) which returns `true` for
    	     * `undefined` and other non-number values.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is `NaN`, else `false`.
    	     * @example
    	     *
    	     * _.isNaN(NaN);
    	     * // => true
    	     *
    	     * _.isNaN(new Number(NaN));
    	     * // => true
    	     *
    	     * isNaN(undefined);
    	     * // => true
    	     *
    	     * _.isNaN(undefined);
    	     * // => false
    	     */function isNaN(value){// An `NaN` primitive is the only value that is not equal to itself.
    	// Perform the `toStringTag` check first to avoid errors with some
    	// ActiveX objects in IE.
    	return isNumber(value)&&value!=+value;}/**
    	     * Checks if `value` is a pristine native function.
    	     *
    	     * **Note:** This method can't reliably detect native functions in the presence
    	     * of the core-js package because core-js circumvents this kind of detection.
    	     * Despite multiple requests, the core-js maintainer has made it clear: any
    	     * attempt to fix the detection will be obstructed. As a result, we're left
    	     * with little choice but to throw an error. Unfortunately, this also affects
    	     * packages, like [babel-polyfill](https://www.npmjs.com/package/babel-polyfill),
    	     * which rely on core-js.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a native function,
    	     *  else `false`.
    	     * @example
    	     *
    	     * _.isNative(Array.prototype.push);
    	     * // => true
    	     *
    	     * _.isNative(_);
    	     * // => false
    	     */function isNative(value){if(isMaskable(value)){throw new Error(CORE_ERROR_TEXT);}return baseIsNative(value);}/**
    	     * Checks if `value` is `null`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is `null`, else `false`.
    	     * @example
    	     *
    	     * _.isNull(null);
    	     * // => true
    	     *
    	     * _.isNull(void 0);
    	     * // => false
    	     */function isNull(value){return value===null;}/**
    	     * Checks if `value` is `null` or `undefined`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is nullish, else `false`.
    	     * @example
    	     *
    	     * _.isNil(null);
    	     * // => true
    	     *
    	     * _.isNil(void 0);
    	     * // => true
    	     *
    	     * _.isNil(NaN);
    	     * // => false
    	     */function isNil(value){return value==null;}/**
    	     * Checks if `value` is classified as a `Number` primitive or object.
    	     *
    	     * **Note:** To exclude `Infinity`, `-Infinity`, and `NaN`, which are
    	     * classified as numbers, use the `_.isFinite` method.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a number, else `false`.
    	     * @example
    	     *
    	     * _.isNumber(3);
    	     * // => true
    	     *
    	     * _.isNumber(Number.MIN_VALUE);
    	     * // => true
    	     *
    	     * _.isNumber(Infinity);
    	     * // => true
    	     *
    	     * _.isNumber('3');
    	     * // => false
    	     */function isNumber(value){return typeof value=='number'||isObjectLike(value)&&baseGetTag(value)==numberTag;}/**
    	     * Checks if `value` is a plain object, that is, an object created by the
    	     * `Object` constructor or one with a `[[Prototype]]` of `null`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.8.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a plain object, else `false`.
    	     * @example
    	     *
    	     * function Foo() {
    	     *   this.a = 1;
    	     * }
    	     *
    	     * _.isPlainObject(new Foo);
    	     * // => false
    	     *
    	     * _.isPlainObject([1, 2, 3]);
    	     * // => false
    	     *
    	     * _.isPlainObject({ 'x': 0, 'y': 0 });
    	     * // => true
    	     *
    	     * _.isPlainObject(Object.create(null));
    	     * // => true
    	     */function isPlainObject(value){if(!isObjectLike(value)||baseGetTag(value)!=objectTag){return false;}var proto=getPrototype(value);if(proto===null){return true;}var Ctor=hasOwnProperty.call(proto,'constructor')&&proto.constructor;return typeof Ctor=='function'&&Ctor instanceof Ctor&&funcToString.call(Ctor)==objectCtorString;}/**
    	     * Checks if `value` is classified as a `RegExp` object.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.1.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a regexp, else `false`.
    	     * @example
    	     *
    	     * _.isRegExp(/abc/);
    	     * // => true
    	     *
    	     * _.isRegExp('/abc/');
    	     * // => false
    	     */var isRegExp=nodeIsRegExp?baseUnary(nodeIsRegExp):baseIsRegExp;/**
    	     * Checks if `value` is a safe integer. An integer is safe if it's an IEEE-754
    	     * double precision number which isn't the result of a rounded unsafe integer.
    	     *
    	     * **Note:** This method is based on
    	     * [`Number.isSafeInteger`](https://mdn.io/Number/isSafeInteger).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a safe integer, else `false`.
    	     * @example
    	     *
    	     * _.isSafeInteger(3);
    	     * // => true
    	     *
    	     * _.isSafeInteger(Number.MIN_VALUE);
    	     * // => false
    	     *
    	     * _.isSafeInteger(Infinity);
    	     * // => false
    	     *
    	     * _.isSafeInteger('3');
    	     * // => false
    	     */function isSafeInteger(value){return isInteger(value)&&value>=-MAX_SAFE_INTEGER&&value<=MAX_SAFE_INTEGER;}/**
    	     * Checks if `value` is classified as a `Set` object.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.3.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a set, else `false`.
    	     * @example
    	     *
    	     * _.isSet(new Set);
    	     * // => true
    	     *
    	     * _.isSet(new WeakSet);
    	     * // => false
    	     */var isSet=nodeIsSet?baseUnary(nodeIsSet):baseIsSet;/**
    	     * Checks if `value` is classified as a `String` primitive or object.
    	     *
    	     * @static
    	     * @since 0.1.0
    	     * @memberOf _
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a string, else `false`.
    	     * @example
    	     *
    	     * _.isString('abc');
    	     * // => true
    	     *
    	     * _.isString(1);
    	     * // => false
    	     */function isString(value){return typeof value=='string'||!isArray(value)&&isObjectLike(value)&&baseGetTag(value)==stringTag;}/**
    	     * Checks if `value` is classified as a `Symbol` primitive or object.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a symbol, else `false`.
    	     * @example
    	     *
    	     * _.isSymbol(Symbol.iterator);
    	     * // => true
    	     *
    	     * _.isSymbol('abc');
    	     * // => false
    	     */function isSymbol(value){return typeof value=='symbol'||isObjectLike(value)&&baseGetTag(value)==symbolTag;}/**
    	     * Checks if `value` is classified as a typed array.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a typed array, else `false`.
    	     * @example
    	     *
    	     * _.isTypedArray(new Uint8Array);
    	     * // => true
    	     *
    	     * _.isTypedArray([]);
    	     * // => false
    	     */var isTypedArray=nodeIsTypedArray?baseUnary(nodeIsTypedArray):baseIsTypedArray;/**
    	     * Checks if `value` is `undefined`.
    	     *
    	     * @static
    	     * @since 0.1.0
    	     * @memberOf _
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is `undefined`, else `false`.
    	     * @example
    	     *
    	     * _.isUndefined(void 0);
    	     * // => true
    	     *
    	     * _.isUndefined(null);
    	     * // => false
    	     */function isUndefined(value){return value===undefined$1;}/**
    	     * Checks if `value` is classified as a `WeakMap` object.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.3.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a weak map, else `false`.
    	     * @example
    	     *
    	     * _.isWeakMap(new WeakMap);
    	     * // => true
    	     *
    	     * _.isWeakMap(new Map);
    	     * // => false
    	     */function isWeakMap(value){return isObjectLike(value)&&getTag(value)==weakMapTag;}/**
    	     * Checks if `value` is classified as a `WeakSet` object.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.3.0
    	     * @category Lang
    	     * @param {*} value The value to check.
    	     * @returns {boolean} Returns `true` if `value` is a weak set, else `false`.
    	     * @example
    	     *
    	     * _.isWeakSet(new WeakSet);
    	     * // => true
    	     *
    	     * _.isWeakSet(new Set);
    	     * // => false
    	     */function isWeakSet(value){return isObjectLike(value)&&baseGetTag(value)==weakSetTag;}/**
    	     * Checks if `value` is less than `other`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.9.0
    	     * @category Lang
    	     * @param {*} value The value to compare.
    	     * @param {*} other The other value to compare.
    	     * @returns {boolean} Returns `true` if `value` is less than `other`,
    	     *  else `false`.
    	     * @see _.gt
    	     * @example
    	     *
    	     * _.lt(1, 3);
    	     * // => true
    	     *
    	     * _.lt(3, 3);
    	     * // => false
    	     *
    	     * _.lt(3, 1);
    	     * // => false
    	     */var lt=createRelationalOperation(baseLt);/**
    	     * Checks if `value` is less than or equal to `other`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.9.0
    	     * @category Lang
    	     * @param {*} value The value to compare.
    	     * @param {*} other The other value to compare.
    	     * @returns {boolean} Returns `true` if `value` is less than or equal to
    	     *  `other`, else `false`.
    	     * @see _.gte
    	     * @example
    	     *
    	     * _.lte(1, 3);
    	     * // => true
    	     *
    	     * _.lte(3, 3);
    	     * // => true
    	     *
    	     * _.lte(3, 1);
    	     * // => false
    	     */var lte=createRelationalOperation(function(value,other){return value<=other;});/**
    	     * Converts `value` to an array.
    	     *
    	     * @static
    	     * @since 0.1.0
    	     * @memberOf _
    	     * @category Lang
    	     * @param {*} value The value to convert.
    	     * @returns {Array} Returns the converted array.
    	     * @example
    	     *
    	     * _.toArray({ 'a': 1, 'b': 2 });
    	     * // => [1, 2]
    	     *
    	     * _.toArray('abc');
    	     * // => ['a', 'b', 'c']
    	     *
    	     * _.toArray(1);
    	     * // => []
    	     *
    	     * _.toArray(null);
    	     * // => []
    	     */function toArray(value){if(!value){return [];}if(isArrayLike(value)){return isString(value)?stringToArray(value):copyArray(value);}if(symIterator&&value[symIterator]){return iteratorToArray(value[symIterator]());}var tag=getTag(value),func=tag==mapTag?mapToArray:tag==setTag?setToArray:values;return func(value);}/**
    	     * Converts `value` to a finite number.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.12.0
    	     * @category Lang
    	     * @param {*} value The value to convert.
    	     * @returns {number} Returns the converted number.
    	     * @example
    	     *
    	     * _.toFinite(3.2);
    	     * // => 3.2
    	     *
    	     * _.toFinite(Number.MIN_VALUE);
    	     * // => 5e-324
    	     *
    	     * _.toFinite(Infinity);
    	     * // => 1.7976931348623157e+308
    	     *
    	     * _.toFinite('3.2');
    	     * // => 3.2
    	     */function toFinite(value){if(!value){return value===0?value:0;}value=toNumber(value);if(value===INFINITY||value===-INFINITY){var sign=value<0?-1:1;return sign*MAX_INTEGER;}return value===value?value:0;}/**
    	     * Converts `value` to an integer.
    	     *
    	     * **Note:** This method is loosely based on
    	     * [`ToInteger`](http://www.ecma-international.org/ecma-262/7.0/#sec-tointeger).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Lang
    	     * @param {*} value The value to convert.
    	     * @returns {number} Returns the converted integer.
    	     * @example
    	     *
    	     * _.toInteger(3.2);
    	     * // => 3
    	     *
    	     * _.toInteger(Number.MIN_VALUE);
    	     * // => 0
    	     *
    	     * _.toInteger(Infinity);
    	     * // => 1.7976931348623157e+308
    	     *
    	     * _.toInteger('3.2');
    	     * // => 3
    	     */function toInteger(value){var result=toFinite(value),remainder=result%1;return result===result?remainder?result-remainder:result:0;}/**
    	     * Converts `value` to an integer suitable for use as the length of an
    	     * array-like object.
    	     *
    	     * **Note:** This method is based on
    	     * [`ToLength`](http://ecma-international.org/ecma-262/7.0/#sec-tolength).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Lang
    	     * @param {*} value The value to convert.
    	     * @returns {number} Returns the converted integer.
    	     * @example
    	     *
    	     * _.toLength(3.2);
    	     * // => 3
    	     *
    	     * _.toLength(Number.MIN_VALUE);
    	     * // => 0
    	     *
    	     * _.toLength(Infinity);
    	     * // => 4294967295
    	     *
    	     * _.toLength('3.2');
    	     * // => 3
    	     */function toLength(value){return value?baseClamp(toInteger(value),0,MAX_ARRAY_LENGTH):0;}/**
    	     * Converts `value` to a number.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Lang
    	     * @param {*} value The value to process.
    	     * @returns {number} Returns the number.
    	     * @example
    	     *
    	     * _.toNumber(3.2);
    	     * // => 3.2
    	     *
    	     * _.toNumber(Number.MIN_VALUE);
    	     * // => 5e-324
    	     *
    	     * _.toNumber(Infinity);
    	     * // => Infinity
    	     *
    	     * _.toNumber('3.2');
    	     * // => 3.2
    	     */function toNumber(value){if(typeof value=='number'){return value;}if(isSymbol(value)){return NAN;}if(isObject(value)){var other=typeof value.valueOf=='function'?value.valueOf():value;value=isObject(other)?other+'':other;}if(typeof value!='string'){return value===0?value:+value;}value=baseTrim(value);var isBinary=reIsBinary.test(value);return isBinary||reIsOctal.test(value)?freeParseInt(value.slice(2),isBinary?2:8):reIsBadHex.test(value)?NAN:+value;}/**
    	     * Converts `value` to a plain object flattening inherited enumerable string
    	     * keyed properties of `value` to own properties of the plain object.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Lang
    	     * @param {*} value The value to convert.
    	     * @returns {Object} Returns the converted plain object.
    	     * @example
    	     *
    	     * function Foo() {
    	     *   this.b = 2;
    	     * }
    	     *
    	     * Foo.prototype.c = 3;
    	     *
    	     * _.assign({ 'a': 1 }, new Foo);
    	     * // => { 'a': 1, 'b': 2 }
    	     *
    	     * _.assign({ 'a': 1 }, _.toPlainObject(new Foo));
    	     * // => { 'a': 1, 'b': 2, 'c': 3 }
    	     */function toPlainObject(value){return copyObject(value,keysIn(value));}/**
    	     * Converts `value` to a safe integer. A safe integer can be compared and
    	     * represented correctly.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Lang
    	     * @param {*} value The value to convert.
    	     * @returns {number} Returns the converted integer.
    	     * @example
    	     *
    	     * _.toSafeInteger(3.2);
    	     * // => 3
    	     *
    	     * _.toSafeInteger(Number.MIN_VALUE);
    	     * // => 0
    	     *
    	     * _.toSafeInteger(Infinity);
    	     * // => 9007199254740991
    	     *
    	     * _.toSafeInteger('3.2');
    	     * // => 3
    	     */function toSafeInteger(value){return value?baseClamp(toInteger(value),-MAX_SAFE_INTEGER,MAX_SAFE_INTEGER):value===0?value:0;}/**
    	     * Converts `value` to a string. An empty string is returned for `null`
    	     * and `undefined` values. The sign of `-0` is preserved.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Lang
    	     * @param {*} value The value to convert.
    	     * @returns {string} Returns the converted string.
    	     * @example
    	     *
    	     * _.toString(null);
    	     * // => ''
    	     *
    	     * _.toString(-0);
    	     * // => '-0'
    	     *
    	     * _.toString([1, 2, 3]);
    	     * // => '1,2,3'
    	     */function toString(value){return value==null?'':baseToString(value);}/*------------------------------------------------------------------------*/ /**
    	     * Assigns own enumerable string keyed properties of source objects to the
    	     * destination object. Source objects are applied from left to right.
    	     * Subsequent sources overwrite property assignments of previous sources.
    	     *
    	     * **Note:** This method mutates `object` and is loosely based on
    	     * [`Object.assign`](https://mdn.io/Object/assign).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.10.0
    	     * @category Object
    	     * @param {Object} object The destination object.
    	     * @param {...Object} [sources] The source objects.
    	     * @returns {Object} Returns `object`.
    	     * @see _.assignIn
    	     * @example
    	     *
    	     * function Foo() {
    	     *   this.a = 1;
    	     * }
    	     *
    	     * function Bar() {
    	     *   this.c = 3;
    	     * }
    	     *
    	     * Foo.prototype.b = 2;
    	     * Bar.prototype.d = 4;
    	     *
    	     * _.assign({ 'a': 0 }, new Foo, new Bar);
    	     * // => { 'a': 1, 'c': 3 }
    	     */var assign=createAssigner(function(object,source){if(isPrototype(source)||isArrayLike(source)){copyObject(source,keys(source),object);return;}for(var key in source){if(hasOwnProperty.call(source,key)){assignValue(object,key,source[key]);}}});/**
    	     * This method is like `_.assign` except that it iterates over own and
    	     * inherited source properties.
    	     *
    	     * **Note:** This method mutates `object`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @alias extend
    	     * @category Object
    	     * @param {Object} object The destination object.
    	     * @param {...Object} [sources] The source objects.
    	     * @returns {Object} Returns `object`.
    	     * @see _.assign
    	     * @example
    	     *
    	     * function Foo() {
    	     *   this.a = 1;
    	     * }
    	     *
    	     * function Bar() {
    	     *   this.c = 3;
    	     * }
    	     *
    	     * Foo.prototype.b = 2;
    	     * Bar.prototype.d = 4;
    	     *
    	     * _.assignIn({ 'a': 0 }, new Foo, new Bar);
    	     * // => { 'a': 1, 'b': 2, 'c': 3, 'd': 4 }
    	     */var assignIn=createAssigner(function(object,source){copyObject(source,keysIn(source),object);});/**
    	     * This method is like `_.assignIn` except that it accepts `customizer`
    	     * which is invoked to produce the assigned values. If `customizer` returns
    	     * `undefined`, assignment is handled by the method instead. The `customizer`
    	     * is invoked with five arguments: (objValue, srcValue, key, object, source).
    	     *
    	     * **Note:** This method mutates `object`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @alias extendWith
    	     * @category Object
    	     * @param {Object} object The destination object.
    	     * @param {...Object} sources The source objects.
    	     * @param {Function} [customizer] The function to customize assigned values.
    	     * @returns {Object} Returns `object`.
    	     * @see _.assignWith
    	     * @example
    	     *
    	     * function customizer(objValue, srcValue) {
    	     *   return _.isUndefined(objValue) ? srcValue : objValue;
    	     * }
    	     *
    	     * var defaults = _.partialRight(_.assignInWith, customizer);
    	     *
    	     * defaults({ 'a': 1 }, { 'b': 2 }, { 'a': 3 });
    	     * // => { 'a': 1, 'b': 2 }
    	     */var assignInWith=createAssigner(function(object,source,srcIndex,customizer){copyObject(source,keysIn(source),object,customizer);});/**
    	     * This method is like `_.assign` except that it accepts `customizer`
    	     * which is invoked to produce the assigned values. If `customizer` returns
    	     * `undefined`, assignment is handled by the method instead. The `customizer`
    	     * is invoked with five arguments: (objValue, srcValue, key, object, source).
    	     *
    	     * **Note:** This method mutates `object`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Object
    	     * @param {Object} object The destination object.
    	     * @param {...Object} sources The source objects.
    	     * @param {Function} [customizer] The function to customize assigned values.
    	     * @returns {Object} Returns `object`.
    	     * @see _.assignInWith
    	     * @example
    	     *
    	     * function customizer(objValue, srcValue) {
    	     *   return _.isUndefined(objValue) ? srcValue : objValue;
    	     * }
    	     *
    	     * var defaults = _.partialRight(_.assignWith, customizer);
    	     *
    	     * defaults({ 'a': 1 }, { 'b': 2 }, { 'a': 3 });
    	     * // => { 'a': 1, 'b': 2 }
    	     */var assignWith=createAssigner(function(object,source,srcIndex,customizer){copyObject(source,keys(source),object,customizer);});/**
    	     * Creates an array of values corresponding to `paths` of `object`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 1.0.0
    	     * @category Object
    	     * @param {Object} object The object to iterate over.
    	     * @param {...(string|string[])} [paths] The property paths to pick.
    	     * @returns {Array} Returns the picked values.
    	     * @example
    	     *
    	     * var object = { 'a': [{ 'b': { 'c': 3 } }, 4] };
    	     *
    	     * _.at(object, ['a[0].b.c', 'a[1]']);
    	     * // => [3, 4]
    	     */var at=flatRest(baseAt);/**
    	     * Creates an object that inherits from the `prototype` object. If a
    	     * `properties` object is given, its own enumerable string keyed properties
    	     * are assigned to the created object.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 2.3.0
    	     * @category Object
    	     * @param {Object} prototype The object to inherit from.
    	     * @param {Object} [properties] The properties to assign to the object.
    	     * @returns {Object} Returns the new object.
    	     * @example
    	     *
    	     * function Shape() {
    	     *   this.x = 0;
    	     *   this.y = 0;
    	     * }
    	     *
    	     * function Circle() {
    	     *   Shape.call(this);
    	     * }
    	     *
    	     * Circle.prototype = _.create(Shape.prototype, {
    	     *   'constructor': Circle
    	     * });
    	     *
    	     * var circle = new Circle;
    	     * circle instanceof Circle;
    	     * // => true
    	     *
    	     * circle instanceof Shape;
    	     * // => true
    	     */function create(prototype,properties){var result=baseCreate(prototype);return properties==null?result:baseAssign(result,properties);}/**
    	     * Assigns own and inherited enumerable string keyed properties of source
    	     * objects to the destination object for all destination properties that
    	     * resolve to `undefined`. Source objects are applied from left to right.
    	     * Once a property is set, additional values of the same property are ignored.
    	     *
    	     * **Note:** This method mutates `object`.
    	     *
    	     * @static
    	     * @since 0.1.0
    	     * @memberOf _
    	     * @category Object
    	     * @param {Object} object The destination object.
    	     * @param {...Object} [sources] The source objects.
    	     * @returns {Object} Returns `object`.
    	     * @see _.defaultsDeep
    	     * @example
    	     *
    	     * _.defaults({ 'a': 1 }, { 'b': 2 }, { 'a': 3 });
    	     * // => { 'a': 1, 'b': 2 }
    	     */var defaults=baseRest(function(object,sources){object=Object(object);var index=-1;var length=sources.length;var guard=length>2?sources[2]:undefined$1;if(guard&&isIterateeCall(sources[0],sources[1],guard)){length=1;}while(++index<length){var source=sources[index];var props=keysIn(source);var propsIndex=-1;var propsLength=props.length;while(++propsIndex<propsLength){var key=props[propsIndex];var value=object[key];if(value===undefined$1||eq(value,objectProto[key])&&!hasOwnProperty.call(object,key)){object[key]=source[key];}}}return object;});/**
    	     * This method is like `_.defaults` except that it recursively assigns
    	     * default properties.
    	     *
    	     * **Note:** This method mutates `object`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.10.0
    	     * @category Object
    	     * @param {Object} object The destination object.
    	     * @param {...Object} [sources] The source objects.
    	     * @returns {Object} Returns `object`.
    	     * @see _.defaults
    	     * @example
    	     *
    	     * _.defaultsDeep({ 'a': { 'b': 2 } }, { 'a': { 'b': 1, 'c': 3 } });
    	     * // => { 'a': { 'b': 2, 'c': 3 } }
    	     */var defaultsDeep=baseRest(function(args){args.push(undefined$1,customDefaultsMerge);return apply(mergeWith,undefined$1,args);});/**
    	     * This method is like `_.find` except that it returns the key of the first
    	     * element `predicate` returns truthy for instead of the element itself.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 1.1.0
    	     * @category Object
    	     * @param {Object} object The object to inspect.
    	     * @param {Function} [predicate=_.identity] The function invoked per iteration.
    	     * @returns {string|undefined} Returns the key of the matched element,
    	     *  else `undefined`.
    	     * @example
    	     *
    	     * var users = {
    	     *   'barney':  { 'age': 36, 'active': true },
    	     *   'fred':    { 'age': 40, 'active': false },
    	     *   'pebbles': { 'age': 1,  'active': true }
    	     * };
    	     *
    	     * _.findKey(users, function(o) { return o.age < 40; });
    	     * // => 'barney' (iteration order is not guaranteed)
    	     *
    	     * // The `_.matches` iteratee shorthand.
    	     * _.findKey(users, { 'age': 1, 'active': true });
    	     * // => 'pebbles'
    	     *
    	     * // The `_.matchesProperty` iteratee shorthand.
    	     * _.findKey(users, ['active', false]);
    	     * // => 'fred'
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.findKey(users, 'active');
    	     * // => 'barney'
    	     */function findKey(object,predicate){return baseFindKey(object,getIteratee(predicate,3),baseForOwn);}/**
    	     * This method is like `_.findKey` except that it iterates over elements of
    	     * a collection in the opposite order.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 2.0.0
    	     * @category Object
    	     * @param {Object} object The object to inspect.
    	     * @param {Function} [predicate=_.identity] The function invoked per iteration.
    	     * @returns {string|undefined} Returns the key of the matched element,
    	     *  else `undefined`.
    	     * @example
    	     *
    	     * var users = {
    	     *   'barney':  { 'age': 36, 'active': true },
    	     *   'fred':    { 'age': 40, 'active': false },
    	     *   'pebbles': { 'age': 1,  'active': true }
    	     * };
    	     *
    	     * _.findLastKey(users, function(o) { return o.age < 40; });
    	     * // => returns 'pebbles' assuming `_.findKey` returns 'barney'
    	     *
    	     * // The `_.matches` iteratee shorthand.
    	     * _.findLastKey(users, { 'age': 36, 'active': true });
    	     * // => 'barney'
    	     *
    	     * // The `_.matchesProperty` iteratee shorthand.
    	     * _.findLastKey(users, ['active', false]);
    	     * // => 'fred'
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.findLastKey(users, 'active');
    	     * // => 'pebbles'
    	     */function findLastKey(object,predicate){return baseFindKey(object,getIteratee(predicate,3),baseForOwnRight);}/**
    	     * Iterates over own and inherited enumerable string keyed properties of an
    	     * object and invokes `iteratee` for each property. The iteratee is invoked
    	     * with three arguments: (value, key, object). Iteratee functions may exit
    	     * iteration early by explicitly returning `false`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.3.0
    	     * @category Object
    	     * @param {Object} object The object to iterate over.
    	     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
    	     * @returns {Object} Returns `object`.
    	     * @see _.forInRight
    	     * @example
    	     *
    	     * function Foo() {
    	     *   this.a = 1;
    	     *   this.b = 2;
    	     * }
    	     *
    	     * Foo.prototype.c = 3;
    	     *
    	     * _.forIn(new Foo, function(value, key) {
    	     *   console.log(key);
    	     * });
    	     * // => Logs 'a', 'b', then 'c' (iteration order is not guaranteed).
    	     */function forIn(object,iteratee){return object==null?object:baseFor(object,getIteratee(iteratee,3),keysIn);}/**
    	     * This method is like `_.forIn` except that it iterates over properties of
    	     * `object` in the opposite order.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 2.0.0
    	     * @category Object
    	     * @param {Object} object The object to iterate over.
    	     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
    	     * @returns {Object} Returns `object`.
    	     * @see _.forIn
    	     * @example
    	     *
    	     * function Foo() {
    	     *   this.a = 1;
    	     *   this.b = 2;
    	     * }
    	     *
    	     * Foo.prototype.c = 3;
    	     *
    	     * _.forInRight(new Foo, function(value, key) {
    	     *   console.log(key);
    	     * });
    	     * // => Logs 'c', 'b', then 'a' assuming `_.forIn` logs 'a', 'b', then 'c'.
    	     */function forInRight(object,iteratee){return object==null?object:baseForRight(object,getIteratee(iteratee,3),keysIn);}/**
    	     * Iterates over own enumerable string keyed properties of an object and
    	     * invokes `iteratee` for each property. The iteratee is invoked with three
    	     * arguments: (value, key, object). Iteratee functions may exit iteration
    	     * early by explicitly returning `false`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.3.0
    	     * @category Object
    	     * @param {Object} object The object to iterate over.
    	     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
    	     * @returns {Object} Returns `object`.
    	     * @see _.forOwnRight
    	     * @example
    	     *
    	     * function Foo() {
    	     *   this.a = 1;
    	     *   this.b = 2;
    	     * }
    	     *
    	     * Foo.prototype.c = 3;
    	     *
    	     * _.forOwn(new Foo, function(value, key) {
    	     *   console.log(key);
    	     * });
    	     * // => Logs 'a' then 'b' (iteration order is not guaranteed).
    	     */function forOwn(object,iteratee){return object&&baseForOwn(object,getIteratee(iteratee,3));}/**
    	     * This method is like `_.forOwn` except that it iterates over properties of
    	     * `object` in the opposite order.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 2.0.0
    	     * @category Object
    	     * @param {Object} object The object to iterate over.
    	     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
    	     * @returns {Object} Returns `object`.
    	     * @see _.forOwn
    	     * @example
    	     *
    	     * function Foo() {
    	     *   this.a = 1;
    	     *   this.b = 2;
    	     * }
    	     *
    	     * Foo.prototype.c = 3;
    	     *
    	     * _.forOwnRight(new Foo, function(value, key) {
    	     *   console.log(key);
    	     * });
    	     * // => Logs 'b' then 'a' assuming `_.forOwn` logs 'a' then 'b'.
    	     */function forOwnRight(object,iteratee){return object&&baseForOwnRight(object,getIteratee(iteratee,3));}/**
    	     * Creates an array of function property names from own enumerable properties
    	     * of `object`.
    	     *
    	     * @static
    	     * @since 0.1.0
    	     * @memberOf _
    	     * @category Object
    	     * @param {Object} object The object to inspect.
    	     * @returns {Array} Returns the function names.
    	     * @see _.functionsIn
    	     * @example
    	     *
    	     * function Foo() {
    	     *   this.a = _.constant('a');
    	     *   this.b = _.constant('b');
    	     * }
    	     *
    	     * Foo.prototype.c = _.constant('c');
    	     *
    	     * _.functions(new Foo);
    	     * // => ['a', 'b']
    	     */function functions(object){return object==null?[]:baseFunctions(object,keys(object));}/**
    	     * Creates an array of function property names from own and inherited
    	     * enumerable properties of `object`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Object
    	     * @param {Object} object The object to inspect.
    	     * @returns {Array} Returns the function names.
    	     * @see _.functions
    	     * @example
    	     *
    	     * function Foo() {
    	     *   this.a = _.constant('a');
    	     *   this.b = _.constant('b');
    	     * }
    	     *
    	     * Foo.prototype.c = _.constant('c');
    	     *
    	     * _.functionsIn(new Foo);
    	     * // => ['a', 'b', 'c']
    	     */function functionsIn(object){return object==null?[]:baseFunctions(object,keysIn(object));}/**
    	     * Gets the value at `path` of `object`. If the resolved value is
    	     * `undefined`, the `defaultValue` is returned in its place.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.7.0
    	     * @category Object
    	     * @param {Object} object The object to query.
    	     * @param {Array|string} path The path of the property to get.
    	     * @param {*} [defaultValue] The value returned for `undefined` resolved values.
    	     * @returns {*} Returns the resolved value.
    	     * @example
    	     *
    	     * var object = { 'a': [{ 'b': { 'c': 3 } }] };
    	     *
    	     * _.get(object, 'a[0].b.c');
    	     * // => 3
    	     *
    	     * _.get(object, ['a', '0', 'b', 'c']);
    	     * // => 3
    	     *
    	     * _.get(object, 'a.b.c', 'default');
    	     * // => 'default'
    	     */function get(object,path,defaultValue){var result=object==null?undefined$1:baseGet(object,path);return result===undefined$1?defaultValue:result;}/**
    	     * Checks if `path` is a direct property of `object`.
    	     *
    	     * @static
    	     * @since 0.1.0
    	     * @memberOf _
    	     * @category Object
    	     * @param {Object} object The object to query.
    	     * @param {Array|string} path The path to check.
    	     * @returns {boolean} Returns `true` if `path` exists, else `false`.
    	     * @example
    	     *
    	     * var object = { 'a': { 'b': 2 } };
    	     * var other = _.create({ 'a': _.create({ 'b': 2 }) });
    	     *
    	     * _.has(object, 'a');
    	     * // => true
    	     *
    	     * _.has(object, 'a.b');
    	     * // => true
    	     *
    	     * _.has(object, ['a', 'b']);
    	     * // => true
    	     *
    	     * _.has(other, 'a');
    	     * // => false
    	     */function has(object,path){return object!=null&&hasPath(object,path,baseHas);}/**
    	     * Checks if `path` is a direct or inherited property of `object`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Object
    	     * @param {Object} object The object to query.
    	     * @param {Array|string} path The path to check.
    	     * @returns {boolean} Returns `true` if `path` exists, else `false`.
    	     * @example
    	     *
    	     * var object = _.create({ 'a': _.create({ 'b': 2 }) });
    	     *
    	     * _.hasIn(object, 'a');
    	     * // => true
    	     *
    	     * _.hasIn(object, 'a.b');
    	     * // => true
    	     *
    	     * _.hasIn(object, ['a', 'b']);
    	     * // => true
    	     *
    	     * _.hasIn(object, 'b');
    	     * // => false
    	     */function hasIn(object,path){return object!=null&&hasPath(object,path,baseHasIn);}/**
    	     * Creates an object composed of the inverted keys and values of `object`.
    	     * If `object` contains duplicate values, subsequent values overwrite
    	     * property assignments of previous values.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.7.0
    	     * @category Object
    	     * @param {Object} object The object to invert.
    	     * @returns {Object} Returns the new inverted object.
    	     * @example
    	     *
    	     * var object = { 'a': 1, 'b': 2, 'c': 1 };
    	     *
    	     * _.invert(object);
    	     * // => { '1': 'c', '2': 'b' }
    	     */var invert=createInverter(function(result,value,key){if(value!=null&&typeof value.toString!='function'){value=nativeObjectToString.call(value);}result[value]=key;},constant(identity));/**
    	     * This method is like `_.invert` except that the inverted object is generated
    	     * from the results of running each element of `object` thru `iteratee`. The
    	     * corresponding inverted value of each inverted key is an array of keys
    	     * responsible for generating the inverted value. The iteratee is invoked
    	     * with one argument: (value).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.1.0
    	     * @category Object
    	     * @param {Object} object The object to invert.
    	     * @param {Function} [iteratee=_.identity] The iteratee invoked per element.
    	     * @returns {Object} Returns the new inverted object.
    	     * @example
    	     *
    	     * var object = { 'a': 1, 'b': 2, 'c': 1 };
    	     *
    	     * _.invertBy(object);
    	     * // => { '1': ['a', 'c'], '2': ['b'] }
    	     *
    	     * _.invertBy(object, function(value) {
    	     *   return 'group' + value;
    	     * });
    	     * // => { 'group1': ['a', 'c'], 'group2': ['b'] }
    	     */var invertBy=createInverter(function(result,value,key){if(value!=null&&typeof value.toString!='function'){value=nativeObjectToString.call(value);}if(hasOwnProperty.call(result,value)){result[value].push(key);}else {result[value]=[key];}},getIteratee);/**
    	     * Invokes the method at `path` of `object`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Object
    	     * @param {Object} object The object to query.
    	     * @param {Array|string} path The path of the method to invoke.
    	     * @param {...*} [args] The arguments to invoke the method with.
    	     * @returns {*} Returns the result of the invoked method.
    	     * @example
    	     *
    	     * var object = { 'a': [{ 'b': { 'c': [1, 2, 3, 4] } }] };
    	     *
    	     * _.invoke(object, 'a[0].b.c.slice', 1, 3);
    	     * // => [2, 3]
    	     */var invoke=baseRest(baseInvoke);/**
    	     * Creates an array of the own enumerable property names of `object`.
    	     *
    	     * **Note:** Non-object values are coerced to objects. See the
    	     * [ES spec](http://ecma-international.org/ecma-262/7.0/#sec-object.keys)
    	     * for more details.
    	     *
    	     * @static
    	     * @since 0.1.0
    	     * @memberOf _
    	     * @category Object
    	     * @param {Object} object The object to query.
    	     * @returns {Array} Returns the array of property names.
    	     * @example
    	     *
    	     * function Foo() {
    	     *   this.a = 1;
    	     *   this.b = 2;
    	     * }
    	     *
    	     * Foo.prototype.c = 3;
    	     *
    	     * _.keys(new Foo);
    	     * // => ['a', 'b'] (iteration order is not guaranteed)
    	     *
    	     * _.keys('hi');
    	     * // => ['0', '1']
    	     */function keys(object){return isArrayLike(object)?arrayLikeKeys(object):baseKeys(object);}/**
    	     * Creates an array of the own and inherited enumerable property names of `object`.
    	     *
    	     * **Note:** Non-object values are coerced to objects.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Object
    	     * @param {Object} object The object to query.
    	     * @returns {Array} Returns the array of property names.
    	     * @example
    	     *
    	     * function Foo() {
    	     *   this.a = 1;
    	     *   this.b = 2;
    	     * }
    	     *
    	     * Foo.prototype.c = 3;
    	     *
    	     * _.keysIn(new Foo);
    	     * // => ['a', 'b', 'c'] (iteration order is not guaranteed)
    	     */function keysIn(object){return isArrayLike(object)?arrayLikeKeys(object,true):baseKeysIn(object);}/**
    	     * The opposite of `_.mapValues`; this method creates an object with the
    	     * same values as `object` and keys generated by running each own enumerable
    	     * string keyed property of `object` thru `iteratee`. The iteratee is invoked
    	     * with three arguments: (value, key, object).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.8.0
    	     * @category Object
    	     * @param {Object} object The object to iterate over.
    	     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
    	     * @returns {Object} Returns the new mapped object.
    	     * @see _.mapValues
    	     * @example
    	     *
    	     * _.mapKeys({ 'a': 1, 'b': 2 }, function(value, key) {
    	     *   return key + value;
    	     * });
    	     * // => { 'a1': 1, 'b2': 2 }
    	     */function mapKeys(object,iteratee){var result={};iteratee=getIteratee(iteratee,3);baseForOwn(object,function(value,key,object){baseAssignValue(result,iteratee(value,key,object),value);});return result;}/**
    	     * Creates an object with the same keys as `object` and values generated
    	     * by running each own enumerable string keyed property of `object` thru
    	     * `iteratee`. The iteratee is invoked with three arguments:
    	     * (value, key, object).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 2.4.0
    	     * @category Object
    	     * @param {Object} object The object to iterate over.
    	     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
    	     * @returns {Object} Returns the new mapped object.
    	     * @see _.mapKeys
    	     * @example
    	     *
    	     * var users = {
    	     *   'fred':    { 'user': 'fred',    'age': 40 },
    	     *   'pebbles': { 'user': 'pebbles', 'age': 1 }
    	     * };
    	     *
    	     * _.mapValues(users, function(o) { return o.age; });
    	     * // => { 'fred': 40, 'pebbles': 1 } (iteration order is not guaranteed)
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.mapValues(users, 'age');
    	     * // => { 'fred': 40, 'pebbles': 1 } (iteration order is not guaranteed)
    	     */function mapValues(object,iteratee){var result={};iteratee=getIteratee(iteratee,3);baseForOwn(object,function(value,key,object){baseAssignValue(result,key,iteratee(value,key,object));});return result;}/**
    	     * This method is like `_.assign` except that it recursively merges own and
    	     * inherited enumerable string keyed properties of source objects into the
    	     * destination object. Source properties that resolve to `undefined` are
    	     * skipped if a destination value exists. Array and plain object properties
    	     * are merged recursively. Other objects and value types are overridden by
    	     * assignment. Source objects are applied from left to right. Subsequent
    	     * sources overwrite property assignments of previous sources.
    	     *
    	     * **Note:** This method mutates `object`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.5.0
    	     * @category Object
    	     * @param {Object} object The destination object.
    	     * @param {...Object} [sources] The source objects.
    	     * @returns {Object} Returns `object`.
    	     * @example
    	     *
    	     * var object = {
    	     *   'a': [{ 'b': 2 }, { 'd': 4 }]
    	     * };
    	     *
    	     * var other = {
    	     *   'a': [{ 'c': 3 }, { 'e': 5 }]
    	     * };
    	     *
    	     * _.merge(object, other);
    	     * // => { 'a': [{ 'b': 2, 'c': 3 }, { 'd': 4, 'e': 5 }] }
    	     */var merge=createAssigner(function(object,source,srcIndex){baseMerge(object,source,srcIndex);});/**
    	     * This method is like `_.merge` except that it accepts `customizer` which
    	     * is invoked to produce the merged values of the destination and source
    	     * properties. If `customizer` returns `undefined`, merging is handled by the
    	     * method instead. The `customizer` is invoked with six arguments:
    	     * (objValue, srcValue, key, object, source, stack).
    	     *
    	     * **Note:** This method mutates `object`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Object
    	     * @param {Object} object The destination object.
    	     * @param {...Object} sources The source objects.
    	     * @param {Function} customizer The function to customize assigned values.
    	     * @returns {Object} Returns `object`.
    	     * @example
    	     *
    	     * function customizer(objValue, srcValue) {
    	     *   if (_.isArray(objValue)) {
    	     *     return objValue.concat(srcValue);
    	     *   }
    	     * }
    	     *
    	     * var object = { 'a': [1], 'b': [2] };
    	     * var other = { 'a': [3], 'b': [4] };
    	     *
    	     * _.mergeWith(object, other, customizer);
    	     * // => { 'a': [1, 3], 'b': [2, 4] }
    	     */var mergeWith=createAssigner(function(object,source,srcIndex,customizer){baseMerge(object,source,srcIndex,customizer);});/**
    	     * The opposite of `_.pick`; this method creates an object composed of the
    	     * own and inherited enumerable property paths of `object` that are not omitted.
    	     *
    	     * **Note:** This method is considerably slower than `_.pick`.
    	     *
    	     * @static
    	     * @since 0.1.0
    	     * @memberOf _
    	     * @category Object
    	     * @param {Object} object The source object.
    	     * @param {...(string|string[])} [paths] The property paths to omit.
    	     * @returns {Object} Returns the new object.
    	     * @example
    	     *
    	     * var object = { 'a': 1, 'b': '2', 'c': 3 };
    	     *
    	     * _.omit(object, ['a', 'c']);
    	     * // => { 'b': '2' }
    	     */var omit=flatRest(function(object,paths){var result={};if(object==null){return result;}var isDeep=false;paths=arrayMap(paths,function(path){path=castPath(path,object);isDeep||(isDeep=path.length>1);return path;});copyObject(object,getAllKeysIn(object),result);if(isDeep){result=baseClone(result,CLONE_DEEP_FLAG|CLONE_FLAT_FLAG|CLONE_SYMBOLS_FLAG,customOmitClone);}var length=paths.length;while(length--){baseUnset(result,paths[length]);}return result;});/**
    	     * The opposite of `_.pickBy`; this method creates an object composed of
    	     * the own and inherited enumerable string keyed properties of `object` that
    	     * `predicate` doesn't return truthy for. The predicate is invoked with two
    	     * arguments: (value, key).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Object
    	     * @param {Object} object The source object.
    	     * @param {Function} [predicate=_.identity] The function invoked per property.
    	     * @returns {Object} Returns the new object.
    	     * @example
    	     *
    	     * var object = { 'a': 1, 'b': '2', 'c': 3 };
    	     *
    	     * _.omitBy(object, _.isNumber);
    	     * // => { 'b': '2' }
    	     */function omitBy(object,predicate){return pickBy(object,negate(getIteratee(predicate)));}/**
    	     * Creates an object composed of the picked `object` properties.
    	     *
    	     * @static
    	     * @since 0.1.0
    	     * @memberOf _
    	     * @category Object
    	     * @param {Object} object The source object.
    	     * @param {...(string|string[])} [paths] The property paths to pick.
    	     * @returns {Object} Returns the new object.
    	     * @example
    	     *
    	     * var object = { 'a': 1, 'b': '2', 'c': 3 };
    	     *
    	     * _.pick(object, ['a', 'c']);
    	     * // => { 'a': 1, 'c': 3 }
    	     */var pick=flatRest(function(object,paths){return object==null?{}:basePick(object,paths);});/**
    	     * Creates an object composed of the `object` properties `predicate` returns
    	     * truthy for. The predicate is invoked with two arguments: (value, key).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Object
    	     * @param {Object} object The source object.
    	     * @param {Function} [predicate=_.identity] The function invoked per property.
    	     * @returns {Object} Returns the new object.
    	     * @example
    	     *
    	     * var object = { 'a': 1, 'b': '2', 'c': 3 };
    	     *
    	     * _.pickBy(object, _.isNumber);
    	     * // => { 'a': 1, 'c': 3 }
    	     */function pickBy(object,predicate){if(object==null){return {};}var props=arrayMap(getAllKeysIn(object),function(prop){return [prop];});predicate=getIteratee(predicate);return basePickBy(object,props,function(value,path){return predicate(value,path[0]);});}/**
    	     * This method is like `_.get` except that if the resolved value is a
    	     * function it's invoked with the `this` binding of its parent object and
    	     * its result is returned.
    	     *
    	     * @static
    	     * @since 0.1.0
    	     * @memberOf _
    	     * @category Object
    	     * @param {Object} object The object to query.
    	     * @param {Array|string} path The path of the property to resolve.
    	     * @param {*} [defaultValue] The value returned for `undefined` resolved values.
    	     * @returns {*} Returns the resolved value.
    	     * @example
    	     *
    	     * var object = { 'a': [{ 'b': { 'c1': 3, 'c2': _.constant(4) } }] };
    	     *
    	     * _.result(object, 'a[0].b.c1');
    	     * // => 3
    	     *
    	     * _.result(object, 'a[0].b.c2');
    	     * // => 4
    	     *
    	     * _.result(object, 'a[0].b.c3', 'default');
    	     * // => 'default'
    	     *
    	     * _.result(object, 'a[0].b.c3', _.constant('default'));
    	     * // => 'default'
    	     */function result(object,path,defaultValue){path=castPath(path,object);var index=-1,length=path.length;// Ensure the loop is entered when path is empty.
    	if(!length){length=1;object=undefined$1;}while(++index<length){var value=object==null?undefined$1:object[toKey(path[index])];if(value===undefined$1){index=length;value=defaultValue;}object=isFunction(value)?value.call(object):value;}return object;}/**
    	     * Sets the value at `path` of `object`. If a portion of `path` doesn't exist,
    	     * it's created. Arrays are created for missing index properties while objects
    	     * are created for all other missing properties. Use `_.setWith` to customize
    	     * `path` creation.
    	     *
    	     * **Note:** This method mutates `object`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.7.0
    	     * @category Object
    	     * @param {Object} object The object to modify.
    	     * @param {Array|string} path The path of the property to set.
    	     * @param {*} value The value to set.
    	     * @returns {Object} Returns `object`.
    	     * @example
    	     *
    	     * var object = { 'a': [{ 'b': { 'c': 3 } }] };
    	     *
    	     * _.set(object, 'a[0].b.c', 4);
    	     * console.log(object.a[0].b.c);
    	     * // => 4
    	     *
    	     * _.set(object, ['x', '0', 'y', 'z'], 5);
    	     * console.log(object.x[0].y.z);
    	     * // => 5
    	     */function set(object,path,value){return object==null?object:baseSet(object,path,value);}/**
    	     * This method is like `_.set` except that it accepts `customizer` which is
    	     * invoked to produce the objects of `path`.  If `customizer` returns `undefined`
    	     * path creation is handled by the method instead. The `customizer` is invoked
    	     * with three arguments: (nsValue, key, nsObject).
    	     *
    	     * **Note:** This method mutates `object`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Object
    	     * @param {Object} object The object to modify.
    	     * @param {Array|string} path The path of the property to set.
    	     * @param {*} value The value to set.
    	     * @param {Function} [customizer] The function to customize assigned values.
    	     * @returns {Object} Returns `object`.
    	     * @example
    	     *
    	     * var object = {};
    	     *
    	     * _.setWith(object, '[0][1]', 'a', Object);
    	     * // => { '0': { '1': 'a' } }
    	     */function setWith(object,path,value,customizer){customizer=typeof customizer=='function'?customizer:undefined$1;return object==null?object:baseSet(object,path,value,customizer);}/**
    	     * Creates an array of own enumerable string keyed-value pairs for `object`
    	     * which can be consumed by `_.fromPairs`. If `object` is a map or set, its
    	     * entries are returned.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @alias entries
    	     * @category Object
    	     * @param {Object} object The object to query.
    	     * @returns {Array} Returns the key-value pairs.
    	     * @example
    	     *
    	     * function Foo() {
    	     *   this.a = 1;
    	     *   this.b = 2;
    	     * }
    	     *
    	     * Foo.prototype.c = 3;
    	     *
    	     * _.toPairs(new Foo);
    	     * // => [['a', 1], ['b', 2]] (iteration order is not guaranteed)
    	     */var toPairs=createToPairs(keys);/**
    	     * Creates an array of own and inherited enumerable string keyed-value pairs
    	     * for `object` which can be consumed by `_.fromPairs`. If `object` is a map
    	     * or set, its entries are returned.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @alias entriesIn
    	     * @category Object
    	     * @param {Object} object The object to query.
    	     * @returns {Array} Returns the key-value pairs.
    	     * @example
    	     *
    	     * function Foo() {
    	     *   this.a = 1;
    	     *   this.b = 2;
    	     * }
    	     *
    	     * Foo.prototype.c = 3;
    	     *
    	     * _.toPairsIn(new Foo);
    	     * // => [['a', 1], ['b', 2], ['c', 3]] (iteration order is not guaranteed)
    	     */var toPairsIn=createToPairs(keysIn);/**
    	     * An alternative to `_.reduce`; this method transforms `object` to a new
    	     * `accumulator` object which is the result of running each of its own
    	     * enumerable string keyed properties thru `iteratee`, with each invocation
    	     * potentially mutating the `accumulator` object. If `accumulator` is not
    	     * provided, a new object with the same `[[Prototype]]` will be used. The
    	     * iteratee is invoked with four arguments: (accumulator, value, key, object).
    	     * Iteratee functions may exit iteration early by explicitly returning `false`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 1.3.0
    	     * @category Object
    	     * @param {Object} object The object to iterate over.
    	     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
    	     * @param {*} [accumulator] The custom accumulator value.
    	     * @returns {*} Returns the accumulated value.
    	     * @example
    	     *
    	     * _.transform([2, 3, 4], function(result, n) {
    	     *   result.push(n *= n);
    	     *   return n % 2 == 0;
    	     * }, []);
    	     * // => [4, 9]
    	     *
    	     * _.transform({ 'a': 1, 'b': 2, 'c': 1 }, function(result, value, key) {
    	     *   (result[value] || (result[value] = [])).push(key);
    	     * }, {});
    	     * // => { '1': ['a', 'c'], '2': ['b'] }
    	     */function transform(object,iteratee,accumulator){var isArr=isArray(object),isArrLike=isArr||isBuffer(object)||isTypedArray(object);iteratee=getIteratee(iteratee,4);if(accumulator==null){var Ctor=object&&object.constructor;if(isArrLike){accumulator=isArr?new Ctor():[];}else if(isObject(object)){accumulator=isFunction(Ctor)?baseCreate(getPrototype(object)):{};}else {accumulator={};}}(isArrLike?arrayEach:baseForOwn)(object,function(value,index,object){return iteratee(accumulator,value,index,object);});return accumulator;}/**
    	     * Removes the property at `path` of `object`.
    	     *
    	     * **Note:** This method mutates `object`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Object
    	     * @param {Object} object The object to modify.
    	     * @param {Array|string} path The path of the property to unset.
    	     * @returns {boolean} Returns `true` if the property is deleted, else `false`.
    	     * @example
    	     *
    	     * var object = { 'a': [{ 'b': { 'c': 7 } }] };
    	     * _.unset(object, 'a[0].b.c');
    	     * // => true
    	     *
    	     * console.log(object);
    	     * // => { 'a': [{ 'b': {} }] };
    	     *
    	     * _.unset(object, ['a', '0', 'b', 'c']);
    	     * // => true
    	     *
    	     * console.log(object);
    	     * // => { 'a': [{ 'b': {} }] };
    	     */function unset(object,path){return object==null?true:baseUnset(object,path);}/**
    	     * This method is like `_.set` except that accepts `updater` to produce the
    	     * value to set. Use `_.updateWith` to customize `path` creation. The `updater`
    	     * is invoked with one argument: (value).
    	     *
    	     * **Note:** This method mutates `object`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.6.0
    	     * @category Object
    	     * @param {Object} object The object to modify.
    	     * @param {Array|string} path The path of the property to set.
    	     * @param {Function} updater The function to produce the updated value.
    	     * @returns {Object} Returns `object`.
    	     * @example
    	     *
    	     * var object = { 'a': [{ 'b': { 'c': 3 } }] };
    	     *
    	     * _.update(object, 'a[0].b.c', function(n) { return n * n; });
    	     * console.log(object.a[0].b.c);
    	     * // => 9
    	     *
    	     * _.update(object, 'x[0].y.z', function(n) { return n ? n + 1 : 0; });
    	     * console.log(object.x[0].y.z);
    	     * // => 0
    	     */function update(object,path,updater){return object==null?object:baseUpdate(object,path,castFunction(updater));}/**
    	     * This method is like `_.update` except that it accepts `customizer` which is
    	     * invoked to produce the objects of `path`.  If `customizer` returns `undefined`
    	     * path creation is handled by the method instead. The `customizer` is invoked
    	     * with three arguments: (nsValue, key, nsObject).
    	     *
    	     * **Note:** This method mutates `object`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.6.0
    	     * @category Object
    	     * @param {Object} object The object to modify.
    	     * @param {Array|string} path The path of the property to set.
    	     * @param {Function} updater The function to produce the updated value.
    	     * @param {Function} [customizer] The function to customize assigned values.
    	     * @returns {Object} Returns `object`.
    	     * @example
    	     *
    	     * var object = {};
    	     *
    	     * _.updateWith(object, '[0][1]', _.constant('a'), Object);
    	     * // => { '0': { '1': 'a' } }
    	     */function updateWith(object,path,updater,customizer){customizer=typeof customizer=='function'?customizer:undefined$1;return object==null?object:baseUpdate(object,path,castFunction(updater),customizer);}/**
    	     * Creates an array of the own enumerable string keyed property values of `object`.
    	     *
    	     * **Note:** Non-object values are coerced to objects.
    	     *
    	     * @static
    	     * @since 0.1.0
    	     * @memberOf _
    	     * @category Object
    	     * @param {Object} object The object to query.
    	     * @returns {Array} Returns the array of property values.
    	     * @example
    	     *
    	     * function Foo() {
    	     *   this.a = 1;
    	     *   this.b = 2;
    	     * }
    	     *
    	     * Foo.prototype.c = 3;
    	     *
    	     * _.values(new Foo);
    	     * // => [1, 2] (iteration order is not guaranteed)
    	     *
    	     * _.values('hi');
    	     * // => ['h', 'i']
    	     */function values(object){return object==null?[]:baseValues(object,keys(object));}/**
    	     * Creates an array of the own and inherited enumerable string keyed property
    	     * values of `object`.
    	     *
    	     * **Note:** Non-object values are coerced to objects.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Object
    	     * @param {Object} object The object to query.
    	     * @returns {Array} Returns the array of property values.
    	     * @example
    	     *
    	     * function Foo() {
    	     *   this.a = 1;
    	     *   this.b = 2;
    	     * }
    	     *
    	     * Foo.prototype.c = 3;
    	     *
    	     * _.valuesIn(new Foo);
    	     * // => [1, 2, 3] (iteration order is not guaranteed)
    	     */function valuesIn(object){return object==null?[]:baseValues(object,keysIn(object));}/*------------------------------------------------------------------------*/ /**
    	     * Clamps `number` within the inclusive `lower` and `upper` bounds.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Number
    	     * @param {number} number The number to clamp.
    	     * @param {number} [lower] The lower bound.
    	     * @param {number} upper The upper bound.
    	     * @returns {number} Returns the clamped number.
    	     * @example
    	     *
    	     * _.clamp(-10, -5, 5);
    	     * // => -5
    	     *
    	     * _.clamp(10, -5, 5);
    	     * // => 5
    	     */function clamp(number,lower,upper){if(upper===undefined$1){upper=lower;lower=undefined$1;}if(upper!==undefined$1){upper=toNumber(upper);upper=upper===upper?upper:0;}if(lower!==undefined$1){lower=toNumber(lower);lower=lower===lower?lower:0;}return baseClamp(toNumber(number),lower,upper);}/**
    	     * Checks if `n` is between `start` and up to, but not including, `end`. If
    	     * `end` is not specified, it's set to `start` with `start` then set to `0`.
    	     * If `start` is greater than `end` the params are swapped to support
    	     * negative ranges.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.3.0
    	     * @category Number
    	     * @param {number} number The number to check.
    	     * @param {number} [start=0] The start of the range.
    	     * @param {number} end The end of the range.
    	     * @returns {boolean} Returns `true` if `number` is in the range, else `false`.
    	     * @see _.range, _.rangeRight
    	     * @example
    	     *
    	     * _.inRange(3, 2, 4);
    	     * // => true
    	     *
    	     * _.inRange(4, 8);
    	     * // => true
    	     *
    	     * _.inRange(4, 2);
    	     * // => false
    	     *
    	     * _.inRange(2, 2);
    	     * // => false
    	     *
    	     * _.inRange(1.2, 2);
    	     * // => true
    	     *
    	     * _.inRange(5.2, 4);
    	     * // => false
    	     *
    	     * _.inRange(-3, -2, -6);
    	     * // => true
    	     */function inRange(number,start,end){start=toFinite(start);if(end===undefined$1){end=start;start=0;}else {end=toFinite(end);}number=toNumber(number);return baseInRange(number,start,end);}/**
    	     * Produces a random number between the inclusive `lower` and `upper` bounds.
    	     * If only one argument is provided a number between `0` and the given number
    	     * is returned. If `floating` is `true`, or either `lower` or `upper` are
    	     * floats, a floating-point number is returned instead of an integer.
    	     *
    	     * **Note:** JavaScript follows the IEEE-754 standard for resolving
    	     * floating-point values which can produce unexpected results.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.7.0
    	     * @category Number
    	     * @param {number} [lower=0] The lower bound.
    	     * @param {number} [upper=1] The upper bound.
    	     * @param {boolean} [floating] Specify returning a floating-point number.
    	     * @returns {number} Returns the random number.
    	     * @example
    	     *
    	     * _.random(0, 5);
    	     * // => an integer between 0 and 5
    	     *
    	     * _.random(5);
    	     * // => also an integer between 0 and 5
    	     *
    	     * _.random(5, true);
    	     * // => a floating-point number between 0 and 5
    	     *
    	     * _.random(1.2, 5.2);
    	     * // => a floating-point number between 1.2 and 5.2
    	     */function random(lower,upper,floating){if(floating&&typeof floating!='boolean'&&isIterateeCall(lower,upper,floating)){upper=floating=undefined$1;}if(floating===undefined$1){if(typeof upper=='boolean'){floating=upper;upper=undefined$1;}else if(typeof lower=='boolean'){floating=lower;lower=undefined$1;}}if(lower===undefined$1&&upper===undefined$1){lower=0;upper=1;}else {lower=toFinite(lower);if(upper===undefined$1){upper=lower;lower=0;}else {upper=toFinite(upper);}}if(lower>upper){var temp=lower;lower=upper;upper=temp;}if(floating||lower%1||upper%1){var rand=nativeRandom();return nativeMin(lower+rand*(upper-lower+freeParseFloat('1e-'+((rand+'').length-1))),upper);}return baseRandom(lower,upper);}/*------------------------------------------------------------------------*/ /**
    	     * Converts `string` to [camel case](https://en.wikipedia.org/wiki/CamelCase).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to convert.
    	     * @returns {string} Returns the camel cased string.
    	     * @example
    	     *
    	     * _.camelCase('Foo Bar');
    	     * // => 'fooBar'
    	     *
    	     * _.camelCase('--foo-bar--');
    	     * // => 'fooBar'
    	     *
    	     * _.camelCase('__FOO_BAR__');
    	     * // => 'fooBar'
    	     */var camelCase=createCompounder(function(result,word,index){word=word.toLowerCase();return result+(index?capitalize(word):word);});/**
    	     * Converts the first character of `string` to upper case and the remaining
    	     * to lower case.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to capitalize.
    	     * @returns {string} Returns the capitalized string.
    	     * @example
    	     *
    	     * _.capitalize('FRED');
    	     * // => 'Fred'
    	     */function capitalize(string){return upperFirst(toString(string).toLowerCase());}/**
    	     * Deburrs `string` by converting
    	     * [Latin-1 Supplement](https://en.wikipedia.org/wiki/Latin-1_Supplement_(Unicode_block)#Character_table)
    	     * and [Latin Extended-A](https://en.wikipedia.org/wiki/Latin_Extended-A)
    	     * letters to basic Latin letters and removing
    	     * [combining diacritical marks](https://en.wikipedia.org/wiki/Combining_Diacritical_Marks).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to deburr.
    	     * @returns {string} Returns the deburred string.
    	     * @example
    	     *
    	     * _.deburr('déjà vu');
    	     * // => 'deja vu'
    	     */function deburr(string){string=toString(string);return string&&string.replace(reLatin,deburrLetter).replace(reComboMark,'');}/**
    	     * Checks if `string` ends with the given target string.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to inspect.
    	     * @param {string} [target] The string to search for.
    	     * @param {number} [position=string.length] The position to search up to.
    	     * @returns {boolean} Returns `true` if `string` ends with `target`,
    	     *  else `false`.
    	     * @example
    	     *
    	     * _.endsWith('abc', 'c');
    	     * // => true
    	     *
    	     * _.endsWith('abc', 'b');
    	     * // => false
    	     *
    	     * _.endsWith('abc', 'b', 2);
    	     * // => true
    	     */function endsWith(string,target,position){string=toString(string);target=baseToString(target);var length=string.length;position=position===undefined$1?length:baseClamp(toInteger(position),0,length);var end=position;position-=target.length;return position>=0&&string.slice(position,end)==target;}/**
    	     * Converts the characters "&", "<", ">", '"', and "'" in `string` to their
    	     * corresponding HTML entities.
    	     *
    	     * **Note:** No other characters are escaped. To escape additional
    	     * characters use a third-party library like [_he_](https://mths.be/he).
    	     *
    	     * Though the ">" character is escaped for symmetry, characters like
    	     * ">" and "/" don't need escaping in HTML and have no special meaning
    	     * unless they're part of a tag or unquoted attribute value. See
    	     * [Mathias Bynens's article](https://mathiasbynens.be/notes/ambiguous-ampersands)
    	     * (under "semi-related fun fact") for more details.
    	     *
    	     * When working with HTML you should always
    	     * [quote attribute values](http://wonko.com/post/html-escaping) to reduce
    	     * XSS vectors.
    	     *
    	     * @static
    	     * @since 0.1.0
    	     * @memberOf _
    	     * @category String
    	     * @param {string} [string=''] The string to escape.
    	     * @returns {string} Returns the escaped string.
    	     * @example
    	     *
    	     * _.escape('fred, barney, & pebbles');
    	     * // => 'fred, barney, &amp; pebbles'
    	     */function escape(string){string=toString(string);return string&&reHasUnescapedHtml.test(string)?string.replace(reUnescapedHtml,escapeHtmlChar):string;}/**
    	     * Escapes the `RegExp` special characters "^", "$", "\", ".", "*", "+",
    	     * "?", "(", ")", "[", "]", "{", "}", and "|" in `string`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to escape.
    	     * @returns {string} Returns the escaped string.
    	     * @example
    	     *
    	     * _.escapeRegExp('[lodash](https://lodash.com/)');
    	     * // => '\[lodash\]\(https://lodash\.com/\)'
    	     */function escapeRegExp(string){string=toString(string);return string&&reHasRegExpChar.test(string)?string.replace(reRegExpChar,'\\$&'):string;}/**
    	     * Converts `string` to
    	     * [kebab case](https://en.wikipedia.org/wiki/Letter_case#Special_case_styles).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to convert.
    	     * @returns {string} Returns the kebab cased string.
    	     * @example
    	     *
    	     * _.kebabCase('Foo Bar');
    	     * // => 'foo-bar'
    	     *
    	     * _.kebabCase('fooBar');
    	     * // => 'foo-bar'
    	     *
    	     * _.kebabCase('__FOO_BAR__');
    	     * // => 'foo-bar'
    	     */var kebabCase=createCompounder(function(result,word,index){return result+(index?'-':'')+word.toLowerCase();});/**
    	     * Converts `string`, as space separated words, to lower case.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to convert.
    	     * @returns {string} Returns the lower cased string.
    	     * @example
    	     *
    	     * _.lowerCase('--Foo-Bar--');
    	     * // => 'foo bar'
    	     *
    	     * _.lowerCase('fooBar');
    	     * // => 'foo bar'
    	     *
    	     * _.lowerCase('__FOO_BAR__');
    	     * // => 'foo bar'
    	     */var lowerCase=createCompounder(function(result,word,index){return result+(index?' ':'')+word.toLowerCase();});/**
    	     * Converts the first character of `string` to lower case.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to convert.
    	     * @returns {string} Returns the converted string.
    	     * @example
    	     *
    	     * _.lowerFirst('Fred');
    	     * // => 'fred'
    	     *
    	     * _.lowerFirst('FRED');
    	     * // => 'fRED'
    	     */var lowerFirst=createCaseFirst('toLowerCase');/**
    	     * Pads `string` on the left and right sides if it's shorter than `length`.
    	     * Padding characters are truncated if they can't be evenly divided by `length`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to pad.
    	     * @param {number} [length=0] The padding length.
    	     * @param {string} [chars=' '] The string used as padding.
    	     * @returns {string} Returns the padded string.
    	     * @example
    	     *
    	     * _.pad('abc', 8);
    	     * // => '  abc   '
    	     *
    	     * _.pad('abc', 8, '_-');
    	     * // => '_-abc_-_'
    	     *
    	     * _.pad('abc', 3);
    	     * // => 'abc'
    	     */function pad(string,length,chars){string=toString(string);length=toInteger(length);var strLength=length?stringSize(string):0;if(!length||strLength>=length){return string;}var mid=(length-strLength)/2;return createPadding(nativeFloor(mid),chars)+string+createPadding(nativeCeil(mid),chars);}/**
    	     * Pads `string` on the right side if it's shorter than `length`. Padding
    	     * characters are truncated if they exceed `length`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to pad.
    	     * @param {number} [length=0] The padding length.
    	     * @param {string} [chars=' '] The string used as padding.
    	     * @returns {string} Returns the padded string.
    	     * @example
    	     *
    	     * _.padEnd('abc', 6);
    	     * // => 'abc   '
    	     *
    	     * _.padEnd('abc', 6, '_-');
    	     * // => 'abc_-_'
    	     *
    	     * _.padEnd('abc', 3);
    	     * // => 'abc'
    	     */function padEnd(string,length,chars){string=toString(string);length=toInteger(length);var strLength=length?stringSize(string):0;return length&&strLength<length?string+createPadding(length-strLength,chars):string;}/**
    	     * Pads `string` on the left side if it's shorter than `length`. Padding
    	     * characters are truncated if they exceed `length`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to pad.
    	     * @param {number} [length=0] The padding length.
    	     * @param {string} [chars=' '] The string used as padding.
    	     * @returns {string} Returns the padded string.
    	     * @example
    	     *
    	     * _.padStart('abc', 6);
    	     * // => '   abc'
    	     *
    	     * _.padStart('abc', 6, '_-');
    	     * // => '_-_abc'
    	     *
    	     * _.padStart('abc', 3);
    	     * // => 'abc'
    	     */function padStart(string,length,chars){string=toString(string);length=toInteger(length);var strLength=length?stringSize(string):0;return length&&strLength<length?createPadding(length-strLength,chars)+string:string;}/**
    	     * Converts `string` to an integer of the specified radix. If `radix` is
    	     * `undefined` or `0`, a `radix` of `10` is used unless `value` is a
    	     * hexadecimal, in which case a `radix` of `16` is used.
    	     *
    	     * **Note:** This method aligns with the
    	     * [ES5 implementation](https://es5.github.io/#x15.1.2.2) of `parseInt`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 1.1.0
    	     * @category String
    	     * @param {string} string The string to convert.
    	     * @param {number} [radix=10] The radix to interpret `value` by.
    	     * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
    	     * @returns {number} Returns the converted integer.
    	     * @example
    	     *
    	     * _.parseInt('08');
    	     * // => 8
    	     *
    	     * _.map(['6', '08', '10'], _.parseInt);
    	     * // => [6, 8, 10]
    	     */function parseInt(string,radix,guard){if(guard||radix==null){radix=0;}else if(radix){radix=+radix;}return nativeParseInt(toString(string).replace(reTrimStart,''),radix||0);}/**
    	     * Repeats the given string `n` times.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to repeat.
    	     * @param {number} [n=1] The number of times to repeat the string.
    	     * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
    	     * @returns {string} Returns the repeated string.
    	     * @example
    	     *
    	     * _.repeat('*', 3);
    	     * // => '***'
    	     *
    	     * _.repeat('abc', 2);
    	     * // => 'abcabc'
    	     *
    	     * _.repeat('abc', 0);
    	     * // => ''
    	     */function repeat(string,n,guard){if(guard?isIterateeCall(string,n,guard):n===undefined$1){n=1;}else {n=toInteger(n);}return baseRepeat(toString(string),n);}/**
    	     * Replaces matches for `pattern` in `string` with `replacement`.
    	     *
    	     * **Note:** This method is based on
    	     * [`String#replace`](https://mdn.io/String/replace).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to modify.
    	     * @param {RegExp|string} pattern The pattern to replace.
    	     * @param {Function|string} replacement The match replacement.
    	     * @returns {string} Returns the modified string.
    	     * @example
    	     *
    	     * _.replace('Hi Fred', 'Fred', 'Barney');
    	     * // => 'Hi Barney'
    	     */function replace(){var args=arguments,string=toString(args[0]);return args.length<3?string:string.replace(args[1],args[2]);}/**
    	     * Converts `string` to
    	     * [snake case](https://en.wikipedia.org/wiki/Snake_case).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to convert.
    	     * @returns {string} Returns the snake cased string.
    	     * @example
    	     *
    	     * _.snakeCase('Foo Bar');
    	     * // => 'foo_bar'
    	     *
    	     * _.snakeCase('fooBar');
    	     * // => 'foo_bar'
    	     *
    	     * _.snakeCase('--FOO-BAR--');
    	     * // => 'foo_bar'
    	     */var snakeCase=createCompounder(function(result,word,index){return result+(index?'_':'')+word.toLowerCase();});/**
    	     * Splits `string` by `separator`.
    	     *
    	     * **Note:** This method is based on
    	     * [`String#split`](https://mdn.io/String/split).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to split.
    	     * @param {RegExp|string} separator The separator pattern to split by.
    	     * @param {number} [limit] The length to truncate results to.
    	     * @returns {Array} Returns the string segments.
    	     * @example
    	     *
    	     * _.split('a-b-c', '-', 2);
    	     * // => ['a', 'b']
    	     */function split(string,separator,limit){if(limit&&typeof limit!='number'&&isIterateeCall(string,separator,limit)){separator=limit=undefined$1;}limit=limit===undefined$1?MAX_ARRAY_LENGTH:limit>>>0;if(!limit){return [];}string=toString(string);if(string&&(typeof separator=='string'||separator!=null&&!isRegExp(separator))){separator=baseToString(separator);if(!separator&&hasUnicode(string)){return castSlice(stringToArray(string),0,limit);}}return string.split(separator,limit);}/**
    	     * Converts `string` to
    	     * [start case](https://en.wikipedia.org/wiki/Letter_case#Stylistic_or_specialised_usage).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.1.0
    	     * @category String
    	     * @param {string} [string=''] The string to convert.
    	     * @returns {string} Returns the start cased string.
    	     * @example
    	     *
    	     * _.startCase('--foo-bar--');
    	     * // => 'Foo Bar'
    	     *
    	     * _.startCase('fooBar');
    	     * // => 'Foo Bar'
    	     *
    	     * _.startCase('__FOO_BAR__');
    	     * // => 'FOO BAR'
    	     */var startCase=createCompounder(function(result,word,index){return result+(index?' ':'')+upperFirst(word);});/**
    	     * Checks if `string` starts with the given target string.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to inspect.
    	     * @param {string} [target] The string to search for.
    	     * @param {number} [position=0] The position to search from.
    	     * @returns {boolean} Returns `true` if `string` starts with `target`,
    	     *  else `false`.
    	     * @example
    	     *
    	     * _.startsWith('abc', 'a');
    	     * // => true
    	     *
    	     * _.startsWith('abc', 'b');
    	     * // => false
    	     *
    	     * _.startsWith('abc', 'b', 1);
    	     * // => true
    	     */function startsWith(string,target,position){string=toString(string);position=position==null?0:baseClamp(toInteger(position),0,string.length);target=baseToString(target);return string.slice(position,position+target.length)==target;}/**
    	     * Creates a compiled template function that can interpolate data properties
    	     * in "interpolate" delimiters, HTML-escape interpolated data properties in
    	     * "escape" delimiters, and execute JavaScript in "evaluate" delimiters. Data
    	     * properties may be accessed as free variables in the template. If a setting
    	     * object is given, it takes precedence over `_.templateSettings` values.
    	     *
    	     * **Note:** In the development build `_.template` utilizes
    	     * [sourceURLs](http://www.html5rocks.com/en/tutorials/developertools/sourcemaps/#toc-sourceurl)
    	     * for easier debugging.
    	     *
    	     * For more information on precompiling templates see
    	     * [lodash's custom builds documentation](https://lodash.com/custom-builds).
    	     *
    	     * For more information on Chrome extension sandboxes see
    	     * [Chrome's extensions documentation](https://developer.chrome.com/extensions/sandboxingEval).
    	     *
    	     * @static
    	     * @since 0.1.0
    	     * @memberOf _
    	     * @category String
    	     * @param {string} [string=''] The template string.
    	     * @param {Object} [options={}] The options object.
    	     * @param {RegExp} [options.escape=_.templateSettings.escape]
    	     *  The HTML "escape" delimiter.
    	     * @param {RegExp} [options.evaluate=_.templateSettings.evaluate]
    	     *  The "evaluate" delimiter.
    	     * @param {Object} [options.imports=_.templateSettings.imports]
    	     *  An object to import into the template as free variables.
    	     * @param {RegExp} [options.interpolate=_.templateSettings.interpolate]
    	     *  The "interpolate" delimiter.
    	     * @param {string} [options.sourceURL='lodash.templateSources[n]']
    	     *  The sourceURL of the compiled template.
    	     * @param {string} [options.variable='obj']
    	     *  The data object variable name.
    	     * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
    	     * @returns {Function} Returns the compiled template function.
    	     * @example
    	     *
    	     * // Use the "interpolate" delimiter to create a compiled template.
    	     * var compiled = _.template('hello <%= user %>!');
    	     * compiled({ 'user': 'fred' });
    	     * // => 'hello fred!'
    	     *
    	     * // Use the HTML "escape" delimiter to escape data property values.
    	     * var compiled = _.template('<b><%- value %></b>');
    	     * compiled({ 'value': '<script>' });
    	     * // => '<b>&lt;script&gt;</b>'
    	     *
    	     * // Use the "evaluate" delimiter to execute JavaScript and generate HTML.
    	     * var compiled = _.template('<% _.forEach(users, function(user) { %><li><%- user %></li><% }); %>');
    	     * compiled({ 'users': ['fred', 'barney'] });
    	     * // => '<li>fred</li><li>barney</li>'
    	     *
    	     * // Use the internal `print` function in "evaluate" delimiters.
    	     * var compiled = _.template('<% print("hello " + user); %>!');
    	     * compiled({ 'user': 'barney' });
    	     * // => 'hello barney!'
    	     *
    	     * // Use the ES template literal delimiter as an "interpolate" delimiter.
    	     * // Disable support by replacing the "interpolate" delimiter.
    	     * var compiled = _.template('hello ${ user }!');
    	     * compiled({ 'user': 'pebbles' });
    	     * // => 'hello pebbles!'
    	     *
    	     * // Use backslashes to treat delimiters as plain text.
    	     * var compiled = _.template('<%= "\\<%- value %\\>" %>');
    	     * compiled({ 'value': 'ignored' });
    	     * // => '<%- value %>'
    	     *
    	     * // Use the `imports` option to import `jQuery` as `jq`.
    	     * var text = '<% jq.each(users, function(user) { %><li><%- user %></li><% }); %>';
    	     * var compiled = _.template(text, { 'imports': { 'jq': jQuery } });
    	     * compiled({ 'users': ['fred', 'barney'] });
    	     * // => '<li>fred</li><li>barney</li>'
    	     *
    	     * // Use the `sourceURL` option to specify a custom sourceURL for the template.
    	     * var compiled = _.template('hello <%= user %>!', { 'sourceURL': '/basic/greeting.jst' });
    	     * compiled(data);
    	     * // => Find the source of "greeting.jst" under the Sources tab or Resources panel of the web inspector.
    	     *
    	     * // Use the `variable` option to ensure a with-statement isn't used in the compiled template.
    	     * var compiled = _.template('hi <%= data.user %>!', { 'variable': 'data' });
    	     * compiled.source;
    	     * // => function(data) {
    	     * //   var __t, __p = '';
    	     * //   __p += 'hi ' + ((__t = ( data.user )) == null ? '' : __t) + '!';
    	     * //   return __p;
    	     * // }
    	     *
    	     * // Use custom template delimiters.
    	     * _.templateSettings.interpolate = /{{([\s\S]+?)}}/g;
    	     * var compiled = _.template('hello {{ user }}!');
    	     * compiled({ 'user': 'mustache' });
    	     * // => 'hello mustache!'
    	     *
    	     * // Use the `source` property to inline compiled templates for meaningful
    	     * // line numbers in error messages and stack traces.
    	     * fs.writeFileSync(path.join(process.cwd(), 'jst.js'), '\
    	     *   var JST = {\
    	     *     "main": ' + _.template(mainText).source + '\
    	     *   };\
    	     * ');
    	     */function template(string,options,guard){// Based on John Resig's `tmpl` implementation
    	// (http://ejohn.org/blog/javascript-micro-templating/)
    	// and Laura Doktorova's doT.js (https://github.com/olado/doT).
    	var settings=lodash.templateSettings;if(guard&&isIterateeCall(string,options,guard)){options=undefined$1;}string=toString(string);options=assignInWith({},options,settings,customDefaultsAssignIn);var imports=assignInWith({},options.imports,settings.imports,customDefaultsAssignIn),importsKeys=keys(imports),importsValues=baseValues(imports,importsKeys);var isEscaping,isEvaluating,index=0,interpolate=options.interpolate||reNoMatch,source="__p += '";// Compile the regexp to match each delimiter.
    	var reDelimiters=RegExp((options.escape||reNoMatch).source+'|'+interpolate.source+'|'+(interpolate===reInterpolate?reEsTemplate:reNoMatch).source+'|'+(options.evaluate||reNoMatch).source+'|$','g');// Use a sourceURL for easier debugging.
    	// The sourceURL gets injected into the source that's eval-ed, so be careful
    	// to normalize all kinds of whitespace, so e.g. newlines (and unicode versions of it) can't sneak in
    	// and escape the comment, thus injecting code that gets evaled.
    	var sourceURL='//# sourceURL='+(hasOwnProperty.call(options,'sourceURL')?(options.sourceURL+'').replace(/\s/g,' '):'lodash.templateSources['+ ++templateCounter+']')+'\n';string.replace(reDelimiters,function(match,escapeValue,interpolateValue,esTemplateValue,evaluateValue,offset){interpolateValue||(interpolateValue=esTemplateValue);// Escape characters that can't be included in string literals.
    	source+=string.slice(index,offset).replace(reUnescapedString,escapeStringChar);// Replace delimiters with snippets.
    	if(escapeValue){isEscaping=true;source+="' +\n__e("+escapeValue+") +\n'";}if(evaluateValue){isEvaluating=true;source+="';\n"+evaluateValue+";\n__p += '";}if(interpolateValue){source+="' +\n((__t = ("+interpolateValue+")) == null ? '' : __t) +\n'";}index=offset+match.length;// The JS engine embedded in Adobe products needs `match` returned in
    	// order to produce the correct `offset` value.
    	return match;});source+="';\n";// If `variable` is not specified wrap a with-statement around the generated
    	// code to add the data object to the top of the scope chain.
    	var variable=hasOwnProperty.call(options,'variable')&&options.variable;if(!variable){source='with (obj) {\n'+source+'\n}\n';}// Throw an error if a forbidden character was found in `variable`, to prevent
    	// potential command injection attacks.
    	else if(reForbiddenIdentifierChars.test(variable)){throw new Error(INVALID_TEMPL_VAR_ERROR_TEXT);}// Cleanup code by stripping empty strings.
    	source=(isEvaluating?source.replace(reEmptyStringLeading,''):source).replace(reEmptyStringMiddle,'$1').replace(reEmptyStringTrailing,'$1;');// Frame code as the function body.
    	source='function('+(variable||'obj')+') {\n'+(variable?'':'obj || (obj = {});\n')+"var __t, __p = ''"+(isEscaping?', __e = _.escape':'')+(isEvaluating?', __j = Array.prototype.join;\n'+"function print() { __p += __j.call(arguments, '') }\n":';\n')+source+'return __p\n}';var result=attempt(function(){return Function(importsKeys,sourceURL+'return '+source).apply(undefined$1,importsValues);});// Provide the compiled function's source by its `toString` method or
    	// the `source` property as a convenience for inlining compiled templates.
    	result.source=source;if(isError(result)){throw result;}return result;}/**
    	     * Converts `string`, as a whole, to lower case just like
    	     * [String#toLowerCase](https://mdn.io/toLowerCase).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to convert.
    	     * @returns {string} Returns the lower cased string.
    	     * @example
    	     *
    	     * _.toLower('--Foo-Bar--');
    	     * // => '--foo-bar--'
    	     *
    	     * _.toLower('fooBar');
    	     * // => 'foobar'
    	     *
    	     * _.toLower('__FOO_BAR__');
    	     * // => '__foo_bar__'
    	     */function toLower(value){return toString(value).toLowerCase();}/**
    	     * Converts `string`, as a whole, to upper case just like
    	     * [String#toUpperCase](https://mdn.io/toUpperCase).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to convert.
    	     * @returns {string} Returns the upper cased string.
    	     * @example
    	     *
    	     * _.toUpper('--foo-bar--');
    	     * // => '--FOO-BAR--'
    	     *
    	     * _.toUpper('fooBar');
    	     * // => 'FOOBAR'
    	     *
    	     * _.toUpper('__foo_bar__');
    	     * // => '__FOO_BAR__'
    	     */function toUpper(value){return toString(value).toUpperCase();}/**
    	     * Removes leading and trailing whitespace or specified characters from `string`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to trim.
    	     * @param {string} [chars=whitespace] The characters to trim.
    	     * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
    	     * @returns {string} Returns the trimmed string.
    	     * @example
    	     *
    	     * _.trim('  abc  ');
    	     * // => 'abc'
    	     *
    	     * _.trim('-_-abc-_-', '_-');
    	     * // => 'abc'
    	     *
    	     * _.map(['  foo  ', '  bar  '], _.trim);
    	     * // => ['foo', 'bar']
    	     */function trim(string,chars,guard){string=toString(string);if(string&&(guard||chars===undefined$1)){return baseTrim(string);}if(!string||!(chars=baseToString(chars))){return string;}var strSymbols=stringToArray(string),chrSymbols=stringToArray(chars),start=charsStartIndex(strSymbols,chrSymbols),end=charsEndIndex(strSymbols,chrSymbols)+1;return castSlice(strSymbols,start,end).join('');}/**
    	     * Removes trailing whitespace or specified characters from `string`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to trim.
    	     * @param {string} [chars=whitespace] The characters to trim.
    	     * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
    	     * @returns {string} Returns the trimmed string.
    	     * @example
    	     *
    	     * _.trimEnd('  abc  ');
    	     * // => '  abc'
    	     *
    	     * _.trimEnd('-_-abc-_-', '_-');
    	     * // => '-_-abc'
    	     */function trimEnd(string,chars,guard){string=toString(string);if(string&&(guard||chars===undefined$1)){return string.slice(0,trimmedEndIndex(string)+1);}if(!string||!(chars=baseToString(chars))){return string;}var strSymbols=stringToArray(string),end=charsEndIndex(strSymbols,stringToArray(chars))+1;return castSlice(strSymbols,0,end).join('');}/**
    	     * Removes leading whitespace or specified characters from `string`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to trim.
    	     * @param {string} [chars=whitespace] The characters to trim.
    	     * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
    	     * @returns {string} Returns the trimmed string.
    	     * @example
    	     *
    	     * _.trimStart('  abc  ');
    	     * // => 'abc  '
    	     *
    	     * _.trimStart('-_-abc-_-', '_-');
    	     * // => 'abc-_-'
    	     */function trimStart(string,chars,guard){string=toString(string);if(string&&(guard||chars===undefined$1)){return string.replace(reTrimStart,'');}if(!string||!(chars=baseToString(chars))){return string;}var strSymbols=stringToArray(string),start=charsStartIndex(strSymbols,stringToArray(chars));return castSlice(strSymbols,start).join('');}/**
    	     * Truncates `string` if it's longer than the given maximum string length.
    	     * The last characters of the truncated string are replaced with the omission
    	     * string which defaults to "...".
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to truncate.
    	     * @param {Object} [options={}] The options object.
    	     * @param {number} [options.length=30] The maximum string length.
    	     * @param {string} [options.omission='...'] The string to indicate text is omitted.
    	     * @param {RegExp|string} [options.separator] The separator pattern to truncate to.
    	     * @returns {string} Returns the truncated string.
    	     * @example
    	     *
    	     * _.truncate('hi-diddly-ho there, neighborino');
    	     * // => 'hi-diddly-ho there, neighbo...'
    	     *
    	     * _.truncate('hi-diddly-ho there, neighborino', {
    	     *   'length': 24,
    	     *   'separator': ' '
    	     * });
    	     * // => 'hi-diddly-ho there,...'
    	     *
    	     * _.truncate('hi-diddly-ho there, neighborino', {
    	     *   'length': 24,
    	     *   'separator': /,? +/
    	     * });
    	     * // => 'hi-diddly-ho there...'
    	     *
    	     * _.truncate('hi-diddly-ho there, neighborino', {
    	     *   'omission': ' [...]'
    	     * });
    	     * // => 'hi-diddly-ho there, neig [...]'
    	     */function truncate(string,options){var length=DEFAULT_TRUNC_LENGTH,omission=DEFAULT_TRUNC_OMISSION;if(isObject(options)){var separator='separator'in options?options.separator:separator;length='length'in options?toInteger(options.length):length;omission='omission'in options?baseToString(options.omission):omission;}string=toString(string);var strLength=string.length;if(hasUnicode(string)){var strSymbols=stringToArray(string);strLength=strSymbols.length;}if(length>=strLength){return string;}var end=length-stringSize(omission);if(end<1){return omission;}var result=strSymbols?castSlice(strSymbols,0,end).join(''):string.slice(0,end);if(separator===undefined$1){return result+omission;}if(strSymbols){end+=result.length-end;}if(isRegExp(separator)){if(string.slice(end).search(separator)){var match,substring=result;if(!separator.global){separator=RegExp(separator.source,toString(reFlags.exec(separator))+'g');}separator.lastIndex=0;while(match=separator.exec(substring)){var newEnd=match.index;}result=result.slice(0,newEnd===undefined$1?end:newEnd);}}else if(string.indexOf(baseToString(separator),end)!=end){var index=result.lastIndexOf(separator);if(index>-1){result=result.slice(0,index);}}return result+omission;}/**
    	     * The inverse of `_.escape`; this method converts the HTML entities
    	     * `&amp;`, `&lt;`, `&gt;`, `&quot;`, and `&#39;` in `string` to
    	     * their corresponding characters.
    	     *
    	     * **Note:** No other HTML entities are unescaped. To unescape additional
    	     * HTML entities use a third-party library like [_he_](https://mths.be/he).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 0.6.0
    	     * @category String
    	     * @param {string} [string=''] The string to unescape.
    	     * @returns {string} Returns the unescaped string.
    	     * @example
    	     *
    	     * _.unescape('fred, barney, &amp; pebbles');
    	     * // => 'fred, barney, & pebbles'
    	     */function unescape(string){string=toString(string);return string&&reHasEscapedHtml.test(string)?string.replace(reEscapedHtml,unescapeHtmlChar):string;}/**
    	     * Converts `string`, as space separated words, to upper case.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to convert.
    	     * @returns {string} Returns the upper cased string.
    	     * @example
    	     *
    	     * _.upperCase('--foo-bar');
    	     * // => 'FOO BAR'
    	     *
    	     * _.upperCase('fooBar');
    	     * // => 'FOO BAR'
    	     *
    	     * _.upperCase('__foo_bar__');
    	     * // => 'FOO BAR'
    	     */var upperCase=createCompounder(function(result,word,index){return result+(index?' ':'')+word.toUpperCase();});/**
    	     * Converts the first character of `string` to upper case.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to convert.
    	     * @returns {string} Returns the converted string.
    	     * @example
    	     *
    	     * _.upperFirst('fred');
    	     * // => 'Fred'
    	     *
    	     * _.upperFirst('FRED');
    	     * // => 'FRED'
    	     */var upperFirst=createCaseFirst('toUpperCase');/**
    	     * Splits `string` into an array of its words.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category String
    	     * @param {string} [string=''] The string to inspect.
    	     * @param {RegExp|string} [pattern] The pattern to match words.
    	     * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
    	     * @returns {Array} Returns the words of `string`.
    	     * @example
    	     *
    	     * _.words('fred, barney, & pebbles');
    	     * // => ['fred', 'barney', 'pebbles']
    	     *
    	     * _.words('fred, barney, & pebbles', /[^, ]+/g);
    	     * // => ['fred', 'barney', '&', 'pebbles']
    	     */function words(string,pattern,guard){string=toString(string);pattern=guard?undefined$1:pattern;if(pattern===undefined$1){return hasUnicodeWord(string)?unicodeWords(string):asciiWords(string);}return string.match(pattern)||[];}/*------------------------------------------------------------------------*/ /**
    	     * Attempts to invoke `func`, returning either the result or the caught error
    	     * object. Any additional arguments are provided to `func` when it's invoked.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Util
    	     * @param {Function} func The function to attempt.
    	     * @param {...*} [args] The arguments to invoke `func` with.
    	     * @returns {*} Returns the `func` result or error object.
    	     * @example
    	     *
    	     * // Avoid throwing errors for invalid selectors.
    	     * var elements = _.attempt(function(selector) {
    	     *   return document.querySelectorAll(selector);
    	     * }, '>_>');
    	     *
    	     * if (_.isError(elements)) {
    	     *   elements = [];
    	     * }
    	     */var attempt=baseRest(function(func,args){try{return apply(func,undefined$1,args);}catch(e){return isError(e)?e:new Error(e);}});/**
    	     * Binds methods of an object to the object itself, overwriting the existing
    	     * method.
    	     *
    	     * **Note:** This method doesn't set the "length" property of bound functions.
    	     *
    	     * @static
    	     * @since 0.1.0
    	     * @memberOf _
    	     * @category Util
    	     * @param {Object} object The object to bind and assign the bound methods to.
    	     * @param {...(string|string[])} methodNames The object method names to bind.
    	     * @returns {Object} Returns `object`.
    	     * @example
    	     *
    	     * var view = {
    	     *   'label': 'docs',
    	     *   'click': function() {
    	     *     console.log('clicked ' + this.label);
    	     *   }
    	     * };
    	     *
    	     * _.bindAll(view, ['click']);
    	     * jQuery(element).on('click', view.click);
    	     * // => Logs 'clicked docs' when clicked.
    	     */var bindAll=flatRest(function(object,methodNames){arrayEach(methodNames,function(key){key=toKey(key);baseAssignValue(object,key,bind(object[key],object));});return object;});/**
    	     * Creates a function that iterates over `pairs` and invokes the corresponding
    	     * function of the first predicate to return truthy. The predicate-function
    	     * pairs are invoked with the `this` binding and arguments of the created
    	     * function.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Util
    	     * @param {Array} pairs The predicate-function pairs.
    	     * @returns {Function} Returns the new composite function.
    	     * @example
    	     *
    	     * var func = _.cond([
    	     *   [_.matches({ 'a': 1 }),           _.constant('matches A')],
    	     *   [_.conforms({ 'b': _.isNumber }), _.constant('matches B')],
    	     *   [_.stubTrue,                      _.constant('no match')]
    	     * ]);
    	     *
    	     * func({ 'a': 1, 'b': 2 });
    	     * // => 'matches A'
    	     *
    	     * func({ 'a': 0, 'b': 1 });
    	     * // => 'matches B'
    	     *
    	     * func({ 'a': '1', 'b': '2' });
    	     * // => 'no match'
    	     */function cond(pairs){var length=pairs==null?0:pairs.length,toIteratee=getIteratee();pairs=!length?[]:arrayMap(pairs,function(pair){if(typeof pair[1]!='function'){throw new TypeError(FUNC_ERROR_TEXT);}return [toIteratee(pair[0]),pair[1]];});return baseRest(function(args){var index=-1;while(++index<length){var pair=pairs[index];if(apply(pair[0],this,args)){return apply(pair[1],this,args);}}});}/**
    	     * Creates a function that invokes the predicate properties of `source` with
    	     * the corresponding property values of a given object, returning `true` if
    	     * all predicates return truthy, else `false`.
    	     *
    	     * **Note:** The created function is equivalent to `_.conformsTo` with
    	     * `source` partially applied.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Util
    	     * @param {Object} source The object of property predicates to conform to.
    	     * @returns {Function} Returns the new spec function.
    	     * @example
    	     *
    	     * var objects = [
    	     *   { 'a': 2, 'b': 1 },
    	     *   { 'a': 1, 'b': 2 }
    	     * ];
    	     *
    	     * _.filter(objects, _.conforms({ 'b': function(n) { return n > 1; } }));
    	     * // => [{ 'a': 1, 'b': 2 }]
    	     */function conforms(source){return baseConforms(baseClone(source,CLONE_DEEP_FLAG));}/**
    	     * Creates a function that returns `value`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 2.4.0
    	     * @category Util
    	     * @param {*} value The value to return from the new function.
    	     * @returns {Function} Returns the new constant function.
    	     * @example
    	     *
    	     * var objects = _.times(2, _.constant({ 'a': 1 }));
    	     *
    	     * console.log(objects);
    	     * // => [{ 'a': 1 }, { 'a': 1 }]
    	     *
    	     * console.log(objects[0] === objects[1]);
    	     * // => true
    	     */function constant(value){return function(){return value;};}/**
    	     * Checks `value` to determine whether a default value should be returned in
    	     * its place. The `defaultValue` is returned if `value` is `NaN`, `null`,
    	     * or `undefined`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.14.0
    	     * @category Util
    	     * @param {*} value The value to check.
    	     * @param {*} defaultValue The default value.
    	     * @returns {*} Returns the resolved value.
    	     * @example
    	     *
    	     * _.defaultTo(1, 10);
    	     * // => 1
    	     *
    	     * _.defaultTo(undefined, 10);
    	     * // => 10
    	     */function defaultTo(value,defaultValue){return value==null||value!==value?defaultValue:value;}/**
    	     * Creates a function that returns the result of invoking the given functions
    	     * with the `this` binding of the created function, where each successive
    	     * invocation is supplied the return value of the previous.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Util
    	     * @param {...(Function|Function[])} [funcs] The functions to invoke.
    	     * @returns {Function} Returns the new composite function.
    	     * @see _.flowRight
    	     * @example
    	     *
    	     * function square(n) {
    	     *   return n * n;
    	     * }
    	     *
    	     * var addSquare = _.flow([_.add, square]);
    	     * addSquare(1, 2);
    	     * // => 9
    	     */var flow=createFlow();/**
    	     * This method is like `_.flow` except that it creates a function that
    	     * invokes the given functions from right to left.
    	     *
    	     * @static
    	     * @since 3.0.0
    	     * @memberOf _
    	     * @category Util
    	     * @param {...(Function|Function[])} [funcs] The functions to invoke.
    	     * @returns {Function} Returns the new composite function.
    	     * @see _.flow
    	     * @example
    	     *
    	     * function square(n) {
    	     *   return n * n;
    	     * }
    	     *
    	     * var addSquare = _.flowRight([square, _.add]);
    	     * addSquare(1, 2);
    	     * // => 9
    	     */var flowRight=createFlow(true);/**
    	     * This method returns the first argument it receives.
    	     *
    	     * @static
    	     * @since 0.1.0
    	     * @memberOf _
    	     * @category Util
    	     * @param {*} value Any value.
    	     * @returns {*} Returns `value`.
    	     * @example
    	     *
    	     * var object = { 'a': 1 };
    	     *
    	     * console.log(_.identity(object) === object);
    	     * // => true
    	     */function identity(value){return value;}/**
    	     * Creates a function that invokes `func` with the arguments of the created
    	     * function. If `func` is a property name, the created function returns the
    	     * property value for a given element. If `func` is an array or object, the
    	     * created function returns `true` for elements that contain the equivalent
    	     * source properties, otherwise it returns `false`.
    	     *
    	     * @static
    	     * @since 4.0.0
    	     * @memberOf _
    	     * @category Util
    	     * @param {*} [func=_.identity] The value to convert to a callback.
    	     * @returns {Function} Returns the callback.
    	     * @example
    	     *
    	     * var users = [
    	     *   { 'user': 'barney', 'age': 36, 'active': true },
    	     *   { 'user': 'fred',   'age': 40, 'active': false }
    	     * ];
    	     *
    	     * // The `_.matches` iteratee shorthand.
    	     * _.filter(users, _.iteratee({ 'user': 'barney', 'active': true }));
    	     * // => [{ 'user': 'barney', 'age': 36, 'active': true }]
    	     *
    	     * // The `_.matchesProperty` iteratee shorthand.
    	     * _.filter(users, _.iteratee(['user', 'fred']));
    	     * // => [{ 'user': 'fred', 'age': 40 }]
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.map(users, _.iteratee('user'));
    	     * // => ['barney', 'fred']
    	     *
    	     * // Create custom iteratee shorthands.
    	     * _.iteratee = _.wrap(_.iteratee, function(iteratee, func) {
    	     *   return !_.isRegExp(func) ? iteratee(func) : function(string) {
    	     *     return func.test(string);
    	     *   };
    	     * });
    	     *
    	     * _.filter(['abc', 'def'], /ef/);
    	     * // => ['def']
    	     */function iteratee(func){return baseIteratee(typeof func=='function'?func:baseClone(func,CLONE_DEEP_FLAG));}/**
    	     * Creates a function that performs a partial deep comparison between a given
    	     * object and `source`, returning `true` if the given object has equivalent
    	     * property values, else `false`.
    	     *
    	     * **Note:** The created function is equivalent to `_.isMatch` with `source`
    	     * partially applied.
    	     *
    	     * Partial comparisons will match empty array and empty object `source`
    	     * values against any array or object value, respectively. See `_.isEqual`
    	     * for a list of supported value comparisons.
    	     *
    	     * **Note:** Multiple values can be checked by combining several matchers
    	     * using `_.overSome`
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Util
    	     * @param {Object} source The object of property values to match.
    	     * @returns {Function} Returns the new spec function.
    	     * @example
    	     *
    	     * var objects = [
    	     *   { 'a': 1, 'b': 2, 'c': 3 },
    	     *   { 'a': 4, 'b': 5, 'c': 6 }
    	     * ];
    	     *
    	     * _.filter(objects, _.matches({ 'a': 4, 'c': 6 }));
    	     * // => [{ 'a': 4, 'b': 5, 'c': 6 }]
    	     *
    	     * // Checking for several possible values
    	     * _.filter(objects, _.overSome([_.matches({ 'a': 1 }), _.matches({ 'a': 4 })]));
    	     * // => [{ 'a': 1, 'b': 2, 'c': 3 }, { 'a': 4, 'b': 5, 'c': 6 }]
    	     */function matches(source){return baseMatches(baseClone(source,CLONE_DEEP_FLAG));}/**
    	     * Creates a function that performs a partial deep comparison between the
    	     * value at `path` of a given object to `srcValue`, returning `true` if the
    	     * object value is equivalent, else `false`.
    	     *
    	     * **Note:** Partial comparisons will match empty array and empty object
    	     * `srcValue` values against any array or object value, respectively. See
    	     * `_.isEqual` for a list of supported value comparisons.
    	     *
    	     * **Note:** Multiple values can be checked by combining several matchers
    	     * using `_.overSome`
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.2.0
    	     * @category Util
    	     * @param {Array|string} path The path of the property to get.
    	     * @param {*} srcValue The value to match.
    	     * @returns {Function} Returns the new spec function.
    	     * @example
    	     *
    	     * var objects = [
    	     *   { 'a': 1, 'b': 2, 'c': 3 },
    	     *   { 'a': 4, 'b': 5, 'c': 6 }
    	     * ];
    	     *
    	     * _.find(objects, _.matchesProperty('a', 4));
    	     * // => { 'a': 4, 'b': 5, 'c': 6 }
    	     *
    	     * // Checking for several possible values
    	     * _.filter(objects, _.overSome([_.matchesProperty('a', 1), _.matchesProperty('a', 4)]));
    	     * // => [{ 'a': 1, 'b': 2, 'c': 3 }, { 'a': 4, 'b': 5, 'c': 6 }]
    	     */function matchesProperty(path,srcValue){return baseMatchesProperty(path,baseClone(srcValue,CLONE_DEEP_FLAG));}/**
    	     * Creates a function that invokes the method at `path` of a given object.
    	     * Any additional arguments are provided to the invoked method.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.7.0
    	     * @category Util
    	     * @param {Array|string} path The path of the method to invoke.
    	     * @param {...*} [args] The arguments to invoke the method with.
    	     * @returns {Function} Returns the new invoker function.
    	     * @example
    	     *
    	     * var objects = [
    	     *   { 'a': { 'b': _.constant(2) } },
    	     *   { 'a': { 'b': _.constant(1) } }
    	     * ];
    	     *
    	     * _.map(objects, _.method('a.b'));
    	     * // => [2, 1]
    	     *
    	     * _.map(objects, _.method(['a', 'b']));
    	     * // => [2, 1]
    	     */var method=baseRest(function(path,args){return function(object){return baseInvoke(object,path,args);};});/**
    	     * The opposite of `_.method`; this method creates a function that invokes
    	     * the method at a given path of `object`. Any additional arguments are
    	     * provided to the invoked method.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.7.0
    	     * @category Util
    	     * @param {Object} object The object to query.
    	     * @param {...*} [args] The arguments to invoke the method with.
    	     * @returns {Function} Returns the new invoker function.
    	     * @example
    	     *
    	     * var array = _.times(3, _.constant),
    	     *     object = { 'a': array, 'b': array, 'c': array };
    	     *
    	     * _.map(['a[2]', 'c[0]'], _.methodOf(object));
    	     * // => [2, 0]
    	     *
    	     * _.map([['a', '2'], ['c', '0']], _.methodOf(object));
    	     * // => [2, 0]
    	     */var methodOf=baseRest(function(object,args){return function(path){return baseInvoke(object,path,args);};});/**
    	     * Adds all own enumerable string keyed function properties of a source
    	     * object to the destination object. If `object` is a function, then methods
    	     * are added to its prototype as well.
    	     *
    	     * **Note:** Use `_.runInContext` to create a pristine `lodash` function to
    	     * avoid conflicts caused by modifying the original.
    	     *
    	     * @static
    	     * @since 0.1.0
    	     * @memberOf _
    	     * @category Util
    	     * @param {Function|Object} [object=lodash] The destination object.
    	     * @param {Object} source The object of functions to add.
    	     * @param {Object} [options={}] The options object.
    	     * @param {boolean} [options.chain=true] Specify whether mixins are chainable.
    	     * @returns {Function|Object} Returns `object`.
    	     * @example
    	     *
    	     * function vowels(string) {
    	     *   return _.filter(string, function(v) {
    	     *     return /[aeiou]/i.test(v);
    	     *   });
    	     * }
    	     *
    	     * _.mixin({ 'vowels': vowels });
    	     * _.vowels('fred');
    	     * // => ['e']
    	     *
    	     * _('fred').vowels().value();
    	     * // => ['e']
    	     *
    	     * _.mixin({ 'vowels': vowels }, { 'chain': false });
    	     * _('fred').vowels();
    	     * // => ['e']
    	     */function mixin(object,source,options){var props=keys(source),methodNames=baseFunctions(source,props);if(options==null&&!(isObject(source)&&(methodNames.length||!props.length))){options=source;source=object;object=this;methodNames=baseFunctions(source,keys(source));}var chain=!(isObject(options)&&'chain'in options)||!!options.chain,isFunc=isFunction(object);arrayEach(methodNames,function(methodName){var func=source[methodName];object[methodName]=func;if(isFunc){object.prototype[methodName]=function(){var chainAll=this.__chain__;if(chain||chainAll){var result=object(this.__wrapped__),actions=result.__actions__=copyArray(this.__actions__);actions.push({'func':func,'args':arguments,'thisArg':object});result.__chain__=chainAll;return result;}return func.apply(object,arrayPush([this.value()],arguments));};}});return object;}/**
    	     * Reverts the `_` variable to its previous value and returns a reference to
    	     * the `lodash` function.
    	     *
    	     * @static
    	     * @since 0.1.0
    	     * @memberOf _
    	     * @category Util
    	     * @returns {Function} Returns the `lodash` function.
    	     * @example
    	     *
    	     * var lodash = _.noConflict();
    	     */function noConflict(){if(root._===this){root._=oldDash;}return this;}/**
    	     * This method returns `undefined`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 2.3.0
    	     * @category Util
    	     * @example
    	     *
    	     * _.times(2, _.noop);
    	     * // => [undefined, undefined]
    	     */function noop(){// No operation performed.
    	}/**
    	     * Creates a function that gets the argument at index `n`. If `n` is negative,
    	     * the nth argument from the end is returned.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Util
    	     * @param {number} [n=0] The index of the argument to return.
    	     * @returns {Function} Returns the new pass-thru function.
    	     * @example
    	     *
    	     * var func = _.nthArg(1);
    	     * func('a', 'b', 'c', 'd');
    	     * // => 'b'
    	     *
    	     * var func = _.nthArg(-2);
    	     * func('a', 'b', 'c', 'd');
    	     * // => 'c'
    	     */function nthArg(n){n=toInteger(n);return baseRest(function(args){return baseNth(args,n);});}/**
    	     * Creates a function that invokes `iteratees` with the arguments it receives
    	     * and returns their results.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Util
    	     * @param {...(Function|Function[])} [iteratees=[_.identity]]
    	     *  The iteratees to invoke.
    	     * @returns {Function} Returns the new function.
    	     * @example
    	     *
    	     * var func = _.over([Math.max, Math.min]);
    	     *
    	     * func(1, 2, 3, 4);
    	     * // => [4, 1]
    	     */var over=createOver(arrayMap);/**
    	     * Creates a function that checks if **all** of the `predicates` return
    	     * truthy when invoked with the arguments it receives.
    	     *
    	     * Following shorthands are possible for providing predicates.
    	     * Pass an `Object` and it will be used as an parameter for `_.matches` to create the predicate.
    	     * Pass an `Array` of parameters for `_.matchesProperty` and the predicate will be created using them.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Util
    	     * @param {...(Function|Function[])} [predicates=[_.identity]]
    	     *  The predicates to check.
    	     * @returns {Function} Returns the new function.
    	     * @example
    	     *
    	     * var func = _.overEvery([Boolean, isFinite]);
    	     *
    	     * func('1');
    	     * // => true
    	     *
    	     * func(null);
    	     * // => false
    	     *
    	     * func(NaN);
    	     * // => false
    	     */var overEvery=createOver(arrayEvery);/**
    	     * Creates a function that checks if **any** of the `predicates` return
    	     * truthy when invoked with the arguments it receives.
    	     *
    	     * Following shorthands are possible for providing predicates.
    	     * Pass an `Object` and it will be used as an parameter for `_.matches` to create the predicate.
    	     * Pass an `Array` of parameters for `_.matchesProperty` and the predicate will be created using them.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Util
    	     * @param {...(Function|Function[])} [predicates=[_.identity]]
    	     *  The predicates to check.
    	     * @returns {Function} Returns the new function.
    	     * @example
    	     *
    	     * var func = _.overSome([Boolean, isFinite]);
    	     *
    	     * func('1');
    	     * // => true
    	     *
    	     * func(null);
    	     * // => true
    	     *
    	     * func(NaN);
    	     * // => false
    	     *
    	     * var matchesFunc = _.overSome([{ 'a': 1 }, { 'a': 2 }])
    	     * var matchesPropertyFunc = _.overSome([['a', 1], ['a', 2]])
    	     */var overSome=createOver(arraySome);/**
    	     * Creates a function that returns the value at `path` of a given object.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 2.4.0
    	     * @category Util
    	     * @param {Array|string} path The path of the property to get.
    	     * @returns {Function} Returns the new accessor function.
    	     * @example
    	     *
    	     * var objects = [
    	     *   { 'a': { 'b': 2 } },
    	     *   { 'a': { 'b': 1 } }
    	     * ];
    	     *
    	     * _.map(objects, _.property('a.b'));
    	     * // => [2, 1]
    	     *
    	     * _.map(_.sortBy(objects, _.property(['a', 'b'])), 'a.b');
    	     * // => [1, 2]
    	     */function property(path){return isKey(path)?baseProperty(toKey(path)):basePropertyDeep(path);}/**
    	     * The opposite of `_.property`; this method creates a function that returns
    	     * the value at a given path of `object`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.0.0
    	     * @category Util
    	     * @param {Object} object The object to query.
    	     * @returns {Function} Returns the new accessor function.
    	     * @example
    	     *
    	     * var array = [0, 1, 2],
    	     *     object = { 'a': array, 'b': array, 'c': array };
    	     *
    	     * _.map(['a[2]', 'c[0]'], _.propertyOf(object));
    	     * // => [2, 0]
    	     *
    	     * _.map([['a', '2'], ['c', '0']], _.propertyOf(object));
    	     * // => [2, 0]
    	     */function propertyOf(object){return function(path){return object==null?undefined$1:baseGet(object,path);};}/**
    	     * Creates an array of numbers (positive and/or negative) progressing from
    	     * `start` up to, but not including, `end`. A step of `-1` is used if a negative
    	     * `start` is specified without an `end` or `step`. If `end` is not specified,
    	     * it's set to `start` with `start` then set to `0`.
    	     *
    	     * **Note:** JavaScript follows the IEEE-754 standard for resolving
    	     * floating-point values which can produce unexpected results.
    	     *
    	     * @static
    	     * @since 0.1.0
    	     * @memberOf _
    	     * @category Util
    	     * @param {number} [start=0] The start of the range.
    	     * @param {number} end The end of the range.
    	     * @param {number} [step=1] The value to increment or decrement by.
    	     * @returns {Array} Returns the range of numbers.
    	     * @see _.inRange, _.rangeRight
    	     * @example
    	     *
    	     * _.range(4);
    	     * // => [0, 1, 2, 3]
    	     *
    	     * _.range(-4);
    	     * // => [0, -1, -2, -3]
    	     *
    	     * _.range(1, 5);
    	     * // => [1, 2, 3, 4]
    	     *
    	     * _.range(0, 20, 5);
    	     * // => [0, 5, 10, 15]
    	     *
    	     * _.range(0, -4, -1);
    	     * // => [0, -1, -2, -3]
    	     *
    	     * _.range(1, 4, 0);
    	     * // => [1, 1, 1]
    	     *
    	     * _.range(0);
    	     * // => []
    	     */var range=createRange();/**
    	     * This method is like `_.range` except that it populates values in
    	     * descending order.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Util
    	     * @param {number} [start=0] The start of the range.
    	     * @param {number} end The end of the range.
    	     * @param {number} [step=1] The value to increment or decrement by.
    	     * @returns {Array} Returns the range of numbers.
    	     * @see _.inRange, _.range
    	     * @example
    	     *
    	     * _.rangeRight(4);
    	     * // => [3, 2, 1, 0]
    	     *
    	     * _.rangeRight(-4);
    	     * // => [-3, -2, -1, 0]
    	     *
    	     * _.rangeRight(1, 5);
    	     * // => [4, 3, 2, 1]
    	     *
    	     * _.rangeRight(0, 20, 5);
    	     * // => [15, 10, 5, 0]
    	     *
    	     * _.rangeRight(0, -4, -1);
    	     * // => [-3, -2, -1, 0]
    	     *
    	     * _.rangeRight(1, 4, 0);
    	     * // => [1, 1, 1]
    	     *
    	     * _.rangeRight(0);
    	     * // => []
    	     */var rangeRight=createRange(true);/**
    	     * This method returns a new empty array.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.13.0
    	     * @category Util
    	     * @returns {Array} Returns the new empty array.
    	     * @example
    	     *
    	     * var arrays = _.times(2, _.stubArray);
    	     *
    	     * console.log(arrays);
    	     * // => [[], []]
    	     *
    	     * console.log(arrays[0] === arrays[1]);
    	     * // => false
    	     */function stubArray(){return [];}/**
    	     * This method returns `false`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.13.0
    	     * @category Util
    	     * @returns {boolean} Returns `false`.
    	     * @example
    	     *
    	     * _.times(2, _.stubFalse);
    	     * // => [false, false]
    	     */function stubFalse(){return false;}/**
    	     * This method returns a new empty object.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.13.0
    	     * @category Util
    	     * @returns {Object} Returns the new empty object.
    	     * @example
    	     *
    	     * var objects = _.times(2, _.stubObject);
    	     *
    	     * console.log(objects);
    	     * // => [{}, {}]
    	     *
    	     * console.log(objects[0] === objects[1]);
    	     * // => false
    	     */function stubObject(){return {};}/**
    	     * This method returns an empty string.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.13.0
    	     * @category Util
    	     * @returns {string} Returns the empty string.
    	     * @example
    	     *
    	     * _.times(2, _.stubString);
    	     * // => ['', '']
    	     */function stubString(){return '';}/**
    	     * This method returns `true`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.13.0
    	     * @category Util
    	     * @returns {boolean} Returns `true`.
    	     * @example
    	     *
    	     * _.times(2, _.stubTrue);
    	     * // => [true, true]
    	     */function stubTrue(){return true;}/**
    	     * Invokes the iteratee `n` times, returning an array of the results of
    	     * each invocation. The iteratee is invoked with one argument; (index).
    	     *
    	     * @static
    	     * @since 0.1.0
    	     * @memberOf _
    	     * @category Util
    	     * @param {number} n The number of times to invoke `iteratee`.
    	     * @param {Function} [iteratee=_.identity] The function invoked per iteration.
    	     * @returns {Array} Returns the array of results.
    	     * @example
    	     *
    	     * _.times(3, String);
    	     * // => ['0', '1', '2']
    	     *
    	     *  _.times(4, _.constant(0));
    	     * // => [0, 0, 0, 0]
    	     */function times(n,iteratee){n=toInteger(n);if(n<1||n>MAX_SAFE_INTEGER){return [];}var index=MAX_ARRAY_LENGTH,length=nativeMin(n,MAX_ARRAY_LENGTH);iteratee=getIteratee(iteratee);n-=MAX_ARRAY_LENGTH;var result=baseTimes(length,iteratee);while(++index<n){iteratee(index);}return result;}/**
    	     * Converts `value` to a property path array.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Util
    	     * @param {*} value The value to convert.
    	     * @returns {Array} Returns the new property path array.
    	     * @example
    	     *
    	     * _.toPath('a.b.c');
    	     * // => ['a', 'b', 'c']
    	     *
    	     * _.toPath('a[0].b.c');
    	     * // => ['a', '0', 'b', 'c']
    	     */function toPath(value){if(isArray(value)){return arrayMap(value,toKey);}return isSymbol(value)?[value]:copyArray(stringToPath(toString(value)));}/**
    	     * Generates a unique ID. If `prefix` is given, the ID is appended to it.
    	     *
    	     * @static
    	     * @since 0.1.0
    	     * @memberOf _
    	     * @category Util
    	     * @param {string} [prefix=''] The value to prefix the ID with.
    	     * @returns {string} Returns the unique ID.
    	     * @example
    	     *
    	     * _.uniqueId('contact_');
    	     * // => 'contact_104'
    	     *
    	     * _.uniqueId();
    	     * // => '105'
    	     */function uniqueId(prefix){var id=++idCounter;return toString(prefix)+id;}/*------------------------------------------------------------------------*/ /**
    	     * Adds two numbers.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.4.0
    	     * @category Math
    	     * @param {number} augend The first number in an addition.
    	     * @param {number} addend The second number in an addition.
    	     * @returns {number} Returns the total.
    	     * @example
    	     *
    	     * _.add(6, 4);
    	     * // => 10
    	     */var add=createMathOperation(function(augend,addend){return augend+addend;},0);/**
    	     * Computes `number` rounded up to `precision`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.10.0
    	     * @category Math
    	     * @param {number} number The number to round up.
    	     * @param {number} [precision=0] The precision to round up to.
    	     * @returns {number} Returns the rounded up number.
    	     * @example
    	     *
    	     * _.ceil(4.006);
    	     * // => 5
    	     *
    	     * _.ceil(6.004, 2);
    	     * // => 6.01
    	     *
    	     * _.ceil(6040, -2);
    	     * // => 6100
    	     */var ceil=createRound('ceil');/**
    	     * Divide two numbers.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.7.0
    	     * @category Math
    	     * @param {number} dividend The first number in a division.
    	     * @param {number} divisor The second number in a division.
    	     * @returns {number} Returns the quotient.
    	     * @example
    	     *
    	     * _.divide(6, 4);
    	     * // => 1.5
    	     */var divide=createMathOperation(function(dividend,divisor){return dividend/divisor;},1);/**
    	     * Computes `number` rounded down to `precision`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.10.0
    	     * @category Math
    	     * @param {number} number The number to round down.
    	     * @param {number} [precision=0] The precision to round down to.
    	     * @returns {number} Returns the rounded down number.
    	     * @example
    	     *
    	     * _.floor(4.006);
    	     * // => 4
    	     *
    	     * _.floor(0.046, 2);
    	     * // => 0.04
    	     *
    	     * _.floor(4060, -2);
    	     * // => 4000
    	     */var floor=createRound('floor');/**
    	     * Computes the maximum value of `array`. If `array` is empty or falsey,
    	     * `undefined` is returned.
    	     *
    	     * @static
    	     * @since 0.1.0
    	     * @memberOf _
    	     * @category Math
    	     * @param {Array} array The array to iterate over.
    	     * @returns {*} Returns the maximum value.
    	     * @example
    	     *
    	     * _.max([4, 2, 8, 6]);
    	     * // => 8
    	     *
    	     * _.max([]);
    	     * // => undefined
    	     */function max(array){return array&&array.length?baseExtremum(array,identity,baseGt):undefined$1;}/**
    	     * This method is like `_.max` except that it accepts `iteratee` which is
    	     * invoked for each element in `array` to generate the criterion by which
    	     * the value is ranked. The iteratee is invoked with one argument: (value).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Math
    	     * @param {Array} array The array to iterate over.
    	     * @param {Function} [iteratee=_.identity] The iteratee invoked per element.
    	     * @returns {*} Returns the maximum value.
    	     * @example
    	     *
    	     * var objects = [{ 'n': 1 }, { 'n': 2 }];
    	     *
    	     * _.maxBy(objects, function(o) { return o.n; });
    	     * // => { 'n': 2 }
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.maxBy(objects, 'n');
    	     * // => { 'n': 2 }
    	     */function maxBy(array,iteratee){return array&&array.length?baseExtremum(array,getIteratee(iteratee,2),baseGt):undefined$1;}/**
    	     * Computes the mean of the values in `array`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Math
    	     * @param {Array} array The array to iterate over.
    	     * @returns {number} Returns the mean.
    	     * @example
    	     *
    	     * _.mean([4, 2, 8, 6]);
    	     * // => 5
    	     */function mean(array){return baseMean(array,identity);}/**
    	     * This method is like `_.mean` except that it accepts `iteratee` which is
    	     * invoked for each element in `array` to generate the value to be averaged.
    	     * The iteratee is invoked with one argument: (value).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.7.0
    	     * @category Math
    	     * @param {Array} array The array to iterate over.
    	     * @param {Function} [iteratee=_.identity] The iteratee invoked per element.
    	     * @returns {number} Returns the mean.
    	     * @example
    	     *
    	     * var objects = [{ 'n': 4 }, { 'n': 2 }, { 'n': 8 }, { 'n': 6 }];
    	     *
    	     * _.meanBy(objects, function(o) { return o.n; });
    	     * // => 5
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.meanBy(objects, 'n');
    	     * // => 5
    	     */function meanBy(array,iteratee){return baseMean(array,getIteratee(iteratee,2));}/**
    	     * Computes the minimum value of `array`. If `array` is empty or falsey,
    	     * `undefined` is returned.
    	     *
    	     * @static
    	     * @since 0.1.0
    	     * @memberOf _
    	     * @category Math
    	     * @param {Array} array The array to iterate over.
    	     * @returns {*} Returns the minimum value.
    	     * @example
    	     *
    	     * _.min([4, 2, 8, 6]);
    	     * // => 2
    	     *
    	     * _.min([]);
    	     * // => undefined
    	     */function min(array){return array&&array.length?baseExtremum(array,identity,baseLt):undefined$1;}/**
    	     * This method is like `_.min` except that it accepts `iteratee` which is
    	     * invoked for each element in `array` to generate the criterion by which
    	     * the value is ranked. The iteratee is invoked with one argument: (value).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Math
    	     * @param {Array} array The array to iterate over.
    	     * @param {Function} [iteratee=_.identity] The iteratee invoked per element.
    	     * @returns {*} Returns the minimum value.
    	     * @example
    	     *
    	     * var objects = [{ 'n': 1 }, { 'n': 2 }];
    	     *
    	     * _.minBy(objects, function(o) { return o.n; });
    	     * // => { 'n': 1 }
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.minBy(objects, 'n');
    	     * // => { 'n': 1 }
    	     */function minBy(array,iteratee){return array&&array.length?baseExtremum(array,getIteratee(iteratee,2),baseLt):undefined$1;}/**
    	     * Multiply two numbers.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.7.0
    	     * @category Math
    	     * @param {number} multiplier The first number in a multiplication.
    	     * @param {number} multiplicand The second number in a multiplication.
    	     * @returns {number} Returns the product.
    	     * @example
    	     *
    	     * _.multiply(6, 4);
    	     * // => 24
    	     */var multiply=createMathOperation(function(multiplier,multiplicand){return multiplier*multiplicand;},1);/**
    	     * Computes `number` rounded to `precision`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.10.0
    	     * @category Math
    	     * @param {number} number The number to round.
    	     * @param {number} [precision=0] The precision to round to.
    	     * @returns {number} Returns the rounded number.
    	     * @example
    	     *
    	     * _.round(4.006);
    	     * // => 4
    	     *
    	     * _.round(4.006, 2);
    	     * // => 4.01
    	     *
    	     * _.round(4060, -2);
    	     * // => 4100
    	     */var round=createRound('round');/**
    	     * Subtract two numbers.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Math
    	     * @param {number} minuend The first number in a subtraction.
    	     * @param {number} subtrahend The second number in a subtraction.
    	     * @returns {number} Returns the difference.
    	     * @example
    	     *
    	     * _.subtract(6, 4);
    	     * // => 2
    	     */var subtract=createMathOperation(function(minuend,subtrahend){return minuend-subtrahend;},0);/**
    	     * Computes the sum of the values in `array`.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 3.4.0
    	     * @category Math
    	     * @param {Array} array The array to iterate over.
    	     * @returns {number} Returns the sum.
    	     * @example
    	     *
    	     * _.sum([4, 2, 8, 6]);
    	     * // => 20
    	     */function sum(array){return array&&array.length?baseSum(array,identity):0;}/**
    	     * This method is like `_.sum` except that it accepts `iteratee` which is
    	     * invoked for each element in `array` to generate the value to be summed.
    	     * The iteratee is invoked with one argument: (value).
    	     *
    	     * @static
    	     * @memberOf _
    	     * @since 4.0.0
    	     * @category Math
    	     * @param {Array} array The array to iterate over.
    	     * @param {Function} [iteratee=_.identity] The iteratee invoked per element.
    	     * @returns {number} Returns the sum.
    	     * @example
    	     *
    	     * var objects = [{ 'n': 4 }, { 'n': 2 }, { 'n': 8 }, { 'n': 6 }];
    	     *
    	     * _.sumBy(objects, function(o) { return o.n; });
    	     * // => 20
    	     *
    	     * // The `_.property` iteratee shorthand.
    	     * _.sumBy(objects, 'n');
    	     * // => 20
    	     */function sumBy(array,iteratee){return array&&array.length?baseSum(array,getIteratee(iteratee,2)):0;}/*------------------------------------------------------------------------*/ // Add methods that return wrapped values in chain sequences.
    	lodash.after=after;lodash.ary=ary;lodash.assign=assign;lodash.assignIn=assignIn;lodash.assignInWith=assignInWith;lodash.assignWith=assignWith;lodash.at=at;lodash.before=before;lodash.bind=bind;lodash.bindAll=bindAll;lodash.bindKey=bindKey;lodash.castArray=castArray;lodash.chain=chain;lodash.chunk=chunk;lodash.compact=compact;lodash.concat=concat;lodash.cond=cond;lodash.conforms=conforms;lodash.constant=constant;lodash.countBy=countBy;lodash.create=create;lodash.curry=curry;lodash.curryRight=curryRight;lodash.debounce=debounce;lodash.defaults=defaults;lodash.defaultsDeep=defaultsDeep;lodash.defer=defer;lodash.delay=delay;lodash.difference=difference;lodash.differenceBy=differenceBy;lodash.differenceWith=differenceWith;lodash.drop=drop;lodash.dropRight=dropRight;lodash.dropRightWhile=dropRightWhile;lodash.dropWhile=dropWhile;lodash.fill=fill;lodash.filter=filter;lodash.flatMap=flatMap;lodash.flatMapDeep=flatMapDeep;lodash.flatMapDepth=flatMapDepth;lodash.flatten=flatten;lodash.flattenDeep=flattenDeep;lodash.flattenDepth=flattenDepth;lodash.flip=flip;lodash.flow=flow;lodash.flowRight=flowRight;lodash.fromPairs=fromPairs;lodash.functions=functions;lodash.functionsIn=functionsIn;lodash.groupBy=groupBy;lodash.initial=initial;lodash.intersection=intersection;lodash.intersectionBy=intersectionBy;lodash.intersectionWith=intersectionWith;lodash.invert=invert;lodash.invertBy=invertBy;lodash.invokeMap=invokeMap;lodash.iteratee=iteratee;lodash.keyBy=keyBy;lodash.keys=keys;lodash.keysIn=keysIn;lodash.map=map;lodash.mapKeys=mapKeys;lodash.mapValues=mapValues;lodash.matches=matches;lodash.matchesProperty=matchesProperty;lodash.memoize=memoize;lodash.merge=merge;lodash.mergeWith=mergeWith;lodash.method=method;lodash.methodOf=methodOf;lodash.mixin=mixin;lodash.negate=negate;lodash.nthArg=nthArg;lodash.omit=omit;lodash.omitBy=omitBy;lodash.once=once;lodash.orderBy=orderBy;lodash.over=over;lodash.overArgs=overArgs;lodash.overEvery=overEvery;lodash.overSome=overSome;lodash.partial=partial;lodash.partialRight=partialRight;lodash.partition=partition;lodash.pick=pick;lodash.pickBy=pickBy;lodash.property=property;lodash.propertyOf=propertyOf;lodash.pull=pull;lodash.pullAll=pullAll;lodash.pullAllBy=pullAllBy;lodash.pullAllWith=pullAllWith;lodash.pullAt=pullAt;lodash.range=range;lodash.rangeRight=rangeRight;lodash.rearg=rearg;lodash.reject=reject;lodash.remove=remove;lodash.rest=rest;lodash.reverse=reverse;lodash.sampleSize=sampleSize;lodash.set=set;lodash.setWith=setWith;lodash.shuffle=shuffle;lodash.slice=slice;lodash.sortBy=sortBy;lodash.sortedUniq=sortedUniq;lodash.sortedUniqBy=sortedUniqBy;lodash.split=split;lodash.spread=spread;lodash.tail=tail;lodash.take=take;lodash.takeRight=takeRight;lodash.takeRightWhile=takeRightWhile;lodash.takeWhile=takeWhile;lodash.tap=tap;lodash.throttle=throttle;lodash.thru=thru;lodash.toArray=toArray;lodash.toPairs=toPairs;lodash.toPairsIn=toPairsIn;lodash.toPath=toPath;lodash.toPlainObject=toPlainObject;lodash.transform=transform;lodash.unary=unary;lodash.union=union;lodash.unionBy=unionBy;lodash.unionWith=unionWith;lodash.uniq=uniq;lodash.uniqBy=uniqBy;lodash.uniqWith=uniqWith;lodash.unset=unset;lodash.unzip=unzip;lodash.unzipWith=unzipWith;lodash.update=update;lodash.updateWith=updateWith;lodash.values=values;lodash.valuesIn=valuesIn;lodash.without=without;lodash.words=words;lodash.wrap=wrap;lodash.xor=xor;lodash.xorBy=xorBy;lodash.xorWith=xorWith;lodash.zip=zip;lodash.zipObject=zipObject;lodash.zipObjectDeep=zipObjectDeep;lodash.zipWith=zipWith;// Add aliases.
    	lodash.entries=toPairs;lodash.entriesIn=toPairsIn;lodash.extend=assignIn;lodash.extendWith=assignInWith;// Add methods to `lodash.prototype`.
    	mixin(lodash,lodash);/*------------------------------------------------------------------------*/ // Add methods that return unwrapped values in chain sequences.
    	lodash.add=add;lodash.attempt=attempt;lodash.camelCase=camelCase;lodash.capitalize=capitalize;lodash.ceil=ceil;lodash.clamp=clamp;lodash.clone=clone;lodash.cloneDeep=cloneDeep;lodash.cloneDeepWith=cloneDeepWith;lodash.cloneWith=cloneWith;lodash.conformsTo=conformsTo;lodash.deburr=deburr;lodash.defaultTo=defaultTo;lodash.divide=divide;lodash.endsWith=endsWith;lodash.eq=eq;lodash.escape=escape;lodash.escapeRegExp=escapeRegExp;lodash.every=every;lodash.find=find;lodash.findIndex=findIndex;lodash.findKey=findKey;lodash.findLast=findLast;lodash.findLastIndex=findLastIndex;lodash.findLastKey=findLastKey;lodash.floor=floor;lodash.forEach=forEach;lodash.forEachRight=forEachRight;lodash.forIn=forIn;lodash.forInRight=forInRight;lodash.forOwn=forOwn;lodash.forOwnRight=forOwnRight;lodash.get=get;lodash.gt=gt;lodash.gte=gte;lodash.has=has;lodash.hasIn=hasIn;lodash.head=head;lodash.identity=identity;lodash.includes=includes;lodash.indexOf=indexOf;lodash.inRange=inRange;lodash.invoke=invoke;lodash.isArguments=isArguments;lodash.isArray=isArray;lodash.isArrayBuffer=isArrayBuffer;lodash.isArrayLike=isArrayLike;lodash.isArrayLikeObject=isArrayLikeObject;lodash.isBoolean=isBoolean;lodash.isBuffer=isBuffer;lodash.isDate=isDate;lodash.isElement=isElement;lodash.isEmpty=isEmpty;lodash.isEqual=isEqual;lodash.isEqualWith=isEqualWith;lodash.isError=isError;lodash.isFinite=isFinite;lodash.isFunction=isFunction;lodash.isInteger=isInteger;lodash.isLength=isLength;lodash.isMap=isMap;lodash.isMatch=isMatch;lodash.isMatchWith=isMatchWith;lodash.isNaN=isNaN;lodash.isNative=isNative;lodash.isNil=isNil;lodash.isNull=isNull;lodash.isNumber=isNumber;lodash.isObject=isObject;lodash.isObjectLike=isObjectLike;lodash.isPlainObject=isPlainObject;lodash.isRegExp=isRegExp;lodash.isSafeInteger=isSafeInteger;lodash.isSet=isSet;lodash.isString=isString;lodash.isSymbol=isSymbol;lodash.isTypedArray=isTypedArray;lodash.isUndefined=isUndefined;lodash.isWeakMap=isWeakMap;lodash.isWeakSet=isWeakSet;lodash.join=join;lodash.kebabCase=kebabCase;lodash.last=last;lodash.lastIndexOf=lastIndexOf;lodash.lowerCase=lowerCase;lodash.lowerFirst=lowerFirst;lodash.lt=lt;lodash.lte=lte;lodash.max=max;lodash.maxBy=maxBy;lodash.mean=mean;lodash.meanBy=meanBy;lodash.min=min;lodash.minBy=minBy;lodash.stubArray=stubArray;lodash.stubFalse=stubFalse;lodash.stubObject=stubObject;lodash.stubString=stubString;lodash.stubTrue=stubTrue;lodash.multiply=multiply;lodash.nth=nth;lodash.noConflict=noConflict;lodash.noop=noop;lodash.now=now;lodash.pad=pad;lodash.padEnd=padEnd;lodash.padStart=padStart;lodash.parseInt=parseInt;lodash.random=random;lodash.reduce=reduce;lodash.reduceRight=reduceRight;lodash.repeat=repeat;lodash.replace=replace;lodash.result=result;lodash.round=round;lodash.runInContext=runInContext;lodash.sample=sample;lodash.size=size;lodash.snakeCase=snakeCase;lodash.some=some;lodash.sortedIndex=sortedIndex;lodash.sortedIndexBy=sortedIndexBy;lodash.sortedIndexOf=sortedIndexOf;lodash.sortedLastIndex=sortedLastIndex;lodash.sortedLastIndexBy=sortedLastIndexBy;lodash.sortedLastIndexOf=sortedLastIndexOf;lodash.startCase=startCase;lodash.startsWith=startsWith;lodash.subtract=subtract;lodash.sum=sum;lodash.sumBy=sumBy;lodash.template=template;lodash.times=times;lodash.toFinite=toFinite;lodash.toInteger=toInteger;lodash.toLength=toLength;lodash.toLower=toLower;lodash.toNumber=toNumber;lodash.toSafeInteger=toSafeInteger;lodash.toString=toString;lodash.toUpper=toUpper;lodash.trim=trim;lodash.trimEnd=trimEnd;lodash.trimStart=trimStart;lodash.truncate=truncate;lodash.unescape=unescape;lodash.uniqueId=uniqueId;lodash.upperCase=upperCase;lodash.upperFirst=upperFirst;// Add aliases.
    	lodash.each=forEach;lodash.eachRight=forEachRight;lodash.first=head;mixin(lodash,function(){var source={};baseForOwn(lodash,function(func,methodName){if(!hasOwnProperty.call(lodash.prototype,methodName)){source[methodName]=func;}});return source;}(),{'chain':false});/*------------------------------------------------------------------------*/ /**
    	     * The semantic version number.
    	     *
    	     * @static
    	     * @memberOf _
    	     * @type {string}
    	     */lodash.VERSION=VERSION;// Assign default placeholders.
    	arrayEach(['bind','bindKey','curry','curryRight','partial','partialRight'],function(methodName){lodash[methodName].placeholder=lodash;});// Add `LazyWrapper` methods for `_.drop` and `_.take` variants.
    	arrayEach(['drop','take'],function(methodName,index){LazyWrapper.prototype[methodName]=function(n){n=n===undefined$1?1:nativeMax(toInteger(n),0);var result=this.__filtered__&&!index?new LazyWrapper(this):this.clone();if(result.__filtered__){result.__takeCount__=nativeMin(n,result.__takeCount__);}else {result.__views__.push({'size':nativeMin(n,MAX_ARRAY_LENGTH),'type':methodName+(result.__dir__<0?'Right':'')});}return result;};LazyWrapper.prototype[methodName+'Right']=function(n){return this.reverse()[methodName](n).reverse();};});// Add `LazyWrapper` methods that accept an `iteratee` value.
    	arrayEach(['filter','map','takeWhile'],function(methodName,index){var type=index+1,isFilter=type==LAZY_FILTER_FLAG||type==LAZY_WHILE_FLAG;LazyWrapper.prototype[methodName]=function(iteratee){var result=this.clone();result.__iteratees__.push({'iteratee':getIteratee(iteratee,3),'type':type});result.__filtered__=result.__filtered__||isFilter;return result;};});// Add `LazyWrapper` methods for `_.head` and `_.last`.
    	arrayEach(['head','last'],function(methodName,index){var takeName='take'+(index?'Right':'');LazyWrapper.prototype[methodName]=function(){return this[takeName](1).value()[0];};});// Add `LazyWrapper` methods for `_.initial` and `_.tail`.
    	arrayEach(['initial','tail'],function(methodName,index){var dropName='drop'+(index?'':'Right');LazyWrapper.prototype[methodName]=function(){return this.__filtered__?new LazyWrapper(this):this[dropName](1);};});LazyWrapper.prototype.compact=function(){return this.filter(identity);};LazyWrapper.prototype.find=function(predicate){return this.filter(predicate).head();};LazyWrapper.prototype.findLast=function(predicate){return this.reverse().find(predicate);};LazyWrapper.prototype.invokeMap=baseRest(function(path,args){if(typeof path=='function'){return new LazyWrapper(this);}return this.map(function(value){return baseInvoke(value,path,args);});});LazyWrapper.prototype.reject=function(predicate){return this.filter(negate(getIteratee(predicate)));};LazyWrapper.prototype.slice=function(start,end){start=toInteger(start);var result=this;if(result.__filtered__&&(start>0||end<0)){return new LazyWrapper(result);}if(start<0){result=result.takeRight(-start);}else if(start){result=result.drop(start);}if(end!==undefined$1){end=toInteger(end);result=end<0?result.dropRight(-end):result.take(end-start);}return result;};LazyWrapper.prototype.takeRightWhile=function(predicate){return this.reverse().takeWhile(predicate).reverse();};LazyWrapper.prototype.toArray=function(){return this.take(MAX_ARRAY_LENGTH);};// Add `LazyWrapper` methods to `lodash.prototype`.
    	baseForOwn(LazyWrapper.prototype,function(func,methodName){var checkIteratee=/^(?:filter|find|map|reject)|While$/.test(methodName),isTaker=/^(?:head|last)$/.test(methodName),lodashFunc=lodash[isTaker?'take'+(methodName=='last'?'Right':''):methodName],retUnwrapped=isTaker||/^find/.test(methodName);if(!lodashFunc){return;}lodash.prototype[methodName]=function(){var value=this.__wrapped__,args=isTaker?[1]:arguments,isLazy=value instanceof LazyWrapper,iteratee=args[0],useLazy=isLazy||isArray(value);var interceptor=function(value){var result=lodashFunc.apply(lodash,arrayPush([value],args));return isTaker&&chainAll?result[0]:result;};if(useLazy&&checkIteratee&&typeof iteratee=='function'&&iteratee.length!=1){// Avoid lazy use if the iteratee has a "length" value other than `1`.
    	isLazy=useLazy=false;}var chainAll=this.__chain__,isHybrid=!!this.__actions__.length,isUnwrapped=retUnwrapped&&!chainAll,onlyLazy=isLazy&&!isHybrid;if(!retUnwrapped&&useLazy){value=onlyLazy?value:new LazyWrapper(this);var result=func.apply(value,args);result.__actions__.push({'func':thru,'args':[interceptor],'thisArg':undefined$1});return new LodashWrapper(result,chainAll);}if(isUnwrapped&&onlyLazy){return func.apply(this,args);}result=this.thru(interceptor);return isUnwrapped?isTaker?result.value()[0]:result.value():result;};});// Add `Array` methods to `lodash.prototype`.
    	arrayEach(['pop','push','shift','sort','splice','unshift'],function(methodName){var func=arrayProto[methodName],chainName=/^(?:push|sort|unshift)$/.test(methodName)?'tap':'thru',retUnwrapped=/^(?:pop|shift)$/.test(methodName);lodash.prototype[methodName]=function(){var args=arguments;if(retUnwrapped&&!this.__chain__){var value=this.value();return func.apply(isArray(value)?value:[],args);}return this[chainName](function(value){return func.apply(isArray(value)?value:[],args);});};});// Map minified method names to their real names.
    	baseForOwn(LazyWrapper.prototype,function(func,methodName){var lodashFunc=lodash[methodName];if(lodashFunc){var key=lodashFunc.name+'';if(!hasOwnProperty.call(realNames,key)){realNames[key]=[];}realNames[key].push({'name':methodName,'func':lodashFunc});}});realNames[createHybrid(undefined$1,WRAP_BIND_KEY_FLAG).name]=[{'name':'wrapper','func':undefined$1}];// Add methods to `LazyWrapper`.
    	LazyWrapper.prototype.clone=lazyClone;LazyWrapper.prototype.reverse=lazyReverse;LazyWrapper.prototype.value=lazyValue;// Add chain sequence methods to the `lodash` wrapper.
    	lodash.prototype.at=wrapperAt;lodash.prototype.chain=wrapperChain;lodash.prototype.commit=wrapperCommit;lodash.prototype.next=wrapperNext;lodash.prototype.plant=wrapperPlant;lodash.prototype.reverse=wrapperReverse;lodash.prototype.toJSON=lodash.prototype.valueOf=lodash.prototype.value=wrapperValue;// Add lazy aliases.
    	lodash.prototype.first=lodash.prototype.head;if(symIterator){lodash.prototype[symIterator]=wrapperToIterator;}return lodash;};/*--------------------------------------------------------------------------*/ // Export lodash.
    	var _=runInContext();// Some AMD build optimizers, like r.js, check for condition patterns like:
    	if(freeModule){// Export for Node.js.
    	(freeModule.exports=_)._=_;// Export for CommonJS support.
    	freeExports._=_;}else {// Export to the global object.
    	root._=_;}}).call(commonjsGlobal);
    } (lodash, lodash.exports));

    var commonVariables$m = {
      fontFamily: 'v-sans, system-ui, -apple-system, BlinkMacSystemFont, "Segoe UI", sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"',
      fontFamilyMono: "v-mono, SFMono-Regular, Menlo, Consolas, Courier, monospace",
      fontWeight: "400",
      fontWeightStrong: "500",
      cubicBezierEaseInOut: "cubic-bezier(.4, 0, .2, 1)",
      cubicBezierEaseOut: "cubic-bezier(0, 0, .2, 1)",
      cubicBezierEaseIn: "cubic-bezier(.4, 0, 1, 1)",
      borderRadius: "3px",
      borderRadiusSmall: "2px",
      fontSize: "14px",
      fontSizeMini: "12px",
      fontSizeTiny: "12px",
      fontSizeSmall: "14px",
      fontSizeMedium: "14px",
      fontSizeLarge: "15px",
      fontSizeHuge: "16px",
      lineHeight: "1.6",
      heightMini: "16px",
      heightTiny: "22px",
      heightSmall: "28px",
      heightMedium: "34px",
      heightLarge: "40px",
      heightHuge: "46px"
    };

    const {
      fontSize,
      fontFamily,
      lineHeight: lineHeight$1
    } = commonVariables$m;
    var globalStyle = c$1("body", `
  margin: 0;
  font-size: ${fontSize};
  font-family: ${fontFamily};
  line-height: ${lineHeight$1};
  -webkit-text-size-adjust: 100%;
  -webkit-tap-highlight-color: transparent;
`, [c$1("input", `
    font-family: inherit;
    font-size: inherit;
  `)]);

    const configProviderInjectionKey = createInjectionKey("n-config-provider");

    const cssrAnchorMetaName = "naive-ui-style";

    function createTheme$1(theme) {
      return theme;
    }

    function useTheme(resolveId, mountId, style, defaultTheme, props, clsPrefixRef) {
      const ssrAdapter = useSsrAdapter();
      const NConfigProvider = vue.inject(configProviderInjectionKey, null);

      if (style) {
        const mountStyle = () => {
          const clsPrefix = clsPrefixRef === null || clsPrefixRef === void 0 ? void 0 : clsPrefixRef.value;
          style.mount({
            id: clsPrefix === void 0 ? mountId : clsPrefix + mountId,
            head: true,
            props: {
              bPrefix: clsPrefix ? `.${clsPrefix}-` : void 0
            },
            anchorMetaName: cssrAnchorMetaName,
            ssr: ssrAdapter
          });

          if (!(NConfigProvider !== null && NConfigProvider !== void 0 && NConfigProvider.preflightStyleDisabled)) {
            globalStyle.mount({
              id: "n-global",
              head: true,
              anchorMetaName: cssrAnchorMetaName,
              ssr: ssrAdapter
            });
          }
        };

        if (ssrAdapter) {
          mountStyle();
        } else {
          vue.onBeforeMount(mountStyle);
        }
      }

      const mergedThemeRef = vue.computed(() => {
        var _ref;

        const {
          theme: {
            common: selfCommon,
            self,
            peers = {}
          } = {},
          themeOverrides: selfOverrides = {},
          builtinThemeOverrides: builtinOverrides = {}
        } = props;
        const {
          common: selfCommonOverrides,
          peers: peersOverrides
        } = selfOverrides;
        const {
          common: globalCommon = void 0,
          [resolveId]: {
            common: globalSelfCommon = void 0,
            self: globalSelf = void 0,
            peers: globalPeers = {}
          } = {}
        } = (NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.mergedThemeRef.value) || {};
        const {
          common: globalCommonOverrides = void 0,
          [resolveId]: globalSelfOverrides = {}
        } = (NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.mergedThemeOverridesRef.value) || {};
        const {
          common: globalSelfCommonOverrides,
          peers: globalPeersOverrides = {}
        } = globalSelfOverrides;
        const mergedCommon = lodash.exports.merge({}, selfCommon || globalSelfCommon || globalCommon || defaultTheme.common, globalCommonOverrides, globalSelfCommonOverrides, selfCommonOverrides);
        const mergedSelf = lodash.exports.merge((_ref = self || globalSelf || defaultTheme.self) === null || _ref === void 0 ? void 0 : _ref(mergedCommon), builtinOverrides, globalSelfOverrides, selfOverrides);
        return {
          common: mergedCommon,
          self: mergedSelf,
          peers: lodash.exports.merge({}, defaultTheme.peers, globalPeers, peers),
          peerOverrides: lodash.exports.merge({}, builtinOverrides.peers, globalPeersOverrides, peersOverrides)
        };
      });
      return mergedThemeRef;
    }

    useTheme.props = {
      theme: Object,
      themeOverrides: Object,
      builtinThemeOverrides: Object
    };

    const defaultClsPrefix = "n";
    function useConfig() {
      let props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {
        defaultBordered: true
      };
      const NConfigProvider = vue.inject(configProviderInjectionKey, null);
      return {
        inlineThemeDisabled: NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.inlineThemeDisabled,
        mergedRtlRef: NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.mergedRtlRef,
        mergedComponentPropsRef: NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.mergedComponentPropsRef,
        mergedBreakpointsRef: NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.mergedBreakpointsRef,
        mergedBorderedRef: vue.computed(() => {
          const {
            bordered
          } = props;
          if (bordered !== void 0) return bordered;
          return (NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.mergedBorderedRef.value) ?? options.defaultBordered ?? true;
        }),
        mergedClsPrefixRef: vue.computed(() => {
          const clsPrefix = NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.mergedClsPrefixRef.value;
          return clsPrefix || defaultClsPrefix;
        }),
        namespaceRef: vue.computed(() => NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.mergedNamespaceRef.value)
      };
    }

    const zhCN = {
      name: "zh-CN",
      global: {
        undo: "\u64A4\u9500",
        redo: "\u91CD\u505A",
        confirm: "\u786E\u8BA4"
      },
      Popconfirm: {
        positiveText: "\u786E\u8BA4",
        negativeText: "\u53D6\u6D88"
      },
      Cascader: {
        placeholder: "\u8BF7\u9009\u62E9",
        loading: "\u52A0\u8F7D\u4E2D",
        loadingRequiredMessage: label => `\u52A0\u8F7D\u5168\u90E8 ${label} \u7684\u5B50\u8282\u70B9\u540E\u624D\u53EF\u9009\u4E2D`
      },
      Time: {
        dateFormat: "yyyy-MM-dd",
        dateTimeFormat: "yyyy-MM-dd HH:mm:ss"
      },
      DatePicker: {
        yearFormat: "yyyy\u5E74",
        monthFormat: "MMM",
        dayFormat: "eeeeee",
        yearTypeFormat: "yyyy",
        monthTypeFormat: "yyyy-MM",
        dateFormat: "yyyy-MM-dd",
        dateTimeFormat: "yyyy-MM-dd HH:mm:ss",
        quarterFormat: "yyyy-qqq",
        clear: "\u6E05\u9664",
        now: "\u6B64\u523B",
        confirm: "\u786E\u8BA4",
        selectTime: "\u9009\u62E9\u65F6\u95F4",
        selectDate: "\u9009\u62E9\u65E5\u671F",
        datePlaceholder: "\u9009\u62E9\u65E5\u671F",
        datetimePlaceholder: "\u9009\u62E9\u65E5\u671F\u65F6\u95F4",
        monthPlaceholder: "\u9009\u62E9\u6708\u4EFD",
        yearPlaceholder: "\u9009\u62E9\u5E74\u4EFD",
        quarterPlaceholder: "\u9009\u62E9\u5B63\u5EA6",
        startDatePlaceholder: "\u5F00\u59CB\u65E5\u671F",
        endDatePlaceholder: "\u7ED3\u675F\u65E5\u671F",
        startDatetimePlaceholder: "\u5F00\u59CB\u65E5\u671F\u65F6\u95F4",
        endDatetimePlaceholder: "\u7ED3\u675F\u65E5\u671F\u65F6\u95F4",
        startMonthPlaceholder: "\u5F00\u59CB\u6708\u4EFD",
        endMonthPlaceholder: "\u7ED3\u675F\u6708\u4EFD",
        monthBeforeYear: false,
        firstDayOfWeek: 0,
        today: "\u4ECA\u5929"
      },
      DataTable: {
        checkTableAll: "\u9009\u62E9\u5168\u90E8\u8868\u683C\u6570\u636E",
        uncheckTableAll: "\u53D6\u6D88\u9009\u62E9\u5168\u90E8\u8868\u683C\u6570\u636E",
        confirm: "\u786E\u8BA4",
        clear: "\u91CD\u7F6E"
      },
      LegacyTransfer: {
        sourceTitle: "\u6E90\u9879",
        targetTitle: "\u76EE\u6807\u9879"
      },
      Transfer: {
        selectAll: "\u5168\u9009",
        clearAll: "\u6E05\u9664",
        unselectAll: "\u53D6\u6D88\u5168\u9009",
        total: num => `\u5171 ${num} \u9879`,
        selected: num => `\u5DF2\u9009 ${num} \u9879`
      },
      Empty: {
        description: "\u65E0\u6570\u636E"
      },
      Select: {
        placeholder: "\u8BF7\u9009\u62E9"
      },
      TimePicker: {
        placeholder: "\u8BF7\u9009\u62E9\u65F6\u95F4",
        positiveText: "\u786E\u8BA4",
        negativeText: "\u53D6\u6D88",
        now: "\u6B64\u523B"
      },
      Pagination: {
        goto: "\u8DF3\u81F3",
        selectionSuffix: "\u9875"
      },
      DynamicTags: {
        add: "\u6DFB\u52A0"
      },
      Log: {
        loading: "\u52A0\u8F7D\u4E2D"
      },
      Input: {
        placeholder: "\u8BF7\u8F93\u5165"
      },
      InputNumber: {
        placeholder: "\u8BF7\u8F93\u5165"
      },
      DynamicInput: {
        create: "\u6DFB\u52A0"
      },
      ThemeEditor: {
        title: "\u4E3B\u9898\u7F16\u8F91\u5668",
        clearAllVars: "\u6E05\u9664\u5168\u90E8\u53D8\u91CF",
        clearSearch: "\u6E05\u9664\u641C\u7D22",
        filterCompName: "\u8FC7\u6EE4\u7EC4\u4EF6\u540D",
        filterVarName: "\u8FC7\u6EE4\u53D8\u91CF\u540D",
        import: "\u5BFC\u5165",
        export: "\u5BFC\u51FA",
        restore: "\u6062\u590D\u9ED8\u8BA4"
      },
      Image: {
        tipPrevious: "\u4E0A\u4E00\u5F20\uFF08\u2190\uFF09",
        tipNext: "\u4E0B\u4E00\u5F20\uFF08\u2192\uFF09",
        tipCounterclockwise: "\u5411\u5DE6\u65CB\u8F6C",
        tipClockwise: "\u5411\u53F3\u65CB\u8F6C",
        tipZoomOut: "\u7F29\u5C0F",
        tipZoomIn: "\u653E\u5927",
        tipClose: "\u5173\u95ED\uFF08Esc\uFF09",
        tipOriginalSize: "\u7F29\u653E\u5230\u539F\u59CB\u5C3A\u5BF8"
      }
    };
    var zhCN$1 = zhCN;

    const zhTW = {
      name: "zh-TW",
      global: {
        undo: "\u64A4\u92B7",
        redo: "\u91CD\u505A",
        confirm: "\u78BA\u8A8D"
      },
      Popconfirm: {
        positiveText: "\u78BA\u8A8D",
        negativeText: "\u53D6\u6D88"
      },
      Cascader: {
        placeholder: "\u8ACB\u9078\u64C7",
        loading: "\u8F09\u5165\u4E2D",
        loadingRequiredMessage: label => `\u8F09\u5165\u5168\u90E8 ${label} \u7684\u5B50\u7BC0\u9EDE\u5F8C\u624D\u53EF\u9078\u4E2D`
      },
      Time: {
        dateFormat: "yyyy-MM-dd",
        dateTimeFormat: "yyyy-MM-dd HH:mm:ss"
      },
      DatePicker: {
        yearFormat: "yyyy\u5E74",
        monthFormat: "MMM",
        dayFormat: "eeeeee",
        yearTypeFormat: "yyyy",
        monthTypeFormat: "yyyy-MM",
        dateFormat: "yyyy-MM-dd",
        dateTimeFormat: "yyyy-MM-dd HH:mm:ss",
        quarterFormat: "yyyy-qqq",
        clear: "\u6E05\u9664",
        now: "\u6B64\u523B",
        confirm: "\u78BA\u8A8D",
        selectTime: "\u9078\u64C7\u6642\u9593",
        selectDate: "\u9078\u64C7\u65E5\u671F",
        datePlaceholder: "\u9078\u64C7\u65E5\u671F",
        datetimePlaceholder: "\u9078\u64C7\u65E5\u671F\u6642\u9593",
        monthPlaceholder: "\u9078\u64C7\u6708\u4EFD",
        yearPlaceholder: "\u9078\u64C7\u5E74\u4EFD",
        quarterPlaceholder: "\u9078\u64C7\u5B63\u5EA6",
        startDatePlaceholder: "\u958B\u59CB\u65E5\u671F",
        endDatePlaceholder: "\u7D50\u675F\u65E5\u671F",
        startDatetimePlaceholder: "\u958B\u59CB\u65E5\u671F\u6642\u9593",
        endDatetimePlaceholder: "\u7D50\u675F\u65E5\u671F\u6642\u9593",
        startMonthPlaceholder: "\u958B\u59CB\u6708\u4EFD",
        endMonthPlaceholder: "\u7D50\u675F\u6708\u4EFD",
        monthBeforeYear: false,
        firstDayOfWeek: 0,
        today: "\u4ECA\u5929"
      },
      DataTable: {
        checkTableAll: "\u9078\u64C7\u5168\u90E8\u8868\u683C\u8CC7\u6599",
        uncheckTableAll: "\u53D6\u6D88\u9078\u64C7\u5168\u90E8\u8868\u683C\u8CC7\u6599",
        confirm: "\u78BA\u8A8D",
        clear: "\u91CD\u7F6E"
      },
      LegacyTransfer: {
        sourceTitle: "\u6E90\u9805",
        targetTitle: "\u76EE\u6A19\u9805"
      },
      Transfer: {
        selectAll: "\u5168\u9009",
        unselectAll: "\u53D6\u6D88\u5168\u9009",
        clearAll: "\u6E05\u9664",
        total: num => `\u5171 ${num} \u9805`,
        selected: num => `\u5DF2\u9078 ${num} \u9805`
      },
      Empty: {
        description: "\u7121\u6578\u64DA"
      },
      Select: {
        placeholder: "\u8ACB\u9078\u64C7"
      },
      TimePicker: {
        placeholder: "\u8ACB\u9078\u64C7\u6642\u9593",
        positiveText: "\u78BA\u8A8D",
        negativeText: "\u53D6\u6D88",
        now: "\u6B64\u523B"
      },
      Pagination: {
        goto: "\u8DF3\u81F3",
        selectionSuffix: "\u9801"
      },
      DynamicTags: {
        add: "\u6DFB\u52A0"
      },
      Log: {
        loading: "\u8F09\u5165\u4E2D"
      },
      Input: {
        placeholder: "\u8ACB\u8F38\u5165"
      },
      InputNumber: {
        placeholder: "\u8ACB\u8F38\u5165"
      },
      DynamicInput: {
        create: "\u6DFB\u52A0"
      },
      ThemeEditor: {
        title: "\u4E3B\u984C\u7DE8\u8F2F\u5668",
        clearAllVars: "\u6E05\u9664\u5168\u90E8\u8B8A\u6578",
        clearSearch: "\u6E05\u9664\u641C\u7D22",
        filterCompName: "\u904E\u6FFE\u7D44\u4EF6\u540D",
        filterVarName: "\u904E\u6FFE\u8B8A\u6578\u540D",
        import: "\u5C0E\u5165",
        export: "\u532F\u51FA",
        restore: "\u6062\u5FA9\u9ED8\u8A8D"
      },
      Image: {
        tipPrevious: "\u4E0A\u4E00\u5F20\uFF08\u2190\uFF09",
        tipNext: "\u4E0B\u4E00\u5F20\uFF08\u2192\uFF09",
        tipCounterclockwise: "\u5411\u5DE6\u65CB\u8F6C",
        tipClockwise: "\u5411\u53F3\u65CB\u8F6C",
        tipZoomOut: "\u7F29\u5C0F",
        tipZoomIn: "\u653E\u5927",
        tipClose: "\u5173\u95ED\uFF08Esc\uFF09",
        tipOriginalSize: "\u7F29\u653E\u5230\u539F\u59CB\u5C3A\u5BF8"
      }
    };
    var zhTW$1 = zhTW;

    const enUS$1 = {
      name: "en-US",
      global: {
        undo: "Undo",
        redo: "Redo",
        confirm: "Confirm"
      },
      Popconfirm: {
        positiveText: "Confirm",
        negativeText: "Cancel"
      },
      Cascader: {
        placeholder: "Please Select",
        loading: "Loading",
        loadingRequiredMessage: label => `Please load all ${label}'s descendants before checking it.`
      },
      Time: {
        dateFormat: "yyyy-MM-dd",
        dateTimeFormat: "yyyy-MM-dd HH:mm:ss"
      },
      DatePicker: {
        yearFormat: "yyyy",
        monthFormat: "MMM",
        dayFormat: "eeeeee",
        yearTypeFormat: "yyyy",
        monthTypeFormat: "yyyy-MM",
        dateFormat: "yyyy-MM-dd",
        dateTimeFormat: "yyyy-MM-dd HH:mm:ss",
        quarterFormat: "yyyy-qqq",
        clear: "Clear",
        now: "Now",
        confirm: "Confirm",
        selectTime: "Select Time",
        selectDate: "Select Date",
        datePlaceholder: "Select Date",
        datetimePlaceholder: "Select Date and Time",
        monthPlaceholder: "Select Month",
        yearPlaceholder: "Select Year",
        quarterPlaceholder: "Select Quarter",
        startDatePlaceholder: "Start Date",
        endDatePlaceholder: "End Date",
        startDatetimePlaceholder: "Start Date and Time",
        endDatetimePlaceholder: "End Date and Time",
        startMonthPlaceholder: "Start Month",
        endMonthPlaceholder: "End Month",
        monthBeforeYear: true,
        firstDayOfWeek: 6,
        today: "Today"
      },
      DataTable: {
        checkTableAll: "Select all in the table",
        uncheckTableAll: "Unselect all in the table",
        confirm: "Confirm",
        clear: "Clear"
      },
      LegacyTransfer: {
        sourceTitle: "Source",
        targetTitle: "Target"
      },
      Transfer: {
        selectAll: "Select all",
        unselectAll: "Unselect all",
        clearAll: "Clear",
        total: num => `Total ${num} items`,
        selected: num => `${num} items selected`
      },
      Empty: {
        description: "No Data"
      },
      Select: {
        placeholder: "Please Select"
      },
      TimePicker: {
        placeholder: "Select Time",
        positiveText: "OK",
        negativeText: "Cancel",
        now: "Now"
      },
      Pagination: {
        goto: "Goto",
        selectionSuffix: "page"
      },
      DynamicTags: {
        add: "Add"
      },
      Log: {
        loading: "Loading"
      },
      Input: {
        placeholder: "Please Input"
      },
      InputNumber: {
        placeholder: "Please Input"
      },
      DynamicInput: {
        create: "Create"
      },
      ThemeEditor: {
        title: "Theme Editor",
        clearAllVars: "Clear All Variables",
        clearSearch: "Clear Search",
        filterCompName: "Filter Component Name",
        filterVarName: "Filter Variable Name",
        import: "Import",
        export: "Export",
        restore: "Reset to Default"
      },
      Image: {
        tipPrevious: "Previous picture (\u2190)",
        tipNext: "Next picture (\u2192)",
        tipCounterclockwise: "Counterclockwise",
        tipClockwise: "Clockwise",
        tipZoomOut: "Zoom out",
        tipZoomIn: "Zoom in",
        tipClose: "Close (Esc)",
        tipOriginalSize: "Zoom to original size"
      }
    };
    var enUS$2 = enUS$1;

    const ruRu = {
      name: "ru-RU",
      global: {
        undo: "\u041E\u0442\u043C\u0435\u043D\u0438\u0442\u044C",
        redo: "\u0412\u0435\u0440\u043D\u0443\u0442\u044C",
        confirm: "\u041F\u043E\u0434\u0442\u0432\u0435\u0440\u0434\u0438\u0442\u044C"
      },
      Popconfirm: {
        positiveText: "\u041F\u043E\u0434\u0442\u0432\u0435\u0440\u0434\u0438\u0442\u044C",
        negativeText: "\u041E\u0442\u043C\u0435\u043D\u0430"
      },
      Cascader: {
        placeholder: "\u0412\u044B\u0431\u0440\u0430\u0442\u044C",
        loading: "\u0417\u0430\u0433\u0440\u0443\u0437\u043A\u0430",
        loadingRequiredMessage: label => `\u0417\u0430\u0433\u0440\u0443\u0437\u0438\u0442\u0435 \u0432\u0441\u0435 \u0434\u043E\u0447\u0435\u0440\u043D\u0438\u0435 \u0443\u0437\u043B\u044B ${label} \u043F\u0440\u0435\u0436\u0434\u0435 \u0447\u0435\u043C \u043E\u043D\u0438 \u0441\u0442\u0430\u043D\u0443\u0442 \u043D\u0435\u043E\u0431\u044F\u0437\u0430\u0442\u0435\u043B\u044C\u043D\u044B\u043C\u0438`
      },
      Time: {
        dateFormat: "yyyy-MM-dd",
        dateTimeFormat: "yyyy-MM-dd HH:mm:ss"
      },
      DatePicker: {
        yearFormat: "yyyy",
        monthFormat: "MMM",
        dayFormat: "eeeeee",
        yearTypeFormat: "yyyy",
        monthTypeFormat: "yyyy-MM",
        dateFormat: "yyyy-MM-dd",
        dateTimeFormat: "yyyy-MM-dd HH:mm:ss",
        quarterFormat: "yyyy-qqq",
        clear: "\u041E\u0447\u0438\u0441\u0442\u0438\u0442\u044C",
        now: "\u0421\u0435\u0439\u0447\u0430\u0441",
        confirm: "\u041F\u043E\u0434\u0442\u0432\u0435\u0440\u0434\u0438\u0442\u044C",
        selectTime: "\u0412\u044B\u0431\u0440\u0430\u0442\u044C \u0432\u0440\u0435\u043C\u044F",
        selectDate: "\u0412\u044B\u0431\u0440\u0430\u0442\u044C \u0434\u0430\u0442\u0443",
        datePlaceholder: "\u0412\u044B\u0431\u0440\u0430\u0442\u044C \u0434\u0430\u0442\u0443",
        datetimePlaceholder: "\u0412\u044B\u0431\u0440\u0430\u0442\u044C \u0434\u0430\u0442\u0443 \u0438 \u0432\u0440\u0435\u043C\u044F",
        monthPlaceholder: "\u0412\u044B\u0431\u0435\u0440\u0438\u0442\u0435 \u043C\u0435\u0441\u044F\u0446",
        yearPlaceholder: "Select Year",
        quarterPlaceholder: "Select Quarter",
        startDatePlaceholder: "\u0414\u0430\u0442\u0430 \u043D\u0430\u0447\u0430\u043B\u0430",
        endDatePlaceholder: "\u0414\u0430\u0442\u0430 \u043E\u043A\u043E\u043D\u0447\u0430\u043D\u0438\u044F",
        startDatetimePlaceholder: "\u0414\u0430\u0442\u0430 \u0438 \u0432\u0440\u0435\u043C\u044F \u043D\u0430\u0447\u0430\u043B\u0430",
        endDatetimePlaceholder: "\u0414\u0430\u0442\u0430 \u0438 \u0432\u0440\u0435\u043C\u044F \u043E\u043A\u043E\u043D\u0447\u0430\u043D\u0438\u044F",
        startMonthPlaceholder: "Start Month",
        endMonthPlaceholder: "End Month",
        monthBeforeYear: true,
        firstDayOfWeek: 0,
        today: "\u0421\u0435\u0433\u043E\u0434\u043D\u044F"
      },
      DataTable: {
        checkTableAll: "\u0412\u044B\u0431\u0440\u0430\u0442\u044C \u0432\u0441\u0435 \u0432 \u0442\u0430\u0431\u043B\u0438\u0446\u0435",
        uncheckTableAll: "\u041E\u0442\u043C\u0435\u043D\u0438\u0442\u044C \u0432\u0441\u0435 \u0432 \u0442\u0430\u0431\u043B\u0438\u0446\u0435",
        confirm: "\u041F\u043E\u0434\u0442\u0432\u0435\u0440\u0434\u0438\u0442\u044C",
        clear: "\u041E\u0447\u0438\u0441\u0442\u0438\u0442\u044C"
      },
      LegacyTransfer: {
        sourceTitle: "\u0418\u0441\u0442\u043E\u0447\u043D\u0438\u043A",
        targetTitle: "\u041D\u0430\u0437\u043D\u0430\u0447\u0435\u043D\u0438\u0435"
      },
      Transfer: {
        selectAll: "Select all",
        unselectAll: "Unselect all",
        clearAll: "Clear",
        total: num => `Total ${num} items`,
        selected: num => `${num} items selected`
      },
      Empty: {
        description: "\u041D\u0435\u0442 \u0434\u0430\u043D\u043D\u044B\u0445"
      },
      Select: {
        placeholder: "\u0412\u044B\u0431\u0440\u0430\u0442\u044C"
      },
      TimePicker: {
        placeholder: "\u0412\u044B\u0431\u0440\u0430\u0442\u044C \u0432\u0440\u0435\u043C\u044F",
        positiveText: "OK",
        negativeText: "\u041E\u0442\u043C\u0435\u043D\u0438\u0442\u044C",
        now: "\u0421\u0435\u0439\u0447\u0430\u0441"
      },
      Pagination: {
        goto: "\u041F\u0435\u0440\u0435\u0439\u0442\u0438",
        selectionSuffix: "\u0441\u0442\u0440\u0430\u043D\u0438\u0446\u0430"
      },
      DynamicTags: {
        add: "\u0414\u043E\u0431\u0430\u0432\u0438\u0442\u044C"
      },
      Log: {
        loading: "\u0417\u0430\u0433\u0440\u0443\u0437\u043A\u0430"
      },
      Input: {
        placeholder: "\u0412\u0432\u0435\u0441\u0442\u0438"
      },
      InputNumber: {
        placeholder: "\u0412\u0432\u0435\u0441\u0442\u0438"
      },
      DynamicInput: {
        create: "\u0421\u043E\u0437\u0434\u0430\u0442\u044C"
      },
      ThemeEditor: {
        title: "\u0420\u0435\u0434\u0430\u043A\u0442\u043E\u0440 \u0442\u0435\u043C\u044B",
        clearAllVars: "\u041E\u0447\u0438\u0441\u0442\u0438\u0442\u044C \u0432\u0441\u0435",
        clearSearch: "\u041E\u0447\u0438\u0441\u0442\u0438\u0442\u044C \u043F\u043E\u0438\u0441\u043A",
        filterCompName: "\u0424\u0438\u043B\u044C\u0442\u0440\u043E\u0432\u0430\u0442\u044C \u043F\u043E \u0438\u043C\u0435\u043D\u0438 \u043A\u043E\u043C\u043F\u043E\u043D\u0435\u043D\u0442\u0430",
        filterVarName: "\u0424\u0438\u043B\u044C\u0442\u0440\u043E\u0432\u0430\u0442\u044C \u0438\u043C\u0435\u043D\u0430 \u043F\u0435\u0440\u0435\u043C\u0435\u043D\u043D\u044B\u0445",
        import: "\u0418\u043C\u043F\u043E\u0440\u0442",
        export: "\u042D\u043A\u0441\u043F\u043E\u0440\u0442",
        restore: "\u0421\u0431\u0440\u043E\u0441\u0438\u0442\u044C"
      },
      Image: {
        tipPrevious: "Previous picture (\u2190)",
        tipNext: "Next picture (\u2192)",
        tipCounterclockwise: "Counterclockwise",
        tipClockwise: "Clockwise",
        tipZoomOut: "Zoom out",
        tipZoomIn: "Zoom in",
        tipClose: "Close (Esc)",
        tipOriginalSize: "Zoom to original size"
      }
    };
    var ruRu$1 = ruRu;

    const ukUA = {
      name: "uk-UA",
      global: {
        undo: "\u0412\u0456\u0434\u043C\u0456\u043D\u0438\u0442\u0438",
        redo: "\u041F\u043E\u0432\u0442\u043E\u0440\u0438\u0442\u0438",
        confirm: "\u041F\u0456\u0434\u0442\u0432\u0435\u0440\u0434\u0438\u0442\u0438"
      },
      Popconfirm: {
        positiveText: "\u041F\u0456\u0434\u0442\u0432\u0435\u0440\u0434\u0438\u0442\u0438",
        negativeText: "\u0421\u043A\u0430\u0441\u0443\u0432\u0430\u0442\u0438"
      },
      Cascader: {
        placeholder: "\u041E\u0431\u0440\u0430\u0442\u0438",
        loading: "\u0417\u0430\u0432\u0430\u043D\u0442\u0430\u0436\u0435\u043D\u043D\u044F",
        loadingRequiredMessage: label => `\u0417\u0430\u0432\u0430\u043D\u0442\u0430\u0436\u0442\u0435 \u0432\u0441\u0456 \u0434\u043E\u0447\u0456\u0440\u043D\u0456 \u0432\u0443\u0437\u043B\u0438 ${label} \u043F\u0435\u0440\u0435\u0434 \u043F\u0435\u0440\u0435\u0432\u0456\u0440\u043A\u043E\u044E`
      },
      Time: {
        dateFormat: "yyyy-MM-dd",
        dateTimeFormat: "yyyy-MM-dd HH:mm:ss"
      },
      DatePicker: {
        yearFormat: "yyyy",
        monthFormat: "MMM",
        dayFormat: "eeeeee",
        yearTypeFormat: "yyyy",
        monthTypeFormat: "yyyy-MM",
        dateFormat: "yyyy-MM-dd",
        dateTimeFormat: "yyyy-MM-dd HH:mm:ss",
        quarterFormat: "yyyy-qqq",
        clear: "\u0421\u0442\u0435\u0440\u0442\u0438",
        now: "\u0417\u0430\u0440\u0430\u0437",
        confirm: "\u041F\u0456\u0434\u0442\u0432\u0435\u0440\u0434\u0438\u0442\u0438",
        selectTime: "\u041E\u0431\u0440\u0430\u0442\u0438 \u0447\u0430\u0441",
        selectDate: "\u041E\u0431\u0440\u0430\u0442\u0438 \u0434\u0430\u0442\u0443",
        datePlaceholder: "\u041E\u0431\u0440\u0430\u0442\u0438 \u0434\u0430\u0442\u0443",
        datetimePlaceholder: "\u041E\u0431\u0440\u0430\u0442\u0438 \u0434\u0430\u0442\u0443 \u0456 \u0447\u0430\u0441",
        monthPlaceholder: "\u041E\u0431\u0435\u0440\u0456\u0442\u044C \u043C\u0456\u0441\u044F\u0446\u044C",
        yearPlaceholder: "\u041E\u0431\u0435\u0440\u0456\u0442\u044C \u0440\u0456\u043A",
        quarterPlaceholder: "\u041E\u0431\u0435\u0440\u0456\u0442\u044C \u043A\u0432\u0430\u0440\u0442\u0430\u043B",
        startDatePlaceholder: "\u0414\u0430\u0442\u0430 \u043F\u043E\u0447\u0430\u0442\u043A\u0443",
        endDatePlaceholder: "\u0414\u0430\u0442\u0430 \u0437\u0430\u0432\u0435\u0440\u0448\u0435\u043D\u043D\u044F",
        startDatetimePlaceholder: "\u0414\u0430\u0442\u0430 \u0456 \u0447\u0430\u0441 \u043F\u043E\u0447\u0430\u0442\u043A\u0443",
        endDatetimePlaceholder: "\u0414\u0430\u0442\u0430 \u0456 \u0447\u0430\u0441 \u0437\u0430\u0432\u0435\u0440\u0448\u0435\u043D\u043D\u044F",
        startMonthPlaceholder: "\u041F\u0435\u0440\u0448\u0438\u0439 \u043C\u0456\u0441\u044F\u0446\u044C",
        endMonthPlaceholder: "\u041E\u0441\u0442\u0430\u043D\u043D\u0456\u0439 \u043C\u0456\u0441\u044F\u0446\u044C",
        monthBeforeYear: true,
        firstDayOfWeek: 0,
        today: "\u0421\u044C\u043E\u0433\u043E\u0434\u043D\u0456"
      },
      DataTable: {
        checkTableAll: "\u041E\u0431\u0440\u0430\u0442\u0438 \u0432\u0441\u0435 \u0432 \u0442\u0430\u0431\u043B\u0438\u0446\u0456",
        uncheckTableAll: "\u0421\u043A\u0430\u0441\u0443\u0432\u0430\u0442\u0438 \u0432\u0438\u0431\u0456\u0440 \u0443\u0441\u044C\u043E\u0433\u043E \u0432 \u0442\u0430\u0431\u043B\u0438\u0446\u0456",
        confirm: "\u041F\u0456\u0434\u0442\u0432\u0435\u0440\u0434\u0438\u0442\u0438",
        clear: "\u0421\u0442\u0435\u0440\u0442\u0438"
      },
      LegacyTransfer: {
        sourceTitle: "\u0414\u0436\u0435\u0440\u0435\u043B\u043E",
        targetTitle: "\u0426\u0456\u043B\u044C"
      },
      Transfer: {
        selectAll: "Select all",
        unselectAll: "Unselect all",
        clearAll: "Clear",
        total: num => `Total ${num} items`,
        selected: num => `${num} items selected`
      },
      Empty: {
        description: "\u041D\u0435\u043C\u0430\u0454 \u0434\u0430\u043D\u0438\u0445"
      },
      Select: {
        placeholder: "\u041E\u0431\u0440\u0430\u0442\u0438"
      },
      TimePicker: {
        placeholder: "\u041E\u0431\u0440\u0430\u0442\u0438 \u0447\u0430\u0441",
        positiveText: "OK",
        negativeText: "\u0421\u043A\u0430\u0441\u0443\u0432\u0430\u0442\u0438",
        now: "\u0417\u0430\u0440\u0430\u0437"
      },
      Pagination: {
        goto: "\u041F\u0435\u0440\u0435\u0439\u0442\u0438",
        selectionSuffix: "\u0441\u0442\u043E\u0440\u0456\u043D\u043A\u0430"
      },
      DynamicTags: {
        add: "\u0414\u043E\u0434\u0430\u0442\u0438"
      },
      Log: {
        loading: "\u0417\u0430\u0432\u0430\u043D\u0442\u0430\u0436\u0435\u043D\u043D\u044F"
      },
      Input: {
        placeholder: "\u0412\u0432\u0435\u0441\u0442\u0438"
      },
      InputNumber: {
        placeholder: "\u0412\u0432\u0435\u0441\u0442\u0438"
      },
      DynamicInput: {
        create: "\u0421\u0442\u0432\u043E\u0440\u0438\u0442\u0438"
      },
      ThemeEditor: {
        title: "\u0420\u0435\u0434\u0430\u043A\u0442\u043E\u0440 \u0442\u0435\u043C\u0438",
        clearAllVars: "\u0421\u0442\u0435\u0440\u0442\u0438 \u0432\u0441\u0435",
        clearSearch: "\u041E\u0447\u0438\u0441\u0442\u0438\u0442\u0438 \u043F\u043E\u0448\u0443\u043A",
        filterCompName: "\u0424\u0456\u043B\u044C\u0442\u0440\u0443\u0432\u0430\u0442\u0438 \u0437\u0430 \u0456\u043C\u0435\u043D\u0435\u043C \u043A\u043E\u043C\u043F\u043E\u043D\u0435\u043D\u0442\u0430",
        filterVarName: "\u0424\u0456\u043B\u044C\u0442\u0440\u0443\u0432\u0430\u0442\u0438 \u0456\u043C\u0435\u043D\u0430 \u0437\u043C\u0456\u043D\u043D\u0438\u0445",
        import: "\u0406\u043C\u043F\u043E\u0440\u0442",
        export: "\u0415\u043A\u0441\u043F\u043E\u0440\u0442",
        restore: "\u0421\u043A\u0438\u043D\u0443\u0442\u0438"
      },
      Image: {
        tipPrevious: "\u041F\u043E\u043F\u0435\u0440\u0435\u0434\u043D\u0454 \u0437\u043E\u0431\u0440\u0430\u0436\u0435\u043D\u043D\u044F (\u2190)",
        tipNext: "\u041D\u0430\u0441\u0442\u0443\u043F\u043D\u0435 \u0437\u043E\u0431\u0440\u0430\u0436\u0435\u043D\u043D\u044F (\u2192)",
        tipCounterclockwise: "\u041F\u0440\u043E\u0442\u0438 \u0433\u043E\u0434\u0438\u043D\u043D\u0438\u043A\u043E\u0432\u043E\u0457 \u0441\u0442\u0440\u0456\u043B\u043A\u0438",
        tipClockwise: "\u0417\u0430 \u0433\u043E\u0434\u0438\u043D\u043D\u0438\u043A\u043E\u0432\u043E\u044E \u0441\u0442\u0440\u0456\u043B\u043A\u043E\u044E",
        tipZoomOut: "\u0412\u0456\u0434\u0434\u0430\u043B\u0438\u0442\u0438",
        tipZoomIn: "\u041D\u0430\u0431\u043B\u0438\u0437\u0438\u0442\u0438",
        tipClose: "\u0417\u0430\u043A\u0440\u0438\u0442\u0438 (Esc)",
        tipOriginalSize: "\u041C\u0430\u0441\u0448\u0442\u0430\u0431\u0443\u0432\u0430\u0442\u0438 \u0434\u043E \u043E\u0440\u0438\u0433\u0456\u043D\u0430\u043B\u044C\u043D\u043E\u0433\u043E \u0440\u043E\u0437\u043C\u0456\u0440\u0443"
      }
    };
    var ukUA$1 = ukUA;

    const jaJP = {
      name: "ja-JP",
      global: {
        undo: "\u5143\u306B\u623B\u3059",
        redo: "\u3084\u308A\u76F4\u3059",
        confirm: "OK"
      },
      Popconfirm: {
        positiveText: "OK",
        negativeText: "\u30AD\u30E3\u30F3\u30BB\u30EB"
      },
      Cascader: {
        placeholder: "\u9078\u629E\u3057\u3066\u304F\u3060\u3055\u3044",
        loading: "\u30ED\u30FC\u30C9\u4E2D",
        loadingRequiredMessage: label => `\u3059\u3079\u3066\u306E ${label} \u30B5\u30D6\u30CE\u30FC\u30C9\u3092\u30ED\u30FC\u30C9\u3057\u3066\u304B\u3089\u9078\u629E\u3067\u304D\u307E\u3059\u3002`
      },
      Time: {
        dateFormat: "yyyy-MM-dd",
        dateTimeFormat: "yyyy-MM-dd HH:mm:ss"
      },
      DatePicker: {
        yearFormat: "yyyy\u5E74",
        monthFormat: "MMM",
        dayFormat: "eeeeee",
        yearTypeFormat: "yyyy",
        monthTypeFormat: "yyyy-MM",
        dateFormat: "yyyy-MM-dd",
        dateTimeFormat: "yyyy-MM-dd HH:mm:ss",
        quarterFormat: "yyyy-qqq",
        clear: "\u30AF\u30EA\u30A2",
        now: "\u73FE\u5728",
        confirm: "OK",
        selectTime: "\u6642\u9593\u3092\u9078\u629E",
        selectDate: "\u65E5\u4ED8\u3092\u9078\u629E",
        datePlaceholder: "\u65E5\u4ED8\u3092\u9078\u629E",
        datetimePlaceholder: "\u9078\u629E",
        monthPlaceholder: "\u6708\u3092\u9078\u629E",
        yearPlaceholder: "\u5E74\u3092\u9078\u629E",
        quarterPlaceholder: "\u56DB\u534A\u671F\u3092\u9078\u629E",
        startDatePlaceholder: "\u958B\u59CB\u65E5",
        endDatePlaceholder: "\u7D42\u4E86\u65E5",
        startDatetimePlaceholder: "\u958B\u59CB\u6642\u9593",
        endDatetimePlaceholder: "\u7D42\u4E86\u6642\u9593",
        startMonthPlaceholder: "Start Month",
        endMonthPlaceholder: "End Month",
        monthBeforeYear: false,
        firstDayOfWeek: 0,
        today: "\u4ECA\u65E5"
      },
      DataTable: {
        checkTableAll: "\u5168\u9078\u629E",
        uncheckTableAll: "\u5168\u9078\u629E\u53D6\u6D88",
        confirm: "OK",
        clear: "\u30EA\u30BB\u30C3\u30C8"
      },
      LegacyTransfer: {
        sourceTitle: "\u5143",
        targetTitle: "\u5148"
      },
      Transfer: {
        selectAll: "Select all",
        unselectAll: "Unselect all",
        clearAll: "Clear",
        total: num => `Total ${num} items`,
        selected: num => `${num} items selected`
      },
      Empty: {
        description: "\u30C7\u30FC\u30BF\u306A\u3057"
      },
      Select: {
        placeholder: "\u9078\u629E\u3057\u3066\u304F\u3060\u3055\u3044"
      },
      TimePicker: {
        placeholder: "\u9078\u629E\u3057\u3066\u304F\u3060\u3055\u3044",
        positiveText: "OK",
        negativeText: "\u30AD\u30E3\u30F3\u30BB\u30EB",
        now: "\u73FE\u5728"
      },
      Pagination: {
        goto: "\u30DA\u30FC\u30B8\u30B8\u30E3\u30F3\u30D7",
        selectionSuffix: "\u30DA\u30FC\u30B8"
      },
      DynamicTags: {
        add: "\u8FFD\u52A0"
      },
      Log: {
        loading: "\u30ED\u30FC\u30C9\u4E2D"
      },
      Input: {
        placeholder: "\u5165\u529B\u3057\u3066\u304F\u3060\u3055\u3044"
      },
      InputNumber: {
        placeholder: "\u5165\u529B\u3057\u3066\u304F\u3060\u3055\u3044"
      },
      DynamicInput: {
        create: "\u8FFD\u52A0"
      },
      ThemeEditor: {
        title: "\u30C6\u30FC\u30DE\u30A8\u30C7\u30A3\u30BF",
        clearAllVars: "\u5168\u4EF6\u5909\u6570\u30AF\u30EA\u30A2",
        clearSearch: "\u691C\u7D22\u30AF\u30EA\u30A2",
        filterCompName: "\u30B3\u30F3\u30DD\u30CD\u30F3\u30C8\u540D\u3092\u30D5\u30A3\u30EB\u30BF",
        filterVarName: "\u5909\u6570\u3092\u30D5\u30A3\u30EB\u30BF",
        import: "\u30A4\u30F3\u30DD\u30FC\u30C8",
        export: "\u30A8\u30AF\u30B9\u30DD\u30FC\u30C8",
        restore: "\u30C7\u30D5\u30A9\u30EB\u30C8"
      },
      Image: {
        tipPrevious: "\u524D\u306E\u753B\u50CF (\u2190)",
        tipNext: "\u6B21\u306E\u753B\u50CF (\u2192)",
        tipCounterclockwise: "\u5DE6\u306B\u56DE\u8EE2",
        tipClockwise: "\u53F3\u306B\u56DE\u8EE2",
        tipZoomOut: "\u7E2E\u5C0F",
        tipZoomIn: "\u62E1\u5927",
        tipClose: "\u9589\u3058\u308B (Esc)",
        tipOriginalSize: "Zoom to original size"
      }
    };
    var jaJP$1 = jaJP;

    const koKR = {
      name: "ko-KR",
      global: {
        undo: "\uC2E4\uD589 \uCDE8\uC18C",
        redo: "\uB2E4\uC2DC \uC2E4\uD589",
        confirm: "\uD655\uC778"
      },
      Popconfirm: {
        positiveText: "\uD655\uC778",
        negativeText: "\uCDE8\uC18C"
      },
      Cascader: {
        placeholder: "\uC120\uD0DD\uD574 \uC8FC\uC138\uC694",
        loading: "\uBD88\uB7EC\uC624\uB294 \uC911",
        loadingRequiredMessage: label => `${label}\uC758 \uBAA8\uB4E0 \uD558\uC704 \uD56D\uBAA9\uC744 \uBD88\uB7EC\uC628 \uB4A4\uC5D0 \uC120\uD0DD\uD560 \uC218 \uC788\uC2B5\uB2C8\uB2E4.`
      },
      Time: {
        dateFormat: "yyyy-MM-dd",
        dateTimeFormat: "yyyy-MM-dd HH:mm:ss"
      },
      DatePicker: {
        yearFormat: "yyyy\uB144",
        monthFormat: "MMM",
        dayFormat: "eeeeee",
        yearTypeFormat: "yyyy",
        monthTypeFormat: "yyyy-MM",
        dateFormat: "yyyy-MM-dd",
        dateTimeFormat: "yyyy-MM-dd HH:mm:ss",
        quarterFormat: "yyyy-qqq",
        clear: "\uC9C0\uC6B0\uAE30",
        now: "\uD604\uC7AC",
        confirm: "\uD655\uC778",
        selectTime: "\uC2DC\uAC04 \uC120\uD0DD",
        selectDate: "\uB0A0\uC9DC \uC120\uD0DD",
        datePlaceholder: "\uB0A0\uC9DC \uC120\uD0DD",
        datetimePlaceholder: "\uB0A0\uC9DC \uBC0F \uC2DC\uAC04 \uC120\uD0DD",
        monthPlaceholder: "\uC6D4 \uC120\uD0DD",
        yearPlaceholder: "\uB144 \uC120\uD0DD",
        quarterPlaceholder: "\uBD84\uAE30 \uC120\uD0DD",
        startDatePlaceholder: "\uC2DC\uC791 \uB0A0\uC9DC",
        endDatePlaceholder: "\uC885\uB8CC \uB0A0\uC9DC",
        startDatetimePlaceholder: "\uC2DC\uC791 \uB0A0\uC9DC \uBC0F \uC2DC\uAC04",
        endDatetimePlaceholder: "\uC885\uB8CC \uB0A0\uC9DC \uBC0F \uC2DC\uAC04",
        startMonthPlaceholder: "Start Month",
        endMonthPlaceholder: "End Month",
        monthBeforeYear: false,
        firstDayOfWeek: 6,
        today: "\uC624\uB298"
      },
      DataTable: {
        checkTableAll: "\uBAA8\uB450 \uC120\uD0DD",
        uncheckTableAll: "\uBAA8\uB450 \uC120\uD0DD \uD574\uC81C",
        confirm: "\uD655\uC778",
        clear: "\uC9C0\uC6B0\uAE30"
      },
      LegacyTransfer: {
        sourceTitle: "\uC6D0\uBCF8",
        targetTitle: "\uD0C0\uAE43"
      },
      Transfer: {
        selectAll: "Select all",
        unselectAll: "Unselect all",
        clearAll: "Clear",
        total: num => `Total ${num} items`,
        selected: num => `${num} items selected`
      },
      Empty: {
        description: "\uB370\uC774\uD130 \uC5C6\uC74C"
      },
      Select: {
        placeholder: "\uC120\uD0DD\uD574 \uC8FC\uC138\uC694"
      },
      TimePicker: {
        placeholder: "\uC2DC\uAC04 \uC120\uD0DD",
        positiveText: "\uD655\uC778",
        negativeText: "\uCDE8\uC18C",
        now: "Now"
      },
      Pagination: {
        goto: "\uC774\uB3D9",
        selectionSuffix: "\uD398\uC774\uC9C0"
      },
      DynamicTags: {
        add: "\uCD94\uAC00"
      },
      Log: {
        loading: "\uBD88\uB7EC\uC624\uB294 \uC911"
      },
      Input: {
        placeholder: "\uC785\uB825\uD574 \uC8FC\uC138\uC694"
      },
      InputNumber: {
        placeholder: "\uC785\uB825\uD574 \uC8FC\uC138\uC694"
      },
      DynamicInput: {
        create: "\uCD94\uAC00"
      },
      ThemeEditor: {
        title: "\uD14C\uB9C8 \uD3B8\uC9D1\uAE30",
        clearAllVars: "\uBAA8\uB4E0 \uBCC0\uC218 \uC9C0\uC6B0\uAE30",
        clearSearch: "\uAC80\uC0C9 \uC9C0\uC6B0\uAE30",
        filterCompName: "\uAD6C\uC131 \uC694\uC18C \uC774\uB984 \uD544\uD130",
        filterVarName: "\uBCC0\uC218 \uC774\uB984 \uD544\uD130",
        import: "\uAC00\uC838\uC624\uAE30",
        export: "\uB0B4\uBCF4\uB0B4\uAE30",
        restore: "\uAE30\uBCF8\uC73C\uB85C \uC7AC\uC124\uC815"
      },
      Image: {
        tipPrevious: "\uC774\uC804 (\u2190)",
        tipNext: "\uB2E4\uC74C (\u2192)",
        tipCounterclockwise: "\uC2DC\uACC4 \uBC18\uB300 \uBC29\uD5A5\uC73C\uB85C \uD68C\uC804",
        tipClockwise: "\uC2DC\uACC4 \uBC29\uD5A5\uC73C\uB85C \uD68C\uC804",
        tipZoomOut: "\uCD95\uC18C",
        tipZoomIn: "\uD655\uB300",
        tipClose: "\uB2EB\uAE30 (Esc)",
        tipOriginalSize: "Zoom to original size"
      }
    };
    var koKR$1 = koKR;

    const idID = {
      name: "id-ID",
      global: {
        undo: "Membatalkan",
        redo: "Mem-perbarui",
        confirm: "Setuju"
      },
      Popconfirm: {
        positiveText: "Setuju",
        negativeText: "Batalkan"
      },
      Cascader: {
        placeholder: "Mohon Pilih",
        loading: "Memuat",
        loadingRequiredMessage: label => `Mohon muat semua ${label}'s turunan sebelum memeriksa.`
      },
      Time: {
        dateFormat: "dd-MM-yyyy",
        dateTimeFormat: "dd-MM-yyyy HH:mm:ss"
      },
      DatePicker: {
        yearFormat: "yyyy",
        monthFormat: "MMM",
        dayFormat: "eeeeee",
        yearTypeFormat: "yyyy",
        monthTypeFormat: "MM-yyyy",
        dateFormat: "dd-MM-yyyy",
        dateTimeFormat: "dd-MM-yyyy HH:mm:ss",
        quarterFormat: "yyyy-qqq",
        clear: "Bersihkan",
        now: "Sekarang",
        confirm: "Setuju",
        selectTime: "Pilih Waktu",
        selectDate: "Pilih Tanggal",
        datePlaceholder: "Pilih Tanggal",
        datetimePlaceholder: "Pilih Tanggal dan Waktu",
        monthPlaceholder: "Pilih Bulan",
        yearPlaceholder: "Select Year",
        quarterPlaceholder: "Select Quarter",
        startDatePlaceholder: "Tanggal Mulai",
        endDatePlaceholder: "Tanggal Selesai",
        startDatetimePlaceholder: "Tanggal dan Waktu Mulai",
        endDatetimePlaceholder: "Tanggal dan Waktu Selesai",
        startMonthPlaceholder: "Start Month",
        endMonthPlaceholder: "End Month",
        monthBeforeYear: true,
        firstDayOfWeek: 6,
        today: "Hari ini"
      },
      DataTable: {
        checkTableAll: "Pilih semua pada tabel",
        uncheckTableAll: "Batalkan pilihan semua",
        confirm: "Setuju",
        clear: "Bersihkan"
      },
      LegacyTransfer: {
        sourceTitle: "Sumber",
        targetTitle: "Tujuan"
      },
      Transfer: {
        selectAll: "Select all",
        unselectAll: "Unselect all",
        clearAll: "Clear",
        total: num => `Total ${num} items`,
        selected: num => `${num} items selected`
      },
      Empty: {
        description: "Tidak ada data"
      },
      Select: {
        placeholder: "Mohon Pilih"
      },
      TimePicker: {
        placeholder: "Pilih Waktu",
        positiveText: "OK",
        negativeText: "Batalkan",
        now: "Sekarang"
      },
      Pagination: {
        goto: "Ke",
        selectionSuffix: "halaman"
      },
      DynamicTags: {
        add: "Tambah"
      },
      Log: {
        loading: "Memuat"
      },
      Input: {
        placeholder: "Mohon isi"
      },
      InputNumber: {
        placeholder: "Mohon isi"
      },
      DynamicInput: {
        create: "Buat baru"
      },
      ThemeEditor: {
        title: "Tema editor",
        clearAllVars: "Bersihkan semua variabel",
        clearSearch: "Bersihkan pencarian",
        filterCompName: "Saring nama komponen",
        filterVarName: "Saring nama variabel",
        import: "Impor",
        export: "Ekspor",
        restore: "Setel ulang ke awal"
      },
      Image: {
        tipPrevious: "Previous picture (\u2190)",
        tipNext: "Next picture (\u2192)",
        tipCounterclockwise: "Counterclockwise",
        tipClockwise: "Clockwise",
        tipZoomOut: "Zoom out",
        tipZoomIn: "Zoom in",
        tipClose: "Close (Esc)",
        tipOriginalSize: "Zoom to original size"
      }
    };
    var idID$1 = idID;

    const deDE = {
      name: "de-DE",
      global: {
        undo: "R\xFCckg\xE4ngig",
        redo: "Wiederholen",
        confirm: "Best\xE4tigen"
      },
      Popconfirm: {
        positiveText: "Best\xE4tigen",
        negativeText: "Abbrechen"
      },
      Cascader: {
        placeholder: "Bitte ausw\xE4hlen",
        loading: "Wird geladen",
        loadingRequiredMessage: label => `Bitte laden Sie alle Unterpunkte von ${label}, bevor Sie es ausw\xE4hlen.`
      },
      Time: {
        dateFormat: "dd.MM.yyyy",
        dateTimeFormat: "dd.MM.yyyy HH:mm:ss"
      },
      DatePicker: {
        yearFormat: "yyyy",
        monthFormat: "MMM",
        dayFormat: "eeeeee",
        yearTypeFormat: "yyyy",
        monthTypeFormat: "MM-yyyy",
        dateFormat: "dd.MM.yyyy",
        dateTimeFormat: "dd.MM.yyyy HH:mm:ss",
        quarterFormat: "yyyy-qqq",
        clear: "L\xF6schen",
        now: "Jetzt",
        confirm: "Best\xE4tigen",
        selectTime: "Uhrzeit ausw\xE4hlen",
        selectDate: "Datum ausw\xE4hlen",
        datePlaceholder: "Datum ausw\xE4hlen",
        datetimePlaceholder: "Datum und Uhrzeit ausw\xE4hlen",
        monthPlaceholder: "Monat ausw\xE4hlen",
        yearPlaceholder: "Jahr ausw\xE4hlen",
        quarterPlaceholder: "Quartal ausw\xE4hlen",
        startDatePlaceholder: "Anfangsdatum",
        endDatePlaceholder: "Enddatum",
        startDatetimePlaceholder: "Anfangsdatum und Uhrzeit",
        endDatetimePlaceholder: "Enddatum und Uhrzeit",
        startMonthPlaceholder: "Anfangsmonat",
        endMonthPlaceholder: "Endmonat",
        monthBeforeYear: true,
        firstDayOfWeek: 0,
        today: "Heute"
      },
      DataTable: {
        checkTableAll: "Alles ausw\xE4hlen",
        uncheckTableAll: "Auswahl aufheben",
        confirm: "Best\xE4tigen",
        clear: "L\xF6schen"
      },
      LegacyTransfer: {
        sourceTitle: "Quelle",
        targetTitle: "Ziel"
      },
      Transfer: {
        selectAll: "Alle ausw\xE4hlen",
        unselectAll: "Alle abw\xE4hlen",
        clearAll: "Leeren",
        total: num => `Insgesamt ${num} Eintr\xE4ge`,
        selected: num => `${num} Eintr\xE4ge ausgew\xE4hlt`
      },
      Empty: {
        description: "Keine Daten"
      },
      Select: {
        placeholder: "Bitte ausw\xE4hlen"
      },
      TimePicker: {
        placeholder: "Uhrzeit ausw\xE4hlen",
        positiveText: "OK",
        negativeText: "Abbrechen",
        now: "Jetzt"
      },
      Pagination: {
        goto: "Gehe zu",
        selectionSuffix: "Seite"
      },
      DynamicTags: {
        add: "Hinzuf\xFCgen"
      },
      Log: {
        loading: "Wird geladen"
      },
      Input: {
        placeholder: "Bitte ausf\xFCllen"
      },
      InputNumber: {
        placeholder: "Bitte ausf\xFCllen"
      },
      DynamicInput: {
        create: "Erstellen"
      },
      ThemeEditor: {
        title: "Theme Editor",
        clearAllVars: "Alle Variablen l\xF6schen",
        clearSearch: "Suche l\xF6schen",
        filterCompName: "Filter Komponentenname",
        filterVarName: "Filter Variablenname",
        import: "Importieren",
        export: "Exportieren",
        restore: "Auf Standard zur\xFCcksetzen"
      },
      Image: {
        tipPrevious: "Vorheriges Bild (\u2190)",
        tipNext: "N\xE4chstes Bild (\u2192)",
        tipCounterclockwise: "Gegen Uhrzeigersinn",
        tipClockwise: "Uhrzeigersinn",
        tipZoomOut: "Rauszoomen",
        tipZoomIn: "Reinzoomen",
        tipClose: "Schlie\xDFen (Esc)",
        tipOriginalSize: "Zoom zur\xFCcksetzen"
      }
    };
    var deDE$1 = deDE;

    const nbNO = {
      name: "nb-NO",
      global: {
        undo: "Angre",
        redo: "Utf\xF8r likevel",
        confirm: "Bekreft"
      },
      Popconfirm: {
        positiveText: "Bekreft",
        negativeText: "Avbryt"
      },
      Cascader: {
        placeholder: "Vennligst velg",
        loading: "Laster",
        loadingRequiredMessage: label => `Vennligst last alle underpunkter av ${label} f\xF8r du velger oppf\xF8ringen.`
      },
      Time: {
        dateFormat: "dd.MM.yyyy",
        dateTimeFormat: "dd.MM.yyyy HH:mm:ss"
      },
      DatePicker: {
        yearFormat: "yyyy",
        monthFormat: "MMM",
        dayFormat: "eeeeee",
        yearTypeFormat: "yyyy",
        monthTypeFormat: "MM.yyyy",
        dateFormat: "dd.MM.yyyy",
        dateTimeFormat: "dd.MM.yyyy HH:mm:ss",
        quarterFormat: "yyyy-qqq",
        clear: "T\xF8m",
        now: "N\xE5",
        confirm: "Bekreft",
        selectTime: "Velg tid",
        selectDate: "Velg dato",
        datePlaceholder: "Velg dato",
        datetimePlaceholder: "Velg dato og tid",
        monthPlaceholder: "Velg m\xE5ned",
        yearPlaceholder: "Select Year",
        quarterPlaceholder: "Select Quarter",
        startDatePlaceholder: "Startdato",
        endDatePlaceholder: "Sluttdato",
        startDatetimePlaceholder: "Startdato og -tid",
        endDatetimePlaceholder: "Sluttdato og -tid",
        startMonthPlaceholder: "Start Month",
        endMonthPlaceholder: "End Month",
        monthBeforeYear: true,
        firstDayOfWeek: 0,
        today: "I dag"
      },
      DataTable: {
        checkTableAll: "Velg alt",
        uncheckTableAll: "Velg ingenting",
        confirm: "Bekreft",
        clear: "T\xF8m"
      },
      LegacyTransfer: {
        sourceTitle: "Kilde",
        targetTitle: "M\xE5l"
      },
      Transfer: {
        selectAll: "Select all",
        unselectAll: "Unselect all",
        clearAll: "Clear",
        total: num => `Total ${num} items`,
        selected: num => `${num} items selected`
      },
      Empty: {
        description: "Ingen data"
      },
      Select: {
        placeholder: "Vennligst velg"
      },
      TimePicker: {
        placeholder: "Velg tid",
        positiveText: "OK",
        negativeText: "Avbryt",
        now: "N\xE5"
      },
      Pagination: {
        goto: "G\xE5 til",
        selectionSuffix: "side"
      },
      DynamicTags: {
        add: "Legg til"
      },
      Log: {
        loading: "Laster"
      },
      Input: {
        placeholder: "Vennligst fyll ut"
      },
      InputNumber: {
        placeholder: "Vennligst fyll ut"
      },
      DynamicInput: {
        create: "Opprett"
      },
      ThemeEditor: {
        title: "Temaredigerer",
        clearAllVars: "Nullstill alle variabler",
        clearSearch: "T\xF8m s\xF8k",
        filterCompName: "Filtrer etter komponentnavn",
        filterVarName: "Filtrer etter variabelnavn",
        import: "Importer",
        export: "Eksporter",
        restore: "Nullstill til standardvalg"
      },
      Image: {
        tipPrevious: "Previous picture (\u2190)",
        tipNext: "Next picture (\u2192)",
        tipCounterclockwise: "Counterclockwise",
        tipClockwise: "Clockwise",
        tipZoomOut: "Zoom out",
        tipZoomIn: "Zoom in",
        tipClose: "Close (Esc)",
        tipOriginalSize: "Zoom to original size"
      }
    };
    var nbNO$1 = nbNO;

    const nlNL = {
      name: "nl-NL",
      global: {
        undo: "Ongedaan Maken",
        redo: "Opnieuw Doen",
        confirm: "Bevestig"
      },
      Popconfirm: {
        positiveText: "Bevestig",
        negativeText: "Annuleer"
      },
      Cascader: {
        placeholder: "Selecteer a.u.b.",
        loading: "Laden",
        loadingRequiredMessage: label => `Laad alle afstammelingen van ${label} alvorens het te selecteren.`
      },
      Time: {
        dateFormat: "dd/MM/yyyy",
        dateTimeFormat: "dd/MM/yyyy HH:mm:ss"
      },
      DatePicker: {
        yearFormat: "yyyy",
        monthFormat: "MMM",
        dayFormat: "eeeeee",
        yearTypeFormat: "yyyy",
        monthTypeFormat: "MM/yyyy",
        dateFormat: "dd/MM/yyyy",
        dateTimeFormat: "dd/MM/yyyy HH:mm:ss",
        quarterFormat: "qqq yyyy",
        clear: "Wis",
        now: "Nu",
        confirm: "Bevestig",
        selectTime: "Selecteer Uur",
        selectDate: "Selecteer Datum",
        datePlaceholder: "Selecteer Datum",
        datetimePlaceholder: "Selecteer Dag en Uur",
        monthPlaceholder: "Selecteer Maand",
        yearPlaceholder: "Selecteer Jaar",
        quarterPlaceholder: "Selecteer Kwartaal",
        startDatePlaceholder: "Begindatum",
        endDatePlaceholder: "Einddatum",
        startDatetimePlaceholder: "Begindatum en Uur",
        endDatetimePlaceholder: "Einddatum en Uur",
        startMonthPlaceholder: "Begin Maand",
        endMonthPlaceholder: "Eind Maand",
        monthBeforeYear: true,
        firstDayOfWeek: 0,
        today: "Vandaag"
      },
      DataTable: {
        checkTableAll: "Selecteer alles in de tabel",
        uncheckTableAll: "Alles in de tabel deselecteren",
        confirm: "Bevestig",
        clear: "Wis"
      },
      LegacyTransfer: {
        sourceTitle: "Bron",
        targetTitle: "Doel"
      },
      Transfer: {
        selectAll: "Select all",
        unselectAll: "Unselect all",
        clearAll: "Clear",
        total: num => `Total ${num} items`,
        selected: num => `${num} items selected`
      },
      Empty: {
        description: "Geen Data"
      },
      Select: {
        placeholder: "Selecteer a.u.b."
      },
      TimePicker: {
        placeholder: "Selecteer Uur",
        positiveText: "OK",
        negativeText: "Annuleer",
        now: "Nu"
      },
      Pagination: {
        goto: "Ga naar",
        selectionSuffix: "pagina"
      },
      DynamicTags: {
        add: "Toevoegen"
      },
      Log: {
        loading: "Laden"
      },
      Input: {
        placeholder: "Invoeren a.u.b."
      },
      InputNumber: {
        placeholder: "Invoeren a.u.b."
      },
      DynamicInput: {
        create: "Cre\xEBer"
      },
      ThemeEditor: {
        title: "Thema Bewerker",
        clearAllVars: "Wis Alle Variabelen",
        clearSearch: "Wis Zoekopdracht",
        filterCompName: "Filter Componentsnaam",
        filterVarName: "Filter Variablenaam",
        import: "Importen",
        export: "Exporteren",
        restore: "Reset naar Standaard"
      },
      Image: {
        tipPrevious: "Vorige afbeelding (\u2190)",
        tipNext: "Volgende afbeelding (\u2192)",
        tipCounterclockwise: "Tegen de klok in",
        tipClockwise: "Met de klok mee",
        tipZoomOut: "Uitzoomen",
        tipZoomIn: "Inzoomen",
        tipClose: "Sluiten (Esc)",
        tipOriginalSize: "Zoom to original size"
      }
    };
    var nlNL$1 = nlNL;

    const frFR = {
      name: "fr-FR",
      global: {
        undo: "D\xE9faire",
        redo: "Refaire",
        confirm: "Confirmer"
      },
      Popconfirm: {
        positiveText: "Confirmer",
        negativeText: "Annuler"
      },
      Cascader: {
        placeholder: "S\xE9lectionner",
        loading: "Chargement",
        loadingRequiredMessage: label => `Charger tous les enfants de ${label} avant de le s\xE9lectionner`
      },
      Time: {
        dateFormat: "dd/MM/yyyy",
        dateTimeFormat: "dd/MM/yyyy HH:mm:ss"
      },
      DatePicker: {
        yearFormat: "yyyy",
        monthFormat: "MMM",
        dayFormat: "eeeeee",
        yearTypeFormat: "yyyy",
        monthTypeFormat: "MM/yyyy",
        dateFormat: "dd/MM/yyyy",
        dateTimeFormat: "dd/MM/yyyy HH:mm:ss",
        quarterFormat: "qqq yyyy",
        clear: "Effacer",
        now: "Maintenant",
        confirm: "Confirmer",
        selectTime: "S\xE9lectionner l'heure",
        selectDate: "S\xE9lectionner la date",
        datePlaceholder: "S\xE9lectionner la date",
        datetimePlaceholder: "S\xE9lectionner la date et l'heure",
        monthPlaceholder: "S\xE9lectionner le mois",
        yearPlaceholder: "S\xE9lectionner l'ann\xE9e",
        quarterPlaceholder: "S\xE9lectionner le trimestre",
        startDatePlaceholder: "Date de d\xE9but",
        endDatePlaceholder: "Date de fin",
        startDatetimePlaceholder: "Date et heure de d\xE9but",
        endDatetimePlaceholder: "Date et heure de fin",
        startMonthPlaceholder: "Mois de d\xE9but",
        endMonthPlaceholder: "Mois de fin",
        monthBeforeYear: true,
        firstDayOfWeek: 1,
        today: "Aujourd'hui"
      },
      DataTable: {
        checkTableAll: "S\xE9lectionner tout",
        uncheckTableAll: "D\xE9s\xE9lectionner tout",
        confirm: "Confirmer",
        clear: "Effacer"
      },
      LegacyTransfer: {
        sourceTitle: "Source",
        targetTitle: "Cible"
      },
      Transfer: {
        selectAll: "S\xE9lectionner tout",
        unselectAll: "D\xE9s\xE9lectionner tout",
        clearAll: "Effacer",
        total: num => `Total ${num} \xE9l\xE9ments`,
        selected: num => `${num} \xE9l\xE9ments s\xE9lectionn\xE9s`
      },
      Empty: {
        description: "Aucune donn\xE9e"
      },
      Select: {
        placeholder: "S\xE9lectionner"
      },
      TimePicker: {
        placeholder: "S\xE9lectionner l'heure",
        positiveText: "OK",
        negativeText: "Annuler",
        now: "Maintenant"
      },
      Pagination: {
        goto: "Aller \xE0",
        selectionSuffix: "page"
      },
      DynamicTags: {
        add: "Ajouter"
      },
      Log: {
        loading: "Chargement"
      },
      Input: {
        placeholder: "Saisir"
      },
      InputNumber: {
        placeholder: "Saisir"
      },
      DynamicInput: {
        create: "Cr\xE9er"
      },
      ThemeEditor: {
        title: "\xC9diteur de th\xE8me",
        clearAllVars: "Effacer toutes les variables",
        clearSearch: "Effacer la recherche",
        filterCompName: "Filtrer par nom de composant",
        filterVarName: "Filtrer par nom de variable",
        import: "Importer",
        export: "Exporter",
        restore: "R\xE9initialiser"
      },
      Image: {
        tipPrevious: "Image pr\xE9c\xE9dente (\u2190)",
        tipNext: "Image suivante (\u2192)",
        tipCounterclockwise: "Sens antihoraire",
        tipClockwise: "Sens horaire",
        tipZoomOut: "D\xE9zoomer",
        tipZoomIn: "Zoomer",
        tipClose: "Fermer (\xC9chap.)",
        tipOriginalSize: "Zoom \xE0 la taille originale"
      }
    };
    var frFR$1 = frFR;

    const esAR = {
      name: "es-AR",
      global: {
        undo: "Deshacer",
        redo: "Rehacer",
        confirm: "Confirmar"
      },
      Popconfirm: {
        positiveText: "Confirmar",
        negativeText: "Cancelar"
      },
      Cascader: {
        placeholder: "Seleccionar por favor",
        loading: "Cargando",
        loadingRequiredMessage: label => `Por favor, cargue los descendientes de ${label} antes de marcarlo.`
      },
      Time: {
        dateFormat: "yyyy-MM-dd",
        dateTimeFormat: "yyyy-MM-dd HH:mm:ss"
      },
      DatePicker: {
        yearFormat: "yyyy",
        monthFormat: "MMM",
        dayFormat: "eeeeee",
        yearTypeFormat: "yyyy",
        monthTypeFormat: "yyyy-MM",
        dateFormat: "yyyy-MM-dd",
        dateTimeFormat: "yyyy-MM-dd HH:mm:ss",
        quarterFormat: "yyyy-qqq",
        clear: "Borrar",
        now: "Ahora",
        confirm: "Confirmar",
        selectTime: "Seleccionar hora",
        selectDate: "Seleccionar fecha",
        datePlaceholder: "Seleccionar fecha",
        datetimePlaceholder: "Seleccionar fecha y hora",
        monthPlaceholder: "Seleccionar mes",
        yearPlaceholder: "Seleccionar a\xF1o",
        quarterPlaceholder: "Seleccionar Trimestre",
        startDatePlaceholder: "Fecha de inicio",
        endDatePlaceholder: "Fecha final",
        startDatetimePlaceholder: "Fecha y hora de inicio",
        endDatetimePlaceholder: "Fecha y hora final",
        monthBeforeYear: true,
        startMonthPlaceholder: "Start Month",
        endMonthPlaceholder: "End Month",
        firstDayOfWeek: 6,
        today: "Hoy"
      },
      DataTable: {
        checkTableAll: "Seleccionar todo de la tabla",
        uncheckTableAll: "Deseleccionar todo de la tabla",
        confirm: "Confirmar",
        clear: "Limpiar"
      },
      LegacyTransfer: {
        sourceTitle: "Fuente",
        targetTitle: "Objetivo"
      },
      Transfer: {
        selectAll: "Select all",
        unselectAll: "Unselect all",
        clearAll: "Clear",
        total: num => `Total ${num} items`,
        selected: num => `${num} items selected`
      },
      Empty: {
        description: "Sin datos"
      },
      Select: {
        placeholder: "Seleccionar por favor"
      },
      TimePicker: {
        placeholder: "Seleccionar hora",
        positiveText: "OK",
        negativeText: "Cancelar",
        now: "Ahora"
      },
      Pagination: {
        goto: "Ir a",
        selectionSuffix: "p\xE1gina"
      },
      DynamicTags: {
        add: "Agregar"
      },
      Log: {
        loading: "Cargando"
      },
      Input: {
        placeholder: "Ingrese datos por favor"
      },
      InputNumber: {
        placeholder: "Ingrese datos por favor"
      },
      DynamicInput: {
        create: "Crear"
      },
      ThemeEditor: {
        title: "Editor de Tema",
        clearAllVars: "Limpiar todas las variables",
        clearSearch: "Limpiar b\xFAsqueda",
        filterCompName: "Filtro para nombre del componente",
        filterVarName: "Filtro para nombre de la variable",
        import: "Importar",
        export: "Exportar",
        restore: "Restablecer los valores por defecto"
      },
      Image: {
        tipPrevious: "Imagen anterior (\u2190)",
        tipNext: "Siguiente imagen (\u2192)",
        tipCounterclockwise: "Sentido antihorario",
        tipClockwise: "Sentido horario",
        tipZoomOut: "Alejar",
        tipZoomIn: "Acercar",
        tipClose: "Cerrar (Esc)",
        tipOriginalSize: "Zoom to original size"
      }
    };
    var esAR$1 = esAR;

    const itIT = {
      name: "it-IT",
      global: {
        undo: "Annulla",
        redo: "Ripeti",
        confirm: "Conferma"
      },
      Popconfirm: {
        positiveText: "Conferma",
        negativeText: "Annulla"
      },
      Cascader: {
        placeholder: "Si prega di selezionare",
        loading: "Caricamento",
        loadingRequiredMessage: label => `Carica tutti i discendenti di ${label} prima di controllarlo.`
      },
      Time: {
        dateFormat: "dd/MM/yyyy",
        dateTimeFormat: "dd/MM/yyyy HH:mm:ss"
      },
      DatePicker: {
        yearFormat: "yyyy",
        monthFormat: "MMM",
        dayFormat: "eeeeee",
        yearTypeFormat: "yyyy",
        monthTypeFormat: "yyyy-MM",
        dateFormat: "yyyy-MM-dd",
        dateTimeFormat: "yyyy-MM-dd HH:mm:ss",
        quarterFormat: "yyyy-qqq",
        clear: "Cancella",
        now: "Adesso",
        confirm: "Conferma",
        selectTime: "Seleziona ora",
        selectDate: "Seleziona data",
        datePlaceholder: "Seleziona data",
        datetimePlaceholder: "Seleziona data e ora",
        monthPlaceholder: "Seleziona mese",
        yearPlaceholder: "Seleziona anno",
        quarterPlaceholder: "Seleziona trimestre",
        startDatePlaceholder: "Data inizio",
        endDatePlaceholder: "Data fine",
        startDatetimePlaceholder: "Data e ora di inizio",
        endDatetimePlaceholder: "Data e ora di fine",
        startMonthPlaceholder: "Start Month",
        endMonthPlaceholder: "End Month",
        monthBeforeYear: true,
        firstDayOfWeek: 0,
        today: "Oggi"
      },
      DataTable: {
        checkTableAll: "Seleziona tutto nella tabella",
        uncheckTableAll: "Deseleziona tutto nella tabella",
        confirm: "Conferma",
        clear: "Cancella"
      },
      LegacyTransfer: {
        sourceTitle: "Fonte",
        targetTitle: "Destinazione"
      },
      Transfer: {
        selectAll: "Select all",
        unselectAll: "Unselect all",
        clearAll: "Clear",
        total: num => `Total ${num} items`,
        selected: num => `${num} items selected`
      },
      Empty: {
        description: "Nessun Dato"
      },
      Select: {
        placeholder: "Si prega di selezionare"
      },
      TimePicker: {
        placeholder: "Seleziona ora",
        positiveText: "OK",
        negativeText: "Annulla",
        now: "Ora"
      },
      Pagination: {
        goto: "Vai a",
        selectionSuffix: "per pagina"
      },
      DynamicTags: {
        add: "Aggiungi"
      },
      Log: {
        loading: "Caricamento"
      },
      Input: {
        placeholder: "Si prega di inserire"
      },
      InputNumber: {
        placeholder: "Si prega di inserire"
      },
      DynamicInput: {
        create: "Crea"
      },
      ThemeEditor: {
        title: "Editor Tema",
        clearAllVars: "Cancella tutte le variabili",
        clearSearch: "Cancella ricerca",
        filterCompName: "Filtra componenti",
        filterVarName: "Filtra variabili",
        import: "Importa",
        export: "Esporta",
        restore: "Ripristina"
      },
      Image: {
        tipPrevious: "Immagine precedente (\u2190)",
        tipNext: "Immagine successiva (\u2192)",
        tipCounterclockwise: "Ruota a sinistra",
        tipClockwise: "Ruota a destra",
        tipZoomOut: "Ingrandisci",
        tipZoomIn: "Riduci",
        tipClose: "Chiudi (Esc)",
        tipOriginalSize: "Zoom to original size"
      }
    };
    var itIT$1 = itIT;

    const skSK = {
      name: "sk-SK",
      global: {
        undo: "Sp\xE4\u0165",
        redo: "Obnovi\u0165",
        confirm: "Potvrdi\u0165"
      },
      Popconfirm: {
        positiveText: "Potvrdi\u0165",
        negativeText: "Zru\u0161i\u0165"
      },
      Cascader: {
        placeholder: "Pros\xEDm vyberte",
        loading: "Na\u010D\xEDtavanie",
        loadingRequiredMessage: label => `Pros\xEDm na\u010D\xEDtajte v\u0161etk\xFDch ${label} potomkov pred kontrolou.`
      },
      Time: {
        dateFormat: "d-M-yyyy",
        dateTimeFormat: "d-M-yyyy HH:mm:ss"
      },
      DatePicker: {
        yearFormat: "yyyy",
        monthFormat: "MMM",
        dayFormat: "EEEE",
        yearTypeFormat: "yyyy",
        monthTypeFormat: "MMM-yyyy",
        dateFormat: "d-M-yyyy",
        dateTimeFormat: "d-M-yyyy HH:mm:ss",
        quarterFormat: "qqq-yyyy",
        clear: "Vy\u010Disti\u0165",
        now: "Teraz",
        confirm: "Potvrdi\u0165",
        selectTime: "Vybra\u0165 \u010Das",
        selectDate: "Vybra\u0165 d\xE1tum",
        datePlaceholder: "Vyberte \u010Das",
        datetimePlaceholder: "Vyberte d\xE1tum a \u010Das",
        monthPlaceholder: "Vyberte mesiac",
        yearPlaceholder: "Vyberte rok",
        quarterPlaceholder: "Vyberte \u0161tvr\u0165rok",
        startDatePlaceholder: "D\xE1tum za\u010Diatku",
        endDatePlaceholder: "D\xE1tum ukon\u010Denia",
        startDatetimePlaceholder: "D\xE1tum a \u010Das za\u010Diatku",
        endDatetimePlaceholder: "D\xE1tum a \u010Das ukon\u010Denia ",
        startMonthPlaceholder: "Start Month",
        endMonthPlaceholder: "End Month",
        monthBeforeYear: true,
        firstDayOfWeek: 6,
        today: "Dnes"
      },
      DataTable: {
        checkTableAll: "Vybra\u0165 v\u0161etko v tabu\u013Eke",
        uncheckTableAll: "Zru\u0161i\u0165 v\xFDber v\u0161etk\xE9ho v tabu\u013Eke ",
        confirm: "Potvrdi\u0165",
        clear: "Vy\u010Disti\u0165"
      },
      LegacyTransfer: {
        sourceTitle: "Zdroj",
        targetTitle: "Cie\u013E"
      },
      Transfer: {
        selectAll: "Select all",
        unselectAll: "Unselect all",
        clearAll: "Clear",
        total: num => `Total ${num} items`,
        selected: num => `${num} items selected`
      },
      Empty: {
        description: "\u017Diadne d\xE1ta"
      },
      Select: {
        placeholder: "Pros\xEDm vyberte"
      },
      TimePicker: {
        placeholder: "Vybra\u0165 \u010Das",
        positiveText: "OK",
        negativeText: "Zru\u0161i\u0165",
        now: "Teraz"
      },
      Pagination: {
        goto: "\xCDs\u0165",
        selectionSuffix: "Strana"
      },
      DynamicTags: {
        add: "Prida\u0165"
      },
      Log: {
        loading: "Na\u010D\xEDtavanie"
      },
      Input: {
        placeholder: "Zadajte"
      },
      InputNumber: {
        placeholder: "Zadajte"
      },
      DynamicInput: {
        create: "Vytvori\u0165"
      },
      ThemeEditor: {
        title: "Editor t\xE9m",
        clearAllVars: "Vymaza\u0165 v\u0161etky premenn\xE9",
        clearSearch: "Vymaza\u0165 vyh\u013Ead\xE1vanie",
        filterCompName: "N\xE1zov komponentu filtra",
        filterVarName: "N\xE1zov premennej filtra",
        import: "Importova\u0165",
        export: "Exportova\u0165",
        restore: "Obnovi\u0165 p\xF4vodn\xE9 nastavenia"
      },
      Image: {
        tipPrevious: "Predch\xE1dzaj\xFAci obr\xE1zok (\u2190)",
        tipNext: "\u010Eal\u0161\xED obr\xE1zok (\u2192)",
        tipCounterclockwise: "Proti smeru hodinov\xFDch ru\u010Di\u010Diek",
        tipClockwise: "V smere hodinov\xFDch ru\u010Di\u010Diek",
        tipZoomOut: "Oddiali\u0165",
        tipZoomIn: "Pribl\xED\u017Ei\u0165",
        tipClose: "Zavrie\u0165 (Esc)",
        tipOriginalSize: "Zoom to original size"
      }
    };
    var skSK$1 = skSK;

    const enGB = {
      name: "en-GB",
      global: {
        undo: "Undo",
        redo: "Redo",
        confirm: "Confirm"
      },
      Popconfirm: {
        positiveText: "Confirm",
        negativeText: "Cancel"
      },
      Cascader: {
        placeholder: "Please Select",
        loading: "Loading",
        loadingRequiredMessage: label => `Please load all ${label}'s descendants before checking it.`
      },
      Time: {
        dateFormat: "yyyy/MM/dd",
        dateTimeFormat: "yyyy/MM/dd HH:mm:ss"
      },
      DatePicker: {
        yearFormat: "yyyy",
        monthFormat: "MMM",
        dayFormat: "eeeeee",
        yearTypeFormat: "yyyy",
        monthTypeFormat: "yyyy/MM",
        dateFormat: "yyyy/MM/dd",
        dateTimeFormat: "yyyy/MM/dd HH:mm:ss",
        quarterFormat: "yyyy-qqq",
        clear: "Clear",
        now: "Now",
        confirm: "Confirm",
        selectTime: "Select Time",
        selectDate: "Select Date",
        datePlaceholder: "Select Date",
        datetimePlaceholder: "Select Date and Time",
        monthPlaceholder: "Select Month",
        yearPlaceholder: "Select Year",
        quarterPlaceholder: "Select Quarter",
        startDatePlaceholder: "Start Date",
        endDatePlaceholder: "End Date",
        startDatetimePlaceholder: "Start Date and Time",
        endDatetimePlaceholder: "End Date and Time",
        startMonthPlaceholder: "Start Month",
        endMonthPlaceholder: "End Month",
        monthBeforeYear: true,
        firstDayOfWeek: 0,
        today: "Today"
      },
      DataTable: {
        checkTableAll: "Select all in the table",
        uncheckTableAll: "Unselect all in the table",
        confirm: "Confirm",
        clear: "Clear"
      },
      LegacyTransfer: {
        sourceTitle: "Source",
        targetTitle: "Target"
      },
      Transfer: {
        selectAll: "Select all",
        unselectAll: "Unselect all",
        clearAll: "Clear",
        total: num => `Total ${num} items`,
        selected: num => `${num} items selected`
      },
      Empty: {
        description: "No Data"
      },
      Select: {
        placeholder: "Please Select"
      },
      TimePicker: {
        placeholder: "Select Time",
        positiveText: "OK",
        negativeText: "Cancel",
        now: "Now"
      },
      Pagination: {
        goto: "Goto",
        selectionSuffix: "page"
      },
      DynamicTags: {
        add: "Add"
      },
      Log: {
        loading: "Loading"
      },
      Input: {
        placeholder: "Please Input"
      },
      InputNumber: {
        placeholder: "Please Input"
      },
      DynamicInput: {
        create: "Create"
      },
      ThemeEditor: {
        title: "Theme Editor",
        clearAllVars: "Clear All Variables",
        clearSearch: "Clear Search",
        filterCompName: "Filter Component Name",
        filterVarName: "Filter Variable Name",
        import: "Import",
        export: "Export",
        restore: "Reset to Default"
      },
      Image: {
        tipPrevious: "Previous picture (\u2190)",
        tipNext: "Next picture (\u2192)",
        tipCounterclockwise: "Counterclockwise",
        tipClockwise: "Clockwise",
        tipZoomOut: "Zoom out",
        tipZoomIn: "Zoom in",
        tipClose: "Close (Esc)",
        tipOriginalSize: "Zoom to original size"
      }
    };
    var enGB$1 = enGB;

    const plPL = {
      name: "pl-PL",
      global: {
        undo: "Cofnij",
        redo: "Pon\xF3w",
        confirm: "Potwierd\u017A"
      },
      Popconfirm: {
        positiveText: "Potwierd\u017A",
        negativeText: "Anuluj"
      },
      Cascader: {
        placeholder: "Wybierz",
        loading: "\u0141adowanie",
        loadingRequiredMessage: label => `Prosz\u0119 za\u0142adowa\u0107 wszystkie ${label}'s elementy przed sprawdzeniem.`
      },
      Time: {
        dateFormat: "yyyy-MM-dd",
        dateTimeFormat: "yyyy-MM-dd HH:mm:ss"
      },
      DatePicker: {
        yearFormat: "yyyy",
        monthFormat: "MMM",
        dayFormat: "eeeeee",
        yearTypeFormat: "yyyy",
        monthTypeFormat: "yyyy-MM",
        dateFormat: "yyyy-MM-dd",
        dateTimeFormat: "yyyy-MM-dd HH:mm:ss",
        quarterFormat: "yyyy-qqq",
        clear: "Wyczy\u015B\u0107",
        now: "Teraz",
        confirm: "Potwierd\u017A",
        selectTime: "Wybierz czas",
        selectDate: "Wybierz dat\u0119",
        datePlaceholder: "Wybierz dat\u0119",
        datetimePlaceholder: "Wybierz dat\u0119 i czas",
        monthPlaceholder: "Wybierz miesi\u0105c",
        yearPlaceholder: "Wybierz rok",
        quarterPlaceholder: "Wybierz kwarta\u0142",
        startDatePlaceholder: "Data rozpocz\u0119cia",
        endDatePlaceholder: "Data zako\u0144czenia",
        startDatetimePlaceholder: "Data i godzina rozpocz\u0119cia",
        endDatetimePlaceholder: "Data i godzina zako\u0144czenia",
        startMonthPlaceholder: "Start Month",
        endMonthPlaceholder: "End Month",
        monthBeforeYear: true,
        firstDayOfWeek: 6,
        today: "Dzi\u015B"
      },
      DataTable: {
        checkTableAll: "Zaznacz wszystkie w tabeli",
        uncheckTableAll: "Odznacz wszystkie w tabeli",
        confirm: "Potwierd\u017A",
        clear: "Wyczy\u015B\u0107"
      },
      LegacyTransfer: {
        sourceTitle: "\u0179r\xF3d\u0142o",
        targetTitle: "Cel"
      },
      Transfer: {
        selectAll: "Select all",
        unselectAll: "Unselect all",
        clearAll: "Clear",
        total: num => `Total ${num} items`,
        selected: num => `${num} items selected`
      },
      Empty: {
        description: "Brak danych"
      },
      Select: {
        placeholder: "Wybierz"
      },
      TimePicker: {
        placeholder: "Wybierz czas",
        positiveText: "Potwierd\u017A",
        negativeText: "Anuluj",
        now: "Teraz"
      },
      Pagination: {
        goto: "Id\u017A do",
        selectionSuffix: "strona"
      },
      DynamicTags: {
        add: "Dodaj"
      },
      Log: {
        loading: "\u0141adowanie"
      },
      Input: {
        placeholder: "Wprowad\u017A dane"
      },
      InputNumber: {
        placeholder: "Wprowad\u017A dane"
      },
      DynamicInput: {
        create: "Utw\xF3rz"
      },
      ThemeEditor: {
        title: "Edytor motyw\xF3w",
        clearAllVars: "Wyczy\u015B\u0107 wszystkie zmienne",
        clearSearch: "Wyczy\u015B\u0107 wyszukiwanie",
        filterCompName: "Nazwa komponentu filtra",
        filterVarName: "Nazwa zmiennej filtra",
        import: "Importuj",
        export: "Eksportuj",
        restore: "Przywr\xF3\u0107 ustawienia domy\u015Blne"
      },
      Image: {
        tipPrevious: "Poprzednie zdj\u0119cie (\u2190)",
        tipNext: "Nast\u0119pne zdj\u0119cie (\u2192)",
        tipCounterclockwise: "Przeciwnie do ruchu wskaz\xF3wek zegara",
        tipClockwise: "Zgodnie z ruchem wskaz\xF3wek zegara",
        tipZoomOut: "Powi\u0119ksz",
        tipZoomIn: "Pomniejsz",
        tipClose: "Zamknij (Esc)",
        tipOriginalSize: "Zoom to original size"
      }
    };
    var plPL$1 = plPL;

    const ptBR = {
      name: "pt-BR",
      global: {
        undo: "Desfazer",
        redo: "Refazer",
        confirm: "Confirmar"
      },
      Popconfirm: {
        positiveText: "Confirmar",
        negativeText: "Cancelar"
      },
      Cascader: {
        placeholder: "Por favor selecione",
        loading: "Carregando",
        loadingRequiredMessage: label => `Carregue todos os descendentes de ${label} antes de verificar.`
      },
      Time: {
        dateFormat: "dd/MM/yyyy",
        dateTimeFormat: "dd/MM/yyyy HH:mm:ss"
      },
      DatePicker: {
        yearFormat: "yyyy",
        monthFormat: "MMM",
        dayFormat: "eeeeee",
        yearTypeFormat: "yyyy",
        monthTypeFormat: "yyyy/MM",
        dateFormat: "dd/MM/yyyy",
        dateTimeFormat: "dd/MM/yyyy HH:mm:ss",
        quarterFormat: "yyyy/qqq",
        clear: "Limpar",
        now: "Agora",
        confirm: "Confirmar",
        selectTime: "Selecionar hora",
        selectDate: "Selecione a data",
        datePlaceholder: "Selecione a data",
        datetimePlaceholder: "Selecione Data e Hora",
        monthPlaceholder: "Selecione o m\xEAs",
        yearPlaceholder: "Selecione o ano",
        quarterPlaceholder: "Selecione o quatrimestre",
        startDatePlaceholder: "Selecione a data de in\xEDcio",
        endDatePlaceholder: "Selecione a data de t\xE9rmino",
        startDatetimePlaceholder: "Selecione a data e hora de in\xEDcio",
        endDatetimePlaceholder: "Select a data e hora de t\xE9rmino",
        startMonthPlaceholder: "Start Month",
        endMonthPlaceholder: "End Month",
        monthBeforeYear: true,
        firstDayOfWeek: 6,
        today: "Hoje"
      },
      DataTable: {
        checkTableAll: "Selecionar todos na tabela",
        uncheckTableAll: "Desmarcar todos na tabela",
        confirm: "Confirmar",
        clear: "Limpar"
      },
      LegacyTransfer: {
        sourceTitle: "Fonte",
        targetTitle: "Destino"
      },
      Transfer: {
        selectAll: "Select all",
        unselectAll: "Unselect all",
        clearAll: "Clear",
        total: num => `Total ${num} items`,
        selected: num => `${num} items selected`
      },
      Empty: {
        description: "N\xE3o h\xE1 dados"
      },
      Select: {
        placeholder: "Por favor selecione"
      },
      TimePicker: {
        placeholder: "Selecione a hora",
        positiveText: "OK",
        negativeText: "Cancelar",
        now: "Agora"
      },
      Pagination: {
        goto: "Ir para",
        selectionSuffix: "p\xE1gina"
      },
      DynamicTags: {
        add: "Adicionar"
      },
      Log: {
        loading: "Carregando"
      },
      Input: {
        placeholder: "Por favor digite"
      },
      InputNumber: {
        placeholder: "Por favor digite"
      },
      DynamicInput: {
        create: "Criar"
      },
      ThemeEditor: {
        title: "Editor de temas",
        clearAllVars: "Limpar todas as vari\xE1veis",
        clearSearch: "Limpar pesquisa",
        filterCompName: "Filtrar nome do componente",
        filterVarName: "Filtrar nome da vari\xE1vel",
        import: "Importar",
        export: "Exportar",
        restore: "Restaurar"
      },
      Image: {
        tipPrevious: "Foto anterior (\u2190)",
        tipNext: "Pr\xF3xima foto (\u2192)",
        tipCounterclockwise: "Sentido anti-hor\xE1rio",
        tipClockwise: "Sentido hor\xE1rio",
        tipZoomOut: "Reduzir o zoom",
        tipZoomIn: "Mais Zoom",
        tipClose: "Fechar (Esc)",
        tipOriginalSize: "Zoom to original size"
      }
    };
    var ptBR$1 = ptBR;

    const thTH = {
      name: "thTH",
      global: {
        undo: "\u0E40\u0E25\u0E34\u0E01\u0E17\u0E33",
        redo: "\u0E17\u0E33\u0E0B\u0E49\u0E33",
        confirm: "\u0E22\u0E37\u0E19\u0E22\u0E31\u0E19"
      },
      Popconfirm: {
        positiveText: "\u0E22\u0E37\u0E19\u0E22\u0E31\u0E19",
        negativeText: "\u0E22\u0E01\u0E40\u0E25\u0E34\u0E01"
      },
      Cascader: {
        placeholder: "\u0E01\u0E23\u0E38\u0E13\u0E32\u0E40\u0E25\u0E37\u0E2D\u0E01",
        loading: "\u0E01\u0E33\u0E25\u0E31\u0E07\u0E42\u0E2B\u0E25\u0E14",
        loadingRequiredMessage: label => `Please load all ${label}'s descendants before checking it.`
      },
      Time: {
        dateFormat: "dd-MMMM-yyyy",
        dateTimeFormat: "dd-MMMM-yyyy HH:mm:ss"
      },
      DatePicker: {
        yearFormat: "yyyy",
        monthFormat: "MMM",
        dayFormat: "eeeeee",
        yearTypeFormat: "yyyy",
        monthTypeFormat: "yyyy-MM",
        dateFormat: "dd/MMMM/yyyy",
        dateTimeFormat: "dd/MMMM/yyyy HH:mm:ss",
        quarterFormat: "yyyy-qqq",
        clear: "\u0E25\u0E49\u0E32\u0E07",
        now: "\u0E27\u0E31\u0E19\u0E19\u0E35\u0E49",
        confirm: "\u0E22\u0E37\u0E19\u0E22\u0E31\u0E19",
        selectTime: "\u0E40\u0E27\u0E25\u0E32",
        selectDate: "\u0E27\u0E31\u0E19\u0E17\u0E35\u0E48",
        datePlaceholder: "\u0E27\u0E31\u0E19\u0E17\u0E35\u0E48",
        datetimePlaceholder: "\u0E40\u0E27\u0E25\u0E32-\u0E27\u0E31\u0E19\u0E17\u0E35\u0E48",
        monthPlaceholder: "\u0E40\u0E14\u0E37\u0E2D\u0E19",
        yearPlaceholder: "\u0E1B\u0E35",
        quarterPlaceholder: "\u0E44\u0E15\u0E23\u0E21\u0E32\u0E2A",
        startDatePlaceholder: "\u0E27\u0E31\u0E19\u0E17\u0E35\u0E48\u0E40\u0E23\u0E34\u0E48\u0E21\u0E15\u0E49\u0E19",
        endDatePlaceholder: "\u0E27\u0E31\u0E19\u0E17\u0E35\u0E48\u0E2A\u0E34\u0E49\u0E19\u0E2A\u0E38\u0E14",
        startDatetimePlaceholder: "\u0E27\u0E31\u0E19\u0E17\u0E35\u0E48\u0E40\u0E23\u0E34\u0E48\u0E21\u0E15\u0E49\u0E19\u0E41\u0E25\u0E30\u0E2A\u0E34\u0E49\u0E19\u0E2A\u0E38\u0E14",
        endDatetimePlaceholder: "\u0E27\u0E31\u0E19\u0E17\u0E35\u0E48\u0E2A\u0E34\u0E49\u0E19\u0E2A\u0E38\u0E14\u0E41\u0E25\u0E30\u0E40\u0E27\u0E25\u0E32",
        startMonthPlaceholder: "Start Month",
        endMonthPlaceholder: "End Month",
        monthBeforeYear: true,
        firstDayOfWeek: 6,
        today: "\u0E27\u0E31\u0E19\u0E19\u0E35\u0E49"
      },
      DataTable: {
        checkTableAll: "\u0E40\u0E25\u0E37\u0E2D\u0E01\u0E17\u0E31\u0E49\u0E07\u0E2B\u0E21\u0E14",
        uncheckTableAll: "\u0E44\u0E21\u0E48\u0E40\u0E25\u0E37\u0E2D\u0E01\u0E17\u0E31\u0E49\u0E07\u0E2B\u0E21\u0E14",
        confirm: "\u0E22\u0E37\u0E19\u0E22\u0E31\u0E19",
        clear: "\u0E25\u0E49\u0E32\u0E07\u0E02\u0E49\u0E2D\u0E21\u0E39\u0E25"
      },
      LegacyTransfer: {
        sourceTitle: "Source",
        targetTitle: "Target"
      },
      Transfer: {
        selectAll: "Select all",
        unselectAll: "Unselect all",
        clearAll: "Clear",
        total: num => `Total ${num} items`,
        selected: num => `${num} items selected`
      },
      Empty: {
        description: "\u0E44\u0E21\u0E48\u0E21\u0E35\u0E02\u0E49\u0E2D\u0E21\u0E39\u0E25"
      },
      Select: {
        placeholder: "\u0E01\u0E23\u0E38\u0E13\u0E32\u0E40\u0E25\u0E37\u0E2D\u0E01"
      },
      TimePicker: {
        placeholder: "\u0E40\u0E27\u0E25\u0E32",
        positiveText: "\u0E15\u0E01\u0E25\u0E07",
        negativeText: "\u0E22\u0E01\u0E40\u0E25\u0E34\u0E01",
        now: "\u0E27\u0E31\u0E19\u0E19\u0E35\u0E49"
      },
      Pagination: {
        goto: "\u0E44\u0E1B\u0E22\u0E31\u0E07",
        selectionSuffix: "\u0E2B\u0E19\u0E49\u0E32"
      },
      DynamicTags: {
        add: "\u0E40\u0E1E\u0E34\u0E48\u0E21"
      },
      Log: {
        loading: "\u0E01\u0E33\u0E25\u0E31\u0E07\u0E42\u0E2B\u0E25\u0E14"
      },
      Input: {
        placeholder: "\u0E01\u0E23\u0E38\u0E13\u0E32\u0E01\u0E23\u0E2D\u0E01"
      },
      InputNumber: {
        placeholder: "\u0E01\u0E23\u0E38\u0E13\u0E32\u0E01\u0E23\u0E2D\u0E01"
      },
      DynamicInput: {
        create: "\u0E2A\u0E23\u0E49\u0E32\u0E07"
      },
      ThemeEditor: {
        title: "\u0E41\u0E01\u0E49\u0E44\u0E02\u0E18\u0E35\u0E21",
        clearAllVars: "\u0E25\u0E49\u0E32\u0E07\u0E02\u0E49\u0E2D\u0E21\u0E39\u0E25\u0E15\u0E31\u0E27\u0E41\u0E1B\u0E23",
        clearSearch: "\u0E25\u0E49\u0E32\u0E07\u0E02\u0E49\u0E2D\u0E21\u0E39\u0E25\u0E04\u0E49\u0E19\u0E2B\u0E32",
        filterCompName: "\u0E01\u0E23\u0E2D\u0E07\u0E42\u0E14\u0E22\u0E0A\u0E37\u0E48\u0E2D Component",
        filterVarName: "\u0E01\u0E23\u0E2D\u0E07\u0E42\u0E14\u0E22\u0E0A\u0E37\u0E48\u0E2D\u0E15\u0E31\u0E27\u0E41\u0E1B\u0E23",
        import: "\u0E19\u0E33\u0E40\u0E02\u0E49\u0E32",
        export: "\u0E2A\u0E48\u0E07\u0E2D\u0E2D\u0E01",
        restore: "\u0E23\u0E35\u0E40\u0E0B\u0E47\u0E15"
      },
      Image: {
        tipPrevious: "\u0E01\u0E48\u0E2D\u0E19\u0E2B\u0E19\u0E49\u0E32 (\u2190)",
        tipNext: "\u0E16\u0E31\u0E14\u0E44\u0E1B (\u2192)",
        tipCounterclockwise: "\u0E2B\u0E21\u0E38\u0E19 (\u21BA)",
        tipClockwise: "\u0E2B\u0E21\u0E38\u0E19 (\u21BB)",
        tipZoomOut: "\u0E0B\u0E39\u0E21\u0E2D\u0E2D\u0E01",
        tipZoomIn: "\u0E0B\u0E39\u0E21\u0E40\u0E02\u0E49\u0E32",
        tipClose: "\u0E1B\u0E34\u0E14 (Esc)",
        tipOriginalSize: "Zoom to original size"
      }
    };
    var thTH$1 = thTH;

    const eo = {
      name: "eo",
      global: {
        undo: "Malfari",
        redo: "Refari",
        confirm: "Konfirmi"
      },
      Popconfirm: {
        positiveText: "Konfirmi",
        negativeText: "Nuligi"
      },
      Cascader: {
        placeholder: "Bonvolu elekti",
        loading: "\u015Cargi\u011Do",
        loadingRequiredMessage: label => `Bonvolu \u015Dargi \u0109iujn idojn de ${label} anta\u016D ol elekti \u011Din.`
      },
      Time: {
        dateFormat: "yyyy-MM-dd",
        dateTimeFormat: "yyyy-MM-dd HH:mm:ss"
      },
      DatePicker: {
        yearFormat: "yyyy",
        monthFormat: "MMM",
        dayFormat: "eeeeee",
        yearTypeFormat: "yyyy",
        monthTypeFormat: "yyyy-MM",
        dateFormat: "yyyy-MM-dd",
        dateTimeFormat: "yyyy-MM-dd HH:mm:ss",
        quarterFormat: "yyyy-qqq",
        clear: "Malplenigi",
        now: "Nun",
        confirm: "Konfirmi",
        selectTime: "Elekti tempon",
        selectDate: "Elekti daton",
        datePlaceholder: "Elekti daton",
        datetimePlaceholder: "Elekti daton kaj tempon",
        monthPlaceholder: "Elekti monaton",
        yearPlaceholder: "Elekti jaron",
        quarterPlaceholder: "Elekti jarkvaronon",
        startDatePlaceholder: "Komenca dato",
        endDatePlaceholder: "Fina dato",
        startDatetimePlaceholder: "Komencaj dato kaj tempo",
        endDatetimePlaceholder: "Finaj dato kaj tempo",
        startMonthPlaceholder: "Start Month",
        endMonthPlaceholder: "End Month",
        monthBeforeYear: true,
        firstDayOfWeek: 0,
        today: "Hodia\u016D"
      },
      DataTable: {
        checkTableAll: "Elekti \u0109iujn en la tabelo",
        uncheckTableAll: "Malelekti \u0109iujn en la tabelo",
        confirm: "Konfirmi",
        clear: "Malplenigi"
      },
      LegacyTransfer: {
        sourceTitle: "Source",
        targetTitle: "Target"
      },
      Transfer: {
        selectAll: "Select all",
        unselectAll: "Unselect all",
        clearAll: "Clear",
        total: num => `Total ${num} items`,
        selected: num => `${num} items selected`
      },
      Empty: {
        description: "Neniu datumo"
      },
      Select: {
        placeholder: "Bonvolu elekti"
      },
      TimePicker: {
        placeholder: "Elekti tempon",
        positiveText: "Bone",
        negativeText: "Nuligi",
        now: "Nun"
      },
      Pagination: {
        goto: "Iri al",
        selectionSuffix: "pa\u011Do"
      },
      DynamicTags: {
        add: "Aldoni"
      },
      Log: {
        loading: "\u015Cargado"
      },
      Input: {
        placeholder: "Bonvolu entajpi"
      },
      InputNumber: {
        placeholder: "Bonvolu entajpi"
      },
      DynamicInput: {
        create: "Krei"
      },
      ThemeEditor: {
        title: "Etosredaktilo",
        clearAllVars: "Malplenigi \u0109iujn variablojn",
        clearSearch: "Malplenigi ser\u0109on",
        filterCompName: "Filtri nomojn de kompona\u0135oj",
        filterVarName: "Filtri nomojn de variabloj",
        import: "Importi",
        export: "Eksporti",
        restore: "Restarigi defa\u016Dltajn valorojn"
      },
      Image: {
        tipPrevious: "Anta\u016Da bildo (\u2190)",
        tipNext: "Sekva bildo (\u2192)",
        tipCounterclockwise: "Maldekstrume",
        tipClockwise: "Dekstrume",
        tipZoomOut: "Malzomi",
        tipZoomIn: "Zomi",
        tipClose: "Fermi (Esc)",
        tipOriginalSize: "Zoom to original size"
      }
    };
    var eo$1 = eo;

    const viVN = {
      name: "vi-VN",
      global: {
        undo: "Ho\xE0n t\xE1c",
        redo: "L\xE0m l\u1EA1i",
        confirm: "X\xE1c nh\u1EADn"
      },
      Popconfirm: {
        positiveText: "X\xE1c nh\u1EADn",
        negativeText: "H\u1EE7y"
      },
      Cascader: {
        placeholder: "Vui l\xF2ng ch\u1ECDn",
        loading: "\u0110ang t\u1EA3i",
        loadingRequiredMessage: label => `Vui l\xF2ng t\u1EA3i t\u1EA5t c\u1EA3 th\xF4ng tin con c\u1EE7a ${label} tr\u01B0\u1EDBc.`
      },
      Time: {
        dateFormat: "",
        dateTimeFormat: "HH:mm:ss dd-MM-yyyy"
      },
      DatePicker: {
        yearFormat: "yyyy",
        monthFormat: "MMM",
        dayFormat: "eeeeee",
        yearTypeFormat: "yyyy",
        monthTypeFormat: "MM-yyyy",
        dateFormat: "dd-MM-yyyy",
        dateTimeFormat: "HH:mm:ss dd-MM-yyyy",
        quarterFormat: "qqq-yyyy",
        clear: "X\xF3a",
        now: "H\xF4m nay",
        confirm: "X\xE1c nh\u1EADn",
        selectTime: "Ch\u1ECDn gi\u1EDD",
        selectDate: "Ch\u1ECDn ng\xE0y",
        datePlaceholder: "Ch\u1ECDn ng\xE0y",
        datetimePlaceholder: "Ch\u1ECDn ng\xE0y gi\u1EDD",
        monthPlaceholder: "Ch\u1ECDn th\xE1ng",
        yearPlaceholder: "Ch\u1ECDn n\u0103m",
        quarterPlaceholder: "Ch\u1ECDn qu\xFD",
        startDatePlaceholder: "Ng\xE0y b\u1EAFt \u0111\u1EA7u",
        endDatePlaceholder: "Ng\xE0y k\u1EBFt th\xFAc",
        startDatetimePlaceholder: "Th\u1EDDi gian b\u1EAFt \u0111\u1EA7u",
        endDatetimePlaceholder: "Th\u1EDDi gian k\u1EBFt th\xFAc",
        startMonthPlaceholder: "Th\xE1ng b\u1EAFt \u0111\u1EA7u",
        endMonthPlaceholder: "Th\xE1ng k\u1EBFt th\xFAc",
        monthBeforeYear: true,
        firstDayOfWeek: 0,
        today: "H\xF4m nay"
      },
      DataTable: {
        checkTableAll: "Ch\u1ECDn t\u1EA5t c\u1EA3 c\xF3 trong b\u1EA3ng",
        uncheckTableAll: "B\u1ECF ch\u1ECDn t\u1EA5t c\u1EA3 c\xF3 trong b\u1EA3ng",
        confirm: "X\xE1c nh\u1EADn",
        clear: "X\xF3a"
      },
      LegacyTransfer: {
        sourceTitle: "Ngu\u1ED3n",
        targetTitle: "\u0110\xEDch"
      },
      Transfer: {
        selectAll: "Ch\u1ECDn t\u1EA5t c\u1EA3",
        unselectAll: "B\u1ECF ch\u1ECDn t\u1EA5t c\u1EA3",
        clearAll: "Xo\xE1 t\u1EA5t c\u1EA3",
        total: num => `T\u1ED5ng c\u1ED9ng ${num} m\u1EE5c`,
        selected: num => `${num} m\u1EE5c \u0111\u01B0\u1EE3c ch\u1ECDn`
      },
      Empty: {
        description: "Kh\xF4ng c\xF3 d\u1EEF li\u1EC7u"
      },
      Select: {
        placeholder: "Vui l\xF2ng ch\u1ECDn"
      },
      TimePicker: {
        placeholder: "Ch\u1ECDn th\u1EDDi gian",
        positiveText: "OK",
        negativeText: "H\u1EE7y",
        now: "Hi\u1EC7n t\u1EA1i"
      },
      Pagination: {
        goto: "\u0110i \u0111\u1EBFn trang",
        selectionSuffix: "trang"
      },
      DynamicTags: {
        add: "Th\xEAm"
      },
      Log: {
        loading: "\u0110ang t\u1EA3i"
      },
      Input: {
        placeholder: "Vui l\xF2ng nh\u1EADp"
      },
      InputNumber: {
        placeholder: "Vui l\xF2ng nh\u1EADp"
      },
      DynamicInput: {
        create: "T\u1EA1o"
      },
      ThemeEditor: {
        title: "T\xF9y ch\u1EC9nh giao di\u1EC7n",
        clearAllVars: "X\xF3a t\u1EA5t c\u1EA3 c\xE1c bi\u1EBFn",
        clearSearch: "X\xF3a t\xECm ki\u1EBFm",
        filterCompName: "L\u1ECDc t\xEAn component",
        filterVarName: "L\u1ECDc t\xEAn bi\u1EBFn",
        import: "Nh\u1EADp",
        export: "Xu\u1EA5t",
        restore: "\u0110\u1EB7t l\u1EA1i m\u1EB7c \u0111\u1ECBnh"
      },
      Image: {
        tipPrevious: "H\xECnh tr\u01B0\u1EDBc (\u2190)",
        tipNext: "H\xECnh ti\u1EBFp (\u2192)",
        tipCounterclockwise: "Counterclockwise",
        tipClockwise: "Chi\u1EC1u kim \u0111\u1ED3ng h\u1ED3",
        tipZoomOut: "Thu nh\u1ECF",
        tipZoomIn: "Ph\xF3ng to",
        tipClose: "\u0110\xF3ng (Esc)",
        tipOriginalSize: "Xem k\xEDch th\u01B0\u1EDBc g\u1ED1c"
      }
    };
    var viVN$1 = viVN;

    var formatDistanceLocale$j = {
      lessThanXSeconds: {
        one: '不到 1 秒',
        other: '不到 {{count}} 秒'
      },
      xSeconds: {
        one: '1 秒',
        other: '{{count}} 秒'
      },
      halfAMinute: '半分钟',
      lessThanXMinutes: {
        one: '不到 1 分钟',
        other: '不到 {{count}} 分钟'
      },
      xMinutes: {
        one: '1 分钟',
        other: '{{count}} 分钟'
      },
      xHours: {
        one: '1 小时',
        other: '{{count}} 小时'
      },
      aboutXHours: {
        one: '大约 1 小时',
        other: '大约 {{count}} 小时'
      },
      xDays: {
        one: '1 天',
        other: '{{count}} 天'
      },
      aboutXWeeks: {
        one: '大约 1 个星期',
        other: '大约 {{count}} 个星期'
      },
      xWeeks: {
        one: '1 个星期',
        other: '{{count}} 个星期'
      },
      aboutXMonths: {
        one: '大约 1 个月',
        other: '大约 {{count}} 个月'
      },
      xMonths: {
        one: '1 个月',
        other: '{{count}} 个月'
      },
      aboutXYears: {
        one: '大约 1 年',
        other: '大约 {{count}} 年'
      },
      xYears: {
        one: '1 年',
        other: '{{count}} 年'
      },
      overXYears: {
        one: '超过 1 年',
        other: '超过 {{count}} 年'
      },
      almostXYears: {
        one: '将近 1 年',
        other: '将近 {{count}} 年'
      }
    };

    var formatDistance$k = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$j[token];

      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }

      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return result + '内';
        } else {
          return result + '前';
        }
      }

      return result;
    };

    function buildFormatLongFn$1(args) {
      return function () {
        var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {}; // TODO: Remove String()

        var width = options.width ? String(options.width) : args.defaultWidth;
        var format = args.formats[width] || args.formats[args.defaultWidth];
        return format;
      };
    }

    var dateFormats$k = {
      full: "y'年'M'月'd'日' EEEE",
      long: "y'年'M'月'd'日'",
      medium: 'yyyy-MM-dd',
      short: 'yy-MM-dd'
    };
    var timeFormats$k = {
      full: 'zzzz a h:mm:ss',
      long: 'z a h:mm:ss',
      medium: 'a h:mm:ss',
      short: 'a h:mm'
    };
    var dateTimeFormats$k = {
      full: '{{date}} {{time}}',
      long: '{{date}} {{time}}',
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$l = {
      date: buildFormatLongFn$1({
        formats: dateFormats$k,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn$1({
        formats: timeFormats$k,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn$1({
        formats: dateTimeFormats$k,
        defaultWidth: 'full'
      })
    };

    function requiredArgs$1(required, args) {
      if (args.length < required) {
        throw new TypeError(required + ' argument' + (required > 1 ? 's' : '') + ' required, but only ' + args.length + ' present');
      }
    }

    /**
     * @name toDate
     * @category Common Helpers
     * @summary Convert the given argument to an instance of Date.
     *
     * @description
     * Convert the given argument to an instance of Date.
     *
     * If the argument is an instance of Date, the function returns its clone.
     *
     * If the argument is a number, it is treated as a timestamp.
     *
     * If the argument is none of the above, the function returns Invalid Date.
     *
     * **Note**: *all* Date arguments passed to any *date-fns* function is processed by `toDate`.
     *
     * @param {Date|Number} argument - the value to convert
     * @returns {Date} the parsed date in the local time zone
     * @throws {TypeError} 1 argument required
     *
     * @example
     * // Clone the date:
     * const result = toDate(new Date(2014, 1, 11, 11, 30, 30))
     * //=> Tue Feb 11 2014 11:30:30
     *
     * @example
     * // Convert the timestamp to date:
     * const result = toDate(1392098430000)
     * //=> Tue Feb 11 2014 11:30:30
     */

    function toDate$2(argument) {
      requiredArgs$1(1, arguments);
      var argStr = Object.prototype.toString.call(argument); // Clone the date

      if (argument instanceof Date || typeof argument === 'object' && argStr === '[object Date]') {
        // Prevent the date to lose the milliseconds when passed to new Date() in IE10
        return new Date(argument.getTime());
      } else if (typeof argument === 'number' || argStr === '[object Number]') {
        return new Date(argument);
      } else {
        if ((typeof argument === 'string' || argStr === '[object String]') && typeof console !== 'undefined') {
          // eslint-disable-next-line no-console
          console.warn("Starting with v2.0.0-beta.1 date-fns doesn't accept strings as date arguments. Please use `parseISO` to parse strings. See: https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#string-arguments"); // eslint-disable-next-line no-console

          console.warn(new Error().stack);
        }

        return new Date(NaN);
      }
    }

    function toInteger$1(dirtyNumber) {
      if (dirtyNumber === null || dirtyNumber === true || dirtyNumber === false) {
        return NaN;
      }

      var number = Number(dirtyNumber);

      if (isNaN(number)) {
        return number;
      }

      return number < 0 ? Math.ceil(number) : Math.floor(number);
    }

    var defaultOptions$2 = {};
    function getDefaultOptions$1() {
      return defaultOptions$2;
    }

    function startOfUTCWeek$1(dirtyDate, options) {
      var _ref, _ref2, _ref3, _options$weekStartsOn, _options$locale, _options$locale$optio, _defaultOptions$local, _defaultOptions$local2;

      requiredArgs$1(1, arguments);
      var defaultOptions = getDefaultOptions$1();
      var weekStartsOn = toInteger$1((_ref = (_ref2 = (_ref3 = (_options$weekStartsOn = options === null || options === void 0 ? void 0 : options.weekStartsOn) !== null && _options$weekStartsOn !== void 0 ? _options$weekStartsOn : options === null || options === void 0 ? void 0 : (_options$locale = options.locale) === null || _options$locale === void 0 ? void 0 : (_options$locale$optio = _options$locale.options) === null || _options$locale$optio === void 0 ? void 0 : _options$locale$optio.weekStartsOn) !== null && _ref3 !== void 0 ? _ref3 : defaultOptions.weekStartsOn) !== null && _ref2 !== void 0 ? _ref2 : (_defaultOptions$local = defaultOptions.locale) === null || _defaultOptions$local === void 0 ? void 0 : (_defaultOptions$local2 = _defaultOptions$local.options) === null || _defaultOptions$local2 === void 0 ? void 0 : _defaultOptions$local2.weekStartsOn) !== null && _ref !== void 0 ? _ref : 0); // Test if weekStartsOn is between 0 and 6 _and_ is not NaN

      if (!(weekStartsOn >= 0 && weekStartsOn <= 6)) {
        throw new RangeError('weekStartsOn must be between 0 and 6 inclusively');
      }

      var date = toDate$2(dirtyDate);
      var day = date.getUTCDay();
      var diff = (day < weekStartsOn ? 7 : 0) + day - weekStartsOn;
      date.setUTCDate(date.getUTCDate() - diff);
      date.setUTCHours(0, 0, 0, 0);
      return date;
    }

    function isSameUTCWeek(dirtyDateLeft, dirtyDateRight, options) {
      requiredArgs$1(2, arguments);
      var dateLeftStartOfWeek = startOfUTCWeek$1(dirtyDateLeft, options);
      var dateRightStartOfWeek = startOfUTCWeek$1(dirtyDateRight, options);
      return dateLeftStartOfWeek.getTime() === dateRightStartOfWeek.getTime();
    }

    function checkWeek(date, baseDate, options) {
      var baseFormat = 'eeee p';

      if (isSameUTCWeek(date, baseDate, options)) {
        return baseFormat; // in same week
      } else if (date.getTime() > baseDate.getTime()) {
        return "'下个'" + baseFormat; // in next week
      }

      return "'上个'" + baseFormat; // in last week
    }

    var formatRelativeLocale$j = {
      lastWeek: checkWeek,
      // days before yesterday, maybe in this week or last week
      yesterday: "'昨天' p",
      today: "'今天' p",
      tomorrow: "'明天' p",
      nextWeek: checkWeek,
      // days after tomorrow, maybe in this week or next week
      other: 'PP p'
    };

    var formatRelative$k = function (token, date, baseDate, options) {
      var format = formatRelativeLocale$j[token];

      if (typeof format === 'function') {
        return format(date, baseDate, options);
      }

      return format;
    };

    function buildLocalizeFn$1(args) {
      return function (dirtyIndex, options) {
        var context = options !== null && options !== void 0 && options.context ? String(options.context) : 'standalone';
        var valuesArray;

        if (context === 'formatting' && args.formattingValues) {
          var defaultWidth = args.defaultFormattingWidth || args.defaultWidth;
          var width = options !== null && options !== void 0 && options.width ? String(options.width) : defaultWidth;
          valuesArray = args.formattingValues[width] || args.formattingValues[defaultWidth];
        } else {
          var _defaultWidth = args.defaultWidth;

          var _width = options !== null && options !== void 0 && options.width ? String(options.width) : args.defaultWidth;

          valuesArray = args.values[_width] || args.values[_defaultWidth];
        }

        var index = args.argumentCallback ? args.argumentCallback(dirtyIndex) : dirtyIndex; // @ts-ignore: For some reason TypeScript just don't want to match it, no matter how hard we try. I challenge you to try to remove it!

        return valuesArray[index];
      };
    }

    var eraValues$j = {
      narrow: ['前', '公元'],
      abbreviated: ['前', '公元'],
      wide: ['公元前', '公元']
    };
    var quarterValues$j = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['第一季', '第二季', '第三季', '第四季'],
      wide: ['第一季度', '第二季度', '第三季度', '第四季度']
    };
    var monthValues$j = {
      narrow: ['一', '二', '三', '四', '五', '六', '七', '八', '九', '十', '十一', '十二'],
      abbreviated: ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月'],
      wide: ['一月', '二月', '三月', '四月', '五月', '六月', '七月', '八月', '九月', '十月', '十一月', '十二月']
    };
    var dayValues$j = {
      narrow: ['日', '一', '二', '三', '四', '五', '六'],
      short: ['日', '一', '二', '三', '四', '五', '六'],
      abbreviated: ['周日', '周一', '周二', '周三', '周四', '周五', '周六'],
      wide: ['星期日', '星期一', '星期二', '星期三', '星期四', '星期五', '星期六']
    };
    var dayPeriodValues$j = {
      narrow: {
        am: '上',
        pm: '下',
        midnight: '凌晨',
        noon: '午',
        morning: '早',
        afternoon: '下午',
        evening: '晚',
        night: '夜'
      },
      abbreviated: {
        am: '上午',
        pm: '下午',
        midnight: '凌晨',
        noon: '中午',
        morning: '早晨',
        afternoon: '中午',
        evening: '晚上',
        night: '夜间'
      },
      wide: {
        am: '上午',
        pm: '下午',
        midnight: '凌晨',
        noon: '中午',
        morning: '早晨',
        afternoon: '中午',
        evening: '晚上',
        night: '夜间'
      }
    };
    var formattingDayPeriodValues$e = {
      narrow: {
        am: '上',
        pm: '下',
        midnight: '凌晨',
        noon: '午',
        morning: '早',
        afternoon: '下午',
        evening: '晚',
        night: '夜'
      },
      abbreviated: {
        am: '上午',
        pm: '下午',
        midnight: '凌晨',
        noon: '中午',
        morning: '早晨',
        afternoon: '中午',
        evening: '晚上',
        night: '夜间'
      },
      wide: {
        am: '上午',
        pm: '下午',
        midnight: '凌晨',
        noon: '中午',
        morning: '早晨',
        afternoon: '中午',
        evening: '晚上',
        night: '夜间'
      }
    };

    var ordinalNumber$j = function (dirtyNumber, options) {
      var number = Number(dirtyNumber);

      switch (options === null || options === void 0 ? void 0 : options.unit) {
        case 'date':
          return number.toString() + '日';

        case 'hour':
          return number.toString() + '时';

        case 'minute':
          return number.toString() + '分';

        case 'second':
          return number.toString() + '秒';

        default:
          return '第 ' + number.toString();
      }
    };

    var localize$k = {
      ordinalNumber: ordinalNumber$j,
      era: buildLocalizeFn$1({
        values: eraValues$j,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn$1({
        values: quarterValues$j,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn$1({
        values: monthValues$j,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn$1({
        values: dayValues$j,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn$1({
        values: dayPeriodValues$j,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$e,
        defaultFormattingWidth: 'wide'
      })
    };

    function buildMatchFn$1(args) {
      return function (string) {
        var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
        var width = options.width;
        var matchPattern = width && args.matchPatterns[width] || args.matchPatterns[args.defaultMatchWidth];
        var matchResult = string.match(matchPattern);

        if (!matchResult) {
          return null;
        }

        var matchedString = matchResult[0];
        var parsePatterns = width && args.parsePatterns[width] || args.parsePatterns[args.defaultParseWidth];
        var key = Array.isArray(parsePatterns) ? findIndex(parsePatterns, function (pattern) {
          return pattern.test(matchedString);
        }) : findKey(parsePatterns, function (pattern) {
          return pattern.test(matchedString);
        });
        var value;
        value = args.valueCallback ? args.valueCallback(key) : key;
        value = options.valueCallback ? options.valueCallback(value) : value;
        var rest = string.slice(matchedString.length);
        return {
          value: value,
          rest: rest
        };
      };
    }

    function findKey(object, predicate) {
      for (var key in object) {
        if (object.hasOwnProperty(key) && predicate(object[key])) {
          return key;
        }
      }

      return undefined;
    }

    function findIndex(array, predicate) {
      for (var key = 0; key < array.length; key++) {
        if (predicate(array[key])) {
          return key;
        }
      }

      return undefined;
    }

    function buildMatchPatternFn$1(args) {
      return function (string) {
        var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
        var matchResult = string.match(args.matchPattern);
        if (!matchResult) return null;
        var matchedString = matchResult[0];
        var parseResult = string.match(args.parsePattern);
        if (!parseResult) return null;
        var value = args.valueCallback ? args.valueCallback(parseResult[0]) : parseResult[0];
        value = options.valueCallback ? options.valueCallback(value) : value;
        var rest = string.slice(matchedString.length);
        return {
          value: value,
          rest: rest
        };
      };
    }

    var matchOrdinalNumberPattern$j = /^(第\s*)?\d+(日|时|分|秒)?/i;
    var parseOrdinalNumberPattern$j = /\d+/i;
    var matchEraPatterns$j = {
      narrow: /^(前)/i,
      abbreviated: /^(前)/i,
      wide: /^(公元前|公元)/i
    };
    var parseEraPatterns$j = {
      any: [/^(前)/i, /^(公元)/i]
    };
    var matchQuarterPatterns$j = {
      narrow: /^[1234]/i,
      abbreviated: /^第[一二三四]刻/i,
      wide: /^第[一二三四]刻钟/i
    };
    var parseQuarterPatterns$j = {
      any: [/(1|一)/i, /(2|二)/i, /(3|三)/i, /(4|四)/i]
    };
    var matchMonthPatterns$j = {
      narrow: /^(一|二|三|四|五|六|七|八|九|十[二一])/i,
      abbreviated: /^(一|二|三|四|五|六|七|八|九|十[二一]|\d|1[12])月/i,
      wide: /^(一|二|三|四|五|六|七|八|九|十[二一])月/i
    };
    var parseMonthPatterns$j = {
      narrow: [/^一/i, /^二/i, /^三/i, /^四/i, /^五/i, /^六/i, /^七/i, /^八/i, /^九/i, /^十(?!(一|二))/i, /^十一/i, /^十二/i],
      any: [/^一|1/i, /^二|2/i, /^三|3/i, /^四|4/i, /^五|5/i, /^六|6/i, /^七|7/i, /^八|8/i, /^九|9/i, /^十(?!(一|二))|10/i, /^十一|11/i, /^十二|12/i]
    };
    var matchDayPatterns$j = {
      narrow: /^[一二三四五六日]/i,
      short: /^[一二三四五六日]/i,
      abbreviated: /^周[一二三四五六日]/i,
      wide: /^星期[一二三四五六日]/i
    };
    var parseDayPatterns$j = {
      any: [/日/i, /一/i, /二/i, /三/i, /四/i, /五/i, /六/i]
    };
    var matchDayPeriodPatterns$j = {
      any: /^(上午?|下午?|午夜|[中正]午|早上?|下午|晚上?|凌晨|)/i
    };
    var parseDayPeriodPatterns$j = {
      any: {
        am: /^上午?/i,
        pm: /^下午?/i,
        midnight: /^午夜/i,
        noon: /^[中正]午/i,
        morning: /^早上/i,
        afternoon: /^下午/i,
        evening: /^晚上?/i,
        night: /^凌晨/i
      }
    };
    var match$k = {
      ordinalNumber: buildMatchPatternFn$1({
        matchPattern: matchOrdinalNumberPattern$j,
        parsePattern: parseOrdinalNumberPattern$j,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn$1({
        matchPatterns: matchEraPatterns$j,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$j,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn$1({
        matchPatterns: matchQuarterPatterns$j,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$j,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn$1({
        matchPatterns: matchMonthPatterns$j,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$j,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn$1({
        matchPatterns: matchDayPatterns$j,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$j,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn$1({
        matchPatterns: matchDayPeriodPatterns$j,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$j,
        defaultParseWidth: 'any'
      })
    };

    /**
     * @type {Locale}
     * @category Locales
     * @summary Chinese Simplified locale.
     * @language Chinese Simplified
     * @iso-639-2 zho
     * @author Changyu Geng [@KingMario]{@link https://github.com/KingMario}
     * @author Song Shuoyun [@fnlctrl]{@link https://github.com/fnlctrl}
     * @author sabrinaM [@sabrinamiao]{@link https://github.com/sabrinamiao}
     * @author Carney Wu [@cubicwork]{@link https://github.com/cubicwork}
     * @author Terrence Lam [@skyuplam]{@link https://github.com/skyuplam}
     */

    var locale$k = {
      code: 'zh-CN',
      formatDistance: formatDistance$k,
      formatLong: formatLong$l,
      formatRelative: formatRelative$k,
      localize: localize$k,
      match: match$k,
      options: {
        weekStartsOn: 1
        /* Monday */
        ,
        firstWeekContainsDate: 4
      }
    };

    const dateZhCN = {
      name: "zh-CN",
      locale: locale$k
    };
    var dateZhCN$1 = dateZhCN;

    var formatDistanceLocale$i = {
      lessThanXSeconds: {
        one: '少於 1 秒',
        other: '少於 {{count}} 秒'
      },
      xSeconds: {
        one: '1 秒',
        other: '{{count}} 秒'
      },
      halfAMinute: '半分鐘',
      lessThanXMinutes: {
        one: '少於 1 分鐘',
        other: '少於 {{count}} 分鐘'
      },
      xMinutes: {
        one: '1 分鐘',
        other: '{{count}} 分鐘'
      },
      xHours: {
        one: '1 小時',
        other: '{{count}} 小時'
      },
      aboutXHours: {
        one: '大約 1 小時',
        other: '大約 {{count}} 小時'
      },
      xDays: {
        one: '1 天',
        other: '{{count}} 天'
      },
      aboutXWeeks: {
        one: '大約 1 個星期',
        other: '大約 {{count}} 個星期'
      },
      xWeeks: {
        one: '1 個星期',
        other: '{{count}} 個星期'
      },
      aboutXMonths: {
        one: '大約 1 個月',
        other: '大約 {{count}} 個月'
      },
      xMonths: {
        one: '1 個月',
        other: '{{count}} 個月'
      },
      aboutXYears: {
        one: '大約 1 年',
        other: '大約 {{count}} 年'
      },
      xYears: {
        one: '1 年',
        other: '{{count}} 年'
      },
      overXYears: {
        one: '超過 1 年',
        other: '超過 {{count}} 年'
      },
      almostXYears: {
        one: '將近 1 年',
        other: '將近 {{count}} 年'
      }
    };

    var formatDistance$j = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$i[token];

      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }

      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return result + '內';
        } else {
          return result + '前';
        }
      }

      return result;
    };

    var dateFormats$j = {
      full: "y'年'M'月'd'日' EEEE",
      long: "y'年'M'月'd'日'",
      medium: 'yyyy-MM-dd',
      short: 'yy-MM-dd'
    };
    var timeFormats$j = {
      full: 'zzzz a h:mm:ss',
      long: 'z a h:mm:ss',
      medium: 'a h:mm:ss',
      short: 'a h:mm'
    };
    var dateTimeFormats$j = {
      full: '{{date}} {{time}}',
      long: '{{date}} {{time}}',
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$k = {
      date: buildFormatLongFn$1({
        formats: dateFormats$j,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn$1({
        formats: timeFormats$j,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn$1({
        formats: dateTimeFormats$j,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$i = {
      lastWeek: "'上個'eeee p",
      yesterday: "'昨天' p",
      today: "'今天' p",
      tomorrow: "'明天' p",
      nextWeek: "'下個'eeee p",
      other: 'P'
    };

    var formatRelative$j = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$i[token];
    };

    var eraValues$i = {
      narrow: ['前', '公元'],
      abbreviated: ['前', '公元'],
      wide: ['公元前', '公元']
    };
    var quarterValues$i = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['第一刻', '第二刻', '第三刻', '第四刻'],
      wide: ['第一刻鐘', '第二刻鐘', '第三刻鐘', '第四刻鐘']
    };
    var monthValues$i = {
      narrow: ['一', '二', '三', '四', '五', '六', '七', '八', '九', '十', '十一', '十二'],
      abbreviated: ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月'],
      wide: ['一月', '二月', '三月', '四月', '五月', '六月', '七月', '八月', '九月', '十月', '十一月', '十二月']
    };
    var dayValues$i = {
      narrow: ['日', '一', '二', '三', '四', '五', '六'],
      short: ['日', '一', '二', '三', '四', '五', '六'],
      abbreviated: ['週日', '週一', '週二', '週三', '週四', '週五', '週六'],
      wide: ['星期日', '星期一', '星期二', '星期三', '星期四', '星期五', '星期六']
    };
    var dayPeriodValues$i = {
      narrow: {
        am: '上',
        pm: '下',
        midnight: '凌晨',
        noon: '午',
        morning: '早',
        afternoon: '下午',
        evening: '晚',
        night: '夜'
      },
      abbreviated: {
        am: '上午',
        pm: '下午',
        midnight: '凌晨',
        noon: '中午',
        morning: '早晨',
        afternoon: '中午',
        evening: '晚上',
        night: '夜間'
      },
      wide: {
        am: '上午',
        pm: '下午',
        midnight: '凌晨',
        noon: '中午',
        morning: '早晨',
        afternoon: '中午',
        evening: '晚上',
        night: '夜間'
      }
    };
    var formattingDayPeriodValues$d = {
      narrow: {
        am: '上',
        pm: '下',
        midnight: '凌晨',
        noon: '午',
        morning: '早',
        afternoon: '下午',
        evening: '晚',
        night: '夜'
      },
      abbreviated: {
        am: '上午',
        pm: '下午',
        midnight: '凌晨',
        noon: '中午',
        morning: '早晨',
        afternoon: '中午',
        evening: '晚上',
        night: '夜間'
      },
      wide: {
        am: '上午',
        pm: '下午',
        midnight: '凌晨',
        noon: '中午',
        morning: '早晨',
        afternoon: '中午',
        evening: '晚上',
        night: '夜間'
      }
    };

    var ordinalNumber$i = function (dirtyNumber, options) {
      var number = Number(dirtyNumber);

      switch (options === null || options === void 0 ? void 0 : options.unit) {
        case 'date':
          return number + '日';

        case 'hour':
          return number + '時';

        case 'minute':
          return number + '分';

        case 'second':
          return number + '秒';

        default:
          return '第 ' + number;
      }
    };

    var localize$j = {
      ordinalNumber: ordinalNumber$i,
      era: buildLocalizeFn$1({
        values: eraValues$i,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn$1({
        values: quarterValues$i,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn$1({
        values: monthValues$i,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn$1({
        values: dayValues$i,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn$1({
        values: dayPeriodValues$i,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$d,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$i = /^(第\s*)?\d+(日|時|分|秒)?/i;
    var parseOrdinalNumberPattern$i = /\d+/i;
    var matchEraPatterns$i = {
      narrow: /^(前)/i,
      abbreviated: /^(前)/i,
      wide: /^(公元前|公元)/i
    };
    var parseEraPatterns$i = {
      any: [/^(前)/i, /^(公元)/i]
    };
    var matchQuarterPatterns$i = {
      narrow: /^[1234]/i,
      abbreviated: /^第[一二三四]刻/i,
      wide: /^第[一二三四]刻鐘/i
    };
    var parseQuarterPatterns$i = {
      any: [/(1|一)/i, /(2|二)/i, /(3|三)/i, /(4|四)/i]
    };
    var matchMonthPatterns$i = {
      narrow: /^(一|二|三|四|五|六|七|八|九|十[二一])/i,
      abbreviated: /^(一|二|三|四|五|六|七|八|九|十[二一]|\d|1[12])月/i,
      wide: /^(一|二|三|四|五|六|七|八|九|十[二一])月/i
    };
    var parseMonthPatterns$i = {
      narrow: [/^一/i, /^二/i, /^三/i, /^四/i, /^五/i, /^六/i, /^七/i, /^八/i, /^九/i, /^十(?!(一|二))/i, /^十一/i, /^十二/i],
      any: [/^一|1/i, /^二|2/i, /^三|3/i, /^四|4/i, /^五|5/i, /^六|6/i, /^七|7/i, /^八|8/i, /^九|9/i, /^十(?!(一|二))|10/i, /^十一|11/i, /^十二|12/i]
    };
    var matchDayPatterns$i = {
      narrow: /^[一二三四五六日]/i,
      short: /^[一二三四五六日]/i,
      abbreviated: /^週[一二三四五六日]/i,
      wide: /^星期[一二三四五六日]/i
    };
    var parseDayPatterns$i = {
      any: [/日/i, /一/i, /二/i, /三/i, /四/i, /五/i, /六/i]
    };
    var matchDayPeriodPatterns$i = {
      any: /^(上午?|下午?|午夜|[中正]午|早上?|下午|晚上?|凌晨)/i
    };
    var parseDayPeriodPatterns$i = {
      any: {
        am: /^上午?/i,
        pm: /^下午?/i,
        midnight: /^午夜/i,
        noon: /^[中正]午/i,
        morning: /^早上/i,
        afternoon: /^下午/i,
        evening: /^晚上?/i,
        night: /^凌晨/i
      }
    };
    var match$j = {
      ordinalNumber: buildMatchPatternFn$1({
        matchPattern: matchOrdinalNumberPattern$i,
        parsePattern: parseOrdinalNumberPattern$i,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn$1({
        matchPatterns: matchEraPatterns$i,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$i,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn$1({
        matchPatterns: matchQuarterPatterns$i,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$i,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn$1({
        matchPatterns: matchMonthPatterns$i,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$i,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn$1({
        matchPatterns: matchDayPatterns$i,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$i,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn$1({
        matchPatterns: matchDayPeriodPatterns$i,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$i,
        defaultParseWidth: 'any'
      })
    };

    /**
     * @type {Locale}
     * @category Locales
     * @summary Chinese Traditional locale.
     * @language Chinese Traditional
     * @iso-639-2 zho
     * @author tonypai [@tpai]{@link https://github.com/tpai}
     * @author Jack Hsu [@jackhsu978]{@link https://github.com/jackhsu978}
     * @author Terrence Lam [@skyuplam]{@link https://github.com/skyuplam}
     */

    var locale$j = {
      code: 'zh-TW',
      formatDistance: formatDistance$j,
      formatLong: formatLong$k,
      formatRelative: formatRelative$j,
      localize: localize$j,
      match: match$j,
      options: {
        weekStartsOn: 1
        /* Monday */
        ,
        firstWeekContainsDate: 4
      }
    };

    const datezhTW = {
      name: "zh-TW",
      locale: locale$j
    };
    var datezhTW$1 = datezhTW;

    var formatDistanceLocale$h = {
      lessThanXSeconds: {
        one: 'less than a second',
        other: 'less than {{count}} seconds'
      },
      xSeconds: {
        one: '1 second',
        other: '{{count}} seconds'
      },
      halfAMinute: 'half a minute',
      lessThanXMinutes: {
        one: 'less than a minute',
        other: 'less than {{count}} minutes'
      },
      xMinutes: {
        one: '1 minute',
        other: '{{count}} minutes'
      },
      aboutXHours: {
        one: 'about 1 hour',
        other: 'about {{count}} hours'
      },
      xHours: {
        one: '1 hour',
        other: '{{count}} hours'
      },
      xDays: {
        one: '1 day',
        other: '{{count}} days'
      },
      aboutXWeeks: {
        one: 'about 1 week',
        other: 'about {{count}} weeks'
      },
      xWeeks: {
        one: '1 week',
        other: '{{count}} weeks'
      },
      aboutXMonths: {
        one: 'about 1 month',
        other: 'about {{count}} months'
      },
      xMonths: {
        one: '1 month',
        other: '{{count}} months'
      },
      aboutXYears: {
        one: 'about 1 year',
        other: 'about {{count}} years'
      },
      xYears: {
        one: '1 year',
        other: '{{count}} years'
      },
      overXYears: {
        one: 'over 1 year',
        other: 'over {{count}} years'
      },
      almostXYears: {
        one: 'almost 1 year',
        other: 'almost {{count}} years'
      }
    };

    var formatDistance$i = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$h[token];

      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', count.toString());
      }

      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'in ' + result;
        } else {
          return result + ' ago';
        }
      }

      return result;
    };

    var dateFormats$i = {
      full: 'EEEE, MMMM do, y',
      long: 'MMMM do, y',
      medium: 'MMM d, y',
      short: 'MM/dd/yyyy'
    };
    var timeFormats$i = {
      full: 'h:mm:ss a zzzz',
      long: 'h:mm:ss a z',
      medium: 'h:mm:ss a',
      short: 'h:mm a'
    };
    var dateTimeFormats$i = {
      full: "{{date}} 'at' {{time}}",
      long: "{{date}} 'at' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$j = {
      date: buildFormatLongFn$1({
        formats: dateFormats$i,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn$1({
        formats: timeFormats$i,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn$1({
        formats: dateTimeFormats$i,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$h = {
      lastWeek: "'last' eeee 'at' p",
      yesterday: "'yesterday at' p",
      today: "'today at' p",
      tomorrow: "'tomorrow at' p",
      nextWeek: "eeee 'at' p",
      other: 'P'
    };

    var formatRelative$i = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$h[token];
    };

    var eraValues$h = {
      narrow: ['B', 'A'],
      abbreviated: ['BC', 'AD'],
      wide: ['Before Christ', 'Anno Domini']
    };
    var quarterValues$h = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['1st quarter', '2nd quarter', '3rd quarter', '4th quarter']
    }; // Note: in English, the names of days of the week and months are capitalized.
    // If you are making a new locale based on this one, check if the same is true for the language you're working on.
    // Generally, formatted dates should look like they are in the middle of a sentence,
    // e.g. in Spanish language the weekdays and months should be in the lowercase.

    var monthValues$h = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
      wide: ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December']
    };
    var dayValues$h = {
      narrow: ['S', 'M', 'T', 'W', 'T', 'F', 'S'],
      short: ['Su', 'Mo', 'Tu', 'We', 'Th', 'Fr', 'Sa'],
      abbreviated: ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'],
      wide: ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday']
    };
    var dayPeriodValues$h = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'mi',
        noon: 'n',
        morning: 'morning',
        afternoon: 'afternoon',
        evening: 'evening',
        night: 'night'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'midnight',
        noon: 'noon',
        morning: 'morning',
        afternoon: 'afternoon',
        evening: 'evening',
        night: 'night'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'midnight',
        noon: 'noon',
        morning: 'morning',
        afternoon: 'afternoon',
        evening: 'evening',
        night: 'night'
      }
    };
    var formattingDayPeriodValues$c = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'mi',
        noon: 'n',
        morning: 'in the morning',
        afternoon: 'in the afternoon',
        evening: 'in the evening',
        night: 'at night'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'midnight',
        noon: 'noon',
        morning: 'in the morning',
        afternoon: 'in the afternoon',
        evening: 'in the evening',
        night: 'at night'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'midnight',
        noon: 'noon',
        morning: 'in the morning',
        afternoon: 'in the afternoon',
        evening: 'in the evening',
        night: 'at night'
      }
    };

    var ordinalNumber$h = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber); // If ordinal numbers depend on context, for example,
      // if they are different for different grammatical genders,
      // use `options.unit`.
      //
      // `unit` can be 'year', 'quarter', 'month', 'week', 'date', 'dayOfYear',
      // 'day', 'hour', 'minute', 'second'.

      var rem100 = number % 100;

      if (rem100 > 20 || rem100 < 10) {
        switch (rem100 % 10) {
          case 1:
            return number + 'st';

          case 2:
            return number + 'nd';

          case 3:
            return number + 'rd';
        }
      }

      return number + 'th';
    };

    var localize$i = {
      ordinalNumber: ordinalNumber$h,
      era: buildLocalizeFn$1({
        values: eraValues$h,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn$1({
        values: quarterValues$h,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn$1({
        values: monthValues$h,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn$1({
        values: dayValues$h,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn$1({
        values: dayPeriodValues$h,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$c,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$h = /^(\d+)(th|st|nd|rd)?/i;
    var parseOrdinalNumberPattern$h = /\d+/i;
    var matchEraPatterns$h = {
      narrow: /^(b|a)/i,
      abbreviated: /^(b\.?\s?c\.?|b\.?\s?c\.?\s?e\.?|a\.?\s?d\.?|c\.?\s?e\.?)/i,
      wide: /^(before christ|before common era|anno domini|common era)/i
    };
    var parseEraPatterns$h = {
      any: [/^b/i, /^(a|c)/i]
    };
    var matchQuarterPatterns$h = {
      narrow: /^[1234]/i,
      abbreviated: /^q[1234]/i,
      wide: /^[1234](th|st|nd|rd)? quarter/i
    };
    var parseQuarterPatterns$h = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$h = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(jan|feb|mar|apr|may|jun|jul|aug|sep|oct|nov|dec)/i,
      wide: /^(january|february|march|april|may|june|july|august|september|october|november|december)/i
    };
    var parseMonthPatterns$h = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^f/i, /^mar/i, /^ap/i, /^may/i, /^jun/i, /^jul/i, /^au/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$h = {
      narrow: /^[smtwf]/i,
      short: /^(su|mo|tu|we|th|fr|sa)/i,
      abbreviated: /^(sun|mon|tue|wed|thu|fri|sat)/i,
      wide: /^(sunday|monday|tuesday|wednesday|thursday|friday|saturday)/i
    };
    var parseDayPatterns$h = {
      narrow: [/^s/i, /^m/i, /^t/i, /^w/i, /^t/i, /^f/i, /^s/i],
      any: [/^su/i, /^m/i, /^tu/i, /^w/i, /^th/i, /^f/i, /^sa/i]
    };
    var matchDayPeriodPatterns$h = {
      narrow: /^(a|p|mi|n|(in the|at) (morning|afternoon|evening|night))/i,
      any: /^([ap]\.?\s?m\.?|midnight|noon|(in the|at) (morning|afternoon|evening|night))/i
    };
    var parseDayPeriodPatterns$h = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^mi/i,
        noon: /^no/i,
        morning: /morning/i,
        afternoon: /afternoon/i,
        evening: /evening/i,
        night: /night/i
      }
    };
    var match$i = {
      ordinalNumber: buildMatchPatternFn$1({
        matchPattern: matchOrdinalNumberPattern$h,
        parsePattern: parseOrdinalNumberPattern$h,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn$1({
        matchPatterns: matchEraPatterns$h,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$h,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn$1({
        matchPatterns: matchQuarterPatterns$h,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$h,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn$1({
        matchPatterns: matchMonthPatterns$h,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$h,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn$1({
        matchPatterns: matchDayPatterns$h,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$h,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn$1({
        matchPatterns: matchDayPeriodPatterns$h,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$h,
        defaultParseWidth: 'any'
      })
    };

    /**
     * @type {Locale}
     * @category Locales
     * @summary English locale (United States).
     * @language English
     * @iso-639-2 eng
     * @author Sasha Koss [@kossnocorp]{@link https://github.com/kossnocorp}
     * @author Lesha Koss [@leshakoss]{@link https://github.com/leshakoss}
     */

    var locale$i = {
      code: 'en-US',
      formatDistance: formatDistance$i,
      formatLong: formatLong$j,
      formatRelative: formatRelative$i,
      localize: localize$i,
      match: match$i,
      options: {
        weekStartsOn: 0
        /* Sunday */
        ,
        firstWeekContainsDate: 1
      }
    };
    var defaultLocale$1 = locale$i;

    const dateEnUs = {
      name: "en-US",
      locale: defaultLocale$1
    };
    var dateEnUS = dateEnUs;

    function declension$3(scheme, count) {
      // scheme for count=1 exists
      if (scheme.one !== undefined && count === 1) {
        return scheme.one;
      }

      var rem10 = count % 10;
      var rem100 = count % 100; // 1, 21, 31, ...

      if (rem10 === 1 && rem100 !== 11) {
        return scheme.singularNominative.replace('{{count}}', String(count)); // 2, 3, 4, 22, 23, 24, 32 ...
      } else if (rem10 >= 2 && rem10 <= 4 && (rem100 < 10 || rem100 > 20)) {
        return scheme.singularGenitive.replace('{{count}}', String(count)); // 5, 6, 7, 8, 9, 10, 11, ...
      } else {
        return scheme.pluralGenitive.replace('{{count}}', String(count));
      }
    }

    function buildLocalizeTokenFn$1(scheme) {
      return function (count, options) {
        if (options !== null && options !== void 0 && options.addSuffix) {
          if (options.comparison && options.comparison > 0) {
            if (scheme.future) {
              return declension$3(scheme.future, count);
            } else {
              return 'через ' + declension$3(scheme.regular, count);
            }
          } else {
            if (scheme.past) {
              return declension$3(scheme.past, count);
            } else {
              return declension$3(scheme.regular, count) + ' назад';
            }
          }
        } else {
          return declension$3(scheme.regular, count);
        }
      };
    }

    var formatDistanceLocale$g = {
      lessThanXSeconds: buildLocalizeTokenFn$1({
        regular: {
          one: 'меньше секунды',
          singularNominative: 'меньше {{count}} секунды',
          singularGenitive: 'меньше {{count}} секунд',
          pluralGenitive: 'меньше {{count}} секунд'
        },
        future: {
          one: 'меньше, чем через секунду',
          singularNominative: 'меньше, чем через {{count}} секунду',
          singularGenitive: 'меньше, чем через {{count}} секунды',
          pluralGenitive: 'меньше, чем через {{count}} секунд'
        }
      }),
      xSeconds: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: '{{count}} секунда',
          singularGenitive: '{{count}} секунды',
          pluralGenitive: '{{count}} секунд'
        },
        past: {
          singularNominative: '{{count}} секунду назад',
          singularGenitive: '{{count}} секунды назад',
          pluralGenitive: '{{count}} секунд назад'
        },
        future: {
          singularNominative: 'через {{count}} секунду',
          singularGenitive: 'через {{count}} секунды',
          pluralGenitive: 'через {{count}} секунд'
        }
      }),
      halfAMinute: function (_count, options) {
        if (options !== null && options !== void 0 && options.addSuffix) {
          if (options.comparison && options.comparison > 0) {
            return 'через полминуты';
          } else {
            return 'полминуты назад';
          }
        }

        return 'полминуты';
      },
      lessThanXMinutes: buildLocalizeTokenFn$1({
        regular: {
          one: 'меньше минуты',
          singularNominative: 'меньше {{count}} минуты',
          singularGenitive: 'меньше {{count}} минут',
          pluralGenitive: 'меньше {{count}} минут'
        },
        future: {
          one: 'меньше, чем через минуту',
          singularNominative: 'меньше, чем через {{count}} минуту',
          singularGenitive: 'меньше, чем через {{count}} минуты',
          pluralGenitive: 'меньше, чем через {{count}} минут'
        }
      }),
      xMinutes: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: '{{count}} минута',
          singularGenitive: '{{count}} минуты',
          pluralGenitive: '{{count}} минут'
        },
        past: {
          singularNominative: '{{count}} минуту назад',
          singularGenitive: '{{count}} минуты назад',
          pluralGenitive: '{{count}} минут назад'
        },
        future: {
          singularNominative: 'через {{count}} минуту',
          singularGenitive: 'через {{count}} минуты',
          pluralGenitive: 'через {{count}} минут'
        }
      }),
      aboutXHours: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: 'около {{count}} часа',
          singularGenitive: 'около {{count}} часов',
          pluralGenitive: 'около {{count}} часов'
        },
        future: {
          singularNominative: 'приблизительно через {{count}} час',
          singularGenitive: 'приблизительно через {{count}} часа',
          pluralGenitive: 'приблизительно через {{count}} часов'
        }
      }),
      xHours: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: '{{count}} час',
          singularGenitive: '{{count}} часа',
          pluralGenitive: '{{count}} часов'
        }
      }),
      xDays: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: '{{count}} день',
          singularGenitive: '{{count}} дня',
          pluralGenitive: '{{count}} дней'
        }
      }),
      aboutXWeeks: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: 'около {{count}} недели',
          singularGenitive: 'около {{count}} недель',
          pluralGenitive: 'около {{count}} недель'
        },
        future: {
          singularNominative: 'приблизительно через {{count}} неделю',
          singularGenitive: 'приблизительно через {{count}} недели',
          pluralGenitive: 'приблизительно через {{count}} недель'
        }
      }),
      xWeeks: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: '{{count}} неделя',
          singularGenitive: '{{count}} недели',
          pluralGenitive: '{{count}} недель'
        }
      }),
      aboutXMonths: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: 'около {{count}} месяца',
          singularGenitive: 'около {{count}} месяцев',
          pluralGenitive: 'около {{count}} месяцев'
        },
        future: {
          singularNominative: 'приблизительно через {{count}} месяц',
          singularGenitive: 'приблизительно через {{count}} месяца',
          pluralGenitive: 'приблизительно через {{count}} месяцев'
        }
      }),
      xMonths: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: '{{count}} месяц',
          singularGenitive: '{{count}} месяца',
          pluralGenitive: '{{count}} месяцев'
        }
      }),
      aboutXYears: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: 'около {{count}} года',
          singularGenitive: 'около {{count}} лет',
          pluralGenitive: 'около {{count}} лет'
        },
        future: {
          singularNominative: 'приблизительно через {{count}} год',
          singularGenitive: 'приблизительно через {{count}} года',
          pluralGenitive: 'приблизительно через {{count}} лет'
        }
      }),
      xYears: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: '{{count}} год',
          singularGenitive: '{{count}} года',
          pluralGenitive: '{{count}} лет'
        }
      }),
      overXYears: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: 'больше {{count}} года',
          singularGenitive: 'больше {{count}} лет',
          pluralGenitive: 'больше {{count}} лет'
        },
        future: {
          singularNominative: 'больше, чем через {{count}} год',
          singularGenitive: 'больше, чем через {{count}} года',
          pluralGenitive: 'больше, чем через {{count}} лет'
        }
      }),
      almostXYears: buildLocalizeTokenFn$1({
        regular: {
          singularNominative: 'почти {{count}} год',
          singularGenitive: 'почти {{count}} года',
          pluralGenitive: 'почти {{count}} лет'
        },
        future: {
          singularNominative: 'почти через {{count}} год',
          singularGenitive: 'почти через {{count}} года',
          pluralGenitive: 'почти через {{count}} лет'
        }
      })
    };

    var formatDistance$h = function (token, count, options) {
      return formatDistanceLocale$g[token](count, options);
    };

    var dateFormats$h = {
      full: "EEEE, d MMMM y 'г.'",
      long: "d MMMM y 'г.'",
      medium: "d MMM y 'г.'",
      short: 'dd.MM.y'
    };
    var timeFormats$h = {
      full: 'H:mm:ss zzzz',
      long: 'H:mm:ss z',
      medium: 'H:mm:ss',
      short: 'H:mm'
    };
    var dateTimeFormats$h = {
      any: '{{date}}, {{time}}'
    };
    var formatLong$i = {
      date: buildFormatLongFn$1({
        formats: dateFormats$h,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn$1({
        formats: timeFormats$h,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn$1({
        formats: dateTimeFormats$h,
        defaultWidth: 'any'
      })
    };

    var accusativeWeekdays$2 = ['воскресенье', 'понедельник', 'вторник', 'среду', 'четверг', 'пятницу', 'субботу'];

    function lastWeek$3(day) {
      var weekday = accusativeWeekdays$2[day];

      switch (day) {
        case 0:
          return "'в прошлое " + weekday + " в' p";

        case 1:
        case 2:
        case 4:
          return "'в прошлый " + weekday + " в' p";

        case 3:
        case 5:
        case 6:
          return "'в прошлую " + weekday + " в' p";
      }
    }

    function thisWeek$3(day) {
      var weekday = accusativeWeekdays$2[day];

      if (day === 2
      /* Tue */
      ) {
        return "'во " + weekday + " в' p";
      } else {
        return "'в " + weekday + " в' p";
      }
    }

    function nextWeek$3(day) {
      var weekday = accusativeWeekdays$2[day];

      switch (day) {
        case 0:
          return "'в следующее " + weekday + " в' p";

        case 1:
        case 2:
        case 4:
          return "'в следующий " + weekday + " в' p";

        case 3:
        case 5:
        case 6:
          return "'в следующую " + weekday + " в' p";
      }
    }

    var formatRelativeLocale$g = {
      lastWeek: function (date, baseDate, options) {
        var day = date.getUTCDay();

        if (isSameUTCWeek(date, baseDate, options)) {
          return thisWeek$3(day);
        } else {
          return lastWeek$3(day);
        }
      },
      yesterday: "'вчера в' p",
      today: "'сегодня в' p",
      tomorrow: "'завтра в' p",
      nextWeek: function (date, baseDate, options) {
        var day = date.getUTCDay();

        if (isSameUTCWeek(date, baseDate, options)) {
          return thisWeek$3(day);
        } else {
          return nextWeek$3(day);
        }
      },
      other: 'P'
    };

    var formatRelative$h = function (token, date, baseDate, options) {
      var format = formatRelativeLocale$g[token];

      if (typeof format === 'function') {
        return format(date, baseDate, options);
      }

      return format;
    };

    var eraValues$g = {
      narrow: ['до н.э.', 'н.э.'],
      abbreviated: ['до н. э.', 'н. э.'],
      wide: ['до нашей эры', 'нашей эры']
    };
    var quarterValues$g = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['1-й кв.', '2-й кв.', '3-й кв.', '4-й кв.'],
      wide: ['1-й квартал', '2-й квартал', '3-й квартал', '4-й квартал']
    };
    var monthValues$g = {
      narrow: ['Я', 'Ф', 'М', 'А', 'М', 'И', 'И', 'А', 'С', 'О', 'Н', 'Д'],
      abbreviated: ['янв.', 'фев.', 'март', 'апр.', 'май', 'июнь', 'июль', 'авг.', 'сент.', 'окт.', 'нояб.', 'дек.'],
      wide: ['январь', 'февраль', 'март', 'апрель', 'май', 'июнь', 'июль', 'август', 'сентябрь', 'октябрь', 'ноябрь', 'декабрь']
    };
    var formattingMonthValues$4 = {
      narrow: ['Я', 'Ф', 'М', 'А', 'М', 'И', 'И', 'А', 'С', 'О', 'Н', 'Д'],
      abbreviated: ['янв.', 'фев.', 'мар.', 'апр.', 'мая', 'июн.', 'июл.', 'авг.', 'сент.', 'окт.', 'нояб.', 'дек.'],
      wide: ['января', 'февраля', 'марта', 'апреля', 'мая', 'июня', 'июля', 'августа', 'сентября', 'октября', 'ноября', 'декабря']
    };
    var dayValues$g = {
      narrow: ['В', 'П', 'В', 'С', 'Ч', 'П', 'С'],
      short: ['вс', 'пн', 'вт', 'ср', 'чт', 'пт', 'сб'],
      abbreviated: ['вск', 'пнд', 'втр', 'срд', 'чтв', 'птн', 'суб'],
      wide: ['воскресенье', 'понедельник', 'вторник', 'среда', 'четверг', 'пятница', 'суббота']
    };
    var dayPeriodValues$g = {
      narrow: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'полн.',
        noon: 'полд.',
        morning: 'утро',
        afternoon: 'день',
        evening: 'веч.',
        night: 'ночь'
      },
      abbreviated: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'полн.',
        noon: 'полд.',
        morning: 'утро',
        afternoon: 'день',
        evening: 'веч.',
        night: 'ночь'
      },
      wide: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'полночь',
        noon: 'полдень',
        morning: 'утро',
        afternoon: 'день',
        evening: 'вечер',
        night: 'ночь'
      }
    };
    var formattingDayPeriodValues$b = {
      narrow: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'полн.',
        noon: 'полд.',
        morning: 'утра',
        afternoon: 'дня',
        evening: 'веч.',
        night: 'ночи'
      },
      abbreviated: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'полн.',
        noon: 'полд.',
        morning: 'утра',
        afternoon: 'дня',
        evening: 'веч.',
        night: 'ночи'
      },
      wide: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'полночь',
        noon: 'полдень',
        morning: 'утра',
        afternoon: 'дня',
        evening: 'вечера',
        night: 'ночи'
      }
    };

    var ordinalNumber$g = function (dirtyNumber, options) {
      var number = Number(dirtyNumber);
      var unit = options === null || options === void 0 ? void 0 : options.unit;
      var suffix;

      if (unit === 'date') {
        suffix = '-е';
      } else if (unit === 'week' || unit === 'minute' || unit === 'second') {
        suffix = '-я';
      } else {
        suffix = '-й';
      }

      return number + suffix;
    };

    var localize$h = {
      ordinalNumber: ordinalNumber$g,
      era: buildLocalizeFn$1({
        values: eraValues$g,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn$1({
        values: quarterValues$g,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn$1({
        values: monthValues$g,
        defaultWidth: 'wide',
        formattingValues: formattingMonthValues$4,
        defaultFormattingWidth: 'wide'
      }),
      day: buildLocalizeFn$1({
        values: dayValues$g,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn$1({
        values: dayPeriodValues$g,
        defaultWidth: 'any',
        formattingValues: formattingDayPeriodValues$b,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$g = /^(\d+)(-?(е|я|й|ое|ье|ая|ья|ый|ой|ий|ый))?/i;
    var parseOrdinalNumberPattern$g = /\d+/i;
    var matchEraPatterns$g = {
      narrow: /^((до )?н\.?\s?э\.?)/i,
      abbreviated: /^((до )?н\.?\s?э\.?)/i,
      wide: /^(до нашей эры|нашей эры|наша эра)/i
    };
    var parseEraPatterns$g = {
      any: [/^д/i, /^н/i]
    };
    var matchQuarterPatterns$g = {
      narrow: /^[1234]/i,
      abbreviated: /^[1234](-?[ыои]?й?)? кв.?/i,
      wide: /^[1234](-?[ыои]?й?)? квартал/i
    };
    var parseQuarterPatterns$g = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$g = {
      narrow: /^[яфмаисонд]/i,
      abbreviated: /^(янв|фев|март?|апр|ма[йя]|июн[ья]?|июл[ья]?|авг|сент?|окт|нояб?|дек)\.?/i,
      wide: /^(январ[ья]|феврал[ья]|марта?|апрел[ья]|ма[йя]|июн[ья]|июл[ья]|августа?|сентябр[ья]|октябр[ья]|октябр[ья]|ноябр[ья]|декабр[ья])/i
    };
    var parseMonthPatterns$g = {
      narrow: [/^я/i, /^ф/i, /^м/i, /^а/i, /^м/i, /^и/i, /^и/i, /^а/i, /^с/i, /^о/i, /^н/i, /^я/i],
      any: [/^я/i, /^ф/i, /^мар/i, /^ап/i, /^ма[йя]/i, /^июн/i, /^июл/i, /^ав/i, /^с/i, /^о/i, /^н/i, /^д/i]
    };
    var matchDayPatterns$g = {
      narrow: /^[впсч]/i,
      short: /^(вс|во|пн|по|вт|ср|чт|че|пт|пя|сб|су)\.?/i,
      abbreviated: /^(вск|вос|пнд|пон|втр|вто|срд|сре|чтв|чет|птн|пят|суб).?/i,
      wide: /^(воскресень[ея]|понедельника?|вторника?|сред[аы]|четверга?|пятниц[аы]|суббот[аы])/i
    };
    var parseDayPatterns$g = {
      narrow: [/^в/i, /^п/i, /^в/i, /^с/i, /^ч/i, /^п/i, /^с/i],
      any: [/^в[ос]/i, /^п[он]/i, /^в/i, /^ср/i, /^ч/i, /^п[ят]/i, /^с[уб]/i]
    };
    var matchDayPeriodPatterns$g = {
      narrow: /^([дп]п|полн\.?|полд\.?|утр[оа]|день|дня|веч\.?|ноч[ьи])/i,
      abbreviated: /^([дп]п|полн\.?|полд\.?|утр[оа]|день|дня|веч\.?|ноч[ьи])/i,
      wide: /^([дп]п|полночь|полдень|утр[оа]|день|дня|вечера?|ноч[ьи])/i
    };
    var parseDayPeriodPatterns$g = {
      any: {
        am: /^дп/i,
        pm: /^пп/i,
        midnight: /^полн/i,
        noon: /^полд/i,
        morning: /^у/i,
        afternoon: /^д[ен]/i,
        evening: /^в/i,
        night: /^н/i
      }
    };
    var match$h = {
      ordinalNumber: buildMatchPatternFn$1({
        matchPattern: matchOrdinalNumberPattern$g,
        parsePattern: parseOrdinalNumberPattern$g,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn$1({
        matchPatterns: matchEraPatterns$g,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$g,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn$1({
        matchPatterns: matchQuarterPatterns$g,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$g,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn$1({
        matchPatterns: matchMonthPatterns$g,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$g,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn$1({
        matchPatterns: matchDayPatterns$g,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$g,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn$1({
        matchPatterns: matchDayPeriodPatterns$g,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPeriodPatterns$g,
        defaultParseWidth: 'any'
      })
    };

    /**
     * @type {Locale}
     * @category Locales
     * @summary Russian locale.
     * @language Russian
     * @iso-639-2 rus
     * @author Sasha Koss [@kossnocorp]{@link https://github.com/kossnocorp}
     * @author Lesha Koss [@leshakoss]{@link https://github.com/leshakoss}
     */

    var locale$h = {
      code: 'ru',
      formatDistance: formatDistance$h,
      formatLong: formatLong$i,
      formatRelative: formatRelative$h,
      localize: localize$h,
      match: match$h,
      options: {
        weekStartsOn: 1
        /* Monday */
        ,
        firstWeekContainsDate: 1
      }
    };

    const dateRuRU = {
      name: "ru-RU",
      locale: locale$h
    };
    var dateRuRU$1 = dateRuRU;

    function declension$2(scheme, count) {
      // scheme for count=1 exists
      if (scheme.one !== undefined && count === 1) {
        return scheme.one;
      }

      var rem10 = count % 10;
      var rem100 = count % 100; // 1, 21, 31, ...

      if (rem10 === 1 && rem100 !== 11) {
        return scheme.singularNominative.replace('{{count}}', String(count)); // 2, 3, 4, 22, 23, 24, 32 ...
      } else if (rem10 >= 2 && rem10 <= 4 && (rem100 < 10 || rem100 > 20)) {
        return scheme.singularGenitive.replace('{{count}}', String(count)); // 5, 6, 7, 8, 9, 10, 11, ...
      } else {
        return scheme.pluralGenitive.replace('{{count}}', String(count));
      }
    }

    function buildLocalizeTokenFn(scheme) {
      return function (count, options) {
        if (options && options.addSuffix) {
          if (options.comparison && options.comparison > 0) {
            if (scheme.future) {
              return declension$2(scheme.future, count);
            } else {
              return 'за ' + declension$2(scheme.regular, count);
            }
          } else {
            if (scheme.past) {
              return declension$2(scheme.past, count);
            } else {
              return declension$2(scheme.regular, count) + ' тому';
            }
          }
        } else {
          return declension$2(scheme.regular, count);
        }
      };
    }

    var halfAtMinute = function (_, options) {
      if (options && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'за півхвилини';
        } else {
          return 'півхвилини тому';
        }
      }

      return 'півхвилини';
    };

    var formatDistanceLocale$f = {
      lessThanXSeconds: buildLocalizeTokenFn({
        regular: {
          one: 'менше секунди',
          singularNominative: 'менше {{count}} секунди',
          singularGenitive: 'менше {{count}} секунд',
          pluralGenitive: 'менше {{count}} секунд'
        },
        future: {
          one: 'менше, ніж за секунду',
          singularNominative: 'менше, ніж за {{count}} секунду',
          singularGenitive: 'менше, ніж за {{count}} секунди',
          pluralGenitive: 'менше, ніж за {{count}} секунд'
        }
      }),
      xSeconds: buildLocalizeTokenFn({
        regular: {
          singularNominative: '{{count}} секунда',
          singularGenitive: '{{count}} секунди',
          pluralGenitive: '{{count}} секунд'
        },
        past: {
          singularNominative: '{{count}} секунду тому',
          singularGenitive: '{{count}} секунди тому',
          pluralGenitive: '{{count}} секунд тому'
        },
        future: {
          singularNominative: 'за {{count}} секунду',
          singularGenitive: 'за {{count}} секунди',
          pluralGenitive: 'за {{count}} секунд'
        }
      }),
      halfAMinute: halfAtMinute,
      lessThanXMinutes: buildLocalizeTokenFn({
        regular: {
          one: 'менше хвилини',
          singularNominative: 'менше {{count}} хвилини',
          singularGenitive: 'менше {{count}} хвилин',
          pluralGenitive: 'менше {{count}} хвилин'
        },
        future: {
          one: 'менше, ніж за хвилину',
          singularNominative: 'менше, ніж за {{count}} хвилину',
          singularGenitive: 'менше, ніж за {{count}} хвилини',
          pluralGenitive: 'менше, ніж за {{count}} хвилин'
        }
      }),
      xMinutes: buildLocalizeTokenFn({
        regular: {
          singularNominative: '{{count}} хвилина',
          singularGenitive: '{{count}} хвилини',
          pluralGenitive: '{{count}} хвилин'
        },
        past: {
          singularNominative: '{{count}} хвилину тому',
          singularGenitive: '{{count}} хвилини тому',
          pluralGenitive: '{{count}} хвилин тому'
        },
        future: {
          singularNominative: 'за {{count}} хвилину',
          singularGenitive: 'за {{count}} хвилини',
          pluralGenitive: 'за {{count}} хвилин'
        }
      }),
      aboutXHours: buildLocalizeTokenFn({
        regular: {
          singularNominative: 'близько {{count}} години',
          singularGenitive: 'близько {{count}} годин',
          pluralGenitive: 'близько {{count}} годин'
        },
        future: {
          singularNominative: 'приблизно за {{count}} годину',
          singularGenitive: 'приблизно за {{count}} години',
          pluralGenitive: 'приблизно за {{count}} годин'
        }
      }),
      xHours: buildLocalizeTokenFn({
        regular: {
          singularNominative: '{{count}} годину',
          singularGenitive: '{{count}} години',
          pluralGenitive: '{{count}} годин'
        }
      }),
      xDays: buildLocalizeTokenFn({
        regular: {
          singularNominative: '{{count}} день',
          singularGenitive: '{{count}} дня',
          pluralGenitive: '{{count}} днів'
        }
      }),
      aboutXWeeks: buildLocalizeTokenFn({
        regular: {
          singularNominative: 'близько {{count}} тижня',
          singularGenitive: 'близько {{count}} тижнів',
          pluralGenitive: 'близько {{count}} тижнів'
        },
        future: {
          singularNominative: 'приблизно за {{count}} тиждень',
          singularGenitive: 'приблизно за {{count}} тижні',
          pluralGenitive: 'приблизно за {{count}} тижні'
        }
      }),
      xWeeks: buildLocalizeTokenFn({
        regular: {
          singularNominative: '{{count}} тиждень',
          singularGenitive: '{{count}} тижня',
          pluralGenitive: '{{count}} тижні'
        }
      }),
      aboutXMonths: buildLocalizeTokenFn({
        regular: {
          singularNominative: 'близько {{count}} місяця',
          singularGenitive: 'близько {{count}} місяців',
          pluralGenitive: 'близько {{count}} місяців'
        },
        future: {
          singularNominative: 'приблизно за {{count}} місяць',
          singularGenitive: 'приблизно за {{count}} місяця',
          pluralGenitive: 'приблизно за {{count}} місяців'
        }
      }),
      xMonths: buildLocalizeTokenFn({
        regular: {
          singularNominative: '{{count}} місяць',
          singularGenitive: '{{count}} місяця',
          pluralGenitive: '{{count}} місяців'
        }
      }),
      aboutXYears: buildLocalizeTokenFn({
        regular: {
          singularNominative: 'близько {{count}} року',
          singularGenitive: 'близько {{count}} років',
          pluralGenitive: 'близько {{count}} років'
        },
        future: {
          singularNominative: 'приблизно за {{count}} рік',
          singularGenitive: 'приблизно за {{count}} роки',
          pluralGenitive: 'приблизно за {{count}} років'
        }
      }),
      xYears: buildLocalizeTokenFn({
        regular: {
          singularNominative: '{{count}} рік',
          singularGenitive: '{{count}} роки',
          pluralGenitive: '{{count}} років'
        }
      }),
      overXYears: buildLocalizeTokenFn({
        regular: {
          singularNominative: 'більше {{count}} року',
          singularGenitive: 'більше {{count}} років',
          pluralGenitive: 'більше {{count}} років'
        },
        future: {
          singularNominative: 'більше, ніж за {{count}} рік',
          singularGenitive: 'більше, ніж за {{count}} роки',
          pluralGenitive: 'більше, ніж за {{count}} років'
        }
      }),
      almostXYears: buildLocalizeTokenFn({
        regular: {
          singularNominative: 'майже {{count}} рік',
          singularGenitive: 'майже {{count}} роки',
          pluralGenitive: 'майже {{count}} років'
        },
        future: {
          singularNominative: 'майже за {{count}} рік',
          singularGenitive: 'майже за {{count}} роки',
          pluralGenitive: 'майже за {{count}} років'
        }
      })
    };

    var formatDistance$g = function (token, count, options) {
      options = options || {};
      return formatDistanceLocale$f[token](count, options);
    };

    var dateFormats$g = {
      full: "EEEE, do MMMM y 'р.'",
      long: "do MMMM y 'р.'",
      medium: "d MMM y 'р.'",
      short: 'dd.MM.y'
    };
    var timeFormats$g = {
      full: 'H:mm:ss zzzz',
      long: 'H:mm:ss z',
      medium: 'H:mm:ss',
      short: 'H:mm'
    };
    var dateTimeFormats$g = {
      full: "{{date}} 'о' {{time}}",
      long: "{{date}} 'о' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$h = {
      date: buildFormatLongFn$1({
        formats: dateFormats$g,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn$1({
        formats: timeFormats$g,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn$1({
        formats: dateTimeFormats$g,
        defaultWidth: 'full'
      })
    };

    /**
     * @name addDays
     * @category Day Helpers
     * @summary Add the specified number of days to the given date.
     *
     * @description
     * Add the specified number of days to the given date.
     *
     * @param {Date|Number} date - the date to be changed
     * @param {Number} amount - the amount of days to be added. Positive decimals will be rounded using `Math.floor`, decimals less than zero will be rounded using `Math.ceil`.
     * @returns {Date} - the new date with the days added
     * @throws {TypeError} - 2 arguments required
     *
     * @example
     * // Add 10 days to 1 September 2014:
     * const result = addDays(new Date(2014, 8, 1), 10)
     * //=> Thu Sep 11 2014 00:00:00
     */

    function addDays(dirtyDate, dirtyAmount) {
      requiredArgs$1(2, arguments);
      var date = toDate$2(dirtyDate);
      var amount = toInteger$1(dirtyAmount);

      if (isNaN(amount)) {
        return new Date(NaN);
      }

      if (!amount) {
        // If 0 days, no-op to avoid changing times in the hour before end of DST
        return date;
      }

      date.setDate(date.getDate() + amount);
      return date;
    }

    /**
     * @name addMonths
     * @category Month Helpers
     * @summary Add the specified number of months to the given date.
     *
     * @description
     * Add the specified number of months to the given date.
     *
     * @param {Date|Number} date - the date to be changed
     * @param {Number} amount - the amount of months to be added. Positive decimals will be rounded using `Math.floor`, decimals less than zero will be rounded using `Math.ceil`.
     * @returns {Date} the new date with the months added
     * @throws {TypeError} 2 arguments required
     *
     * @example
     * // Add 5 months to 1 September 2014:
     * const result = addMonths(new Date(2014, 8, 1), 5)
     * //=> Sun Feb 01 2015 00:00:00
     */

    function addMonths(dirtyDate, dirtyAmount) {
      requiredArgs$1(2, arguments);
      var date = toDate$2(dirtyDate);
      var amount = toInteger$1(dirtyAmount);

      if (isNaN(amount)) {
        return new Date(NaN);
      }

      if (!amount) {
        // If 0 months, no-op to avoid changing times in the hour before end of DST
        return date;
      }

      var dayOfMonth = date.getDate(); // The JS Date object supports date math by accepting out-of-bounds values for
      // month, day, etc. For example, new Date(2020, 0, 0) returns 31 Dec 2019 and
      // new Date(2020, 13, 1) returns 1 Feb 2021.  This is *almost* the behavior we
      // want except that dates will wrap around the end of a month, meaning that
      // new Date(2020, 13, 31) will return 3 Mar 2021 not 28 Feb 2021 as desired. So
      // we'll default to the end of the desired month by adding 1 to the desired
      // month and using a date of 0 to back up one day to the end of the desired
      // month.

      var endOfDesiredMonth = new Date(date.getTime());
      endOfDesiredMonth.setMonth(date.getMonth() + amount + 1, 0);
      var daysInMonth = endOfDesiredMonth.getDate();

      if (dayOfMonth >= daysInMonth) {
        // If we're already at the end of the month, then this is the correct date
        // and we're done.
        return endOfDesiredMonth;
      } else {
        // Otherwise, we now know that setting the original day-of-month value won't
        // cause an overflow, so set the desired day-of-month. Note that we can't
        // just set the date of `endOfDesiredMonth` because that object may have had
        // its time changed in the unusual case where where a DST transition was on
        // the last day of the month and its local time was in the hour skipped or
        // repeated next to a DST transition.  So we use `date` instead which is
        // guaranteed to still have the original time.
        date.setFullYear(endOfDesiredMonth.getFullYear(), endOfDesiredMonth.getMonth(), dayOfMonth);
        return date;
      }
    }

    /**
     * @name addMilliseconds
     * @category Millisecond Helpers
     * @summary Add the specified number of milliseconds to the given date.
     *
     * @description
     * Add the specified number of milliseconds to the given date.
     *
     * @param {Date|Number} date - the date to be changed
     * @param {Number} amount - the amount of milliseconds to be added. Positive decimals will be rounded using `Math.floor`, decimals less than zero will be rounded using `Math.ceil`.
     * @returns {Date} the new date with the milliseconds added
     * @throws {TypeError} 2 arguments required
     *
     * @example
     * // Add 750 milliseconds to 10 July 2014 12:45:30.000:
     * const result = addMilliseconds(new Date(2014, 6, 10, 12, 45, 30, 0), 750)
     * //=> Thu Jul 10 2014 12:45:30.750
     */

    function addMilliseconds$1(dirtyDate, dirtyAmount) {
      requiredArgs$1(2, arguments);
      var timestamp = toDate$2(dirtyDate).getTime();
      var amount = toInteger$1(dirtyAmount);
      return new Date(timestamp + amount);
    }

    /**
     * Google Chrome as of 67.0.3396.87 introduced timezones with offset that includes seconds.
     * They usually appear for dates that denote time before the timezones were introduced
     * (e.g. for 'Europe/Prague' timezone the offset is GMT+00:57:44 before 1 October 1891
     * and GMT+01:00:00 after that date)
     *
     * Date#getTimezoneOffset returns the offset in minutes and would return 57 for the example above,
     * which would lead to incorrect calculations.
     *
     * This function returns the timezone offset in milliseconds that takes seconds in account.
     */
    function getTimezoneOffsetInMilliseconds$1(date) {
      var utcDate = new Date(Date.UTC(date.getFullYear(), date.getMonth(), date.getDate(), date.getHours(), date.getMinutes(), date.getSeconds(), date.getMilliseconds()));
      utcDate.setUTCFullYear(date.getFullYear());
      return date.getTime() - utcDate.getTime();
    }

    /**
     * @name startOfDay
     * @category Day Helpers
     * @summary Return the start of a day for the given date.
     *
     * @description
     * Return the start of a day for the given date.
     * The result will be in the local timezone.
     *
     * @param {Date|Number} date - the original date
     * @returns {Date} the start of a day
     * @throws {TypeError} 1 argument required
     *
     * @example
     * // The start of a day for 2 September 2014 11:55:00:
     * const result = startOfDay(new Date(2014, 8, 2, 11, 55, 0))
     * //=> Tue Sep 02 2014 00:00:00
     */

    function startOfDay(dirtyDate) {
      requiredArgs$1(1, arguments);
      var date = toDate$2(dirtyDate);
      date.setHours(0, 0, 0, 0);
      return date;
    }

    /**
     * @name addQuarters
     * @category Quarter Helpers
     * @summary Add the specified number of year quarters to the given date.
     *
     * @description
     * Add the specified number of year quarters to the given date.
     *
     * @param {Date|Number} date - the date to be changed
     * @param {Number} amount - the amount of quarters to be added. Positive decimals will be rounded using `Math.floor`, decimals less than zero will be rounded using `Math.ceil`.
     * @returns {Date} the new date with the quarters added
     * @throws {TypeError} 2 arguments required
     *
     * @example
     * // Add 1 quarter to 1 September 2014:
     * const result = addQuarters(new Date(2014, 8, 1), 1)
     * //=> Mon Dec 01 2014 00:00:00
     */

    function addQuarters(dirtyDate, dirtyAmount) {
      requiredArgs$1(2, arguments);
      var amount = toInteger$1(dirtyAmount);
      var months = amount * 3;
      return addMonths(dirtyDate, months);
    }

    /**
     * @name addYears
     * @category Year Helpers
     * @summary Add the specified number of years to the given date.
     *
     * @description
     * Add the specified number of years to the given date.
     *
     * @param {Date|Number} date - the date to be changed
     * @param {Number} amount - the amount of years to be added. Positive decimals will be rounded using `Math.floor`, decimals less than zero will be rounded using `Math.ceil`.
     * @returns {Date} the new date with the years added
     * @throws {TypeError} 2 arguments required
     *
     * @example
     * // Add 5 years to 1 September 2014:
     * const result = addYears(new Date(2014, 8, 1), 5)
     * //=> Sun Sep 01 2019 00:00:00
     */

    function addYears(dirtyDate, dirtyAmount) {
      requiredArgs$1(2, arguments);
      var amount = toInteger$1(dirtyAmount);
      return addMonths(dirtyDate, amount * 12);
    }

    /**
     * @name compareAsc
     * @category Common Helpers
     * @summary Compare the two dates and return -1, 0 or 1.
     *
     * @description
     * Compare the two dates and return 1 if the first date is after the second,
     * -1 if the first date is before the second or 0 if dates are equal.
     *
     * @param {Date|Number} dateLeft - the first date to compare
     * @param {Date|Number} dateRight - the second date to compare
     * @returns {Number} the result of the comparison
     * @throws {TypeError} 2 arguments required
     *
     * @example
     * // Compare 11 February 1987 and 10 July 1989:
     * const result = compareAsc(new Date(1987, 1, 11), new Date(1989, 6, 10))
     * //=> -1
     *
     * @example
     * // Sort the array of dates:
     * const result = [
     *   new Date(1995, 6, 2),
     *   new Date(1987, 1, 11),
     *   new Date(1989, 6, 10)
     * ].sort(compareAsc)
     * //=> [
     * //   Wed Feb 11 1987 00:00:00,
     * //   Mon Jul 10 1989 00:00:00,
     * //   Sun Jul 02 1995 00:00:00
     * // ]
     */

    function compareAsc(dirtyDateLeft, dirtyDateRight) {
      requiredArgs$1(2, arguments);
      var dateLeft = toDate$2(dirtyDateLeft);
      var dateRight = toDate$2(dirtyDateRight);
      var diff = dateLeft.getTime() - dateRight.getTime();

      if (diff < 0) {
        return -1;
      } else if (diff > 0) {
        return 1; // Return 0 if diff is 0; return NaN if diff is NaN
      } else {
        return diff;
      }
    }

    /**
     * Days in 1 week.
     *
     * @name daysInWeek
     * @constant
     * @type {number}
     * @default
     */
    /**
     * Milliseconds in 1 minute
     *
     * @name millisecondsInMinute
     * @constant
     * @type {number}
     * @default
     */

    var millisecondsInMinute = 60000;
    /**
     * Milliseconds in 1 hour
     *
     * @name millisecondsInHour
     * @constant
     * @type {number}
     * @default
     */

    var millisecondsInHour = 3600000;
    /**
     * Milliseconds in 1 second
     *
     * @name millisecondsInSecond
     * @constant
     * @type {number}
     * @default
     */

    var millisecondsInSecond = 1000;

    /**
     * @name isSameDay
     * @category Day Helpers
     * @summary Are the given dates in the same day (and year and month)?
     *
     * @description
     * Are the given dates in the same day (and year and month)?
     *
     * @param {Date|Number} dateLeft - the first date to check
     * @param {Date|Number} dateRight - the second date to check
     * @returns {Boolean} the dates are in the same day (and year and month)
     * @throws {TypeError} 2 arguments required
     *
     * @example
     * // Are 4 September 06:00:00 and 4 September 18:00:00 in the same day?
     * const result = isSameDay(new Date(2014, 8, 4, 6, 0), new Date(2014, 8, 4, 18, 0))
     * //=> true
     *
     * @example
     * // Are 4 September and 4 October in the same day?
     * const result = isSameDay(new Date(2014, 8, 4), new Date(2014, 9, 4))
     * //=> false
     *
     * @example
     * // Are 4 September, 2014 and 4 September, 2015 in the same day?
     * const result = isSameDay(new Date(2014, 8, 4), new Date(2015, 8, 4))
     * //=> false
     */

    function isSameDay(dirtyDateLeft, dirtyDateRight) {
      requiredArgs$1(2, arguments);
      var dateLeftStartOfDay = startOfDay(dirtyDateLeft);
      var dateRightStartOfDay = startOfDay(dirtyDateRight);
      return dateLeftStartOfDay.getTime() === dateRightStartOfDay.getTime();
    }

    /**
     * @name isDate
     * @category Common Helpers
     * @summary Is the given value a date?
     *
     * @description
     * Returns true if the given value is an instance of Date. The function works for dates transferred across iframes.
     *
     * @param {*} value - the value to check
     * @returns {boolean} true if the given value is a date
     * @throws {TypeError} 1 arguments required
     *
     * @example
     * // For a valid date:
     * const result = isDate(new Date())
     * //=> true
     *
     * @example
     * // For an invalid date:
     * const result = isDate(new Date(NaN))
     * //=> true
     *
     * @example
     * // For some value:
     * const result = isDate('2014-02-31')
     * //=> false
     *
     * @example
     * // For an object:
     * const result = isDate({})
     * //=> false
     */

    function isDate$1(value) {
      requiredArgs$1(1, arguments);
      return value instanceof Date || typeof value === 'object' && Object.prototype.toString.call(value) === '[object Date]';
    }

    /**
     * @name isValid
     * @category Common Helpers
     * @summary Is the given date valid?
     *
     * @description
     * Returns false if argument is Invalid Date and true otherwise.
     * Argument is converted to Date using `toDate`. See [toDate]{@link https://date-fns.org/docs/toDate}
     * Invalid Date is a Date, whose time value is NaN.
     *
     * Time value of Date: http://es5.github.io/#x15.9.1.1
     *
     * @param {*} date - the date to check
     * @returns {Boolean} the date is valid
     * @throws {TypeError} 1 argument required
     *
     * @example
     * // For the valid date:
     * const result = isValid(new Date(2014, 1, 31))
     * //=> true
     *
     * @example
     * // For the value, convertable into a date:
     * const result = isValid(1393804800000)
     * //=> true
     *
     * @example
     * // For the invalid date:
     * const result = isValid(new Date(''))
     * //=> false
     */

    function isValid$1(dirtyDate) {
      requiredArgs$1(1, arguments);

      if (!isDate$1(dirtyDate) && typeof dirtyDate !== 'number') {
        return false;
      }

      var date = toDate$2(dirtyDate);
      return !isNaN(Number(date));
    }

    /**
     * @name getQuarter
     * @category Quarter Helpers
     * @summary Get the year quarter of the given date.
     *
     * @description
     * Get the year quarter of the given date.
     *
     * @param {Date|Number} date - the given date
     * @returns {Number} the quarter
     * @throws {TypeError} 1 argument required
     *
     * @example
     * // Which quarter is 2 July 2014?
     * const result = getQuarter(new Date(2014, 6, 2))
     * //=> 3
     */

    function getQuarter(dirtyDate) {
      requiredArgs$1(1, arguments);
      var date = toDate$2(dirtyDate);
      var quarter = Math.floor(date.getMonth() / 3) + 1;
      return quarter;
    }

    /**
     * @name startOfMinute
     * @category Minute Helpers
     * @summary Return the start of a minute for the given date.
     *
     * @description
     * Return the start of a minute for the given date.
     * The result will be in the local timezone.
     *
     * @param {Date|Number} date - the original date
     * @returns {Date} the start of a minute
     * @throws {TypeError} 1 argument required
     *
     * @example
     * // The start of a minute for 1 December 2014 22:15:45.400:
     * const result = startOfMinute(new Date(2014, 11, 1, 22, 15, 45, 400))
     * //=> Mon Dec 01 2014 22:15:00
     */

    function startOfMinute(dirtyDate) {
      requiredArgs$1(1, arguments);
      var date = toDate$2(dirtyDate);
      date.setSeconds(0, 0);
      return date;
    }

    /**
     * @name startOfQuarter
     * @category Quarter Helpers
     * @summary Return the start of a year quarter for the given date.
     *
     * @description
     * Return the start of a year quarter for the given date.
     * The result will be in the local timezone.
     *
     * @param {Date|Number} date - the original date
     * @returns {Date} the start of a quarter
     * @throws {TypeError} 1 argument required
     *
     * @example
     * // The start of a quarter for 2 September 2014 11:55:00:
     * const result = startOfQuarter(new Date(2014, 8, 2, 11, 55, 0))
     * //=> Tue Jul 01 2014 00:00:00
     */

    function startOfQuarter(dirtyDate) {
      requiredArgs$1(1, arguments);
      var date = toDate$2(dirtyDate);
      var currentMonth = date.getMonth();
      var month = currentMonth - currentMonth % 3;
      date.setMonth(month, 1);
      date.setHours(0, 0, 0, 0);
      return date;
    }

    /**
     * @name startOfMonth
     * @category Month Helpers
     * @summary Return the start of a month for the given date.
     *
     * @description
     * Return the start of a month for the given date.
     * The result will be in the local timezone.
     *
     * @param {Date|Number} date - the original date
     * @returns {Date} the start of a month
     * @throws {TypeError} 1 argument required
     *
     * @example
     * // The start of a month for 2 September 2014 11:55:00:
     * const result = startOfMonth(new Date(2014, 8, 2, 11, 55, 0))
     * //=> Mon Sep 01 2014 00:00:00
     */

    function startOfMonth(dirtyDate) {
      requiredArgs$1(1, arguments);
      var date = toDate$2(dirtyDate);
      date.setDate(1);
      date.setHours(0, 0, 0, 0);
      return date;
    }

    /**
     * @name startOfYear
     * @category Year Helpers
     * @summary Return the start of a year for the given date.
     *
     * @description
     * Return the start of a year for the given date.
     * The result will be in the local timezone.
     *
     * @param {Date|Number} date - the original date
     * @returns {Date} the start of a year
     * @throws {TypeError} 1 argument required
     *
     * @example
     * // The start of a year for 2 September 2014 11:55:00:
     * const result = startOfYear(new Date(2014, 8, 2, 11, 55, 00))
     * //=> Wed Jan 01 2014 00:00:00
     */

    function startOfYear(dirtyDate) {
      requiredArgs$1(1, arguments);
      var cleanDate = toDate$2(dirtyDate);
      var date = new Date(0);
      date.setFullYear(cleanDate.getFullYear(), 0, 1);
      date.setHours(0, 0, 0, 0);
      return date;
    }

    /**
     * @name subMilliseconds
     * @category Millisecond Helpers
     * @summary Subtract the specified number of milliseconds from the given date.
     *
     * @description
     * Subtract the specified number of milliseconds from the given date.
     *
     * @param {Date|Number} date - the date to be changed
     * @param {Number} amount - the amount of milliseconds to be subtracted. Positive decimals will be rounded using `Math.floor`, decimals less than zero will be rounded using `Math.ceil`.
     * @returns {Date} the new date with the milliseconds subtracted
     * @throws {TypeError} 2 arguments required
     *
     * @example
     * // Subtract 750 milliseconds from 10 July 2014 12:45:30.000:
     * const result = subMilliseconds(new Date(2014, 6, 10, 12, 45, 30, 0), 750)
     * //=> Thu Jul 10 2014 12:45:29.250
     */

    function subMilliseconds$1(dirtyDate, dirtyAmount) {
      requiredArgs$1(2, arguments);
      var amount = toInteger$1(dirtyAmount);
      return addMilliseconds$1(dirtyDate, -amount);
    }

    var MILLISECONDS_IN_DAY = 86400000;
    function getUTCDayOfYear$1(dirtyDate) {
      requiredArgs$1(1, arguments);
      var date = toDate$2(dirtyDate);
      var timestamp = date.getTime();
      date.setUTCMonth(0, 1);
      date.setUTCHours(0, 0, 0, 0);
      var startOfYearTimestamp = date.getTime();
      var difference = timestamp - startOfYearTimestamp;
      return Math.floor(difference / MILLISECONDS_IN_DAY) + 1;
    }

    function startOfUTCISOWeek$1(dirtyDate) {
      requiredArgs$1(1, arguments);
      var weekStartsOn = 1;
      var date = toDate$2(dirtyDate);
      var day = date.getUTCDay();
      var diff = (day < weekStartsOn ? 7 : 0) + day - weekStartsOn;
      date.setUTCDate(date.getUTCDate() - diff);
      date.setUTCHours(0, 0, 0, 0);
      return date;
    }

    function getUTCISOWeekYear$1(dirtyDate) {
      requiredArgs$1(1, arguments);
      var date = toDate$2(dirtyDate);
      var year = date.getUTCFullYear();
      var fourthOfJanuaryOfNextYear = new Date(0);
      fourthOfJanuaryOfNextYear.setUTCFullYear(year + 1, 0, 4);
      fourthOfJanuaryOfNextYear.setUTCHours(0, 0, 0, 0);
      var startOfNextYear = startOfUTCISOWeek$1(fourthOfJanuaryOfNextYear);
      var fourthOfJanuaryOfThisYear = new Date(0);
      fourthOfJanuaryOfThisYear.setUTCFullYear(year, 0, 4);
      fourthOfJanuaryOfThisYear.setUTCHours(0, 0, 0, 0);
      var startOfThisYear = startOfUTCISOWeek$1(fourthOfJanuaryOfThisYear);

      if (date.getTime() >= startOfNextYear.getTime()) {
        return year + 1;
      } else if (date.getTime() >= startOfThisYear.getTime()) {
        return year;
      } else {
        return year - 1;
      }
    }

    function startOfUTCISOWeekYear$1(dirtyDate) {
      requiredArgs$1(1, arguments);
      var year = getUTCISOWeekYear$1(dirtyDate);
      var fourthOfJanuary = new Date(0);
      fourthOfJanuary.setUTCFullYear(year, 0, 4);
      fourthOfJanuary.setUTCHours(0, 0, 0, 0);
      var date = startOfUTCISOWeek$1(fourthOfJanuary);
      return date;
    }

    var MILLISECONDS_IN_WEEK$1 = 604800000;
    function getUTCISOWeek$1(dirtyDate) {
      requiredArgs$1(1, arguments);
      var date = toDate$2(dirtyDate);
      var diff = startOfUTCISOWeek$1(date).getTime() - startOfUTCISOWeekYear$1(date).getTime(); // Round the number of days to the nearest integer
      // because the number of milliseconds in a week is not constant
      // (e.g. it's different in the week of the daylight saving time clock shift)

      return Math.round(diff / MILLISECONDS_IN_WEEK$1) + 1;
    }

    function getUTCWeekYear$1(dirtyDate, options) {
      var _ref, _ref2, _ref3, _options$firstWeekCon, _options$locale, _options$locale$optio, _defaultOptions$local, _defaultOptions$local2;

      requiredArgs$1(1, arguments);
      var date = toDate$2(dirtyDate);
      var year = date.getUTCFullYear();
      var defaultOptions = getDefaultOptions$1();
      var firstWeekContainsDate = toInteger$1((_ref = (_ref2 = (_ref3 = (_options$firstWeekCon = options === null || options === void 0 ? void 0 : options.firstWeekContainsDate) !== null && _options$firstWeekCon !== void 0 ? _options$firstWeekCon : options === null || options === void 0 ? void 0 : (_options$locale = options.locale) === null || _options$locale === void 0 ? void 0 : (_options$locale$optio = _options$locale.options) === null || _options$locale$optio === void 0 ? void 0 : _options$locale$optio.firstWeekContainsDate) !== null && _ref3 !== void 0 ? _ref3 : defaultOptions.firstWeekContainsDate) !== null && _ref2 !== void 0 ? _ref2 : (_defaultOptions$local = defaultOptions.locale) === null || _defaultOptions$local === void 0 ? void 0 : (_defaultOptions$local2 = _defaultOptions$local.options) === null || _defaultOptions$local2 === void 0 ? void 0 : _defaultOptions$local2.firstWeekContainsDate) !== null && _ref !== void 0 ? _ref : 1); // Test if weekStartsOn is between 1 and 7 _and_ is not NaN

      if (!(firstWeekContainsDate >= 1 && firstWeekContainsDate <= 7)) {
        throw new RangeError('firstWeekContainsDate must be between 1 and 7 inclusively');
      }

      var firstWeekOfNextYear = new Date(0);
      firstWeekOfNextYear.setUTCFullYear(year + 1, 0, firstWeekContainsDate);
      firstWeekOfNextYear.setUTCHours(0, 0, 0, 0);
      var startOfNextYear = startOfUTCWeek$1(firstWeekOfNextYear, options);
      var firstWeekOfThisYear = new Date(0);
      firstWeekOfThisYear.setUTCFullYear(year, 0, firstWeekContainsDate);
      firstWeekOfThisYear.setUTCHours(0, 0, 0, 0);
      var startOfThisYear = startOfUTCWeek$1(firstWeekOfThisYear, options);

      if (date.getTime() >= startOfNextYear.getTime()) {
        return year + 1;
      } else if (date.getTime() >= startOfThisYear.getTime()) {
        return year;
      } else {
        return year - 1;
      }
    }

    function startOfUTCWeekYear$1(dirtyDate, options) {
      var _ref, _ref2, _ref3, _options$firstWeekCon, _options$locale, _options$locale$optio, _defaultOptions$local, _defaultOptions$local2;

      requiredArgs$1(1, arguments);
      var defaultOptions = getDefaultOptions$1();
      var firstWeekContainsDate = toInteger$1((_ref = (_ref2 = (_ref3 = (_options$firstWeekCon = options === null || options === void 0 ? void 0 : options.firstWeekContainsDate) !== null && _options$firstWeekCon !== void 0 ? _options$firstWeekCon : options === null || options === void 0 ? void 0 : (_options$locale = options.locale) === null || _options$locale === void 0 ? void 0 : (_options$locale$optio = _options$locale.options) === null || _options$locale$optio === void 0 ? void 0 : _options$locale$optio.firstWeekContainsDate) !== null && _ref3 !== void 0 ? _ref3 : defaultOptions.firstWeekContainsDate) !== null && _ref2 !== void 0 ? _ref2 : (_defaultOptions$local = defaultOptions.locale) === null || _defaultOptions$local === void 0 ? void 0 : (_defaultOptions$local2 = _defaultOptions$local.options) === null || _defaultOptions$local2 === void 0 ? void 0 : _defaultOptions$local2.firstWeekContainsDate) !== null && _ref !== void 0 ? _ref : 1);
      var year = getUTCWeekYear$1(dirtyDate, options);
      var firstWeek = new Date(0);
      firstWeek.setUTCFullYear(year, 0, firstWeekContainsDate);
      firstWeek.setUTCHours(0, 0, 0, 0);
      var date = startOfUTCWeek$1(firstWeek, options);
      return date;
    }

    var MILLISECONDS_IN_WEEK = 604800000;
    function getUTCWeek$1(dirtyDate, options) {
      requiredArgs$1(1, arguments);
      var date = toDate$2(dirtyDate);
      var diff = startOfUTCWeek$1(date, options).getTime() - startOfUTCWeekYear$1(date, options).getTime(); // Round the number of days to the nearest integer
      // because the number of milliseconds in a week is not constant
      // (e.g. it's different in the week of the daylight saving time clock shift)

      return Math.round(diff / MILLISECONDS_IN_WEEK) + 1;
    }

    function addLeadingZeros$1(number, targetLength) {
      var sign = number < 0 ? '-' : '';
      var output = Math.abs(number).toString();

      while (output.length < targetLength) {
        output = '0' + output;
      }

      return sign + output;
    }

    /*
     * |     | Unit                           |     | Unit                           |
     * |-----|--------------------------------|-----|--------------------------------|
     * |  a  | AM, PM                         |  A* |                                |
     * |  d  | Day of month                   |  D  |                                |
     * |  h  | Hour [1-12]                    |  H  | Hour [0-23]                    |
     * |  m  | Minute                         |  M  | Month                          |
     * |  s  | Second                         |  S  | Fraction of second             |
     * |  y  | Year (abs)                     |  Y  |                                |
     *
     * Letters marked by * are not implemented but reserved by Unicode standard.
     */

    var formatters$4 = {
      // Year
      y: function (date, token) {
        // From http://www.unicode.org/reports/tr35/tr35-31/tr35-dates.html#Date_Format_tokens
        // | Year     |     y | yy |   yyy |  yyyy | yyyyy |
        // |----------|-------|----|-------|-------|-------|
        // | AD 1     |     1 | 01 |   001 |  0001 | 00001 |
        // | AD 12    |    12 | 12 |   012 |  0012 | 00012 |
        // | AD 123   |   123 | 23 |   123 |  0123 | 00123 |
        // | AD 1234  |  1234 | 34 |  1234 |  1234 | 01234 |
        // | AD 12345 | 12345 | 45 | 12345 | 12345 | 12345 |
        var signedYear = date.getUTCFullYear(); // Returns 1 for 1 BC (which is year 0 in JavaScript)

        var year = signedYear > 0 ? signedYear : 1 - signedYear;
        return addLeadingZeros$1(token === 'yy' ? year % 100 : year, token.length);
      },
      // Month
      M: function (date, token) {
        var month = date.getUTCMonth();
        return token === 'M' ? String(month + 1) : addLeadingZeros$1(month + 1, 2);
      },
      // Day of the month
      d: function (date, token) {
        return addLeadingZeros$1(date.getUTCDate(), token.length);
      },
      // AM or PM
      a: function (date, token) {
        var dayPeriodEnumValue = date.getUTCHours() / 12 >= 1 ? 'pm' : 'am';

        switch (token) {
          case 'a':
          case 'aa':
            return dayPeriodEnumValue.toUpperCase();

          case 'aaa':
            return dayPeriodEnumValue;

          case 'aaaaa':
            return dayPeriodEnumValue[0];

          case 'aaaa':
          default:
            return dayPeriodEnumValue === 'am' ? 'a.m.' : 'p.m.';
        }
      },
      // Hour [1-12]
      h: function (date, token) {
        return addLeadingZeros$1(date.getUTCHours() % 12 || 12, token.length);
      },
      // Hour [0-23]
      H: function (date, token) {
        return addLeadingZeros$1(date.getUTCHours(), token.length);
      },
      // Minute
      m: function (date, token) {
        return addLeadingZeros$1(date.getUTCMinutes(), token.length);
      },
      // Second
      s: function (date, token) {
        return addLeadingZeros$1(date.getUTCSeconds(), token.length);
      },
      // Fraction of second
      S: function (date, token) {
        var numberOfDigits = token.length;
        var milliseconds = date.getUTCMilliseconds();
        var fractionalSeconds = Math.floor(milliseconds * Math.pow(10, numberOfDigits - 3));
        return addLeadingZeros$1(fractionalSeconds, token.length);
      }
    };

    var dayPeriodEnum = {
      am: 'am',
      pm: 'pm',
      midnight: 'midnight',
      noon: 'noon',
      morning: 'morning',
      afternoon: 'afternoon',
      evening: 'evening',
      night: 'night'
    };
    /*
     * |     | Unit                           |     | Unit                           |
     * |-----|--------------------------------|-----|--------------------------------|
     * |  a  | AM, PM                         |  A* | Milliseconds in day            |
     * |  b  | AM, PM, noon, midnight         |  B  | Flexible day period            |
     * |  c  | Stand-alone local day of week  |  C* | Localized hour w/ day period   |
     * |  d  | Day of month                   |  D  | Day of year                    |
     * |  e  | Local day of week              |  E  | Day of week                    |
     * |  f  |                                |  F* | Day of week in month           |
     * |  g* | Modified Julian day            |  G  | Era                            |
     * |  h  | Hour [1-12]                    |  H  | Hour [0-23]                    |
     * |  i! | ISO day of week                |  I! | ISO week of year               |
     * |  j* | Localized hour w/ day period   |  J* | Localized hour w/o day period  |
     * |  k  | Hour [1-24]                    |  K  | Hour [0-11]                    |
     * |  l* | (deprecated)                   |  L  | Stand-alone month              |
     * |  m  | Minute                         |  M  | Month                          |
     * |  n  |                                |  N  |                                |
     * |  o! | Ordinal number modifier        |  O  | Timezone (GMT)                 |
     * |  p! | Long localized time            |  P! | Long localized date            |
     * |  q  | Stand-alone quarter            |  Q  | Quarter                        |
     * |  r* | Related Gregorian year         |  R! | ISO week-numbering year        |
     * |  s  | Second                         |  S  | Fraction of second             |
     * |  t! | Seconds timestamp              |  T! | Milliseconds timestamp         |
     * |  u  | Extended year                  |  U* | Cyclic year                    |
     * |  v* | Timezone (generic non-locat.)  |  V* | Timezone (location)            |
     * |  w  | Local week of year             |  W* | Week of month                  |
     * |  x  | Timezone (ISO-8601 w/o Z)      |  X  | Timezone (ISO-8601)            |
     * |  y  | Year (abs)                     |  Y  | Local week-numbering year      |
     * |  z  | Timezone (specific non-locat.) |  Z* | Timezone (aliases)             |
     *
     * Letters marked by * are not implemented but reserved by Unicode standard.
     *
     * Letters marked by ! are non-standard, but implemented by date-fns:
     * - `o` modifies the previous token to turn it into an ordinal (see `format` docs)
     * - `i` is ISO day of week. For `i` and `ii` is returns numeric ISO week days,
     *   i.e. 7 for Sunday, 1 for Monday, etc.
     * - `I` is ISO week of year, as opposed to `w` which is local week of year.
     * - `R` is ISO week-numbering year, as opposed to `Y` which is local week-numbering year.
     *   `R` is supposed to be used in conjunction with `I` and `i`
     *   for universal ISO week-numbering date, whereas
     *   `Y` is supposed to be used in conjunction with `w` and `e`
     *   for week-numbering date specific to the locale.
     * - `P` is long localized date format
     * - `p` is long localized time format
     */

    var formatters$2 = {
      // Era
      G: function (date, token, localize) {
        var era = date.getUTCFullYear() > 0 ? 1 : 0;

        switch (token) {
          // AD, BC
          case 'G':
          case 'GG':
          case 'GGG':
            return localize.era(era, {
              width: 'abbreviated'
            });
          // A, B

          case 'GGGGG':
            return localize.era(era, {
              width: 'narrow'
            });
          // Anno Domini, Before Christ

          case 'GGGG':
          default:
            return localize.era(era, {
              width: 'wide'
            });
        }
      },
      // Year
      y: function (date, token, localize) {
        // Ordinal number
        if (token === 'yo') {
          var signedYear = date.getUTCFullYear(); // Returns 1 for 1 BC (which is year 0 in JavaScript)

          var year = signedYear > 0 ? signedYear : 1 - signedYear;
          return localize.ordinalNumber(year, {
            unit: 'year'
          });
        }

        return formatters$4.y(date, token);
      },
      // Local week-numbering year
      Y: function (date, token, localize, options) {
        var signedWeekYear = getUTCWeekYear$1(date, options); // Returns 1 for 1 BC (which is year 0 in JavaScript)

        var weekYear = signedWeekYear > 0 ? signedWeekYear : 1 - signedWeekYear; // Two digit year

        if (token === 'YY') {
          var twoDigitYear = weekYear % 100;
          return addLeadingZeros$1(twoDigitYear, 2);
        } // Ordinal number


        if (token === 'Yo') {
          return localize.ordinalNumber(weekYear, {
            unit: 'year'
          });
        } // Padding


        return addLeadingZeros$1(weekYear, token.length);
      },
      // ISO week-numbering year
      R: function (date, token) {
        var isoWeekYear = getUTCISOWeekYear$1(date); // Padding

        return addLeadingZeros$1(isoWeekYear, token.length);
      },
      // Extended year. This is a single number designating the year of this calendar system.
      // The main difference between `y` and `u` localizers are B.C. years:
      // | Year | `y` | `u` |
      // |------|-----|-----|
      // | AC 1 |   1 |   1 |
      // | BC 1 |   1 |   0 |
      // | BC 2 |   2 |  -1 |
      // Also `yy` always returns the last two digits of a year,
      // while `uu` pads single digit years to 2 characters and returns other years unchanged.
      u: function (date, token) {
        var year = date.getUTCFullYear();
        return addLeadingZeros$1(year, token.length);
      },
      // Quarter
      Q: function (date, token, localize) {
        var quarter = Math.ceil((date.getUTCMonth() + 1) / 3);

        switch (token) {
          // 1, 2, 3, 4
          case 'Q':
            return String(quarter);
          // 01, 02, 03, 04

          case 'QQ':
            return addLeadingZeros$1(quarter, 2);
          // 1st, 2nd, 3rd, 4th

          case 'Qo':
            return localize.ordinalNumber(quarter, {
              unit: 'quarter'
            });
          // Q1, Q2, Q3, Q4

          case 'QQQ':
            return localize.quarter(quarter, {
              width: 'abbreviated',
              context: 'formatting'
            });
          // 1, 2, 3, 4 (narrow quarter; could be not numerical)

          case 'QQQQQ':
            return localize.quarter(quarter, {
              width: 'narrow',
              context: 'formatting'
            });
          // 1st quarter, 2nd quarter, ...

          case 'QQQQ':
          default:
            return localize.quarter(quarter, {
              width: 'wide',
              context: 'formatting'
            });
        }
      },
      // Stand-alone quarter
      q: function (date, token, localize) {
        var quarter = Math.ceil((date.getUTCMonth() + 1) / 3);

        switch (token) {
          // 1, 2, 3, 4
          case 'q':
            return String(quarter);
          // 01, 02, 03, 04

          case 'qq':
            return addLeadingZeros$1(quarter, 2);
          // 1st, 2nd, 3rd, 4th

          case 'qo':
            return localize.ordinalNumber(quarter, {
              unit: 'quarter'
            });
          // Q1, Q2, Q3, Q4

          case 'qqq':
            return localize.quarter(quarter, {
              width: 'abbreviated',
              context: 'standalone'
            });
          // 1, 2, 3, 4 (narrow quarter; could be not numerical)

          case 'qqqqq':
            return localize.quarter(quarter, {
              width: 'narrow',
              context: 'standalone'
            });
          // 1st quarter, 2nd quarter, ...

          case 'qqqq':
          default:
            return localize.quarter(quarter, {
              width: 'wide',
              context: 'standalone'
            });
        }
      },
      // Month
      M: function (date, token, localize) {
        var month = date.getUTCMonth();

        switch (token) {
          case 'M':
          case 'MM':
            return formatters$4.M(date, token);
          // 1st, 2nd, ..., 12th

          case 'Mo':
            return localize.ordinalNumber(month + 1, {
              unit: 'month'
            });
          // Jan, Feb, ..., Dec

          case 'MMM':
            return localize.month(month, {
              width: 'abbreviated',
              context: 'formatting'
            });
          // J, F, ..., D

          case 'MMMMM':
            return localize.month(month, {
              width: 'narrow',
              context: 'formatting'
            });
          // January, February, ..., December

          case 'MMMM':
          default:
            return localize.month(month, {
              width: 'wide',
              context: 'formatting'
            });
        }
      },
      // Stand-alone month
      L: function (date, token, localize) {
        var month = date.getUTCMonth();

        switch (token) {
          // 1, 2, ..., 12
          case 'L':
            return String(month + 1);
          // 01, 02, ..., 12

          case 'LL':
            return addLeadingZeros$1(month + 1, 2);
          // 1st, 2nd, ..., 12th

          case 'Lo':
            return localize.ordinalNumber(month + 1, {
              unit: 'month'
            });
          // Jan, Feb, ..., Dec

          case 'LLL':
            return localize.month(month, {
              width: 'abbreviated',
              context: 'standalone'
            });
          // J, F, ..., D

          case 'LLLLL':
            return localize.month(month, {
              width: 'narrow',
              context: 'standalone'
            });
          // January, February, ..., December

          case 'LLLL':
          default:
            return localize.month(month, {
              width: 'wide',
              context: 'standalone'
            });
        }
      },
      // Local week of year
      w: function (date, token, localize, options) {
        var week = getUTCWeek$1(date, options);

        if (token === 'wo') {
          return localize.ordinalNumber(week, {
            unit: 'week'
          });
        }

        return addLeadingZeros$1(week, token.length);
      },
      // ISO week of year
      I: function (date, token, localize) {
        var isoWeek = getUTCISOWeek$1(date);

        if (token === 'Io') {
          return localize.ordinalNumber(isoWeek, {
            unit: 'week'
          });
        }

        return addLeadingZeros$1(isoWeek, token.length);
      },
      // Day of the month
      d: function (date, token, localize) {
        if (token === 'do') {
          return localize.ordinalNumber(date.getUTCDate(), {
            unit: 'date'
          });
        }

        return formatters$4.d(date, token);
      },
      // Day of year
      D: function (date, token, localize) {
        var dayOfYear = getUTCDayOfYear$1(date);

        if (token === 'Do') {
          return localize.ordinalNumber(dayOfYear, {
            unit: 'dayOfYear'
          });
        }

        return addLeadingZeros$1(dayOfYear, token.length);
      },
      // Day of week
      E: function (date, token, localize) {
        var dayOfWeek = date.getUTCDay();

        switch (token) {
          // Tue
          case 'E':
          case 'EE':
          case 'EEE':
            return localize.day(dayOfWeek, {
              width: 'abbreviated',
              context: 'formatting'
            });
          // T

          case 'EEEEE':
            return localize.day(dayOfWeek, {
              width: 'narrow',
              context: 'formatting'
            });
          // Tu

          case 'EEEEEE':
            return localize.day(dayOfWeek, {
              width: 'short',
              context: 'formatting'
            });
          // Tuesday

          case 'EEEE':
          default:
            return localize.day(dayOfWeek, {
              width: 'wide',
              context: 'formatting'
            });
        }
      },
      // Local day of week
      e: function (date, token, localize, options) {
        var dayOfWeek = date.getUTCDay();
        var localDayOfWeek = (dayOfWeek - options.weekStartsOn + 8) % 7 || 7;

        switch (token) {
          // Numerical value (Nth day of week with current locale or weekStartsOn)
          case 'e':
            return String(localDayOfWeek);
          // Padded numerical value

          case 'ee':
            return addLeadingZeros$1(localDayOfWeek, 2);
          // 1st, 2nd, ..., 7th

          case 'eo':
            return localize.ordinalNumber(localDayOfWeek, {
              unit: 'day'
            });

          case 'eee':
            return localize.day(dayOfWeek, {
              width: 'abbreviated',
              context: 'formatting'
            });
          // T

          case 'eeeee':
            return localize.day(dayOfWeek, {
              width: 'narrow',
              context: 'formatting'
            });
          // Tu

          case 'eeeeee':
            return localize.day(dayOfWeek, {
              width: 'short',
              context: 'formatting'
            });
          // Tuesday

          case 'eeee':
          default:
            return localize.day(dayOfWeek, {
              width: 'wide',
              context: 'formatting'
            });
        }
      },
      // Stand-alone local day of week
      c: function (date, token, localize, options) {
        var dayOfWeek = date.getUTCDay();
        var localDayOfWeek = (dayOfWeek - options.weekStartsOn + 8) % 7 || 7;

        switch (token) {
          // Numerical value (same as in `e`)
          case 'c':
            return String(localDayOfWeek);
          // Padded numerical value

          case 'cc':
            return addLeadingZeros$1(localDayOfWeek, token.length);
          // 1st, 2nd, ..., 7th

          case 'co':
            return localize.ordinalNumber(localDayOfWeek, {
              unit: 'day'
            });

          case 'ccc':
            return localize.day(dayOfWeek, {
              width: 'abbreviated',
              context: 'standalone'
            });
          // T

          case 'ccccc':
            return localize.day(dayOfWeek, {
              width: 'narrow',
              context: 'standalone'
            });
          // Tu

          case 'cccccc':
            return localize.day(dayOfWeek, {
              width: 'short',
              context: 'standalone'
            });
          // Tuesday

          case 'cccc':
          default:
            return localize.day(dayOfWeek, {
              width: 'wide',
              context: 'standalone'
            });
        }
      },
      // ISO day of week
      i: function (date, token, localize) {
        var dayOfWeek = date.getUTCDay();
        var isoDayOfWeek = dayOfWeek === 0 ? 7 : dayOfWeek;

        switch (token) {
          // 2
          case 'i':
            return String(isoDayOfWeek);
          // 02

          case 'ii':
            return addLeadingZeros$1(isoDayOfWeek, token.length);
          // 2nd

          case 'io':
            return localize.ordinalNumber(isoDayOfWeek, {
              unit: 'day'
            });
          // Tue

          case 'iii':
            return localize.day(dayOfWeek, {
              width: 'abbreviated',
              context: 'formatting'
            });
          // T

          case 'iiiii':
            return localize.day(dayOfWeek, {
              width: 'narrow',
              context: 'formatting'
            });
          // Tu

          case 'iiiiii':
            return localize.day(dayOfWeek, {
              width: 'short',
              context: 'formatting'
            });
          // Tuesday

          case 'iiii':
          default:
            return localize.day(dayOfWeek, {
              width: 'wide',
              context: 'formatting'
            });
        }
      },
      // AM or PM
      a: function (date, token, localize) {
        var hours = date.getUTCHours();
        var dayPeriodEnumValue = hours / 12 >= 1 ? 'pm' : 'am';

        switch (token) {
          case 'a':
          case 'aa':
            return localize.dayPeriod(dayPeriodEnumValue, {
              width: 'abbreviated',
              context: 'formatting'
            });

          case 'aaa':
            return localize.dayPeriod(dayPeriodEnumValue, {
              width: 'abbreviated',
              context: 'formatting'
            }).toLowerCase();

          case 'aaaaa':
            return localize.dayPeriod(dayPeriodEnumValue, {
              width: 'narrow',
              context: 'formatting'
            });

          case 'aaaa':
          default:
            return localize.dayPeriod(dayPeriodEnumValue, {
              width: 'wide',
              context: 'formatting'
            });
        }
      },
      // AM, PM, midnight, noon
      b: function (date, token, localize) {
        var hours = date.getUTCHours();
        var dayPeriodEnumValue;

        if (hours === 12) {
          dayPeriodEnumValue = dayPeriodEnum.noon;
        } else if (hours === 0) {
          dayPeriodEnumValue = dayPeriodEnum.midnight;
        } else {
          dayPeriodEnumValue = hours / 12 >= 1 ? 'pm' : 'am';
        }

        switch (token) {
          case 'b':
          case 'bb':
            return localize.dayPeriod(dayPeriodEnumValue, {
              width: 'abbreviated',
              context: 'formatting'
            });

          case 'bbb':
            return localize.dayPeriod(dayPeriodEnumValue, {
              width: 'abbreviated',
              context: 'formatting'
            }).toLowerCase();

          case 'bbbbb':
            return localize.dayPeriod(dayPeriodEnumValue, {
              width: 'narrow',
              context: 'formatting'
            });

          case 'bbbb':
          default:
            return localize.dayPeriod(dayPeriodEnumValue, {
              width: 'wide',
              context: 'formatting'
            });
        }
      },
      // in the morning, in the afternoon, in the evening, at night
      B: function (date, token, localize) {
        var hours = date.getUTCHours();
        var dayPeriodEnumValue;

        if (hours >= 17) {
          dayPeriodEnumValue = dayPeriodEnum.evening;
        } else if (hours >= 12) {
          dayPeriodEnumValue = dayPeriodEnum.afternoon;
        } else if (hours >= 4) {
          dayPeriodEnumValue = dayPeriodEnum.morning;
        } else {
          dayPeriodEnumValue = dayPeriodEnum.night;
        }

        switch (token) {
          case 'B':
          case 'BB':
          case 'BBB':
            return localize.dayPeriod(dayPeriodEnumValue, {
              width: 'abbreviated',
              context: 'formatting'
            });

          case 'BBBBB':
            return localize.dayPeriod(dayPeriodEnumValue, {
              width: 'narrow',
              context: 'formatting'
            });

          case 'BBBB':
          default:
            return localize.dayPeriod(dayPeriodEnumValue, {
              width: 'wide',
              context: 'formatting'
            });
        }
      },
      // Hour [1-12]
      h: function (date, token, localize) {
        if (token === 'ho') {
          var hours = date.getUTCHours() % 12;
          if (hours === 0) hours = 12;
          return localize.ordinalNumber(hours, {
            unit: 'hour'
          });
        }

        return formatters$4.h(date, token);
      },
      // Hour [0-23]
      H: function (date, token, localize) {
        if (token === 'Ho') {
          return localize.ordinalNumber(date.getUTCHours(), {
            unit: 'hour'
          });
        }

        return formatters$4.H(date, token);
      },
      // Hour [0-11]
      K: function (date, token, localize) {
        var hours = date.getUTCHours() % 12;

        if (token === 'Ko') {
          return localize.ordinalNumber(hours, {
            unit: 'hour'
          });
        }

        return addLeadingZeros$1(hours, token.length);
      },
      // Hour [1-24]
      k: function (date, token, localize) {
        var hours = date.getUTCHours();
        if (hours === 0) hours = 24;

        if (token === 'ko') {
          return localize.ordinalNumber(hours, {
            unit: 'hour'
          });
        }

        return addLeadingZeros$1(hours, token.length);
      },
      // Minute
      m: function (date, token, localize) {
        if (token === 'mo') {
          return localize.ordinalNumber(date.getUTCMinutes(), {
            unit: 'minute'
          });
        }

        return formatters$4.m(date, token);
      },
      // Second
      s: function (date, token, localize) {
        if (token === 'so') {
          return localize.ordinalNumber(date.getUTCSeconds(), {
            unit: 'second'
          });
        }

        return formatters$4.s(date, token);
      },
      // Fraction of second
      S: function (date, token) {
        return formatters$4.S(date, token);
      },
      // Timezone (ISO-8601. If offset is 0, output is always `'Z'`)
      X: function (date, token, _localize, options) {
        var originalDate = options._originalDate || date;
        var timezoneOffset = originalDate.getTimezoneOffset();

        if (timezoneOffset === 0) {
          return 'Z';
        }

        switch (token) {
          // Hours and optional minutes
          case 'X':
            return formatTimezoneWithOptionalMinutes(timezoneOffset);
          // Hours, minutes and optional seconds without `:` delimiter
          // Note: neither ISO-8601 nor JavaScript supports seconds in timezone offsets
          // so this token always has the same output as `XX`

          case 'XXXX':
          case 'XX':
            // Hours and minutes without `:` delimiter
            return formatTimezone(timezoneOffset);
          // Hours, minutes and optional seconds with `:` delimiter
          // Note: neither ISO-8601 nor JavaScript supports seconds in timezone offsets
          // so this token always has the same output as `XXX`

          case 'XXXXX':
          case 'XXX': // Hours and minutes with `:` delimiter

          default:
            return formatTimezone(timezoneOffset, ':');
        }
      },
      // Timezone (ISO-8601. If offset is 0, output is `'+00:00'` or equivalent)
      x: function (date, token, _localize, options) {
        var originalDate = options._originalDate || date;
        var timezoneOffset = originalDate.getTimezoneOffset();

        switch (token) {
          // Hours and optional minutes
          case 'x':
            return formatTimezoneWithOptionalMinutes(timezoneOffset);
          // Hours, minutes and optional seconds without `:` delimiter
          // Note: neither ISO-8601 nor JavaScript supports seconds in timezone offsets
          // so this token always has the same output as `xx`

          case 'xxxx':
          case 'xx':
            // Hours and minutes without `:` delimiter
            return formatTimezone(timezoneOffset);
          // Hours, minutes and optional seconds with `:` delimiter
          // Note: neither ISO-8601 nor JavaScript supports seconds in timezone offsets
          // so this token always has the same output as `xxx`

          case 'xxxxx':
          case 'xxx': // Hours and minutes with `:` delimiter

          default:
            return formatTimezone(timezoneOffset, ':');
        }
      },
      // Timezone (GMT)
      O: function (date, token, _localize, options) {
        var originalDate = options._originalDate || date;
        var timezoneOffset = originalDate.getTimezoneOffset();

        switch (token) {
          // Short
          case 'O':
          case 'OO':
          case 'OOO':
            return 'GMT' + formatTimezoneShort(timezoneOffset, ':');
          // Long

          case 'OOOO':
          default:
            return 'GMT' + formatTimezone(timezoneOffset, ':');
        }
      },
      // Timezone (specific non-location)
      z: function (date, token, _localize, options) {
        var originalDate = options._originalDate || date;
        var timezoneOffset = originalDate.getTimezoneOffset();

        switch (token) {
          // Short
          case 'z':
          case 'zz':
          case 'zzz':
            return 'GMT' + formatTimezoneShort(timezoneOffset, ':');
          // Long

          case 'zzzz':
          default:
            return 'GMT' + formatTimezone(timezoneOffset, ':');
        }
      },
      // Seconds timestamp
      t: function (date, token, _localize, options) {
        var originalDate = options._originalDate || date;
        var timestamp = Math.floor(originalDate.getTime() / 1000);
        return addLeadingZeros$1(timestamp, token.length);
      },
      // Milliseconds timestamp
      T: function (date, token, _localize, options) {
        var originalDate = options._originalDate || date;
        var timestamp = originalDate.getTime();
        return addLeadingZeros$1(timestamp, token.length);
      }
    };

    function formatTimezoneShort(offset, dirtyDelimiter) {
      var sign = offset > 0 ? '-' : '+';
      var absOffset = Math.abs(offset);
      var hours = Math.floor(absOffset / 60);
      var minutes = absOffset % 60;

      if (minutes === 0) {
        return sign + String(hours);
      }

      var delimiter = dirtyDelimiter || '';
      return sign + String(hours) + delimiter + addLeadingZeros$1(minutes, 2);
    }

    function formatTimezoneWithOptionalMinutes(offset, dirtyDelimiter) {
      if (offset % 60 === 0) {
        var sign = offset > 0 ? '-' : '+';
        return sign + addLeadingZeros$1(Math.abs(offset) / 60, 2);
      }

      return formatTimezone(offset, dirtyDelimiter);
    }

    function formatTimezone(offset, dirtyDelimiter) {
      var delimiter = dirtyDelimiter || '';
      var sign = offset > 0 ? '-' : '+';
      var absOffset = Math.abs(offset);
      var hours = addLeadingZeros$1(Math.floor(absOffset / 60), 2);
      var minutes = addLeadingZeros$1(absOffset % 60, 2);
      return sign + hours + delimiter + minutes;
    }

    var formatters$3 = formatters$2;

    var dateLongFormatter = function (pattern, formatLong) {
      switch (pattern) {
        case 'P':
          return formatLong.date({
            width: 'short'
          });

        case 'PP':
          return formatLong.date({
            width: 'medium'
          });

        case 'PPP':
          return formatLong.date({
            width: 'long'
          });

        case 'PPPP':
        default:
          return formatLong.date({
            width: 'full'
          });
      }
    };

    var timeLongFormatter = function (pattern, formatLong) {
      switch (pattern) {
        case 'p':
          return formatLong.time({
            width: 'short'
          });

        case 'pp':
          return formatLong.time({
            width: 'medium'
          });

        case 'ppp':
          return formatLong.time({
            width: 'long'
          });

        case 'pppp':
        default:
          return formatLong.time({
            width: 'full'
          });
      }
    };

    var dateTimeLongFormatter = function (pattern, formatLong) {
      var matchResult = pattern.match(/(P+)(p+)?/) || [];
      var datePattern = matchResult[1];
      var timePattern = matchResult[2];

      if (!timePattern) {
        return dateLongFormatter(pattern, formatLong);
      }

      var dateTimeFormat;

      switch (datePattern) {
        case 'P':
          dateTimeFormat = formatLong.dateTime({
            width: 'short'
          });
          break;

        case 'PP':
          dateTimeFormat = formatLong.dateTime({
            width: 'medium'
          });
          break;

        case 'PPP':
          dateTimeFormat = formatLong.dateTime({
            width: 'long'
          });
          break;

        case 'PPPP':
        default:
          dateTimeFormat = formatLong.dateTime({
            width: 'full'
          });
          break;
      }

      return dateTimeFormat.replace('{{date}}', dateLongFormatter(datePattern, formatLong)).replace('{{time}}', timeLongFormatter(timePattern, formatLong));
    };

    var longFormatters$1 = {
      p: timeLongFormatter,
      P: dateTimeLongFormatter
    };
    var longFormatters$2 = longFormatters$1;

    var protectedDayOfYearTokens$1 = ['D', 'DD'];
    var protectedWeekYearTokens$1 = ['YY', 'YYYY'];
    function isProtectedDayOfYearToken$1(token) {
      return protectedDayOfYearTokens$1.indexOf(token) !== -1;
    }
    function isProtectedWeekYearToken$1(token) {
      return protectedWeekYearTokens$1.indexOf(token) !== -1;
    }
    function throwProtectedError$1(token, format, input) {
      if (token === 'YYYY') {
        throw new RangeError("Use `yyyy` instead of `YYYY` (in `".concat(format, "`) for formatting years to the input `").concat(input, "`; see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md"));
      } else if (token === 'YY') {
        throw new RangeError("Use `yy` instead of `YY` (in `".concat(format, "`) for formatting years to the input `").concat(input, "`; see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md"));
      } else if (token === 'D') {
        throw new RangeError("Use `d` instead of `D` (in `".concat(format, "`) for formatting days of the month to the input `").concat(input, "`; see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md"));
      } else if (token === 'DD') {
        throw new RangeError("Use `dd` instead of `DD` (in `".concat(format, "`) for formatting days of the month to the input `").concat(input, "`; see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md"));
      }
    }

    // - [yYQqMLwIdDecihHKkms]o matches any available ordinal number token
    //   (one of the certain letters followed by `o`)
    // - (\w)\1* matches any sequences of the same letter
    // - '' matches two quote characters in a row
    // - '(''|[^'])+('|$) matches anything surrounded by two quote characters ('),
    //   except a single quote symbol, which ends the sequence.
    //   Two quote characters do not end the sequence.
    //   If there is no matching single quote
    //   then the sequence will continue until the end of the string.
    // - . matches any single character unmatched by previous parts of the RegExps

    var formattingTokensRegExp$1 = /[yYQqMLwIdDecihHKkms]o|(\w)\1*|''|'(''|[^'])+('|$)|./g; // This RegExp catches symbols escaped by quotes, and also
    // sequences of symbols P, p, and the combinations like `PPPPPPPppppp`

    var longFormattingTokensRegExp$1 = /P+p+|P+|p+|''|'(''|[^'])+('|$)|./g;
    var escapedStringRegExp$1 = /^'([^]*?)'?$/;
    var doubleQuoteRegExp$1 = /''/g;
    var unescapedLatinCharacterRegExp$1 = /[a-zA-Z]/;
    /**
     * @name format
     * @category Common Helpers
     * @summary Format the date.
     *
     * @description
     * Return the formatted date string in the given format. The result may vary by locale.
     *
     * > ⚠️ Please note that the `format` tokens differ from Moment.js and other libraries.
     * > See: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
     *
     * The characters wrapped between two single quotes characters (') are escaped.
     * Two single quotes in a row, whether inside or outside a quoted sequence, represent a 'real' single quote.
     * (see the last example)
     *
     * Format of the string is based on Unicode Technical Standard #35:
     * https://www.unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table
     * with a few additions (see note 7 below the table).
     *
     * Accepted patterns:
     * | Unit                            | Pattern | Result examples                   | Notes |
     * |---------------------------------|---------|-----------------------------------|-------|
     * | Era                             | G..GGG  | AD, BC                            |       |
     * |                                 | GGGG    | Anno Domini, Before Christ        | 2     |
     * |                                 | GGGGG   | A, B                              |       |
     * | Calendar year                   | y       | 44, 1, 1900, 2017                 | 5     |
     * |                                 | yo      | 44th, 1st, 0th, 17th              | 5,7   |
     * |                                 | yy      | 44, 01, 00, 17                    | 5     |
     * |                                 | yyy     | 044, 001, 1900, 2017              | 5     |
     * |                                 | yyyy    | 0044, 0001, 1900, 2017            | 5     |
     * |                                 | yyyyy   | ...                               | 3,5   |
     * | Local week-numbering year       | Y       | 44, 1, 1900, 2017                 | 5     |
     * |                                 | Yo      | 44th, 1st, 1900th, 2017th         | 5,7   |
     * |                                 | YY      | 44, 01, 00, 17                    | 5,8   |
     * |                                 | YYY     | 044, 001, 1900, 2017              | 5     |
     * |                                 | YYYY    | 0044, 0001, 1900, 2017            | 5,8   |
     * |                                 | YYYYY   | ...                               | 3,5   |
     * | ISO week-numbering year         | R       | -43, 0, 1, 1900, 2017             | 5,7   |
     * |                                 | RR      | -43, 00, 01, 1900, 2017           | 5,7   |
     * |                                 | RRR     | -043, 000, 001, 1900, 2017        | 5,7   |
     * |                                 | RRRR    | -0043, 0000, 0001, 1900, 2017     | 5,7   |
     * |                                 | RRRRR   | ...                               | 3,5,7 |
     * | Extended year                   | u       | -43, 0, 1, 1900, 2017             | 5     |
     * |                                 | uu      | -43, 01, 1900, 2017               | 5     |
     * |                                 | uuu     | -043, 001, 1900, 2017             | 5     |
     * |                                 | uuuu    | -0043, 0001, 1900, 2017           | 5     |
     * |                                 | uuuuu   | ...                               | 3,5   |
     * | Quarter (formatting)            | Q       | 1, 2, 3, 4                        |       |
     * |                                 | Qo      | 1st, 2nd, 3rd, 4th                | 7     |
     * |                                 | QQ      | 01, 02, 03, 04                    |       |
     * |                                 | QQQ     | Q1, Q2, Q3, Q4                    |       |
     * |                                 | QQQQ    | 1st quarter, 2nd quarter, ...     | 2     |
     * |                                 | QQQQQ   | 1, 2, 3, 4                        | 4     |
     * | Quarter (stand-alone)           | q       | 1, 2, 3, 4                        |       |
     * |                                 | qo      | 1st, 2nd, 3rd, 4th                | 7     |
     * |                                 | qq      | 01, 02, 03, 04                    |       |
     * |                                 | qqq     | Q1, Q2, Q3, Q4                    |       |
     * |                                 | qqqq    | 1st quarter, 2nd quarter, ...     | 2     |
     * |                                 | qqqqq   | 1, 2, 3, 4                        | 4     |
     * | Month (formatting)              | M       | 1, 2, ..., 12                     |       |
     * |                                 | Mo      | 1st, 2nd, ..., 12th               | 7     |
     * |                                 | MM      | 01, 02, ..., 12                   |       |
     * |                                 | MMM     | Jan, Feb, ..., Dec                |       |
     * |                                 | MMMM    | January, February, ..., December  | 2     |
     * |                                 | MMMMM   | J, F, ..., D                      |       |
     * | Month (stand-alone)             | L       | 1, 2, ..., 12                     |       |
     * |                                 | Lo      | 1st, 2nd, ..., 12th               | 7     |
     * |                                 | LL      | 01, 02, ..., 12                   |       |
     * |                                 | LLL     | Jan, Feb, ..., Dec                |       |
     * |                                 | LLLL    | January, February, ..., December  | 2     |
     * |                                 | LLLLL   | J, F, ..., D                      |       |
     * | Local week of year              | w       | 1, 2, ..., 53                     |       |
     * |                                 | wo      | 1st, 2nd, ..., 53th               | 7     |
     * |                                 | ww      | 01, 02, ..., 53                   |       |
     * | ISO week of year                | I       | 1, 2, ..., 53                     | 7     |
     * |                                 | Io      | 1st, 2nd, ..., 53th               | 7     |
     * |                                 | II      | 01, 02, ..., 53                   | 7     |
     * | Day of month                    | d       | 1, 2, ..., 31                     |       |
     * |                                 | do      | 1st, 2nd, ..., 31st               | 7     |
     * |                                 | dd      | 01, 02, ..., 31                   |       |
     * | Day of year                     | D       | 1, 2, ..., 365, 366               | 9     |
     * |                                 | Do      | 1st, 2nd, ..., 365th, 366th       | 7     |
     * |                                 | DD      | 01, 02, ..., 365, 366             | 9     |
     * |                                 | DDD     | 001, 002, ..., 365, 366           |       |
     * |                                 | DDDD    | ...                               | 3     |
     * | Day of week (formatting)        | E..EEE  | Mon, Tue, Wed, ..., Sun           |       |
     * |                                 | EEEE    | Monday, Tuesday, ..., Sunday      | 2     |
     * |                                 | EEEEE   | M, T, W, T, F, S, S               |       |
     * |                                 | EEEEEE  | Mo, Tu, We, Th, Fr, Sa, Su        |       |
     * | ISO day of week (formatting)    | i       | 1, 2, 3, ..., 7                   | 7     |
     * |                                 | io      | 1st, 2nd, ..., 7th                | 7     |
     * |                                 | ii      | 01, 02, ..., 07                   | 7     |
     * |                                 | iii     | Mon, Tue, Wed, ..., Sun           | 7     |
     * |                                 | iiii    | Monday, Tuesday, ..., Sunday      | 2,7   |
     * |                                 | iiiii   | M, T, W, T, F, S, S               | 7     |
     * |                                 | iiiiii  | Mo, Tu, We, Th, Fr, Sa, Su        | 7     |
     * | Local day of week (formatting)  | e       | 2, 3, 4, ..., 1                   |       |
     * |                                 | eo      | 2nd, 3rd, ..., 1st                | 7     |
     * |                                 | ee      | 02, 03, ..., 01                   |       |
     * |                                 | eee     | Mon, Tue, Wed, ..., Sun           |       |
     * |                                 | eeee    | Monday, Tuesday, ..., Sunday      | 2     |
     * |                                 | eeeee   | M, T, W, T, F, S, S               |       |
     * |                                 | eeeeee  | Mo, Tu, We, Th, Fr, Sa, Su        |       |
     * | Local day of week (stand-alone) | c       | 2, 3, 4, ..., 1                   |       |
     * |                                 | co      | 2nd, 3rd, ..., 1st                | 7     |
     * |                                 | cc      | 02, 03, ..., 01                   |       |
     * |                                 | ccc     | Mon, Tue, Wed, ..., Sun           |       |
     * |                                 | cccc    | Monday, Tuesday, ..., Sunday      | 2     |
     * |                                 | ccccc   | M, T, W, T, F, S, S               |       |
     * |                                 | cccccc  | Mo, Tu, We, Th, Fr, Sa, Su        |       |
     * | AM, PM                          | a..aa   | AM, PM                            |       |
     * |                                 | aaa     | am, pm                            |       |
     * |                                 | aaaa    | a.m., p.m.                        | 2     |
     * |                                 | aaaaa   | a, p                              |       |
     * | AM, PM, noon, midnight          | b..bb   | AM, PM, noon, midnight            |       |
     * |                                 | bbb     | am, pm, noon, midnight            |       |
     * |                                 | bbbb    | a.m., p.m., noon, midnight        | 2     |
     * |                                 | bbbbb   | a, p, n, mi                       |       |
     * | Flexible day period             | B..BBB  | at night, in the morning, ...     |       |
     * |                                 | BBBB    | at night, in the morning, ...     | 2     |
     * |                                 | BBBBB   | at night, in the morning, ...     |       |
     * | Hour [1-12]                     | h       | 1, 2, ..., 11, 12                 |       |
     * |                                 | ho      | 1st, 2nd, ..., 11th, 12th         | 7     |
     * |                                 | hh      | 01, 02, ..., 11, 12               |       |
     * | Hour [0-23]                     | H       | 0, 1, 2, ..., 23                  |       |
     * |                                 | Ho      | 0th, 1st, 2nd, ..., 23rd          | 7     |
     * |                                 | HH      | 00, 01, 02, ..., 23               |       |
     * | Hour [0-11]                     | K       | 1, 2, ..., 11, 0                  |       |
     * |                                 | Ko      | 1st, 2nd, ..., 11th, 0th          | 7     |
     * |                                 | KK      | 01, 02, ..., 11, 00               |       |
     * | Hour [1-24]                     | k       | 24, 1, 2, ..., 23                 |       |
     * |                                 | ko      | 24th, 1st, 2nd, ..., 23rd         | 7     |
     * |                                 | kk      | 24, 01, 02, ..., 23               |       |
     * | Minute                          | m       | 0, 1, ..., 59                     |       |
     * |                                 | mo      | 0th, 1st, ..., 59th               | 7     |
     * |                                 | mm      | 00, 01, ..., 59                   |       |
     * | Second                          | s       | 0, 1, ..., 59                     |       |
     * |                                 | so      | 0th, 1st, ..., 59th               | 7     |
     * |                                 | ss      | 00, 01, ..., 59                   |       |
     * | Fraction of second              | S       | 0, 1, ..., 9                      |       |
     * |                                 | SS      | 00, 01, ..., 99                   |       |
     * |                                 | SSS     | 000, 001, ..., 999                |       |
     * |                                 | SSSS    | ...                               | 3     |
     * | Timezone (ISO-8601 w/ Z)        | X       | -08, +0530, Z                     |       |
     * |                                 | XX      | -0800, +0530, Z                   |       |
     * |                                 | XXX     | -08:00, +05:30, Z                 |       |
     * |                                 | XXXX    | -0800, +0530, Z, +123456          | 2     |
     * |                                 | XXXXX   | -08:00, +05:30, Z, +12:34:56      |       |
     * | Timezone (ISO-8601 w/o Z)       | x       | -08, +0530, +00                   |       |
     * |                                 | xx      | -0800, +0530, +0000               |       |
     * |                                 | xxx     | -08:00, +05:30, +00:00            | 2     |
     * |                                 | xxxx    | -0800, +0530, +0000, +123456      |       |
     * |                                 | xxxxx   | -08:00, +05:30, +00:00, +12:34:56 |       |
     * | Timezone (GMT)                  | O...OOO | GMT-8, GMT+5:30, GMT+0            |       |
     * |                                 | OOOO    | GMT-08:00, GMT+05:30, GMT+00:00   | 2     |
     * | Timezone (specific non-locat.)  | z...zzz | GMT-8, GMT+5:30, GMT+0            | 6     |
     * |                                 | zzzz    | GMT-08:00, GMT+05:30, GMT+00:00   | 2,6   |
     * | Seconds timestamp               | t       | 512969520                         | 7     |
     * |                                 | tt      | ...                               | 3,7   |
     * | Milliseconds timestamp          | T       | 512969520900                      | 7     |
     * |                                 | TT      | ...                               | 3,7   |
     * | Long localized date             | P       | 04/29/1453                        | 7     |
     * |                                 | PP      | Apr 29, 1453                      | 7     |
     * |                                 | PPP     | April 29th, 1453                  | 7     |
     * |                                 | PPPP    | Friday, April 29th, 1453          | 2,7   |
     * | Long localized time             | p       | 12:00 AM                          | 7     |
     * |                                 | pp      | 12:00:00 AM                       | 7     |
     * |                                 | ppp     | 12:00:00 AM GMT+2                 | 7     |
     * |                                 | pppp    | 12:00:00 AM GMT+02:00             | 2,7   |
     * | Combination of date and time    | Pp      | 04/29/1453, 12:00 AM              | 7     |
     * |                                 | PPpp    | Apr 29, 1453, 12:00:00 AM         | 7     |
     * |                                 | PPPppp  | April 29th, 1453 at ...           | 7     |
     * |                                 | PPPPpppp| Friday, April 29th, 1453 at ...   | 2,7   |
     * Notes:
     * 1. "Formatting" units (e.g. formatting quarter) in the default en-US locale
     *    are the same as "stand-alone" units, but are different in some languages.
     *    "Formatting" units are declined according to the rules of the language
     *    in the context of a date. "Stand-alone" units are always nominative singular:
     *
     *    `format(new Date(2017, 10, 6), 'do LLLL', {locale: cs}) //=> '6. listopad'`
     *
     *    `format(new Date(2017, 10, 6), 'do MMMM', {locale: cs}) //=> '6. listopadu'`
     *
     * 2. Any sequence of the identical letters is a pattern, unless it is escaped by
     *    the single quote characters (see below).
     *    If the sequence is longer than listed in table (e.g. `EEEEEEEEEEE`)
     *    the output will be the same as default pattern for this unit, usually
     *    the longest one (in case of ISO weekdays, `EEEE`). Default patterns for units
     *    are marked with "2" in the last column of the table.
     *
     *    `format(new Date(2017, 10, 6), 'MMM') //=> 'Nov'`
     *
     *    `format(new Date(2017, 10, 6), 'MMMM') //=> 'November'`
     *
     *    `format(new Date(2017, 10, 6), 'MMMMM') //=> 'N'`
     *
     *    `format(new Date(2017, 10, 6), 'MMMMMM') //=> 'November'`
     *
     *    `format(new Date(2017, 10, 6), 'MMMMMMM') //=> 'November'`
     *
     * 3. Some patterns could be unlimited length (such as `yyyyyyyy`).
     *    The output will be padded with zeros to match the length of the pattern.
     *
     *    `format(new Date(2017, 10, 6), 'yyyyyyyy') //=> '00002017'`
     *
     * 4. `QQQQQ` and `qqqqq` could be not strictly numerical in some locales.
     *    These tokens represent the shortest form of the quarter.
     *
     * 5. The main difference between `y` and `u` patterns are B.C. years:
     *
     *    | Year | `y` | `u` |
     *    |------|-----|-----|
     *    | AC 1 |   1 |   1 |
     *    | BC 1 |   1 |   0 |
     *    | BC 2 |   2 |  -1 |
     *
     *    Also `yy` always returns the last two digits of a year,
     *    while `uu` pads single digit years to 2 characters and returns other years unchanged:
     *
     *    | Year | `yy` | `uu` |
     *    |------|------|------|
     *    | 1    |   01 |   01 |
     *    | 14   |   14 |   14 |
     *    | 376  |   76 |  376 |
     *    | 1453 |   53 | 1453 |
     *
     *    The same difference is true for local and ISO week-numbering years (`Y` and `R`),
     *    except local week-numbering years are dependent on `options.weekStartsOn`
     *    and `options.firstWeekContainsDate` (compare [getISOWeekYear]{@link https://date-fns.org/docs/getISOWeekYear}
     *    and [getWeekYear]{@link https://date-fns.org/docs/getWeekYear}).
     *
     * 6. Specific non-location timezones are currently unavailable in `date-fns`,
     *    so right now these tokens fall back to GMT timezones.
     *
     * 7. These patterns are not in the Unicode Technical Standard #35:
     *    - `i`: ISO day of week
     *    - `I`: ISO week of year
     *    - `R`: ISO week-numbering year
     *    - `t`: seconds timestamp
     *    - `T`: milliseconds timestamp
     *    - `o`: ordinal number modifier
     *    - `P`: long localized date
     *    - `p`: long localized time
     *
     * 8. `YY` and `YYYY` tokens represent week-numbering years but they are often confused with years.
     *    You should enable `options.useAdditionalWeekYearTokens` to use them. See: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
     *
     * 9. `D` and `DD` tokens represent days of the year but they are often confused with days of the month.
     *    You should enable `options.useAdditionalDayOfYearTokens` to use them. See: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
     *
     * @param {Date|Number} date - the original date
     * @param {String} format - the string of tokens
     * @param {Object} [options] - an object with options.
     * @param {Locale} [options.locale=defaultLocale] - the locale object. See [Locale]{@link https://date-fns.org/docs/Locale}
     * @param {0|1|2|3|4|5|6} [options.weekStartsOn=0] - the index of the first day of the week (0 - Sunday)
     * @param {Number} [options.firstWeekContainsDate=1] - the day of January, which is
     * @param {Boolean} [options.useAdditionalWeekYearTokens=false] - if true, allows usage of the week-numbering year tokens `YY` and `YYYY`;
     *   see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
     * @param {Boolean} [options.useAdditionalDayOfYearTokens=false] - if true, allows usage of the day of year tokens `D` and `DD`;
     *   see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
     * @returns {String} the formatted date string
     * @throws {TypeError} 2 arguments required
     * @throws {RangeError} `date` must not be Invalid Date
     * @throws {RangeError} `options.locale` must contain `localize` property
     * @throws {RangeError} `options.locale` must contain `formatLong` property
     * @throws {RangeError} `options.weekStartsOn` must be between 0 and 6
     * @throws {RangeError} `options.firstWeekContainsDate` must be between 1 and 7
     * @throws {RangeError} use `yyyy` instead of `YYYY` for formatting years using [format provided] to the input [input provided]; see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
     * @throws {RangeError} use `yy` instead of `YY` for formatting years using [format provided] to the input [input provided]; see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
     * @throws {RangeError} use `d` instead of `D` for formatting days of the month using [format provided] to the input [input provided]; see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
     * @throws {RangeError} use `dd` instead of `DD` for formatting days of the month using [format provided] to the input [input provided]; see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
     * @throws {RangeError} format string contains an unescaped latin alphabet character
     *
     * @example
     * // Represent 11 February 2014 in middle-endian format:
     * const result = format(new Date(2014, 1, 11), 'MM/dd/yyyy')
     * //=> '02/11/2014'
     *
     * @example
     * // Represent 2 July 2014 in Esperanto:
     * import { eoLocale } from 'date-fns/locale/eo'
     * const result = format(new Date(2014, 6, 2), "do 'de' MMMM yyyy", {
     *   locale: eoLocale
     * })
     * //=> '2-a de julio 2014'
     *
     * @example
     * // Escape string by single quote characters:
     * const result = format(new Date(2014, 6, 2, 15), "h 'o''clock'")
     * //=> "3 o'clock"
     */

    function format$4(dirtyDate, dirtyFormatStr, options) {
      var _ref, _options$locale, _ref2, _ref3, _ref4, _options$firstWeekCon, _options$locale2, _options$locale2$opti, _defaultOptions$local, _defaultOptions$local2, _ref5, _ref6, _ref7, _options$weekStartsOn, _options$locale3, _options$locale3$opti, _defaultOptions$local3, _defaultOptions$local4;

      requiredArgs$1(2, arguments);
      var formatStr = String(dirtyFormatStr);
      var defaultOptions = getDefaultOptions$1();
      var locale = (_ref = (_options$locale = options === null || options === void 0 ? void 0 : options.locale) !== null && _options$locale !== void 0 ? _options$locale : defaultOptions.locale) !== null && _ref !== void 0 ? _ref : defaultLocale$1;
      var firstWeekContainsDate = toInteger$1((_ref2 = (_ref3 = (_ref4 = (_options$firstWeekCon = options === null || options === void 0 ? void 0 : options.firstWeekContainsDate) !== null && _options$firstWeekCon !== void 0 ? _options$firstWeekCon : options === null || options === void 0 ? void 0 : (_options$locale2 = options.locale) === null || _options$locale2 === void 0 ? void 0 : (_options$locale2$opti = _options$locale2.options) === null || _options$locale2$opti === void 0 ? void 0 : _options$locale2$opti.firstWeekContainsDate) !== null && _ref4 !== void 0 ? _ref4 : defaultOptions.firstWeekContainsDate) !== null && _ref3 !== void 0 ? _ref3 : (_defaultOptions$local = defaultOptions.locale) === null || _defaultOptions$local === void 0 ? void 0 : (_defaultOptions$local2 = _defaultOptions$local.options) === null || _defaultOptions$local2 === void 0 ? void 0 : _defaultOptions$local2.firstWeekContainsDate) !== null && _ref2 !== void 0 ? _ref2 : 1); // Test if weekStartsOn is between 1 and 7 _and_ is not NaN

      if (!(firstWeekContainsDate >= 1 && firstWeekContainsDate <= 7)) {
        throw new RangeError('firstWeekContainsDate must be between 1 and 7 inclusively');
      }

      var weekStartsOn = toInteger$1((_ref5 = (_ref6 = (_ref7 = (_options$weekStartsOn = options === null || options === void 0 ? void 0 : options.weekStartsOn) !== null && _options$weekStartsOn !== void 0 ? _options$weekStartsOn : options === null || options === void 0 ? void 0 : (_options$locale3 = options.locale) === null || _options$locale3 === void 0 ? void 0 : (_options$locale3$opti = _options$locale3.options) === null || _options$locale3$opti === void 0 ? void 0 : _options$locale3$opti.weekStartsOn) !== null && _ref7 !== void 0 ? _ref7 : defaultOptions.weekStartsOn) !== null && _ref6 !== void 0 ? _ref6 : (_defaultOptions$local3 = defaultOptions.locale) === null || _defaultOptions$local3 === void 0 ? void 0 : (_defaultOptions$local4 = _defaultOptions$local3.options) === null || _defaultOptions$local4 === void 0 ? void 0 : _defaultOptions$local4.weekStartsOn) !== null && _ref5 !== void 0 ? _ref5 : 0); // Test if weekStartsOn is between 0 and 6 _and_ is not NaN

      if (!(weekStartsOn >= 0 && weekStartsOn <= 6)) {
        throw new RangeError('weekStartsOn must be between 0 and 6 inclusively');
      }

      if (!locale.localize) {
        throw new RangeError('locale must contain localize property');
      }

      if (!locale.formatLong) {
        throw new RangeError('locale must contain formatLong property');
      }

      var originalDate = toDate$2(dirtyDate);

      if (!isValid$1(originalDate)) {
        throw new RangeError('Invalid time value');
      } // Convert the date in system timezone to the same date in UTC+00:00 timezone.
      // This ensures that when UTC functions will be implemented, locales will be compatible with them.
      // See an issue about UTC functions: https://github.com/date-fns/date-fns/issues/376


      var timezoneOffset = getTimezoneOffsetInMilliseconds$1(originalDate);
      var utcDate = subMilliseconds$1(originalDate, timezoneOffset);
      var formatterOptions = {
        firstWeekContainsDate: firstWeekContainsDate,
        weekStartsOn: weekStartsOn,
        locale: locale,
        _originalDate: originalDate
      };
      var result = formatStr.match(longFormattingTokensRegExp$1).map(function (substring) {
        var firstCharacter = substring[0];

        if (firstCharacter === 'p' || firstCharacter === 'P') {
          var longFormatter = longFormatters$2[firstCharacter];
          return longFormatter(substring, locale.formatLong);
        }

        return substring;
      }).join('').match(formattingTokensRegExp$1).map(function (substring) {
        // Replace two single quote characters with one single quote character
        if (substring === "''") {
          return "'";
        }

        var firstCharacter = substring[0];

        if (firstCharacter === "'") {
          return cleanEscapedString$1(substring);
        }

        var formatter = formatters$3[firstCharacter];

        if (formatter) {
          if (!(options !== null && options !== void 0 && options.useAdditionalWeekYearTokens) && isProtectedWeekYearToken$1(substring)) {
            throwProtectedError$1(substring, dirtyFormatStr, String(dirtyDate));
          }

          if (!(options !== null && options !== void 0 && options.useAdditionalDayOfYearTokens) && isProtectedDayOfYearToken$1(substring)) {
            throwProtectedError$1(substring, dirtyFormatStr, String(dirtyDate));
          }

          return formatter(utcDate, substring, locale.localize, formatterOptions);
        }

        if (firstCharacter.match(unescapedLatinCharacterRegExp$1)) {
          throw new RangeError('Format string contains an unescaped latin alphabet character `' + firstCharacter + '`');
        }

        return substring;
      }).join('');
      return result;
    }

    function cleanEscapedString$1(input) {
      var matched = input.match(escapedStringRegExp$1);

      if (!matched) {
        return input;
      }

      return matched[1].replace(doubleQuoteRegExp$1, "'");
    }

    function assign$1(target, object) {
      if (target == null) {
        throw new TypeError('assign requires that input parameter not be null or undefined');
      }

      for (var property in object) {
        if (Object.prototype.hasOwnProperty.call(object, property)) {
          target[property] = object[property];
        }
      }

      return target;
    }

    function cloneObject$1(object) {
      return assign$1({}, object);
    }

    var MILLISECONDS_IN_MINUTE = 1000 * 60;
    var MINUTES_IN_DAY = 60 * 24;
    var MINUTES_IN_MONTH = MINUTES_IN_DAY * 30;
    var MINUTES_IN_YEAR = MINUTES_IN_DAY * 365;
    /**
     * @name formatDistanceStrict
     * @category Common Helpers
     * @summary Return the distance between the given dates in words.
     *
     * @description
     * Return the distance between the given dates in words, using strict units.
     * This is like `formatDistance`, but does not use helpers like 'almost', 'over',
     * 'less than' and the like.
     *
     * | Distance between dates | Result              |
     * |------------------------|---------------------|
     * | 0 ... 59 secs          | [0..59] seconds     |
     * | 1 ... 59 mins          | [1..59] minutes     |
     * | 1 ... 23 hrs           | [1..23] hours       |
     * | 1 ... 29 days          | [1..29] days        |
     * | 1 ... 11 months        | [1..11] months      |
     * | 1 ... N years          | [1..N]  years       |
     *
     * @param {Date|Number} date - the date
     * @param {Date|Number} baseDate - the date to compare with
     * @param {Object} [options] - an object with options.
     * @param {Boolean} [options.addSuffix=false] - result indicates if the second date is earlier or later than the first
     * @param {'second'|'minute'|'hour'|'day'|'month'|'year'} [options.unit] - if specified, will force a unit
     * @param {'floor'|'ceil'|'round'} [options.roundingMethod='round'] - which way to round partial units
     * @param {Locale} [options.locale=defaultLocale] - the locale object. See [Locale]{@link https://date-fns.org/docs/Locale}
     * @returns {String} the distance in words
     * @throws {TypeError} 2 arguments required
     * @throws {RangeError} `date` must not be Invalid Date
     * @throws {RangeError} `baseDate` must not be Invalid Date
     * @throws {RangeError} `options.roundingMethod` must be 'floor', 'ceil' or 'round'
     * @throws {RangeError} `options.unit` must be 'second', 'minute', 'hour', 'day', 'month' or 'year'
     * @throws {RangeError} `options.locale` must contain `formatDistance` property
     *
     * @example
     * // What is the distance between 2 July 2014 and 1 January 2015?
     * const result = formatDistanceStrict(new Date(2014, 6, 2), new Date(2015, 0, 2))
     * //=> '6 months'
     *
     * @example
     * // What is the distance between 1 January 2015 00:00:15
     * // and 1 January 2015 00:00:00?
     * const result = formatDistanceStrict(
     *   new Date(2015, 0, 1, 0, 0, 15),
     *   new Date(2015, 0, 1, 0, 0, 0)
     * )
     * //=> '15 seconds'
     *
     * @example
     * // What is the distance from 1 January 2016
     * // to 1 January 2015, with a suffix?
     * const result = formatDistanceStrict(new Date(2015, 0, 1), new Date(2016, 0, 1), {
     *   addSuffix: true
     * })
     * //=> '1 year ago'
     *
     * @example
     * // What is the distance from 1 January 2016
     * // to 1 January 2015, in minutes?
     * const result = formatDistanceStrict(new Date(2016, 0, 1), new Date(2015, 0, 1), {
     *   unit: 'minute'
     * })
     * //=> '525600 minutes'
     *
     * @example
     * // What is the distance from 1 January 2015
     * // to 28 January 2015, in months, rounded up?
     * const result = formatDistanceStrict(new Date(2015, 0, 28), new Date(2015, 0, 1), {
     *   unit: 'month',
     *   roundingMethod: 'ceil'
     * })
     * //=> '1 month'
     *
     * @example
     * // What is the distance between 1 August 2016 and 1 January 2015 in Esperanto?
     * import { eoLocale } from 'date-fns/locale/eo'
     * const result = formatDistanceStrict(new Date(2016, 7, 1), new Date(2015, 0, 1), {
     *   locale: eoLocale
     * })
     * //=> '1 jaro'
     */

    function formatDistanceStrict(dirtyDate, dirtyBaseDate, options) {
      var _ref, _options$locale, _options$roundingMeth;

      requiredArgs$1(2, arguments);
      var defaultOptions = getDefaultOptions$1();
      var locale = (_ref = (_options$locale = options === null || options === void 0 ? void 0 : options.locale) !== null && _options$locale !== void 0 ? _options$locale : defaultOptions.locale) !== null && _ref !== void 0 ? _ref : defaultLocale$1;

      if (!locale.formatDistance) {
        throw new RangeError('locale must contain localize.formatDistance property');
      }

      var comparison = compareAsc(dirtyDate, dirtyBaseDate);

      if (isNaN(comparison)) {
        throw new RangeError('Invalid time value');
      }

      var localizeOptions = assign$1(cloneObject$1(options), {
        addSuffix: Boolean(options === null || options === void 0 ? void 0 : options.addSuffix),
        comparison: comparison
      });
      var dateLeft;
      var dateRight;

      if (comparison > 0) {
        dateLeft = toDate$2(dirtyBaseDate);
        dateRight = toDate$2(dirtyDate);
      } else {
        dateLeft = toDate$2(dirtyDate);
        dateRight = toDate$2(dirtyBaseDate);
      }

      var roundingMethod = String((_options$roundingMeth = options === null || options === void 0 ? void 0 : options.roundingMethod) !== null && _options$roundingMeth !== void 0 ? _options$roundingMeth : 'round');
      var roundingMethodFn;

      if (roundingMethod === 'floor') {
        roundingMethodFn = Math.floor;
      } else if (roundingMethod === 'ceil') {
        roundingMethodFn = Math.ceil;
      } else if (roundingMethod === 'round') {
        roundingMethodFn = Math.round;
      } else {
        throw new RangeError("roundingMethod must be 'floor', 'ceil' or 'round'");
      }

      var milliseconds = dateRight.getTime() - dateLeft.getTime();
      var minutes = milliseconds / MILLISECONDS_IN_MINUTE;
      var timezoneOffset = getTimezoneOffsetInMilliseconds$1(dateRight) - getTimezoneOffsetInMilliseconds$1(dateLeft); // Use DST-normalized difference in minutes for years, months and days;
      // use regular difference in minutes for hours, minutes and seconds.

      var dstNormalizedMinutes = (milliseconds - timezoneOffset) / MILLISECONDS_IN_MINUTE;
      var defaultUnit = options === null || options === void 0 ? void 0 : options.unit;
      var unit;

      if (!defaultUnit) {
        if (minutes < 1) {
          unit = 'second';
        } else if (minutes < 60) {
          unit = 'minute';
        } else if (minutes < MINUTES_IN_DAY) {
          unit = 'hour';
        } else if (dstNormalizedMinutes < MINUTES_IN_MONTH) {
          unit = 'day';
        } else if (dstNormalizedMinutes < MINUTES_IN_YEAR) {
          unit = 'month';
        } else {
          unit = 'year';
        }
      } else {
        unit = String(defaultUnit);
      } // 0 up to 60 seconds


      if (unit === 'second') {
        var seconds = roundingMethodFn(milliseconds / 1000);
        return locale.formatDistance('xSeconds', seconds, localizeOptions); // 1 up to 60 mins
      } else if (unit === 'minute') {
        var roundedMinutes = roundingMethodFn(minutes);
        return locale.formatDistance('xMinutes', roundedMinutes, localizeOptions); // 1 up to 24 hours
      } else if (unit === 'hour') {
        var hours = roundingMethodFn(minutes / 60);
        return locale.formatDistance('xHours', hours, localizeOptions); // 1 up to 30 days
      } else if (unit === 'day') {
        var days = roundingMethodFn(dstNormalizedMinutes / MINUTES_IN_DAY);
        return locale.formatDistance('xDays', days, localizeOptions); // 1 up to 12 months
      } else if (unit === 'month') {
        var months = roundingMethodFn(dstNormalizedMinutes / MINUTES_IN_MONTH);
        return months === 12 && defaultUnit !== 'month' ? locale.formatDistance('xYears', 1, localizeOptions) : locale.formatDistance('xMonths', months, localizeOptions); // 1 year up to max Date
      } else if (unit === 'year') {
        var years = roundingMethodFn(dstNormalizedMinutes / MINUTES_IN_YEAR);
        return locale.formatDistance('xYears', years, localizeOptions);
      }

      throw new RangeError("unit must be 'second', 'minute', 'hour', 'day', 'month' or 'year'");
    }

    /**
     * @name fromUnixTime
     * @category Timestamp Helpers
     * @summary Create a date from a Unix timestamp.
     *
     * @description
     * Create a date from a Unix timestamp (in seconds). Decimal values will be discarded.
     *
     * @param {Number} unixTime - the given Unix timestamp (in seconds)
     * @returns {Date} the date
     * @throws {TypeError} 1 argument required
     *
     * @example
     * // Create the date 29 February 2012 11:45:05:
     * const result = fromUnixTime(1330515905)
     * //=> Wed Feb 29 2012 11:45:05
     */

    function fromUnixTime(dirtyUnixTime) {
      requiredArgs$1(1, arguments);
      var unixTime = toInteger$1(dirtyUnixTime);
      return toDate$2(unixTime * 1000);
    }

    /**
     * @name getDate
     * @category Day Helpers
     * @summary Get the day of the month of the given date.
     *
     * @description
     * Get the day of the month of the given date.
     *
     * @param {Date|Number} date - the given date
     * @returns {Number} the day of month
     * @throws {TypeError} 1 argument required
     *
     * @example
     * // Which day of the month is 29 February 2012?
     * const result = getDate(new Date(2012, 1, 29))
     * //=> 29
     */

    function getDate(dirtyDate) {
      requiredArgs$1(1, arguments);
      var date = toDate$2(dirtyDate);
      var dayOfMonth = date.getDate();
      return dayOfMonth;
    }

    /**
     * @name getDay
     * @category Weekday Helpers
     * @summary Get the day of the week of the given date.
     *
     * @description
     * Get the day of the week of the given date.
     *
     * @param {Date|Number} date - the given date
     * @returns {0|1|2|3|4|5|6} the day of week, 0 represents Sunday
     * @throws {TypeError} 1 argument required
     *
     * @example
     * // Which day of the week is 29 February 2012?
     * const result = getDay(new Date(2012, 1, 29))
     * //=> 3
     */

    function getDay(dirtyDate) {
      requiredArgs$1(1, arguments);
      var date = toDate$2(dirtyDate);
      var day = date.getDay();
      return day;
    }

    /**
     * @name getDaysInMonth
     * @category Month Helpers
     * @summary Get the number of days in a month of the given date.
     *
     * @description
     * Get the number of days in a month of the given date.
     *
     * @param {Date|Number} date - the given date
     * @returns {Number} the number of days in a month
     * @throws {TypeError} 1 argument required
     *
     * @example
     * // How many days are in February 2000?
     * const result = getDaysInMonth(new Date(2000, 1))
     * //=> 29
     */

    function getDaysInMonth(dirtyDate) {
      requiredArgs$1(1, arguments);
      var date = toDate$2(dirtyDate);
      var year = date.getFullYear();
      var monthIndex = date.getMonth();
      var lastDayOfMonth = new Date(0);
      lastDayOfMonth.setFullYear(year, monthIndex + 1, 0);
      lastDayOfMonth.setHours(0, 0, 0, 0);
      return lastDayOfMonth.getDate();
    }

    /**
     * @name getHours
     * @category Hour Helpers
     * @summary Get the hours of the given date.
     *
     * @description
     * Get the hours of the given date.
     *
     * @param {Date|Number} date - the given date
     * @returns {Number} the hours
     * @throws {TypeError} 1 argument required
     *
     * @example
     * // Get the hours of 29 February 2012 11:45:00:
     * const result = getHours(new Date(2012, 1, 29, 11, 45))
     * //=> 11
     */

    function getHours(dirtyDate) {
      requiredArgs$1(1, arguments);
      var date = toDate$2(dirtyDate);
      var hours = date.getHours();
      return hours;
    }

    /**
     * @name getMinutes
     * @category Minute Helpers
     * @summary Get the minutes of the given date.
     *
     * @description
     * Get the minutes of the given date.
     *
     * @param {Date|Number} date - the given date
     * @returns {Number} the minutes
     * @throws {TypeError} 1 argument required
     *
     * @example
     * // Get the minutes of 29 February 2012 11:45:05:
     * const result = getMinutes(new Date(2012, 1, 29, 11, 45, 5))
     * //=> 45
     */

    function getMinutes(dirtyDate) {
      requiredArgs$1(1, arguments);
      var date = toDate$2(dirtyDate);
      var minutes = date.getMinutes();
      return minutes;
    }

    /**
     * @name getMonth
     * @category Month Helpers
     * @summary Get the month of the given date.
     *
     * @description
     * Get the month of the given date.
     *
     * @param {Date|Number} date - the given date
     * @returns {Number} the month
     * @throws {TypeError} 1 argument required
     *
     * @example
     * // Which month is 29 February 2012?
     * const result = getMonth(new Date(2012, 1, 29))
     * //=> 1
     */

    function getMonth(dirtyDate) {
      requiredArgs$1(1, arguments);
      var date = toDate$2(dirtyDate);
      var month = date.getMonth();
      return month;
    }

    /**
     * @name getSeconds
     * @category Second Helpers
     * @summary Get the seconds of the given date.
     *
     * @description
     * Get the seconds of the given date.
     *
     * @param {Date|Number} date - the given date
     * @returns {Number} the seconds
     * @throws {TypeError} 1 argument required
     *
     * @example
     * // Get the seconds of 29 February 2012 11:45:05.123:
     * const result = getSeconds(new Date(2012, 1, 29, 11, 45, 5, 123))
     * //=> 5
     */

    function getSeconds(dirtyDate) {
      requiredArgs$1(1, arguments);
      var date = toDate$2(dirtyDate);
      var seconds = date.getSeconds();
      return seconds;
    }

    /**
     * @name getTime
     * @category Timestamp Helpers
     * @summary Get the milliseconds timestamp of the given date.
     *
     * @description
     * Get the milliseconds timestamp of the given date.
     *
     * @param {Date|Number} date - the given date
     * @returns {Number} the timestamp
     * @throws {TypeError} 1 argument required
     *
     * @example
     * // Get the timestamp of 29 February 2012 11:45:05.123:
     * const result = getTime(new Date(2012, 1, 29, 11, 45, 5, 123))
     * //=> 1330515905123
     */

    function getTime(dirtyDate) {
      requiredArgs$1(1, arguments);
      var date = toDate$2(dirtyDate);
      var timestamp = date.getTime();
      return timestamp;
    }

    /**
     * @name getYear
     * @category Year Helpers
     * @summary Get the year of the given date.
     *
     * @description
     * Get the year of the given date.
     *
     * @param {Date|Number} date - the given date
     * @returns {Number} the year
     * @throws {TypeError} 1 argument required
     *
     * @example
     * // Which year is 2 July 2014?
     * const result = getYear(new Date(2014, 6, 2))
     * //=> 2014
     */

    function getYear(dirtyDate) {
      requiredArgs$1(1, arguments);
      return toDate$2(dirtyDate).getFullYear();
    }

    function _defineProperty$w(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }

    var TIMEZONE_UNIT_PRIORITY = 10;
    class Setter {
      constructor() {
        _defineProperty$w(this, "priority", void 0);

        _defineProperty$w(this, "subPriority", 0);
      }

      validate(_utcDate, _options) {
        return true;
      }

    }
    class ValueSetter extends Setter {
      constructor(value, validateValue, setValue, priority, subPriority) {
        super();
        this.value = value;
        this.validateValue = validateValue;
        this.setValue = setValue;
        this.priority = priority;

        if (subPriority) {
          this.subPriority = subPriority;
        }
      }

      validate(utcDate, options) {
        return this.validateValue(utcDate, this.value, options);
      }

      set(utcDate, flags, options) {
        return this.setValue(utcDate, flags, this.value, options);
      }

    }
    class DateToSystemTimezoneSetter extends Setter {
      constructor() {
        super(...arguments);

        _defineProperty$w(this, "priority", TIMEZONE_UNIT_PRIORITY);

        _defineProperty$w(this, "subPriority", -1);
      }

      set(date, flags) {
        if (flags.timestampIsSet) {
          return date;
        }

        var convertedDate = new Date(0);
        convertedDate.setFullYear(date.getUTCFullYear(), date.getUTCMonth(), date.getUTCDate());
        convertedDate.setHours(date.getUTCHours(), date.getUTCMinutes(), date.getUTCSeconds(), date.getUTCMilliseconds());
        return convertedDate;
      }

    }

    function _defineProperty$v(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }
    class Parser {
      constructor() {
        _defineProperty$v(this, "incompatibleTokens", void 0);

        _defineProperty$v(this, "priority", void 0);

        _defineProperty$v(this, "subPriority", void 0);
      }

      run(dateString, token, match, options) {
        var result = this.parse(dateString, token, match, options);

        if (!result) {
          return null;
        }

        return {
          setter: new ValueSetter(result.value, this.validate, this.set, this.priority, this.subPriority),
          rest: result.rest
        };
      }

      validate(_utcDate, _value, _options) {
        return true;
      }

    }

    function _defineProperty$u(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }
    class EraParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$u(this, "priority", 140);

        _defineProperty$u(this, "incompatibleTokens", ['R', 'u', 't', 'T']);
      }

      parse(dateString, token, match) {
        switch (token) {
          // AD, BC
          case 'G':
          case 'GG':
          case 'GGG':
            return match.era(dateString, {
              width: 'abbreviated'
            }) || match.era(dateString, {
              width: 'narrow'
            });
          // A, B

          case 'GGGGG':
            return match.era(dateString, {
              width: 'narrow'
            });
          // Anno Domini, Before Christ

          case 'GGGG':
          default:
            return match.era(dateString, {
              width: 'wide'
            }) || match.era(dateString, {
              width: 'abbreviated'
            }) || match.era(dateString, {
              width: 'narrow'
            });
        }
      }

      set(date, flags, value) {
        flags.era = value;
        date.setUTCFullYear(value, 0, 1);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }

    }

    var numericPatterns = {
      month: /^(1[0-2]|0?\d)/,
      // 0 to 12
      date: /^(3[0-1]|[0-2]?\d)/,
      // 0 to 31
      dayOfYear: /^(36[0-6]|3[0-5]\d|[0-2]?\d?\d)/,
      // 0 to 366
      week: /^(5[0-3]|[0-4]?\d)/,
      // 0 to 53
      hour23h: /^(2[0-3]|[0-1]?\d)/,
      // 0 to 23
      hour24h: /^(2[0-4]|[0-1]?\d)/,
      // 0 to 24
      hour11h: /^(1[0-1]|0?\d)/,
      // 0 to 11
      hour12h: /^(1[0-2]|0?\d)/,
      // 0 to 12
      minute: /^[0-5]?\d/,
      // 0 to 59
      second: /^[0-5]?\d/,
      // 0 to 59
      singleDigit: /^\d/,
      // 0 to 9
      twoDigits: /^\d{1,2}/,
      // 0 to 99
      threeDigits: /^\d{1,3}/,
      // 0 to 999
      fourDigits: /^\d{1,4}/,
      // 0 to 9999
      anyDigitsSigned: /^-?\d+/,
      singleDigitSigned: /^-?\d/,
      // 0 to 9, -0 to -9
      twoDigitsSigned: /^-?\d{1,2}/,
      // 0 to 99, -0 to -99
      threeDigitsSigned: /^-?\d{1,3}/,
      // 0 to 999, -0 to -999
      fourDigitsSigned: /^-?\d{1,4}/ // 0 to 9999, -0 to -9999

    };
    var timezonePatterns = {
      basicOptionalMinutes: /^([+-])(\d{2})(\d{2})?|Z/,
      basic: /^([+-])(\d{2})(\d{2})|Z/,
      basicOptionalSeconds: /^([+-])(\d{2})(\d{2})((\d{2}))?|Z/,
      extended: /^([+-])(\d{2}):(\d{2})|Z/,
      extendedOptionalSeconds: /^([+-])(\d{2}):(\d{2})(:(\d{2}))?|Z/
    };

    function mapValue(parseFnResult, mapFn) {
      if (!parseFnResult) {
        return parseFnResult;
      }

      return {
        value: mapFn(parseFnResult.value),
        rest: parseFnResult.rest
      };
    }
    function parseNumericPattern(pattern, dateString) {
      var matchResult = dateString.match(pattern);

      if (!matchResult) {
        return null;
      }

      return {
        value: parseInt(matchResult[0], 10),
        rest: dateString.slice(matchResult[0].length)
      };
    }
    function parseTimezonePattern(pattern, dateString) {
      var matchResult = dateString.match(pattern);

      if (!matchResult) {
        return null;
      } // Input is 'Z'


      if (matchResult[0] === 'Z') {
        return {
          value: 0,
          rest: dateString.slice(1)
        };
      }

      var sign = matchResult[1] === '+' ? 1 : -1;
      var hours = matchResult[2] ? parseInt(matchResult[2], 10) : 0;
      var minutes = matchResult[3] ? parseInt(matchResult[3], 10) : 0;
      var seconds = matchResult[5] ? parseInt(matchResult[5], 10) : 0;
      return {
        value: sign * (hours * millisecondsInHour + minutes * millisecondsInMinute + seconds * millisecondsInSecond),
        rest: dateString.slice(matchResult[0].length)
      };
    }
    function parseAnyDigitsSigned(dateString) {
      return parseNumericPattern(numericPatterns.anyDigitsSigned, dateString);
    }
    function parseNDigits(n, dateString) {
      switch (n) {
        case 1:
          return parseNumericPattern(numericPatterns.singleDigit, dateString);

        case 2:
          return parseNumericPattern(numericPatterns.twoDigits, dateString);

        case 3:
          return parseNumericPattern(numericPatterns.threeDigits, dateString);

        case 4:
          return parseNumericPattern(numericPatterns.fourDigits, dateString);

        default:
          return parseNumericPattern(new RegExp('^\\d{1,' + n + '}'), dateString);
      }
    }
    function parseNDigitsSigned(n, dateString) {
      switch (n) {
        case 1:
          return parseNumericPattern(numericPatterns.singleDigitSigned, dateString);

        case 2:
          return parseNumericPattern(numericPatterns.twoDigitsSigned, dateString);

        case 3:
          return parseNumericPattern(numericPatterns.threeDigitsSigned, dateString);

        case 4:
          return parseNumericPattern(numericPatterns.fourDigitsSigned, dateString);

        default:
          return parseNumericPattern(new RegExp('^-?\\d{1,' + n + '}'), dateString);
      }
    }
    function dayPeriodEnumToHours(dayPeriod) {
      switch (dayPeriod) {
        case 'morning':
          return 4;

        case 'evening':
          return 17;

        case 'pm':
        case 'noon':
        case 'afternoon':
          return 12;

        case 'am':
        case 'midnight':
        case 'night':
        default:
          return 0;
      }
    }
    function normalizeTwoDigitYear(twoDigitYear, currentYear) {
      var isCommonEra = currentYear > 0; // Absolute number of the current year:
      // 1 -> 1 AC
      // 0 -> 1 BC
      // -1 -> 2 BC

      var absCurrentYear = isCommonEra ? currentYear : 1 - currentYear;
      var result;

      if (absCurrentYear <= 50) {
        result = twoDigitYear || 100;
      } else {
        var rangeEnd = absCurrentYear + 50;
        var rangeEndCentury = Math.floor(rangeEnd / 100) * 100;
        var isPreviousCentury = twoDigitYear >= rangeEnd % 100;
        result = twoDigitYear + rangeEndCentury - (isPreviousCentury ? 100 : 0);
      }

      return isCommonEra ? result : 1 - result;
    }
    function isLeapYearIndex(year) {
      return year % 400 === 0 || year % 4 === 0 && year % 100 !== 0;
    }

    function _defineProperty$t(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }
    // | Year     |     y | yy |   yyy |  yyyy | yyyyy |
    // |----------|-------|----|-------|-------|-------|
    // | AD 1     |     1 | 01 |   001 |  0001 | 00001 |
    // | AD 12    |    12 | 12 |   012 |  0012 | 00012 |
    // | AD 123   |   123 | 23 |   123 |  0123 | 00123 |
    // | AD 1234  |  1234 | 34 |  1234 |  1234 | 01234 |
    // | AD 12345 | 12345 | 45 | 12345 | 12345 | 12345 |

    class YearParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$t(this, "priority", 130);

        _defineProperty$t(this, "incompatibleTokens", ['Y', 'R', 'u', 'w', 'I', 'i', 'e', 'c', 't', 'T']);
      }

      parse(dateString, token, match) {
        var valueCallback = function (year) {
          return {
            year: year,
            isTwoDigitYear: token === 'yy'
          };
        };

        switch (token) {
          case 'y':
            return mapValue(parseNDigits(4, dateString), valueCallback);

          case 'yo':
            return mapValue(match.ordinalNumber(dateString, {
              unit: 'year'
            }), valueCallback);

          default:
            return mapValue(parseNDigits(token.length, dateString), valueCallback);
        }
      }

      validate(_date, value) {
        return value.isTwoDigitYear || value.year > 0;
      }

      set(date, flags, value) {
        var currentYear = date.getUTCFullYear();

        if (value.isTwoDigitYear) {
          var normalizedTwoDigitYear = normalizeTwoDigitYear(value.year, currentYear);
          date.setUTCFullYear(normalizedTwoDigitYear, 0, 1);
          date.setUTCHours(0, 0, 0, 0);
          return date;
        }

        var year = !('era' in flags) || flags.era === 1 ? value.year : 1 - value.year;
        date.setUTCFullYear(year, 0, 1);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }

    }

    function _defineProperty$s(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }

    class LocalWeekYearParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$s(this, "priority", 130);

        _defineProperty$s(this, "incompatibleTokens", ['y', 'R', 'u', 'Q', 'q', 'M', 'L', 'I', 'd', 'D', 'i', 't', 'T']);
      }

      parse(dateString, token, match) {
        var valueCallback = function (year) {
          return {
            year: year,
            isTwoDigitYear: token === 'YY'
          };
        };

        switch (token) {
          case 'Y':
            return mapValue(parseNDigits(4, dateString), valueCallback);

          case 'Yo':
            return mapValue(match.ordinalNumber(dateString, {
              unit: 'year'
            }), valueCallback);

          default:
            return mapValue(parseNDigits(token.length, dateString), valueCallback);
        }
      }

      validate(_date, value) {
        return value.isTwoDigitYear || value.year > 0;
      }

      set(date, flags, value, options) {
        var currentYear = getUTCWeekYear$1(date, options);

        if (value.isTwoDigitYear) {
          var normalizedTwoDigitYear = normalizeTwoDigitYear(value.year, currentYear);
          date.setUTCFullYear(normalizedTwoDigitYear, 0, options.firstWeekContainsDate);
          date.setUTCHours(0, 0, 0, 0);
          return startOfUTCWeek$1(date, options);
        }

        var year = !('era' in flags) || flags.era === 1 ? value.year : 1 - value.year;
        date.setUTCFullYear(year, 0, options.firstWeekContainsDate);
        date.setUTCHours(0, 0, 0, 0);
        return startOfUTCWeek$1(date, options);
      }

    }

    function _defineProperty$r(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }

    class ISOWeekYearParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$r(this, "priority", 130);

        _defineProperty$r(this, "incompatibleTokens", ['G', 'y', 'Y', 'u', 'Q', 'q', 'M', 'L', 'w', 'd', 'D', 'e', 'c', 't', 'T']);
      }

      parse(dateString, token) {
        if (token === 'R') {
          return parseNDigitsSigned(4, dateString);
        }

        return parseNDigitsSigned(token.length, dateString);
      }

      set(_date, _flags, value) {
        var firstWeekOfYear = new Date(0);
        firstWeekOfYear.setUTCFullYear(value, 0, 4);
        firstWeekOfYear.setUTCHours(0, 0, 0, 0);
        return startOfUTCISOWeek$1(firstWeekOfYear);
      }

    }

    function _defineProperty$q(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }
    class ExtendedYearParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$q(this, "priority", 130);

        _defineProperty$q(this, "incompatibleTokens", ['G', 'y', 'Y', 'R', 'w', 'I', 'i', 'e', 'c', 't', 'T']);
      }

      parse(dateString, token) {
        if (token === 'u') {
          return parseNDigitsSigned(4, dateString);
        }

        return parseNDigitsSigned(token.length, dateString);
      }

      set(date, _flags, value) {
        date.setUTCFullYear(value, 0, 1);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }

    }

    function _defineProperty$p(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }
    class QuarterParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$p(this, "priority", 120);

        _defineProperty$p(this, "incompatibleTokens", ['Y', 'R', 'q', 'M', 'L', 'w', 'I', 'd', 'D', 'i', 'e', 'c', 't', 'T']);
      }

      parse(dateString, token, match) {
        switch (token) {
          // 1, 2, 3, 4
          case 'Q':
          case 'QQ':
            // 01, 02, 03, 04
            return parseNDigits(token.length, dateString);
          // 1st, 2nd, 3rd, 4th

          case 'Qo':
            return match.ordinalNumber(dateString, {
              unit: 'quarter'
            });
          // Q1, Q2, Q3, Q4

          case 'QQQ':
            return match.quarter(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.quarter(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          // 1, 2, 3, 4 (narrow quarter; could be not numerical)

          case 'QQQQQ':
            return match.quarter(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          // 1st quarter, 2nd quarter, ...

          case 'QQQQ':
          default:
            return match.quarter(dateString, {
              width: 'wide',
              context: 'formatting'
            }) || match.quarter(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.quarter(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
        }
      }

      validate(_date, value) {
        return value >= 1 && value <= 4;
      }

      set(date, _flags, value) {
        date.setUTCMonth((value - 1) * 3, 1);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }

    }

    function _defineProperty$o(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }
    class StandAloneQuarterParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$o(this, "priority", 120);

        _defineProperty$o(this, "incompatibleTokens", ['Y', 'R', 'Q', 'M', 'L', 'w', 'I', 'd', 'D', 'i', 'e', 'c', 't', 'T']);
      }

      parse(dateString, token, match) {
        switch (token) {
          // 1, 2, 3, 4
          case 'q':
          case 'qq':
            // 01, 02, 03, 04
            return parseNDigits(token.length, dateString);
          // 1st, 2nd, 3rd, 4th

          case 'qo':
            return match.ordinalNumber(dateString, {
              unit: 'quarter'
            });
          // Q1, Q2, Q3, Q4

          case 'qqq':
            return match.quarter(dateString, {
              width: 'abbreviated',
              context: 'standalone'
            }) || match.quarter(dateString, {
              width: 'narrow',
              context: 'standalone'
            });
          // 1, 2, 3, 4 (narrow quarter; could be not numerical)

          case 'qqqqq':
            return match.quarter(dateString, {
              width: 'narrow',
              context: 'standalone'
            });
          // 1st quarter, 2nd quarter, ...

          case 'qqqq':
          default:
            return match.quarter(dateString, {
              width: 'wide',
              context: 'standalone'
            }) || match.quarter(dateString, {
              width: 'abbreviated',
              context: 'standalone'
            }) || match.quarter(dateString, {
              width: 'narrow',
              context: 'standalone'
            });
        }
      }

      validate(_date, value) {
        return value >= 1 && value <= 4;
      }

      set(date, _flags, value) {
        date.setUTCMonth((value - 1) * 3, 1);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }

    }

    function _defineProperty$n(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }
    class MonthParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$n(this, "incompatibleTokens", ['Y', 'R', 'q', 'Q', 'L', 'w', 'I', 'D', 'i', 'e', 'c', 't', 'T']);

        _defineProperty$n(this, "priority", 110);
      }

      parse(dateString, token, match) {
        var valueCallback = function (value) {
          return value - 1;
        };

        switch (token) {
          // 1, 2, ..., 12
          case 'M':
            return mapValue(parseNumericPattern(numericPatterns.month, dateString), valueCallback);
          // 01, 02, ..., 12

          case 'MM':
            return mapValue(parseNDigits(2, dateString), valueCallback);
          // 1st, 2nd, ..., 12th

          case 'Mo':
            return mapValue(match.ordinalNumber(dateString, {
              unit: 'month'
            }), valueCallback);
          // Jan, Feb, ..., Dec

          case 'MMM':
            return match.month(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.month(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          // J, F, ..., D

          case 'MMMMM':
            return match.month(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          // January, February, ..., December

          case 'MMMM':
          default:
            return match.month(dateString, {
              width: 'wide',
              context: 'formatting'
            }) || match.month(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.month(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
        }
      }

      validate(_date, value) {
        return value >= 0 && value <= 11;
      }

      set(date, _flags, value) {
        date.setUTCMonth(value, 1);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }

    }

    function _defineProperty$m(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }
    class StandAloneMonthParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$m(this, "priority", 110);

        _defineProperty$m(this, "incompatibleTokens", ['Y', 'R', 'q', 'Q', 'M', 'w', 'I', 'D', 'i', 'e', 'c', 't', 'T']);
      }

      parse(dateString, token, match) {
        var valueCallback = function (value) {
          return value - 1;
        };

        switch (token) {
          // 1, 2, ..., 12
          case 'L':
            return mapValue(parseNumericPattern(numericPatterns.month, dateString), valueCallback);
          // 01, 02, ..., 12

          case 'LL':
            return mapValue(parseNDigits(2, dateString), valueCallback);
          // 1st, 2nd, ..., 12th

          case 'Lo':
            return mapValue(match.ordinalNumber(dateString, {
              unit: 'month'
            }), valueCallback);
          // Jan, Feb, ..., Dec

          case 'LLL':
            return match.month(dateString, {
              width: 'abbreviated',
              context: 'standalone'
            }) || match.month(dateString, {
              width: 'narrow',
              context: 'standalone'
            });
          // J, F, ..., D

          case 'LLLLL':
            return match.month(dateString, {
              width: 'narrow',
              context: 'standalone'
            });
          // January, February, ..., December

          case 'LLLL':
          default:
            return match.month(dateString, {
              width: 'wide',
              context: 'standalone'
            }) || match.month(dateString, {
              width: 'abbreviated',
              context: 'standalone'
            }) || match.month(dateString, {
              width: 'narrow',
              context: 'standalone'
            });
        }
      }

      validate(_date, value) {
        return value >= 0 && value <= 11;
      }

      set(date, _flags, value) {
        date.setUTCMonth(value, 1);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }

    }

    function setUTCWeek(dirtyDate, dirtyWeek, options) {
      requiredArgs$1(2, arguments);
      var date = toDate$2(dirtyDate);
      var week = toInteger$1(dirtyWeek);
      var diff = getUTCWeek$1(date, options) - week;
      date.setUTCDate(date.getUTCDate() - diff * 7);
      return date;
    }

    function _defineProperty$l(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }

    class LocalWeekParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$l(this, "priority", 100);

        _defineProperty$l(this, "incompatibleTokens", ['y', 'R', 'u', 'q', 'Q', 'M', 'L', 'I', 'd', 'D', 'i', 't', 'T']);
      }

      parse(dateString, token, match) {
        switch (token) {
          case 'w':
            return parseNumericPattern(numericPatterns.week, dateString);

          case 'wo':
            return match.ordinalNumber(dateString, {
              unit: 'week'
            });

          default:
            return parseNDigits(token.length, dateString);
        }
      }

      validate(_date, value) {
        return value >= 1 && value <= 53;
      }

      set(date, _flags, value, options) {
        return startOfUTCWeek$1(setUTCWeek(date, value, options), options);
      }

    }

    function setUTCISOWeek(dirtyDate, dirtyISOWeek) {
      requiredArgs$1(2, arguments);
      var date = toDate$2(dirtyDate);
      var isoWeek = toInteger$1(dirtyISOWeek);
      var diff = getUTCISOWeek$1(date) - isoWeek;
      date.setUTCDate(date.getUTCDate() - diff * 7);
      return date;
    }

    function _defineProperty$k(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }

    class ISOWeekParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$k(this, "priority", 100);

        _defineProperty$k(this, "incompatibleTokens", ['y', 'Y', 'u', 'q', 'Q', 'M', 'L', 'w', 'd', 'D', 'e', 'c', 't', 'T']);
      }

      parse(dateString, token, match) {
        switch (token) {
          case 'I':
            return parseNumericPattern(numericPatterns.week, dateString);

          case 'Io':
            return match.ordinalNumber(dateString, {
              unit: 'week'
            });

          default:
            return parseNDigits(token.length, dateString);
        }
      }

      validate(_date, value) {
        return value >= 1 && value <= 53;
      }

      set(date, _flags, value) {
        return startOfUTCISOWeek$1(setUTCISOWeek(date, value));
      }

    }

    function _defineProperty$j(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }
    var DAYS_IN_MONTH = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
    var DAYS_IN_MONTH_LEAP_YEAR = [31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31]; // Day of the month

    class DateParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$j(this, "priority", 90);

        _defineProperty$j(this, "subPriority", 1);

        _defineProperty$j(this, "incompatibleTokens", ['Y', 'R', 'q', 'Q', 'w', 'I', 'D', 'i', 'e', 'c', 't', 'T']);
      }

      parse(dateString, token, match) {
        switch (token) {
          case 'd':
            return parseNumericPattern(numericPatterns.date, dateString);

          case 'do':
            return match.ordinalNumber(dateString, {
              unit: 'date'
            });

          default:
            return parseNDigits(token.length, dateString);
        }
      }

      validate(date, value) {
        var year = date.getUTCFullYear();
        var isLeapYear = isLeapYearIndex(year);
        var month = date.getUTCMonth();

        if (isLeapYear) {
          return value >= 1 && value <= DAYS_IN_MONTH_LEAP_YEAR[month];
        } else {
          return value >= 1 && value <= DAYS_IN_MONTH[month];
        }
      }

      set(date, _flags, value) {
        date.setUTCDate(value);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }

    }

    function _defineProperty$i(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }
    class DayOfYearParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$i(this, "priority", 90);

        _defineProperty$i(this, "subpriority", 1);

        _defineProperty$i(this, "incompatibleTokens", ['Y', 'R', 'q', 'Q', 'M', 'L', 'w', 'I', 'd', 'E', 'i', 'e', 'c', 't', 'T']);
      }

      parse(dateString, token, match) {
        switch (token) {
          case 'D':
          case 'DD':
            return parseNumericPattern(numericPatterns.dayOfYear, dateString);

          case 'Do':
            return match.ordinalNumber(dateString, {
              unit: 'date'
            });

          default:
            return parseNDigits(token.length, dateString);
        }
      }

      validate(date, value) {
        var year = date.getUTCFullYear();
        var isLeapYear = isLeapYearIndex(year);

        if (isLeapYear) {
          return value >= 1 && value <= 366;
        } else {
          return value >= 1 && value <= 365;
        }
      }

      set(date, _flags, value) {
        date.setUTCMonth(0, value);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }

    }

    function setUTCDay(dirtyDate, dirtyDay, options) {
      var _ref, _ref2, _ref3, _options$weekStartsOn, _options$locale, _options$locale$optio, _defaultOptions$local, _defaultOptions$local2;

      requiredArgs$1(2, arguments);
      var defaultOptions = getDefaultOptions$1();
      var weekStartsOn = toInteger$1((_ref = (_ref2 = (_ref3 = (_options$weekStartsOn = options === null || options === void 0 ? void 0 : options.weekStartsOn) !== null && _options$weekStartsOn !== void 0 ? _options$weekStartsOn : options === null || options === void 0 ? void 0 : (_options$locale = options.locale) === null || _options$locale === void 0 ? void 0 : (_options$locale$optio = _options$locale.options) === null || _options$locale$optio === void 0 ? void 0 : _options$locale$optio.weekStartsOn) !== null && _ref3 !== void 0 ? _ref3 : defaultOptions.weekStartsOn) !== null && _ref2 !== void 0 ? _ref2 : (_defaultOptions$local = defaultOptions.locale) === null || _defaultOptions$local === void 0 ? void 0 : (_defaultOptions$local2 = _defaultOptions$local.options) === null || _defaultOptions$local2 === void 0 ? void 0 : _defaultOptions$local2.weekStartsOn) !== null && _ref !== void 0 ? _ref : 0); // Test if weekStartsOn is between 0 and 6 _and_ is not NaN

      if (!(weekStartsOn >= 0 && weekStartsOn <= 6)) {
        throw new RangeError('weekStartsOn must be between 0 and 6 inclusively');
      }

      var date = toDate$2(dirtyDate);
      var day = toInteger$1(dirtyDay);
      var currentDay = date.getUTCDay();
      var remainder = day % 7;
      var dayIndex = (remainder + 7) % 7;
      var diff = (dayIndex < weekStartsOn ? 7 : 0) + day - currentDay;
      date.setUTCDate(date.getUTCDate() + diff);
      return date;
    }

    function _defineProperty$h(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }

    class DayParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$h(this, "priority", 90);

        _defineProperty$h(this, "incompatibleTokens", ['D', 'i', 'e', 'c', 't', 'T']);
      }

      parse(dateString, token, match) {
        switch (token) {
          // Tue
          case 'E':
          case 'EE':
          case 'EEE':
            return match.day(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'short',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          // T

          case 'EEEEE':
            return match.day(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          // Tu

          case 'EEEEEE':
            return match.day(dateString, {
              width: 'short',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          // Tuesday

          case 'EEEE':
          default:
            return match.day(dateString, {
              width: 'wide',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'short',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
        }
      }

      validate(_date, value) {
        return value >= 0 && value <= 6;
      }

      set(date, _flags, value, options) {
        date = setUTCDay(date, value, options);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }

    }

    function _defineProperty$g(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }

    class LocalDayParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$g(this, "priority", 90);

        _defineProperty$g(this, "incompatibleTokens", ['y', 'R', 'u', 'q', 'Q', 'M', 'L', 'I', 'd', 'D', 'E', 'i', 'c', 't', 'T']);
      }

      parse(dateString, token, match, options) {
        var valueCallback = function (value) {
          var wholeWeekDays = Math.floor((value - 1) / 7) * 7;
          return (value + options.weekStartsOn + 6) % 7 + wholeWeekDays;
        };

        switch (token) {
          // 3
          case 'e':
          case 'ee':
            // 03
            return mapValue(parseNDigits(token.length, dateString), valueCallback);
          // 3rd

          case 'eo':
            return mapValue(match.ordinalNumber(dateString, {
              unit: 'day'
            }), valueCallback);
          // Tue

          case 'eee':
            return match.day(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'short',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          // T

          case 'eeeee':
            return match.day(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          // Tu

          case 'eeeeee':
            return match.day(dateString, {
              width: 'short',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
          // Tuesday

          case 'eeee':
          default:
            return match.day(dateString, {
              width: 'wide',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'short',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
        }
      }

      validate(_date, value) {
        return value >= 0 && value <= 6;
      }

      set(date, _flags, value, options) {
        date = setUTCDay(date, value, options);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }

    }

    function _defineProperty$f(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }

    class StandAloneLocalDayParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$f(this, "priority", 90);

        _defineProperty$f(this, "incompatibleTokens", ['y', 'R', 'u', 'q', 'Q', 'M', 'L', 'I', 'd', 'D', 'E', 'i', 'e', 't', 'T']);
      }

      parse(dateString, token, match, options) {
        var valueCallback = function (value) {
          var wholeWeekDays = Math.floor((value - 1) / 7) * 7;
          return (value + options.weekStartsOn + 6) % 7 + wholeWeekDays;
        };

        switch (token) {
          // 3
          case 'c':
          case 'cc':
            // 03
            return mapValue(parseNDigits(token.length, dateString), valueCallback);
          // 3rd

          case 'co':
            return mapValue(match.ordinalNumber(dateString, {
              unit: 'day'
            }), valueCallback);
          // Tue

          case 'ccc':
            return match.day(dateString, {
              width: 'abbreviated',
              context: 'standalone'
            }) || match.day(dateString, {
              width: 'short',
              context: 'standalone'
            }) || match.day(dateString, {
              width: 'narrow',
              context: 'standalone'
            });
          // T

          case 'ccccc':
            return match.day(dateString, {
              width: 'narrow',
              context: 'standalone'
            });
          // Tu

          case 'cccccc':
            return match.day(dateString, {
              width: 'short',
              context: 'standalone'
            }) || match.day(dateString, {
              width: 'narrow',
              context: 'standalone'
            });
          // Tuesday

          case 'cccc':
          default:
            return match.day(dateString, {
              width: 'wide',
              context: 'standalone'
            }) || match.day(dateString, {
              width: 'abbreviated',
              context: 'standalone'
            }) || match.day(dateString, {
              width: 'short',
              context: 'standalone'
            }) || match.day(dateString, {
              width: 'narrow',
              context: 'standalone'
            });
        }
      }

      validate(_date, value) {
        return value >= 0 && value <= 6;
      }

      set(date, _flags, value, options) {
        date = setUTCDay(date, value, options);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }

    }

    function setUTCISODay(dirtyDate, dirtyDay) {
      requiredArgs$1(2, arguments);
      var day = toInteger$1(dirtyDay);

      if (day % 7 === 0) {
        day = day - 7;
      }

      var weekStartsOn = 1;
      var date = toDate$2(dirtyDate);
      var currentDay = date.getUTCDay();
      var remainder = day % 7;
      var dayIndex = (remainder + 7) % 7;
      var diff = (dayIndex < weekStartsOn ? 7 : 0) + day - currentDay;
      date.setUTCDate(date.getUTCDate() + diff);
      return date;
    }

    function _defineProperty$e(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }

    class ISODayParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$e(this, "priority", 90);

        _defineProperty$e(this, "incompatibleTokens", ['y', 'Y', 'u', 'q', 'Q', 'M', 'L', 'w', 'd', 'D', 'E', 'e', 'c', 't', 'T']);
      }

      parse(dateString, token, match) {
        var valueCallback = function (value) {
          if (value === 0) {
            return 7;
          }

          return value;
        };

        switch (token) {
          // 2
          case 'i':
          case 'ii':
            // 02
            return parseNDigits(token.length, dateString);
          // 2nd

          case 'io':
            return match.ordinalNumber(dateString, {
              unit: 'day'
            });
          // Tue

          case 'iii':
            return mapValue(match.day(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'short',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'narrow',
              context: 'formatting'
            }), valueCallback);
          // T

          case 'iiiii':
            return mapValue(match.day(dateString, {
              width: 'narrow',
              context: 'formatting'
            }), valueCallback);
          // Tu

          case 'iiiiii':
            return mapValue(match.day(dateString, {
              width: 'short',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'narrow',
              context: 'formatting'
            }), valueCallback);
          // Tuesday

          case 'iiii':
          default:
            return mapValue(match.day(dateString, {
              width: 'wide',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'short',
              context: 'formatting'
            }) || match.day(dateString, {
              width: 'narrow',
              context: 'formatting'
            }), valueCallback);
        }
      }

      validate(_date, value) {
        return value >= 1 && value <= 7;
      }

      set(date, _flags, value) {
        date = setUTCISODay(date, value);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }

    }

    function _defineProperty$d(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }
    class AMPMParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$d(this, "priority", 80);

        _defineProperty$d(this, "incompatibleTokens", ['b', 'B', 'H', 'k', 't', 'T']);
      }

      parse(dateString, token, match) {
        switch (token) {
          case 'a':
          case 'aa':
          case 'aaa':
            return match.dayPeriod(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.dayPeriod(dateString, {
              width: 'narrow',
              context: 'formatting'
            });

          case 'aaaaa':
            return match.dayPeriod(dateString, {
              width: 'narrow',
              context: 'formatting'
            });

          case 'aaaa':
          default:
            return match.dayPeriod(dateString, {
              width: 'wide',
              context: 'formatting'
            }) || match.dayPeriod(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.dayPeriod(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
        }
      }

      set(date, _flags, value) {
        date.setUTCHours(dayPeriodEnumToHours(value), 0, 0, 0);
        return date;
      }

    }

    function _defineProperty$c(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }
    class AMPMMidnightParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$c(this, "priority", 80);

        _defineProperty$c(this, "incompatibleTokens", ['a', 'B', 'H', 'k', 't', 'T']);
      }

      parse(dateString, token, match) {
        switch (token) {
          case 'b':
          case 'bb':
          case 'bbb':
            return match.dayPeriod(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.dayPeriod(dateString, {
              width: 'narrow',
              context: 'formatting'
            });

          case 'bbbbb':
            return match.dayPeriod(dateString, {
              width: 'narrow',
              context: 'formatting'
            });

          case 'bbbb':
          default:
            return match.dayPeriod(dateString, {
              width: 'wide',
              context: 'formatting'
            }) || match.dayPeriod(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.dayPeriod(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
        }
      }

      set(date, _flags, value) {
        date.setUTCHours(dayPeriodEnumToHours(value), 0, 0, 0);
        return date;
      }

    }

    function _defineProperty$b(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }

    class DayPeriodParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$b(this, "priority", 80);

        _defineProperty$b(this, "incompatibleTokens", ['a', 'b', 't', 'T']);
      }

      parse(dateString, token, match) {
        switch (token) {
          case 'B':
          case 'BB':
          case 'BBB':
            return match.dayPeriod(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.dayPeriod(dateString, {
              width: 'narrow',
              context: 'formatting'
            });

          case 'BBBBB':
            return match.dayPeriod(dateString, {
              width: 'narrow',
              context: 'formatting'
            });

          case 'BBBB':
          default:
            return match.dayPeriod(dateString, {
              width: 'wide',
              context: 'formatting'
            }) || match.dayPeriod(dateString, {
              width: 'abbreviated',
              context: 'formatting'
            }) || match.dayPeriod(dateString, {
              width: 'narrow',
              context: 'formatting'
            });
        }
      }

      set(date, _flags, value) {
        date.setUTCHours(dayPeriodEnumToHours(value), 0, 0, 0);
        return date;
      }

    }

    function _defineProperty$a(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }
    class Hour1to12Parser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$a(this, "priority", 70);

        _defineProperty$a(this, "incompatibleTokens", ['H', 'K', 'k', 't', 'T']);
      }

      parse(dateString, token, match) {
        switch (token) {
          case 'h':
            return parseNumericPattern(numericPatterns.hour12h, dateString);

          case 'ho':
            return match.ordinalNumber(dateString, {
              unit: 'hour'
            });

          default:
            return parseNDigits(token.length, dateString);
        }
      }

      validate(_date, value) {
        return value >= 1 && value <= 12;
      }

      set(date, _flags, value) {
        var isPM = date.getUTCHours() >= 12;

        if (isPM && value < 12) {
          date.setUTCHours(value + 12, 0, 0, 0);
        } else if (!isPM && value === 12) {
          date.setUTCHours(0, 0, 0, 0);
        } else {
          date.setUTCHours(value, 0, 0, 0);
        }

        return date;
      }

    }

    function _defineProperty$9(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }
    class Hour0to23Parser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$9(this, "priority", 70);

        _defineProperty$9(this, "incompatibleTokens", ['a', 'b', 'h', 'K', 'k', 't', 'T']);
      }

      parse(dateString, token, match) {
        switch (token) {
          case 'H':
            return parseNumericPattern(numericPatterns.hour23h, dateString);

          case 'Ho':
            return match.ordinalNumber(dateString, {
              unit: 'hour'
            });

          default:
            return parseNDigits(token.length, dateString);
        }
      }

      validate(_date, value) {
        return value >= 0 && value <= 23;
      }

      set(date, _flags, value) {
        date.setUTCHours(value, 0, 0, 0);
        return date;
      }

    }

    function _defineProperty$8(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }
    class Hour0To11Parser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$8(this, "priority", 70);

        _defineProperty$8(this, "incompatibleTokens", ['h', 'H', 'k', 't', 'T']);
      }

      parse(dateString, token, match) {
        switch (token) {
          case 'K':
            return parseNumericPattern(numericPatterns.hour11h, dateString);

          case 'Ko':
            return match.ordinalNumber(dateString, {
              unit: 'hour'
            });

          default:
            return parseNDigits(token.length, dateString);
        }
      }

      validate(_date, value) {
        return value >= 0 && value <= 11;
      }

      set(date, _flags, value) {
        var isPM = date.getUTCHours() >= 12;

        if (isPM && value < 12) {
          date.setUTCHours(value + 12, 0, 0, 0);
        } else {
          date.setUTCHours(value, 0, 0, 0);
        }

        return date;
      }

    }

    function _defineProperty$7(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }
    class Hour1To24Parser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$7(this, "priority", 70);

        _defineProperty$7(this, "incompatibleTokens", ['a', 'b', 'h', 'H', 'K', 't', 'T']);
      }

      parse(dateString, token, match) {
        switch (token) {
          case 'k':
            return parseNumericPattern(numericPatterns.hour24h, dateString);

          case 'ko':
            return match.ordinalNumber(dateString, {
              unit: 'hour'
            });

          default:
            return parseNDigits(token.length, dateString);
        }
      }

      validate(_date, value) {
        return value >= 1 && value <= 24;
      }

      set(date, _flags, value) {
        var hours = value <= 24 ? value % 24 : value;
        date.setUTCHours(hours, 0, 0, 0);
        return date;
      }

    }

    function _defineProperty$6(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }
    class MinuteParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$6(this, "priority", 60);

        _defineProperty$6(this, "incompatibleTokens", ['t', 'T']);
      }

      parse(dateString, token, match) {
        switch (token) {
          case 'm':
            return parseNumericPattern(numericPatterns.minute, dateString);

          case 'mo':
            return match.ordinalNumber(dateString, {
              unit: 'minute'
            });

          default:
            return parseNDigits(token.length, dateString);
        }
      }

      validate(_date, value) {
        return value >= 0 && value <= 59;
      }

      set(date, _flags, value) {
        date.setUTCMinutes(value, 0, 0);
        return date;
      }

    }

    function _defineProperty$5(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }
    class SecondParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$5(this, "priority", 50);

        _defineProperty$5(this, "incompatibleTokens", ['t', 'T']);
      }

      parse(dateString, token, match) {
        switch (token) {
          case 's':
            return parseNumericPattern(numericPatterns.second, dateString);

          case 'so':
            return match.ordinalNumber(dateString, {
              unit: 'second'
            });

          default:
            return parseNDigits(token.length, dateString);
        }
      }

      validate(_date, value) {
        return value >= 0 && value <= 59;
      }

      set(date, _flags, value) {
        date.setUTCSeconds(value, 0);
        return date;
      }

    }

    function _defineProperty$4(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }
    class FractionOfSecondParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$4(this, "priority", 30);

        _defineProperty$4(this, "incompatibleTokens", ['t', 'T']);
      }

      parse(dateString, token) {
        var valueCallback = function (value) {
          return Math.floor(value * Math.pow(10, -token.length + 3));
        };

        return mapValue(parseNDigits(token.length, dateString), valueCallback);
      }

      set(date, _flags, value) {
        date.setUTCMilliseconds(value);
        return date;
      }

    }

    function _defineProperty$3(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }

    class ISOTimezoneWithZParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$3(this, "priority", 10);

        _defineProperty$3(this, "incompatibleTokens", ['t', 'T', 'x']);
      }

      parse(dateString, token) {
        switch (token) {
          case 'X':
            return parseTimezonePattern(timezonePatterns.basicOptionalMinutes, dateString);

          case 'XX':
            return parseTimezonePattern(timezonePatterns.basic, dateString);

          case 'XXXX':
            return parseTimezonePattern(timezonePatterns.basicOptionalSeconds, dateString);

          case 'XXXXX':
            return parseTimezonePattern(timezonePatterns.extendedOptionalSeconds, dateString);

          case 'XXX':
          default:
            return parseTimezonePattern(timezonePatterns.extended, dateString);
        }
      }

      set(date, flags, value) {
        if (flags.timestampIsSet) {
          return date;
        }

        return new Date(date.getTime() - value);
      }

    }

    function _defineProperty$2(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }

    class ISOTimezoneParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$2(this, "priority", 10);

        _defineProperty$2(this, "incompatibleTokens", ['t', 'T', 'X']);
      }

      parse(dateString, token) {
        switch (token) {
          case 'x':
            return parseTimezonePattern(timezonePatterns.basicOptionalMinutes, dateString);

          case 'xx':
            return parseTimezonePattern(timezonePatterns.basic, dateString);

          case 'xxxx':
            return parseTimezonePattern(timezonePatterns.basicOptionalSeconds, dateString);

          case 'xxxxx':
            return parseTimezonePattern(timezonePatterns.extendedOptionalSeconds, dateString);

          case 'xxx':
          default:
            return parseTimezonePattern(timezonePatterns.extended, dateString);
        }
      }

      set(date, flags, value) {
        if (flags.timestampIsSet) {
          return date;
        }

        return new Date(date.getTime() - value);
      }

    }

    function _defineProperty$1(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }
    class TimestampSecondsParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty$1(this, "priority", 40);

        _defineProperty$1(this, "incompatibleTokens", '*');
      }

      parse(dateString) {
        return parseAnyDigitsSigned(dateString);
      }

      set(_date, _flags, value) {
        return [new Date(value * 1000), {
          timestampIsSet: true
        }];
      }

    }

    function _defineProperty(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, {
          value: value,
          enumerable: true,
          configurable: true,
          writable: true
        });
      } else {
        obj[key] = value;
      }

      return obj;
    }
    class TimestampMillisecondsParser extends Parser {
      constructor() {
        super(...arguments);

        _defineProperty(this, "priority", 20);

        _defineProperty(this, "incompatibleTokens", '*');
      }

      parse(dateString) {
        return parseAnyDigitsSigned(dateString);
      }

      set(_date, _flags, value) {
        return [new Date(value), {
          timestampIsSet: true
        }];
      }

    }

    /*
     * |     | Unit                           |     | Unit                           |
     * |-----|--------------------------------|-----|--------------------------------|
     * |  a  | AM, PM                         |  A* | Milliseconds in day            |
     * |  b  | AM, PM, noon, midnight         |  B  | Flexible day period            |
     * |  c  | Stand-alone local day of week  |  C* | Localized hour w/ day period   |
     * |  d  | Day of month                   |  D  | Day of year                    |
     * |  e  | Local day of week              |  E  | Day of week                    |
     * |  f  |                                |  F* | Day of week in month           |
     * |  g* | Modified Julian day            |  G  | Era                            |
     * |  h  | Hour [1-12]                    |  H  | Hour [0-23]                    |
     * |  i! | ISO day of week                |  I! | ISO week of year               |
     * |  j* | Localized hour w/ day period   |  J* | Localized hour w/o day period  |
     * |  k  | Hour [1-24]                    |  K  | Hour [0-11]                    |
     * |  l* | (deprecated)                   |  L  | Stand-alone month              |
     * |  m  | Minute                         |  M  | Month                          |
     * |  n  |                                |  N  |                                |
     * |  o! | Ordinal number modifier        |  O* | Timezone (GMT)                 |
     * |  p  |                                |  P  |                                |
     * |  q  | Stand-alone quarter            |  Q  | Quarter                        |
     * |  r* | Related Gregorian year         |  R! | ISO week-numbering year        |
     * |  s  | Second                         |  S  | Fraction of second             |
     * |  t! | Seconds timestamp              |  T! | Milliseconds timestamp         |
     * |  u  | Extended year                  |  U* | Cyclic year                    |
     * |  v* | Timezone (generic non-locat.)  |  V* | Timezone (location)            |
     * |  w  | Local week of year             |  W* | Week of month                  |
     * |  x  | Timezone (ISO-8601 w/o Z)      |  X  | Timezone (ISO-8601)            |
     * |  y  | Year (abs)                     |  Y  | Local week-numbering year      |
     * |  z* | Timezone (specific non-locat.) |  Z* | Timezone (aliases)             |
     *
     * Letters marked by * are not implemented but reserved by Unicode standard.
     *
     * Letters marked by ! are non-standard, but implemented by date-fns:
     * - `o` modifies the previous token to turn it into an ordinal (see `parse` docs)
     * - `i` is ISO day of week. For `i` and `ii` is returns numeric ISO week days,
     *   i.e. 7 for Sunday, 1 for Monday, etc.
     * - `I` is ISO week of year, as opposed to `w` which is local week of year.
     * - `R` is ISO week-numbering year, as opposed to `Y` which is local week-numbering year.
     *   `R` is supposed to be used in conjunction with `I` and `i`
     *   for universal ISO week-numbering date, whereas
     *   `Y` is supposed to be used in conjunction with `w` and `e`
     *   for week-numbering date specific to the locale.
     */

    var parsers = {
      G: new EraParser(),
      y: new YearParser(),
      Y: new LocalWeekYearParser(),
      R: new ISOWeekYearParser(),
      u: new ExtendedYearParser(),
      Q: new QuarterParser(),
      q: new StandAloneQuarterParser(),
      M: new MonthParser(),
      L: new StandAloneMonthParser(),
      w: new LocalWeekParser(),
      I: new ISOWeekParser(),
      d: new DateParser(),
      D: new DayOfYearParser(),
      E: new DayParser(),
      e: new LocalDayParser(),
      c: new StandAloneLocalDayParser(),
      i: new ISODayParser(),
      a: new AMPMParser(),
      b: new AMPMMidnightParser(),
      B: new DayPeriodParser(),
      h: new Hour1to12Parser(),
      H: new Hour0to23Parser(),
      K: new Hour0To11Parser(),
      k: new Hour1To24Parser(),
      m: new MinuteParser(),
      s: new SecondParser(),
      S: new FractionOfSecondParser(),
      X: new ISOTimezoneWithZParser(),
      x: new ISOTimezoneParser(),
      t: new TimestampSecondsParser(),
      T: new TimestampMillisecondsParser()
    };

    // - [yYQqMLwIdDecihHKkms]o matches any available ordinal number token
    //   (one of the certain letters followed by `o`)
    // - (\w)\1* matches any sequences of the same letter
    // - '' matches two quote characters in a row
    // - '(''|[^'])+('|$) matches anything surrounded by two quote characters ('),
    //   except a single quote symbol, which ends the sequence.
    //   Two quote characters do not end the sequence.
    //   If there is no matching single quote
    //   then the sequence will continue until the end of the string.
    // - . matches any single character unmatched by previous parts of the RegExps

    var formattingTokensRegExp = /[yYQqMLwIdDecihHKkms]o|(\w)\1*|''|'(''|[^'])+('|$)|./g; // This RegExp catches symbols escaped by quotes, and also
    // sequences of symbols P, p, and the combinations like `PPPPPPPppppp`

    var longFormattingTokensRegExp = /P+p+|P+|p+|''|'(''|[^'])+('|$)|./g;
    var escapedStringRegExp = /^'([^]*?)'?$/;
    var doubleQuoteRegExp = /''/g;
    var notWhitespaceRegExp = /\S/;
    var unescapedLatinCharacterRegExp = /[a-zA-Z]/;
    /**
     * @name parse
     * @category Common Helpers
     * @summary Parse the date.
     *
     * @description
     * Return the date parsed from string using the given format string.
     *
     * > ⚠️ Please note that the `format` tokens differ from Moment.js and other libraries.
     * > See: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
     *
     * The characters in the format string wrapped between two single quotes characters (') are escaped.
     * Two single quotes in a row, whether inside or outside a quoted sequence, represent a 'real' single quote.
     *
     * Format of the format string is based on Unicode Technical Standard #35:
     * https://www.unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table
     * with a few additions (see note 5 below the table).
     *
     * Not all tokens are compatible. Combinations that don't make sense or could lead to bugs are prohibited
     * and will throw `RangeError`. For example usage of 24-hour format token with AM/PM token will throw an exception:
     *
     * ```javascript
     * parse('23 AM', 'HH a', new Date())
     * //=> RangeError: The format string mustn't contain `HH` and `a` at the same time
     * ```
     *
     * See the compatibility table: https://docs.google.com/spreadsheets/d/e/2PACX-1vQOPU3xUhplll6dyoMmVUXHKl_8CRDs6_ueLmex3SoqwhuolkuN3O05l4rqx5h1dKX8eb46Ul-CCSrq/pubhtml?gid=0&single=true
     *
     * Accepted format string patterns:
     * | Unit                            |Prior| Pattern | Result examples                   | Notes |
     * |---------------------------------|-----|---------|-----------------------------------|-------|
     * | Era                             | 140 | G..GGG  | AD, BC                            |       |
     * |                                 |     | GGGG    | Anno Domini, Before Christ        | 2     |
     * |                                 |     | GGGGG   | A, B                              |       |
     * | Calendar year                   | 130 | y       | 44, 1, 1900, 2017, 9999           | 4     |
     * |                                 |     | yo      | 44th, 1st, 1900th, 9999999th      | 4,5   |
     * |                                 |     | yy      | 44, 01, 00, 17                    | 4     |
     * |                                 |     | yyy     | 044, 001, 123, 999                | 4     |
     * |                                 |     | yyyy    | 0044, 0001, 1900, 2017            | 4     |
     * |                                 |     | yyyyy   | ...                               | 2,4   |
     * | Local week-numbering year       | 130 | Y       | 44, 1, 1900, 2017, 9000           | 4     |
     * |                                 |     | Yo      | 44th, 1st, 1900th, 9999999th      | 4,5   |
     * |                                 |     | YY      | 44, 01, 00, 17                    | 4,6   |
     * |                                 |     | YYY     | 044, 001, 123, 999                | 4     |
     * |                                 |     | YYYY    | 0044, 0001, 1900, 2017            | 4,6   |
     * |                                 |     | YYYYY   | ...                               | 2,4   |
     * | ISO week-numbering year         | 130 | R       | -43, 1, 1900, 2017, 9999, -9999   | 4,5   |
     * |                                 |     | RR      | -43, 01, 00, 17                   | 4,5   |
     * |                                 |     | RRR     | -043, 001, 123, 999, -999         | 4,5   |
     * |                                 |     | RRRR    | -0043, 0001, 2017, 9999, -9999    | 4,5   |
     * |                                 |     | RRRRR   | ...                               | 2,4,5 |
     * | Extended year                   | 130 | u       | -43, 1, 1900, 2017, 9999, -999    | 4     |
     * |                                 |     | uu      | -43, 01, 99, -99                  | 4     |
     * |                                 |     | uuu     | -043, 001, 123, 999, -999         | 4     |
     * |                                 |     | uuuu    | -0043, 0001, 2017, 9999, -9999    | 4     |
     * |                                 |     | uuuuu   | ...                               | 2,4   |
     * | Quarter (formatting)            | 120 | Q       | 1, 2, 3, 4                        |       |
     * |                                 |     | Qo      | 1st, 2nd, 3rd, 4th                | 5     |
     * |                                 |     | QQ      | 01, 02, 03, 04                    |       |
     * |                                 |     | QQQ     | Q1, Q2, Q3, Q4                    |       |
     * |                                 |     | QQQQ    | 1st quarter, 2nd quarter, ...     | 2     |
     * |                                 |     | QQQQQ   | 1, 2, 3, 4                        | 4     |
     * | Quarter (stand-alone)           | 120 | q       | 1, 2, 3, 4                        |       |
     * |                                 |     | qo      | 1st, 2nd, 3rd, 4th                | 5     |
     * |                                 |     | qq      | 01, 02, 03, 04                    |       |
     * |                                 |     | qqq     | Q1, Q2, Q3, Q4                    |       |
     * |                                 |     | qqqq    | 1st quarter, 2nd quarter, ...     | 2     |
     * |                                 |     | qqqqq   | 1, 2, 3, 4                        | 3     |
     * | Month (formatting)              | 110 | M       | 1, 2, ..., 12                     |       |
     * |                                 |     | Mo      | 1st, 2nd, ..., 12th               | 5     |
     * |                                 |     | MM      | 01, 02, ..., 12                   |       |
     * |                                 |     | MMM     | Jan, Feb, ..., Dec                |       |
     * |                                 |     | MMMM    | January, February, ..., December  | 2     |
     * |                                 |     | MMMMM   | J, F, ..., D                      |       |
     * | Month (stand-alone)             | 110 | L       | 1, 2, ..., 12                     |       |
     * |                                 |     | Lo      | 1st, 2nd, ..., 12th               | 5     |
     * |                                 |     | LL      | 01, 02, ..., 12                   |       |
     * |                                 |     | LLL     | Jan, Feb, ..., Dec                |       |
     * |                                 |     | LLLL    | January, February, ..., December  | 2     |
     * |                                 |     | LLLLL   | J, F, ..., D                      |       |
     * | Local week of year              | 100 | w       | 1, 2, ..., 53                     |       |
     * |                                 |     | wo      | 1st, 2nd, ..., 53th               | 5     |
     * |                                 |     | ww      | 01, 02, ..., 53                   |       |
     * | ISO week of year                | 100 | I       | 1, 2, ..., 53                     | 5     |
     * |                                 |     | Io      | 1st, 2nd, ..., 53th               | 5     |
     * |                                 |     | II      | 01, 02, ..., 53                   | 5     |
     * | Day of month                    |  90 | d       | 1, 2, ..., 31                     |       |
     * |                                 |     | do      | 1st, 2nd, ..., 31st               | 5     |
     * |                                 |     | dd      | 01, 02, ..., 31                   |       |
     * | Day of year                     |  90 | D       | 1, 2, ..., 365, 366               | 7     |
     * |                                 |     | Do      | 1st, 2nd, ..., 365th, 366th       | 5     |
     * |                                 |     | DD      | 01, 02, ..., 365, 366             | 7     |
     * |                                 |     | DDD     | 001, 002, ..., 365, 366           |       |
     * |                                 |     | DDDD    | ...                               | 2     |
     * | Day of week (formatting)        |  90 | E..EEE  | Mon, Tue, Wed, ..., Sun           |       |
     * |                                 |     | EEEE    | Monday, Tuesday, ..., Sunday      | 2     |
     * |                                 |     | EEEEE   | M, T, W, T, F, S, S               |       |
     * |                                 |     | EEEEEE  | Mo, Tu, We, Th, Fr, Sa, Su        |       |
     * | ISO day of week (formatting)    |  90 | i       | 1, 2, 3, ..., 7                   | 5     |
     * |                                 |     | io      | 1st, 2nd, ..., 7th                | 5     |
     * |                                 |     | ii      | 01, 02, ..., 07                   | 5     |
     * |                                 |     | iii     | Mon, Tue, Wed, ..., Sun           | 5     |
     * |                                 |     | iiii    | Monday, Tuesday, ..., Sunday      | 2,5   |
     * |                                 |     | iiiii   | M, T, W, T, F, S, S               | 5     |
     * |                                 |     | iiiiii  | Mo, Tu, We, Th, Fr, Sa, Su        | 5     |
     * | Local day of week (formatting)  |  90 | e       | 2, 3, 4, ..., 1                   |       |
     * |                                 |     | eo      | 2nd, 3rd, ..., 1st                | 5     |
     * |                                 |     | ee      | 02, 03, ..., 01                   |       |
     * |                                 |     | eee     | Mon, Tue, Wed, ..., Sun           |       |
     * |                                 |     | eeee    | Monday, Tuesday, ..., Sunday      | 2     |
     * |                                 |     | eeeee   | M, T, W, T, F, S, S               |       |
     * |                                 |     | eeeeee  | Mo, Tu, We, Th, Fr, Sa, Su        |       |
     * | Local day of week (stand-alone) |  90 | c       | 2, 3, 4, ..., 1                   |       |
     * |                                 |     | co      | 2nd, 3rd, ..., 1st                | 5     |
     * |                                 |     | cc      | 02, 03, ..., 01                   |       |
     * |                                 |     | ccc     | Mon, Tue, Wed, ..., Sun           |       |
     * |                                 |     | cccc    | Monday, Tuesday, ..., Sunday      | 2     |
     * |                                 |     | ccccc   | M, T, W, T, F, S, S               |       |
     * |                                 |     | cccccc  | Mo, Tu, We, Th, Fr, Sa, Su        |       |
     * | AM, PM                          |  80 | a..aaa  | AM, PM                            |       |
     * |                                 |     | aaaa    | a.m., p.m.                        | 2     |
     * |                                 |     | aaaaa   | a, p                              |       |
     * | AM, PM, noon, midnight          |  80 | b..bbb  | AM, PM, noon, midnight            |       |
     * |                                 |     | bbbb    | a.m., p.m., noon, midnight        | 2     |
     * |                                 |     | bbbbb   | a, p, n, mi                       |       |
     * | Flexible day period             |  80 | B..BBB  | at night, in the morning, ...     |       |
     * |                                 |     | BBBB    | at night, in the morning, ...     | 2     |
     * |                                 |     | BBBBB   | at night, in the morning, ...     |       |
     * | Hour [1-12]                     |  70 | h       | 1, 2, ..., 11, 12                 |       |
     * |                                 |     | ho      | 1st, 2nd, ..., 11th, 12th         | 5     |
     * |                                 |     | hh      | 01, 02, ..., 11, 12               |       |
     * | Hour [0-23]                     |  70 | H       | 0, 1, 2, ..., 23                  |       |
     * |                                 |     | Ho      | 0th, 1st, 2nd, ..., 23rd          | 5     |
     * |                                 |     | HH      | 00, 01, 02, ..., 23               |       |
     * | Hour [0-11]                     |  70 | K       | 1, 2, ..., 11, 0                  |       |
     * |                                 |     | Ko      | 1st, 2nd, ..., 11th, 0th          | 5     |
     * |                                 |     | KK      | 01, 02, ..., 11, 00               |       |
     * | Hour [1-24]                     |  70 | k       | 24, 1, 2, ..., 23                 |       |
     * |                                 |     | ko      | 24th, 1st, 2nd, ..., 23rd         | 5     |
     * |                                 |     | kk      | 24, 01, 02, ..., 23               |       |
     * | Minute                          |  60 | m       | 0, 1, ..., 59                     |       |
     * |                                 |     | mo      | 0th, 1st, ..., 59th               | 5     |
     * |                                 |     | mm      | 00, 01, ..., 59                   |       |
     * | Second                          |  50 | s       | 0, 1, ..., 59                     |       |
     * |                                 |     | so      | 0th, 1st, ..., 59th               | 5     |
     * |                                 |     | ss      | 00, 01, ..., 59                   |       |
     * | Seconds timestamp               |  40 | t       | 512969520                         |       |
     * |                                 |     | tt      | ...                               | 2     |
     * | Fraction of second              |  30 | S       | 0, 1, ..., 9                      |       |
     * |                                 |     | SS      | 00, 01, ..., 99                   |       |
     * |                                 |     | SSS     | 000, 001, ..., 999                |       |
     * |                                 |     | SSSS    | ...                               | 2     |
     * | Milliseconds timestamp          |  20 | T       | 512969520900                      |       |
     * |                                 |     | TT      | ...                               | 2     |
     * | Timezone (ISO-8601 w/ Z)        |  10 | X       | -08, +0530, Z                     |       |
     * |                                 |     | XX      | -0800, +0530, Z                   |       |
     * |                                 |     | XXX     | -08:00, +05:30, Z                 |       |
     * |                                 |     | XXXX    | -0800, +0530, Z, +123456          | 2     |
     * |                                 |     | XXXXX   | -08:00, +05:30, Z, +12:34:56      |       |
     * | Timezone (ISO-8601 w/o Z)       |  10 | x       | -08, +0530, +00                   |       |
     * |                                 |     | xx      | -0800, +0530, +0000               |       |
     * |                                 |     | xxx     | -08:00, +05:30, +00:00            | 2     |
     * |                                 |     | xxxx    | -0800, +0530, +0000, +123456      |       |
     * |                                 |     | xxxxx   | -08:00, +05:30, +00:00, +12:34:56 |       |
     * | Long localized date             |  NA | P       | 05/29/1453                        | 5,8   |
     * |                                 |     | PP      | May 29, 1453                      |       |
     * |                                 |     | PPP     | May 29th, 1453                    |       |
     * |                                 |     | PPPP    | Sunday, May 29th, 1453            | 2,5,8 |
     * | Long localized time             |  NA | p       | 12:00 AM                          | 5,8   |
     * |                                 |     | pp      | 12:00:00 AM                       |       |
     * | Combination of date and time    |  NA | Pp      | 05/29/1453, 12:00 AM              |       |
     * |                                 |     | PPpp    | May 29, 1453, 12:00:00 AM         |       |
     * |                                 |     | PPPpp   | May 29th, 1453 at ...             |       |
     * |                                 |     | PPPPpp  | Sunday, May 29th, 1453 at ...     | 2,5,8 |
     * Notes:
     * 1. "Formatting" units (e.g. formatting quarter) in the default en-US locale
     *    are the same as "stand-alone" units, but are different in some languages.
     *    "Formatting" units are declined according to the rules of the language
     *    in the context of a date. "Stand-alone" units are always nominative singular.
     *    In `format` function, they will produce different result:
     *
     *    `format(new Date(2017, 10, 6), 'do LLLL', {locale: cs}) //=> '6. listopad'`
     *
     *    `format(new Date(2017, 10, 6), 'do MMMM', {locale: cs}) //=> '6. listopadu'`
     *
     *    `parse` will try to match both formatting and stand-alone units interchangably.
     *
     * 2. Any sequence of the identical letters is a pattern, unless it is escaped by
     *    the single quote characters (see below).
     *    If the sequence is longer than listed in table:
     *    - for numerical units (`yyyyyyyy`) `parse` will try to match a number
     *      as wide as the sequence
     *    - for text units (`MMMMMMMM`) `parse` will try to match the widest variation of the unit.
     *      These variations are marked with "2" in the last column of the table.
     *
     * 3. `QQQQQ` and `qqqqq` could be not strictly numerical in some locales.
     *    These tokens represent the shortest form of the quarter.
     *
     * 4. The main difference between `y` and `u` patterns are B.C. years:
     *
     *    | Year | `y` | `u` |
     *    |------|-----|-----|
     *    | AC 1 |   1 |   1 |
     *    | BC 1 |   1 |   0 |
     *    | BC 2 |   2 |  -1 |
     *
     *    Also `yy` will try to guess the century of two digit year by proximity with `referenceDate`:
     *
     *    `parse('50', 'yy', new Date(2018, 0, 1)) //=> Sat Jan 01 2050 00:00:00`
     *
     *    `parse('75', 'yy', new Date(2018, 0, 1)) //=> Wed Jan 01 1975 00:00:00`
     *
     *    while `uu` will just assign the year as is:
     *
     *    `parse('50', 'uu', new Date(2018, 0, 1)) //=> Sat Jan 01 0050 00:00:00`
     *
     *    `parse('75', 'uu', new Date(2018, 0, 1)) //=> Tue Jan 01 0075 00:00:00`
     *
     *    The same difference is true for local and ISO week-numbering years (`Y` and `R`),
     *    except local week-numbering years are dependent on `options.weekStartsOn`
     *    and `options.firstWeekContainsDate` (compare [setISOWeekYear]{@link https://date-fns.org/docs/setISOWeekYear}
     *    and [setWeekYear]{@link https://date-fns.org/docs/setWeekYear}).
     *
     * 5. These patterns are not in the Unicode Technical Standard #35:
     *    - `i`: ISO day of week
     *    - `I`: ISO week of year
     *    - `R`: ISO week-numbering year
     *    - `o`: ordinal number modifier
     *    - `P`: long localized date
     *    - `p`: long localized time
     *
     * 6. `YY` and `YYYY` tokens represent week-numbering years but they are often confused with years.
     *    You should enable `options.useAdditionalWeekYearTokens` to use them. See: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
     *
     * 7. `D` and `DD` tokens represent days of the year but they are ofthen confused with days of the month.
     *    You should enable `options.useAdditionalDayOfYearTokens` to use them. See: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
     *
     * 8. `P+` tokens do not have a defined priority since they are merely aliases to other tokens based
     *    on the given locale.
     *
     *    using `en-US` locale: `P` => `MM/dd/yyyy`
     *    using `en-US` locale: `p` => `hh:mm a`
     *    using `pt-BR` locale: `P` => `dd/MM/yyyy`
     *    using `pt-BR` locale: `p` => `HH:mm`
     *
     * Values will be assigned to the date in the descending order of its unit's priority.
     * Units of an equal priority overwrite each other in the order of appearance.
     *
     * If no values of higher priority are parsed (e.g. when parsing string 'January 1st' without a year),
     * the values will be taken from 3rd argument `referenceDate` which works as a context of parsing.
     *
     * `referenceDate` must be passed for correct work of the function.
     * If you're not sure which `referenceDate` to supply, create a new instance of Date:
     * `parse('02/11/2014', 'MM/dd/yyyy', new Date())`
     * In this case parsing will be done in the context of the current date.
     * If `referenceDate` is `Invalid Date` or a value not convertible to valid `Date`,
     * then `Invalid Date` will be returned.
     *
     * The result may vary by locale.
     *
     * If `formatString` matches with `dateString` but does not provides tokens, `referenceDate` will be returned.
     *
     * If parsing failed, `Invalid Date` will be returned.
     * Invalid Date is a Date, whose time value is NaN.
     * Time value of Date: http://es5.github.io/#x15.9.1.1
     *
     * @param {String} dateString - the string to parse
     * @param {String} formatString - the string of tokens
     * @param {Date|Number} referenceDate - defines values missing from the parsed dateString
     * @param {Object} [options] - an object with options.
     * @param {Locale} [options.locale=defaultLocale] - the locale object. See [Locale]{@link https://date-fns.org/docs/Locale}
     * @param {0|1|2|3|4|5|6} [options.weekStartsOn=0] - the index of the first day of the week (0 - Sunday)
     * @param {1|2|3|4|5|6|7} [options.firstWeekContainsDate=1] - the day of January, which is always in the first week of the year
     * @param {Boolean} [options.useAdditionalWeekYearTokens=false] - if true, allows usage of the week-numbering year tokens `YY` and `YYYY`;
     *   see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
     * @param {Boolean} [options.useAdditionalDayOfYearTokens=false] - if true, allows usage of the day of year tokens `D` and `DD`;
     *   see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
     * @returns {Date} the parsed date
     * @throws {TypeError} 3 arguments required
     * @throws {RangeError} `options.weekStartsOn` must be between 0 and 6
     * @throws {RangeError} `options.firstWeekContainsDate` must be between 1 and 7
     * @throws {RangeError} `options.locale` must contain `match` property
     * @throws {RangeError} use `yyyy` instead of `YYYY` for formatting years using [format provided] to the input [input provided]; see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
     * @throws {RangeError} use `yy` instead of `YY` for formatting years using [format provided] to the input [input provided]; see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
     * @throws {RangeError} use `d` instead of `D` for formatting days of the month using [format provided] to the input [input provided]; see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
     * @throws {RangeError} use `dd` instead of `DD` for formatting days of the month using [format provided] to the input [input provided]; see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
     * @throws {RangeError} format string contains an unescaped latin alphabet character
     *
     * @example
     * // Parse 11 February 2014 from middle-endian format:
     * var result = parse('02/11/2014', 'MM/dd/yyyy', new Date())
     * //=> Tue Feb 11 2014 00:00:00
     *
     * @example
     * // Parse 28th of February in Esperanto locale in the context of 2010 year:
     * import eo from 'date-fns/locale/eo'
     * var result = parse('28-a de februaro', "do 'de' MMMM", new Date(2010, 0, 1), {
     *   locale: eo
     * })
     * //=> Sun Feb 28 2010 00:00:00
     */

    function parse$1(dirtyDateString, dirtyFormatString, dirtyReferenceDate, options) {
      var _ref, _options$locale, _ref2, _ref3, _ref4, _options$firstWeekCon, _options$locale2, _options$locale2$opti, _defaultOptions$local, _defaultOptions$local2, _ref5, _ref6, _ref7, _options$weekStartsOn, _options$locale3, _options$locale3$opti, _defaultOptions$local3, _defaultOptions$local4;

      requiredArgs$1(3, arguments);
      var dateString = String(dirtyDateString);
      var formatString = String(dirtyFormatString);
      var defaultOptions = getDefaultOptions$1();
      var locale = (_ref = (_options$locale = options === null || options === void 0 ? void 0 : options.locale) !== null && _options$locale !== void 0 ? _options$locale : defaultOptions.locale) !== null && _ref !== void 0 ? _ref : defaultLocale$1;

      if (!locale.match) {
        throw new RangeError('locale must contain match property');
      }

      var firstWeekContainsDate = toInteger$1((_ref2 = (_ref3 = (_ref4 = (_options$firstWeekCon = options === null || options === void 0 ? void 0 : options.firstWeekContainsDate) !== null && _options$firstWeekCon !== void 0 ? _options$firstWeekCon : options === null || options === void 0 ? void 0 : (_options$locale2 = options.locale) === null || _options$locale2 === void 0 ? void 0 : (_options$locale2$opti = _options$locale2.options) === null || _options$locale2$opti === void 0 ? void 0 : _options$locale2$opti.firstWeekContainsDate) !== null && _ref4 !== void 0 ? _ref4 : defaultOptions.firstWeekContainsDate) !== null && _ref3 !== void 0 ? _ref3 : (_defaultOptions$local = defaultOptions.locale) === null || _defaultOptions$local === void 0 ? void 0 : (_defaultOptions$local2 = _defaultOptions$local.options) === null || _defaultOptions$local2 === void 0 ? void 0 : _defaultOptions$local2.firstWeekContainsDate) !== null && _ref2 !== void 0 ? _ref2 : 1); // Test if weekStartsOn is between 1 and 7 _and_ is not NaN

      if (!(firstWeekContainsDate >= 1 && firstWeekContainsDate <= 7)) {
        throw new RangeError('firstWeekContainsDate must be between 1 and 7 inclusively');
      }

      var weekStartsOn = toInteger$1((_ref5 = (_ref6 = (_ref7 = (_options$weekStartsOn = options === null || options === void 0 ? void 0 : options.weekStartsOn) !== null && _options$weekStartsOn !== void 0 ? _options$weekStartsOn : options === null || options === void 0 ? void 0 : (_options$locale3 = options.locale) === null || _options$locale3 === void 0 ? void 0 : (_options$locale3$opti = _options$locale3.options) === null || _options$locale3$opti === void 0 ? void 0 : _options$locale3$opti.weekStartsOn) !== null && _ref7 !== void 0 ? _ref7 : defaultOptions.weekStartsOn) !== null && _ref6 !== void 0 ? _ref6 : (_defaultOptions$local3 = defaultOptions.locale) === null || _defaultOptions$local3 === void 0 ? void 0 : (_defaultOptions$local4 = _defaultOptions$local3.options) === null || _defaultOptions$local4 === void 0 ? void 0 : _defaultOptions$local4.weekStartsOn) !== null && _ref5 !== void 0 ? _ref5 : 0); // Test if weekStartsOn is between 0 and 6 _and_ is not NaN

      if (!(weekStartsOn >= 0 && weekStartsOn <= 6)) {
        throw new RangeError('weekStartsOn must be between 0 and 6 inclusively');
      }

      if (formatString === '') {
        if (dateString === '') {
          return toDate$2(dirtyReferenceDate);
        } else {
          return new Date(NaN);
        }
      }

      var subFnOptions = {
        firstWeekContainsDate: firstWeekContainsDate,
        weekStartsOn: weekStartsOn,
        locale: locale
      }; // If timezone isn't specified, it will be set to the system timezone

      var setters = [new DateToSystemTimezoneSetter()];
      var tokens = formatString.match(longFormattingTokensRegExp).map(function (substring) {
        var firstCharacter = substring[0];

        if (firstCharacter in longFormatters$2) {
          var longFormatter = longFormatters$2[firstCharacter];
          return longFormatter(substring, locale.formatLong);
        }

        return substring;
      }).join('').match(formattingTokensRegExp);
      var usedTokens = [];

      var _loop = function (_token) {
        if (!(options !== null && options !== void 0 && options.useAdditionalWeekYearTokens) && isProtectedWeekYearToken$1(_token)) {
          throwProtectedError$1(_token, formatString, dirtyDateString);
        }

        if (!(options !== null && options !== void 0 && options.useAdditionalDayOfYearTokens) && isProtectedDayOfYearToken$1(_token)) {
          throwProtectedError$1(_token, formatString, dirtyDateString);
        }

        var firstCharacter = _token[0];
        var parser = parsers[firstCharacter];

        if (parser) {
          var incompatibleTokens = parser.incompatibleTokens;

          if (Array.isArray(incompatibleTokens)) {
            var incompatibleToken = usedTokens.find(function (usedToken) {
              return incompatibleTokens.includes(usedToken.token) || usedToken.token === firstCharacter;
            });

            if (incompatibleToken) {
              throw new RangeError("The format string mustn't contain `".concat(incompatibleToken.fullToken, "` and `").concat(_token, "` at the same time"));
            }
          } else if (parser.incompatibleTokens === '*' && usedTokens.length > 0) {
            throw new RangeError("The format string mustn't contain `".concat(_token, "` and any other token at the same time"));
          }

          usedTokens.push({
            token: firstCharacter,
            fullToken: _token
          });
          var parseResult = parser.run(dateString, _token, locale.match, subFnOptions);

          if (!parseResult) {
            token = _token;
            return {
              v: new Date(NaN)
            };
          }

          setters.push(parseResult.setter);
          dateString = parseResult.rest;
        } else {
          if (firstCharacter.match(unescapedLatinCharacterRegExp)) {
            throw new RangeError('Format string contains an unescaped latin alphabet character `' + firstCharacter + '`');
          } // Replace two single quote characters with one single quote character


          if (_token === "''") {
            _token = "'";
          } else if (firstCharacter === "'") {
            _token = cleanEscapedString(_token);
          } // Cut token from string, or, if string doesn't match the token, return Invalid Date


          if (dateString.indexOf(_token) === 0) {
            dateString = dateString.slice(_token.length);
          } else {
            token = _token;
            return {
              v: new Date(NaN)
            };
          }
        }

        token = _token;
      };

      for (var token of tokens) {
        var _ret = _loop(token);

        if (typeof _ret === "object") return _ret.v;
      } // Check if the remaining input contains something other than whitespace


      if (dateString.length > 0 && notWhitespaceRegExp.test(dateString)) {
        return new Date(NaN);
      }

      var uniquePrioritySetters = setters.map(function (setter) {
        return setter.priority;
      }).sort(function (a, b) {
        return b - a;
      }).filter(function (priority, index, array) {
        return array.indexOf(priority) === index;
      }).map(function (priority) {
        return setters.filter(function (setter) {
          return setter.priority === priority;
        }).sort(function (a, b) {
          return b.subPriority - a.subPriority;
        });
      }).map(function (setterArray) {
        return setterArray[0];
      });
      var date = toDate$2(dirtyReferenceDate);

      if (isNaN(date.getTime())) {
        return new Date(NaN);
      } // Convert the date in system timezone to the same date in UTC+00:00 timezone.


      var utcDate = subMilliseconds$1(date, getTimezoneOffsetInMilliseconds$1(date));
      var flags = {};

      for (var setter of uniquePrioritySetters) {
        if (!setter.validate(utcDate, subFnOptions)) {
          return new Date(NaN);
        }

        var result = setter.set(utcDate, flags, subFnOptions); // Result is tuple (date, flags)

        if (Array.isArray(result)) {
          utcDate = result[0];
          assign$1(flags, result[1]); // Result is date
        } else {
          utcDate = result;
        }
      }

      return utcDate;
    }

    function cleanEscapedString(input) {
      return input.match(escapedStringRegExp)[1].replace(doubleQuoteRegExp, "'");
    }

    /**
     * @name startOfHour
     * @category Hour Helpers
     * @summary Return the start of an hour for the given date.
     *
     * @description
     * Return the start of an hour for the given date.
     * The result will be in the local timezone.
     *
     * @param {Date|Number} date - the original date
     * @returns {Date} the start of an hour
     * @throws {TypeError} 1 argument required
     *
     * @example
     * // The start of an hour for 2 September 2014 11:55:00:
     * const result = startOfHour(new Date(2014, 8, 2, 11, 55))
     * //=> Tue Sep 02 2014 11:00:00
     */

    function startOfHour(dirtyDate) {
      requiredArgs$1(1, arguments);
      var date = toDate$2(dirtyDate);
      date.setMinutes(0, 0, 0);
      return date;
    }

    /**
     * @name isSameMonth
     * @category Month Helpers
     * @summary Are the given dates in the same month (and year)?
     *
     * @description
     * Are the given dates in the same month (and year)?
     *
     * @param {Date|Number} dateLeft - the first date to check
     * @param {Date|Number} dateRight - the second date to check
     * @returns {Boolean} the dates are in the same month (and year)
     * @throws {TypeError} 2 arguments required
     *
     * @example
     * // Are 2 September 2014 and 25 September 2014 in the same month?
     * const result = isSameMonth(new Date(2014, 8, 2), new Date(2014, 8, 25))
     * //=> true
     *
     * @example
     * // Are 2 September 2014 and 25 September 2015 in the same month?
     * const result = isSameMonth(new Date(2014, 8, 2), new Date(2015, 8, 25))
     * //=> false
     */

    function isSameMonth(dirtyDateLeft, dirtyDateRight) {
      requiredArgs$1(2, arguments);
      var dateLeft = toDate$2(dirtyDateLeft);
      var dateRight = toDate$2(dirtyDateRight);
      return dateLeft.getFullYear() === dateRight.getFullYear() && dateLeft.getMonth() === dateRight.getMonth();
    }

    /**
     * @name isSameQuarter
     * @category Quarter Helpers
     * @summary Are the given dates in the same quarter (and year)?
     *
     * @description
     * Are the given dates in the same quarter (and year)?
     *
     * @param {Date|Number} dateLeft - the first date to check
     * @param {Date|Number} dateRight - the second date to check
     * @returns {Boolean} the dates are in the same quarter (and year)
     * @throws {TypeError} 2 arguments required
     *
     * @example
     * // Are 1 January 2014 and 8 March 2014 in the same quarter?
     * const result = isSameQuarter(new Date(2014, 0, 1), new Date(2014, 2, 8))
     * //=> true
     *
     * @example
     * // Are 1 January 2014 and 1 January 2015 in the same quarter?
     * const result = isSameQuarter(new Date(2014, 0, 1), new Date(2015, 0, 1))
     * //=> false
     */

    function isSameQuarter(dirtyDateLeft, dirtyDateRight) {
      requiredArgs$1(2, arguments);
      var dateLeftStartOfQuarter = startOfQuarter(dirtyDateLeft);
      var dateRightStartOfQuarter = startOfQuarter(dirtyDateRight);
      return dateLeftStartOfQuarter.getTime() === dateRightStartOfQuarter.getTime();
    }

    /**
     * @name startOfSecond
     * @category Second Helpers
     * @summary Return the start of a second for the given date.
     *
     * @description
     * Return the start of a second for the given date.
     * The result will be in the local timezone.
     *
     * @param {Date|Number} date - the original date
     * @returns {Date} the start of a second
     * @throws {TypeError} 1 argument required
     *
     * @example
     * // The start of a second for 1 December 2014 22:15:45.400:
     * const result = startOfSecond(new Date(2014, 11, 1, 22, 15, 45, 400))
     * //=> Mon Dec 01 2014 22:15:45.000
     */

    function startOfSecond(dirtyDate) {
      requiredArgs$1(1, arguments);
      var date = toDate$2(dirtyDate);
      date.setMilliseconds(0);
      return date;
    }

    /**
     * @name isSameYear
     * @category Year Helpers
     * @summary Are the given dates in the same year?
     *
     * @description
     * Are the given dates in the same year?
     *
     * @param {Date|Number} dateLeft - the first date to check
     * @param {Date|Number} dateRight - the second date to check
     * @returns {Boolean} the dates are in the same year
     * @throws {TypeError} 2 arguments required
     *
     * @example
     * // Are 2 September 2014 and 25 September 2014 in the same year?
     * const result = isSameYear(new Date(2014, 8, 2), new Date(2014, 8, 25))
     * //=> true
     */

    function isSameYear(dirtyDateLeft, dirtyDateRight) {
      requiredArgs$1(2, arguments);
      var dateLeft = toDate$2(dirtyDateLeft);
      var dateRight = toDate$2(dirtyDateRight);
      return dateLeft.getFullYear() === dateRight.getFullYear();
    }

    /**
     * @name setMonth
     * @category Month Helpers
     * @summary Set the month to the given date.
     *
     * @description
     * Set the month to the given date.
     *
     * @param {Date|Number} date - the date to be changed
     * @param {Number} month - the month of the new date
     * @returns {Date} the new date with the month set
     * @throws {TypeError} 2 arguments required
     *
     * @example
     * // Set February to 1 September 2014:
     * const result = setMonth(new Date(2014, 8, 1), 1)
     * //=> Sat Feb 01 2014 00:00:00
     */

    function setMonth(dirtyDate, dirtyMonth) {
      requiredArgs$1(2, arguments);
      var date = toDate$2(dirtyDate);
      var month = toInteger$1(dirtyMonth);
      var year = date.getFullYear();
      var day = date.getDate();
      var dateWithDesiredMonth = new Date(0);
      dateWithDesiredMonth.setFullYear(year, month, 15);
      dateWithDesiredMonth.setHours(0, 0, 0, 0);
      var daysInMonth = getDaysInMonth(dateWithDesiredMonth); // Set the last day of the new month
      // if the original date was the last day of the longer month

      date.setMonth(month, Math.min(day, daysInMonth));
      return date;
    }

    /**
     * @name set
     * @category Common Helpers
     * @summary Set date values to a given date.
     *
     * @description
     * Set date values to a given date.
     *
     * Sets time values to date from object `values`.
     * A value is not set if it is undefined or null or doesn't exist in `values`.
     *
     * Note about bundle size: `set` does not internally use `setX` functions from date-fns but instead opts
     * to use native `Date#setX` methods. If you use this function, you may not want to include the
     * other `setX` functions that date-fns provides if you are concerned about the bundle size.
     *
     * @param {Date|Number} date - the date to be changed
     * @param {Object} values - an object with options
     * @param {Number} [values.year] - the number of years to be set
     * @param {Number} [values.month] - the number of months to be set
     * @param {Number} [values.date] - the number of days to be set
     * @param {Number} [values.hours] - the number of hours to be set
     * @param {Number} [values.minutes] - the number of minutes to be set
     * @param {Number} [values.seconds] - the number of seconds to be set
     * @param {Number} [values.milliseconds] - the number of milliseconds to be set
     * @returns {Date} the new date with options set
     * @throws {TypeError} 2 arguments required
     * @throws {RangeError} `values` must be an object
     *
     * @example
     * // Transform 1 September 2014 into 20 October 2015 in a single line:
     * const result = set(new Date(2014, 8, 20), { year: 2015, month: 9, date: 20 })
     * //=> Tue Oct 20 2015 00:00:00
     *
     * @example
     * // Set 12 PM to 1 September 2014 01:23:45 to 1 September 2014 12:00:00:
     * const result = set(new Date(2014, 8, 1, 1, 23, 45), { hours: 12 })
     * //=> Mon Sep 01 2014 12:23:45
     */

    function set(dirtyDate, values) {
      requiredArgs$1(2, arguments);

      if (typeof values !== 'object' || values === null) {
        throw new RangeError('values parameter must be an object');
      }

      var date = toDate$2(dirtyDate); // Check if date is Invalid Date because Date.prototype.setFullYear ignores the value of Invalid Date

      if (isNaN(date.getTime())) {
        return new Date(NaN);
      }

      if (values.year != null) {
        date.setFullYear(values.year);
      }

      if (values.month != null) {
        date = setMonth(date, values.month);
      }

      if (values.date != null) {
        date.setDate(toInteger$1(values.date));
      }

      if (values.hours != null) {
        date.setHours(toInteger$1(values.hours));
      }

      if (values.minutes != null) {
        date.setMinutes(toInteger$1(values.minutes));
      }

      if (values.seconds != null) {
        date.setSeconds(toInteger$1(values.seconds));
      }

      if (values.milliseconds != null) {
        date.setMilliseconds(toInteger$1(values.milliseconds));
      }

      return date;
    }

    /**
     * @name setHours
     * @category Hour Helpers
     * @summary Set the hours to the given date.
     *
     * @description
     * Set the hours to the given date.
     *
     * @param {Date|Number} date - the date to be changed
     * @param {Number} hours - the hours of the new date
     * @returns {Date} the new date with the hours set
     * @throws {TypeError} 2 arguments required
     *
     * @example
     * // Set 4 hours to 1 September 2014 11:30:00:
     * const result = setHours(new Date(2014, 8, 1, 11, 30), 4)
     * //=> Mon Sep 01 2014 04:30:00
     */

    function setHours(dirtyDate, dirtyHours) {
      requiredArgs$1(2, arguments);
      var date = toDate$2(dirtyDate);
      var hours = toInteger$1(dirtyHours);
      date.setHours(hours);
      return date;
    }

    /**
     * @name setMinutes
     * @category Minute Helpers
     * @summary Set the minutes to the given date.
     *
     * @description
     * Set the minutes to the given date.
     *
     * @param {Date|Number} date - the date to be changed
     * @param {Number} minutes - the minutes of the new date
     * @returns {Date} the new date with the minutes set
     * @throws {TypeError} 2 arguments required
     *
     * @example
     * // Set 45 minutes to 1 September 2014 11:30:40:
     * const result = setMinutes(new Date(2014, 8, 1, 11, 30, 40), 45)
     * //=> Mon Sep 01 2014 11:45:40
     */

    function setMinutes(dirtyDate, dirtyMinutes) {
      requiredArgs$1(2, arguments);
      var date = toDate$2(dirtyDate);
      var minutes = toInteger$1(dirtyMinutes);
      date.setMinutes(minutes);
      return date;
    }

    /**
     * @name setQuarter
     * @category Quarter Helpers
     * @summary Set the year quarter to the given date.
     *
     * @description
     * Set the year quarter to the given date.
     *
     * @param {Date|Number} date - the date to be changed
     * @param {Number} quarter - the quarter of the new date
     * @returns {Date} the new date with the quarter set
     * @throws {TypeError} 2 arguments required
     *
     * @example
     * // Set the 2nd quarter to 2 July 2014:
     * const result = setQuarter(new Date(2014, 6, 2), 2)
     * //=> Wed Apr 02 2014 00:00:00
     */

    function setQuarter(dirtyDate, dirtyQuarter) {
      requiredArgs$1(2, arguments);
      var date = toDate$2(dirtyDate);
      var quarter = toInteger$1(dirtyQuarter);
      var oldQuarter = Math.floor(date.getMonth() / 3) + 1;
      var diff = quarter - oldQuarter;
      return setMonth(date, date.getMonth() + diff * 3);
    }

    /**
     * @name setSeconds
     * @category Second Helpers
     * @summary Set the seconds to the given date.
     *
     * @description
     * Set the seconds to the given date.
     *
     * @param {Date|Number} date - the date to be changed
     * @param {Number} seconds - the seconds of the new date
     * @returns {Date} the new date with the seconds set
     * @throws {TypeError} 2 arguments required
     *
     * @example
     * // Set 45 seconds to 1 September 2014 11:30:40:
     * const result = setSeconds(new Date(2014, 8, 1, 11, 30, 40), 45)
     * //=> Mon Sep 01 2014 11:30:45
     */

    function setSeconds(dirtyDate, dirtySeconds) {
      requiredArgs$1(2, arguments);
      var date = toDate$2(dirtyDate);
      var seconds = toInteger$1(dirtySeconds);
      date.setSeconds(seconds);
      return date;
    }

    /**
     * @name setYear
     * @category Year Helpers
     * @summary Set the year to the given date.
     *
     * @description
     * Set the year to the given date.
     *
     * @param {Date|Number} date - the date to be changed
     * @param {Number} year - the year of the new date
     * @returns {Date} the new date with the year set
     * @throws {TypeError} 2 arguments required
     *
     * @example
     * // Set year 2013 to 1 September 2014:
     * const result = setYear(new Date(2014, 8, 1), 2013)
     * //=> Sun Sep 01 2013 00:00:00
     */

    function setYear(dirtyDate, dirtyYear) {
      requiredArgs$1(2, arguments);
      var date = toDate$2(dirtyDate);
      var year = toInteger$1(dirtyYear); // Check if date is Invalid Date because Date.prototype.setFullYear ignores the value of Invalid Date

      if (isNaN(date.getTime())) {
        return new Date(NaN);
      }

      date.setFullYear(year);
      return date;
    }

    var accusativeWeekdays$1 = ['неділю', 'понеділок', 'вівторок', 'середу', 'четвер', 'п’ятницю', 'суботу'];

    function lastWeek$2(day) {
      var weekday = accusativeWeekdays$1[day];

      switch (day) {
        case 0:
        case 3:
        case 5:
        case 6:
          return "'у минулу " + weekday + " о' p";

        case 1:
        case 2:
        case 4:
          return "'у минулий " + weekday + " о' p";
      }
    }

    function thisWeek$2(day) {
      var weekday = accusativeWeekdays$1[day];
      return "'у " + weekday + " о' p";
    }

    function nextWeek$2(day) {
      var weekday = accusativeWeekdays$1[day];

      switch (day) {
        case 0:
        case 3:
        case 5:
        case 6:
          return "'у наступну " + weekday + " о' p";

        case 1:
        case 2:
        case 4:
          return "'у наступний " + weekday + " о' p";
      }
    }

    var lastWeekFormat = function (dirtyDate, baseDate, options) {
      var date = toDate$2(dirtyDate);
      var day = date.getUTCDay();

      if (isSameUTCWeek(date, baseDate, options)) {
        return thisWeek$2(day);
      } else {
        return lastWeek$2(day);
      }
    };

    var nextWeekFormat = function (dirtyDate, baseDate, options) {
      var date = toDate$2(dirtyDate);
      var day = date.getUTCDay();

      if (isSameUTCWeek(date, baseDate, options)) {
        return thisWeek$2(day);
      } else {
        return nextWeek$2(day);
      }
    };

    var formatRelativeLocale$f = {
      lastWeek: lastWeekFormat,
      yesterday: "'вчора о' p",
      today: "'сьогодні о' p",
      tomorrow: "'завтра о' p",
      nextWeek: nextWeekFormat,
      other: 'P'
    };

    var formatRelative$g = function (token, date, baseDate, options) {
      var format = formatRelativeLocale$f[token];

      if (typeof format === 'function') {
        return format(date, baseDate, options);
      }

      return format;
    };

    var eraValues$f = {
      narrow: ['до н.е.', 'н.е.'],
      abbreviated: ['до н. е.', 'н. е.'],
      wide: ['до нашої ери', 'нашої ери']
    };
    var quarterValues$f = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['1-й кв.', '2-й кв.', '3-й кв.', '4-й кв.'],
      wide: ['1-й квартал', '2-й квартал', '3-й квартал', '4-й квартал']
    };
    var monthValues$f = {
      // ДСТУ 3582:2013
      narrow: ['С', 'Л', 'Б', 'К', 'Т', 'Ч', 'Л', 'С', 'В', 'Ж', 'Л', 'Г'],
      abbreviated: ['січ.', 'лют.', 'берез.', 'квіт.', 'трав.', 'черв.', 'лип.', 'серп.', 'верес.', 'жовт.', 'листоп.', 'груд.'],
      wide: ['січень', 'лютий', 'березень', 'квітень', 'травень', 'червень', 'липень', 'серпень', 'вересень', 'жовтень', 'листопад', 'грудень']
    };
    var formattingMonthValues$3 = {
      narrow: ['С', 'Л', 'Б', 'К', 'Т', 'Ч', 'Л', 'С', 'В', 'Ж', 'Л', 'Г'],
      abbreviated: ['січ.', 'лют.', 'берез.', 'квіт.', 'трав.', 'черв.', 'лип.', 'серп.', 'верес.', 'жовт.', 'листоп.', 'груд.'],
      wide: ['січня', 'лютого', 'березня', 'квітня', 'травня', 'червня', 'липня', 'серпня', 'вересня', 'жовтня', 'листопада', 'грудня']
    };
    var dayValues$f = {
      narrow: ['Н', 'П', 'В', 'С', 'Ч', 'П', 'С'],
      short: ['нд', 'пн', 'вт', 'ср', 'чт', 'пт', 'сб'],
      abbreviated: ['нед', 'пон', 'вів', 'сер', 'чтв', 'птн', 'суб'],
      wide: ['неділя', 'понеділок', 'вівторок', 'середа', 'четвер', 'п’ятниця', 'субота']
    };
    var dayPeriodValues$f = {
      narrow: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'півн.',
        noon: 'пол.',
        morning: 'ранок',
        afternoon: 'день',
        evening: 'веч.',
        night: 'ніч'
      },
      abbreviated: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'півн.',
        noon: 'пол.',
        morning: 'ранок',
        afternoon: 'день',
        evening: 'веч.',
        night: 'ніч'
      },
      wide: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'північ',
        noon: 'полудень',
        morning: 'ранок',
        afternoon: 'день',
        evening: 'вечір',
        night: 'ніч'
      }
    };
    var formattingDayPeriodValues$a = {
      narrow: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'півн.',
        noon: 'пол.',
        morning: 'ранку',
        afternoon: 'дня',
        evening: 'веч.',
        night: 'ночі'
      },
      abbreviated: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'півн.',
        noon: 'пол.',
        morning: 'ранку',
        afternoon: 'дня',
        evening: 'веч.',
        night: 'ночі'
      },
      wide: {
        am: 'ДП',
        pm: 'ПП',
        midnight: 'північ',
        noon: 'полудень',
        morning: 'ранку',
        afternoon: 'дня',
        evening: 'веч.',
        night: 'ночі'
      }
    };

    var ordinalNumber$f = function (dirtyNumber, options) {
      var unit = String(options === null || options === void 0 ? void 0 : options.unit);
      var number = Number(dirtyNumber);
      var suffix;

      if (unit === 'date') {
        if (number === 3 || number === 23) {
          suffix = '-є';
        } else {
          suffix = '-е';
        }
      } else if (unit === 'minute' || unit === 'second' || unit === 'hour') {
        suffix = '-а';
      } else {
        suffix = '-й';
      }

      return number + suffix;
    };

    var localize$g = {
      ordinalNumber: ordinalNumber$f,
      era: buildLocalizeFn$1({
        values: eraValues$f,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn$1({
        values: quarterValues$f,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn$1({
        values: monthValues$f,
        defaultWidth: 'wide',
        formattingValues: formattingMonthValues$3,
        defaultFormattingWidth: 'wide'
      }),
      day: buildLocalizeFn$1({
        values: dayValues$f,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn$1({
        values: dayPeriodValues$f,
        defaultWidth: 'any',
        formattingValues: formattingDayPeriodValues$a,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$f = /^(\d+)(-?(е|й|є|а|я))?/i;
    var parseOrdinalNumberPattern$f = /\d+/i;
    var matchEraPatterns$f = {
      narrow: /^((до )?н\.?\s?е\.?)/i,
      abbreviated: /^((до )?н\.?\s?е\.?)/i,
      wide: /^(до нашої ери|нашої ери|наша ера)/i
    };
    var parseEraPatterns$f = {
      any: [/^д/i, /^н/i]
    };
    var matchQuarterPatterns$f = {
      narrow: /^[1234]/i,
      abbreviated: /^[1234](-?[иі]?й?)? кв.?/i,
      wide: /^[1234](-?[иі]?й?)? квартал/i
    };
    var parseQuarterPatterns$f = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$f = {
      narrow: /^[слбктчвжг]/i,
      abbreviated: /^(січ|лют|бер(ез)?|квіт|трав|черв|лип|серп|вер(ес)?|жовт|лис(топ)?|груд)\.?/i,
      wide: /^(січень|січня|лютий|лютого|березень|березня|квітень|квітня|травень|травня|червня|червень|липень|липня|серпень|серпня|вересень|вересня|жовтень|жовтня|листопад[а]?|грудень|грудня)/i
    };
    var parseMonthPatterns$f = {
      narrow: [/^с/i, /^л/i, /^б/i, /^к/i, /^т/i, /^ч/i, /^л/i, /^с/i, /^в/i, /^ж/i, /^л/i, /^г/i],
      any: [/^сі/i, /^лю/i, /^б/i, /^к/i, /^т/i, /^ч/i, /^лип/i, /^се/i, /^в/i, /^ж/i, /^лис/i, /^г/i]
    };
    var matchDayPatterns$f = {
      narrow: /^[нпвсч]/i,
      short: /^(нд|пн|вт|ср|чт|пт|сб)\.?/i,
      abbreviated: /^(нед|пон|вів|сер|че?тв|птн?|суб)\.?/i,
      wide: /^(неділ[яі]|понеділ[ок][ка]|вівтор[ок][ка]|серед[аи]|четвер(га)?|п\W*?ятниц[яі]|субот[аи])/i
    };
    var parseDayPatterns$f = {
      narrow: [/^н/i, /^п/i, /^в/i, /^с/i, /^ч/i, /^п/i, /^с/i],
      any: [/^н/i, /^п[он]/i, /^в/i, /^с[ер]/i, /^ч/i, /^п\W*?[ят]/i, /^с[уб]/i]
    };
    var matchDayPeriodPatterns$f = {
      narrow: /^([дп]п|півн\.?|пол\.?|ранок|ранку|день|дня|веч\.?|ніч|ночі)/i,
      abbreviated: /^([дп]п|півн\.?|пол\.?|ранок|ранку|день|дня|веч\.?|ніч|ночі)/i,
      wide: /^([дп]п|північ|полудень|ранок|ранку|день|дня|вечір|вечора|ніч|ночі)/i
    };
    var parseDayPeriodPatterns$f = {
      any: {
        am: /^дп/i,
        pm: /^пп/i,
        midnight: /^півн/i,
        noon: /^пол/i,
        morning: /^р/i,
        afternoon: /^д[ен]/i,
        evening: /^в/i,
        night: /^н/i
      }
    };
    var match$g = {
      ordinalNumber: buildMatchPatternFn$1({
        matchPattern: matchOrdinalNumberPattern$f,
        parsePattern: parseOrdinalNumberPattern$f,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn$1({
        matchPatterns: matchEraPatterns$f,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$f,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn$1({
        matchPatterns: matchQuarterPatterns$f,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$f,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn$1({
        matchPatterns: matchMonthPatterns$f,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$f,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn$1({
        matchPatterns: matchDayPatterns$f,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$f,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn$1({
        matchPatterns: matchDayPeriodPatterns$f,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPeriodPatterns$f,
        defaultParseWidth: 'any'
      })
    };

    /**
     * @type {Locale}
     * @category Locales
     * @summary Ukrainian locale.
     * @language Ukrainian
     * @iso-639-2 ukr
     * @author Andrii Korzh [@korzhyk]{@link https://github.com/korzhyk}
     * @author Andriy Shcherbyak [@shcherbyakdev]{@link https://github.com/shcherbyakdev}
     */

    var locale$g = {
      code: 'uk',
      formatDistance: formatDistance$g,
      formatLong: formatLong$h,
      formatRelative: formatRelative$g,
      localize: localize$g,
      match: match$g,
      options: {
        weekStartsOn: 1
        /* Monday */
        ,
        firstWeekContainsDate: 1
      }
    };

    const dateUkUA = {
      name: "uk-UA",
      locale: locale$g
    };
    var dateUkUA$1 = dateUkUA;

    var formatDistanceLocale$e = {
      lessThanXSeconds: {
        one: '1秒未満',
        other: '{{count}}秒未満',
        oneWithSuffix: '約1秒',
        otherWithSuffix: '約{{count}}秒'
      },
      xSeconds: {
        one: '1秒',
        other: '{{count}}秒'
      },
      halfAMinute: '30秒',
      lessThanXMinutes: {
        one: '1分未満',
        other: '{{count}}分未満',
        oneWithSuffix: '約1分',
        otherWithSuffix: '約{{count}}分'
      },
      xMinutes: {
        one: '1分',
        other: '{{count}}分'
      },
      aboutXHours: {
        one: '約1時間',
        other: '約{{count}}時間'
      },
      xHours: {
        one: '1時間',
        other: '{{count}}時間'
      },
      xDays: {
        one: '1日',
        other: '{{count}}日'
      },
      aboutXWeeks: {
        one: '約1週間',
        other: '約{{count}}週間'
      },
      xWeeks: {
        one: '1週間',
        other: '{{count}}週間'
      },
      aboutXMonths: {
        one: '約1か月',
        other: '約{{count}}か月'
      },
      xMonths: {
        one: '1か月',
        other: '{{count}}か月'
      },
      aboutXYears: {
        one: '約1年',
        other: '約{{count}}年'
      },
      xYears: {
        one: '1年',
        other: '{{count}}年'
      },
      overXYears: {
        one: '1年以上',
        other: '{{count}}年以上'
      },
      almostXYears: {
        one: '1年近く',
        other: '{{count}}年近く'
      }
    };

    var formatDistance$f = function (token, count, options) {
      options = options || {};
      var result;
      var tokenValue = formatDistanceLocale$e[token];

      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        if (options.addSuffix && tokenValue.oneWithSuffix) {
          result = tokenValue.oneWithSuffix;
        } else {
          result = tokenValue.one;
        }
      } else {
        if (options.addSuffix && tokenValue.otherWithSuffix) {
          result = tokenValue.otherWithSuffix.replace('{{count}}', String(count));
        } else {
          result = tokenValue.other.replace('{{count}}', String(count));
        }
      }

      if (options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return result + '後';
        } else {
          return result + '前';
        }
      }

      return result;
    };

    var dateFormats$f = {
      full: 'y年M月d日EEEE',
      long: 'y年M月d日',
      medium: 'y/MM/dd',
      short: 'y/MM/dd'
    };
    var timeFormats$f = {
      full: 'H時mm分ss秒 zzzz',
      long: 'H:mm:ss z',
      medium: 'H:mm:ss',
      short: 'H:mm'
    };
    var dateTimeFormats$f = {
      full: '{{date}} {{time}}',
      long: '{{date}} {{time}}',
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$g = {
      date: buildFormatLongFn$1({
        formats: dateFormats$f,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn$1({
        formats: timeFormats$f,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn$1({
        formats: dateTimeFormats$f,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$e = {
      lastWeek: '先週のeeeeのp',
      yesterday: '昨日のp',
      today: '今日のp',
      tomorrow: '明日のp',
      nextWeek: '翌週のeeeeのp',
      other: 'P'
    };

    var formatRelative$f = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$e[token];
    };

    var eraValues$e = {
      narrow: ['BC', 'AC'],
      abbreviated: ['紀元前', '西暦'],
      wide: ['紀元前', '西暦']
    };
    var quarterValues$e = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['第1四半期', '第2四半期', '第3四半期', '第4四半期']
    };
    var monthValues$e = {
      narrow: ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12'],
      abbreviated: ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月'],
      wide: ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月']
    };
    var dayValues$e = {
      narrow: ['日', '月', '火', '水', '木', '金', '土'],
      short: ['日', '月', '火', '水', '木', '金', '土'],
      abbreviated: ['日', '月', '火', '水', '木', '金', '土'],
      wide: ['日曜日', '月曜日', '火曜日', '水曜日', '木曜日', '金曜日', '土曜日']
    };
    var dayPeriodValues$e = {
      narrow: {
        am: '午前',
        pm: '午後',
        midnight: '深夜',
        noon: '正午',
        morning: '朝',
        afternoon: '午後',
        evening: '夜',
        night: '深夜'
      },
      abbreviated: {
        am: '午前',
        pm: '午後',
        midnight: '深夜',
        noon: '正午',
        morning: '朝',
        afternoon: '午後',
        evening: '夜',
        night: '深夜'
      },
      wide: {
        am: '午前',
        pm: '午後',
        midnight: '深夜',
        noon: '正午',
        morning: '朝',
        afternoon: '午後',
        evening: '夜',
        night: '深夜'
      }
    };
    var formattingDayPeriodValues$9 = {
      narrow: {
        am: '午前',
        pm: '午後',
        midnight: '深夜',
        noon: '正午',
        morning: '朝',
        afternoon: '午後',
        evening: '夜',
        night: '深夜'
      },
      abbreviated: {
        am: '午前',
        pm: '午後',
        midnight: '深夜',
        noon: '正午',
        morning: '朝',
        afternoon: '午後',
        evening: '夜',
        night: '深夜'
      },
      wide: {
        am: '午前',
        pm: '午後',
        midnight: '深夜',
        noon: '正午',
        morning: '朝',
        afternoon: '午後',
        evening: '夜',
        night: '深夜'
      }
    };

    var ordinalNumber$e = function (dirtyNumber, options) {
      var number = Number(dirtyNumber);
      var unit = String(options === null || options === void 0 ? void 0 : options.unit);

      switch (unit) {
        case 'year':
          return "".concat(number, "\u5E74");

        case 'quarter':
          return "\u7B2C".concat(number, "\u56DB\u534A\u671F");

        case 'month':
          return "".concat(number, "\u6708");

        case 'week':
          return "\u7B2C".concat(number, "\u9031");

        case 'date':
          return "".concat(number, "\u65E5");

        case 'hour':
          return "".concat(number, "\u6642");

        case 'minute':
          return "".concat(number, "\u5206");

        case 'second':
          return "".concat(number, "\u79D2");

        default:
          return "".concat(number);
      }
    };

    var localize$f = {
      ordinalNumber: ordinalNumber$e,
      era: buildLocalizeFn$1({
        values: eraValues$e,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn$1({
        values: quarterValues$e,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return Number(quarter) - 1;
        }
      }),
      month: buildLocalizeFn$1({
        values: monthValues$e,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn$1({
        values: dayValues$e,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn$1({
        values: dayPeriodValues$e,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$9,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$e = /^第?\d+(年|四半期|月|週|日|時|分|秒)?/i;
    var parseOrdinalNumberPattern$e = /\d+/i;
    var matchEraPatterns$e = {
      narrow: /^(B\.?C\.?|A\.?D\.?)/i,
      abbreviated: /^(紀元[前後]|西暦)/i,
      wide: /^(紀元[前後]|西暦)/i
    };
    var parseEraPatterns$e = {
      narrow: [/^B/i, /^A/i],
      any: [/^(紀元前)/i, /^(西暦|紀元後)/i]
    };
    var matchQuarterPatterns$e = {
      narrow: /^[1234]/i,
      abbreviated: /^Q[1234]/i,
      wide: /^第[1234一二三四１２３４]四半期/i
    };
    var parseQuarterPatterns$e = {
      any: [/(1|一|１)/i, /(2|二|２)/i, /(3|三|３)/i, /(4|四|４)/i]
    };
    var matchMonthPatterns$e = {
      narrow: /^([123456789]|1[012])/,
      abbreviated: /^([123456789]|1[012])月/i,
      wide: /^([123456789]|1[012])月/i
    };
    var parseMonthPatterns$e = {
      any: [/^1\D/, /^2/, /^3/, /^4/, /^5/, /^6/, /^7/, /^8/, /^9/, /^10/, /^11/, /^12/]
    };
    var matchDayPatterns$e = {
      narrow: /^[日月火水木金土]/,
      short: /^[日月火水木金土]/,
      abbreviated: /^[日月火水木金土]/,
      wide: /^[日月火水木金土]曜日/
    };
    var parseDayPatterns$e = {
      any: [/^日/, /^月/, /^火/, /^水/, /^木/, /^金/, /^土/]
    };
    var matchDayPeriodPatterns$e = {
      any: /^(AM|PM|午前|午後|正午|深夜|真夜中|夜|朝)/i
    };
    var parseDayPeriodPatterns$e = {
      any: {
        am: /^(A|午前)/i,
        pm: /^(P|午後)/i,
        midnight: /^深夜|真夜中/i,
        noon: /^正午/i,
        morning: /^朝/i,
        afternoon: /^午後/i,
        evening: /^夜/i,
        night: /^深夜/i
      }
    };
    var match$f = {
      ordinalNumber: buildMatchPatternFn$1({
        matchPattern: matchOrdinalNumberPattern$e,
        parsePattern: parseOrdinalNumberPattern$e,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn$1({
        matchPatterns: matchEraPatterns$e,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$e,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn$1({
        matchPatterns: matchQuarterPatterns$e,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$e,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn$1({
        matchPatterns: matchMonthPatterns$e,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$e,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn$1({
        matchPatterns: matchDayPatterns$e,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$e,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn$1({
        matchPatterns: matchDayPeriodPatterns$e,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$e,
        defaultParseWidth: 'any'
      })
    };

    /**
     * @type {Locale}
     * @category Locales
     * @summary Japanese locale.
     * @language Japanese
     * @iso-639-2 jpn
     * @author Thomas Eilmsteiner [@DeMuu]{@link https://github.com/DeMuu}
     * @author Yamagishi Kazutoshi [@ykzts]{@link https://github.com/ykzts}
     * @author Luca Ban [@mesqueeb]{@link https://github.com/mesqueeb}
     * @author Terrence Lam [@skyuplam]{@link https://github.com/skyuplam}
     * @author Taiki IKeda [@so99ynoodles]{@link https://github.com/so99ynoodles}
     */

    var locale$f = {
      code: 'ja',
      formatDistance: formatDistance$f,
      formatLong: formatLong$g,
      formatRelative: formatRelative$f,
      localize: localize$f,
      match: match$f,
      options: {
        weekStartsOn: 0
        /* Sunday */
        ,
        firstWeekContainsDate: 1
      }
    };

    const dateJaJP = {
      name: "ja-JP",
      locale: locale$f
    };
    var dateJaJP$1 = dateJaJP;

    var formatDistanceLocale$d = {
      lessThanXSeconds: {
        one: '1초 미만',
        other: '{{count}}초 미만'
      },
      xSeconds: {
        one: '1초',
        other: '{{count}}초'
      },
      halfAMinute: '30초',
      lessThanXMinutes: {
        one: '1분 미만',
        other: '{{count}}분 미만'
      },
      xMinutes: {
        one: '1분',
        other: '{{count}}분'
      },
      aboutXHours: {
        one: '약 1시간',
        other: '약 {{count}}시간'
      },
      xHours: {
        one: '1시간',
        other: '{{count}}시간'
      },
      xDays: {
        one: '1일',
        other: '{{count}}일'
      },
      aboutXWeeks: {
        one: '약 1주',
        other: '약 {{count}}주'
      },
      xWeeks: {
        one: '1주',
        other: '{{count}}주'
      },
      aboutXMonths: {
        one: '약 1개월',
        other: '약 {{count}}개월'
      },
      xMonths: {
        one: '1개월',
        other: '{{count}}개월'
      },
      aboutXYears: {
        one: '약 1년',
        other: '약 {{count}}년'
      },
      xYears: {
        one: '1년',
        other: '{{count}}년'
      },
      overXYears: {
        one: '1년 이상',
        other: '{{count}}년 이상'
      },
      almostXYears: {
        one: '거의 1년',
        other: '거의 {{count}}년'
      }
    };

    var formatDistance$e = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$d[token];

      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', count.toString());
      }

      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return result + ' 후';
        } else {
          return result + ' 전';
        }
      }

      return result;
    };

    var dateFormats$e = {
      full: 'y년 M월 d일 EEEE',
      long: 'y년 M월 d일',
      medium: 'y.MM.dd',
      short: 'y.MM.dd'
    };
    var timeFormats$e = {
      full: 'a H시 mm분 ss초 zzzz',
      long: 'a H:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$e = {
      full: '{{date}} {{time}}',
      long: '{{date}} {{time}}',
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$f = {
      date: buildFormatLongFn$1({
        formats: dateFormats$e,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn$1({
        formats: timeFormats$e,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn$1({
        formats: dateTimeFormats$e,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$d = {
      lastWeek: "'지난' eeee p",
      yesterday: "'어제' p",
      today: "'오늘' p",
      tomorrow: "'내일' p",
      nextWeek: "'다음' eeee p",
      other: 'P'
    };

    var formatRelative$e = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$d[token];
    };

    var eraValues$d = {
      narrow: ['BC', 'AD'],
      abbreviated: ['BC', 'AD'],
      wide: ['기원전', '서기']
    };
    var quarterValues$d = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['1분기', '2분기', '3분기', '4분기']
    };
    var monthValues$d = {
      narrow: ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12'],
      abbreviated: ['1월', '2월', '3월', '4월', '5월', '6월', '7월', '8월', '9월', '10월', '11월', '12월'],
      wide: ['1월', '2월', '3월', '4월', '5월', '6월', '7월', '8월', '9월', '10월', '11월', '12월']
    };
    var dayValues$d = {
      narrow: ['일', '월', '화', '수', '목', '금', '토'],
      short: ['일', '월', '화', '수', '목', '금', '토'],
      abbreviated: ['일', '월', '화', '수', '목', '금', '토'],
      wide: ['일요일', '월요일', '화요일', '수요일', '목요일', '금요일', '토요일']
    };
    var dayPeriodValues$d = {
      narrow: {
        am: '오전',
        pm: '오후',
        midnight: '자정',
        noon: '정오',
        morning: '아침',
        afternoon: '오후',
        evening: '저녁',
        night: '밤'
      },
      abbreviated: {
        am: '오전',
        pm: '오후',
        midnight: '자정',
        noon: '정오',
        morning: '아침',
        afternoon: '오후',
        evening: '저녁',
        night: '밤'
      },
      wide: {
        am: '오전',
        pm: '오후',
        midnight: '자정',
        noon: '정오',
        morning: '아침',
        afternoon: '오후',
        evening: '저녁',
        night: '밤'
      }
    };
    var formattingDayPeriodValues$8 = {
      narrow: {
        am: '오전',
        pm: '오후',
        midnight: '자정',
        noon: '정오',
        morning: '아침',
        afternoon: '오후',
        evening: '저녁',
        night: '밤'
      },
      abbreviated: {
        am: '오전',
        pm: '오후',
        midnight: '자정',
        noon: '정오',
        morning: '아침',
        afternoon: '오후',
        evening: '저녁',
        night: '밤'
      },
      wide: {
        am: '오전',
        pm: '오후',
        midnight: '자정',
        noon: '정오',
        morning: '아침',
        afternoon: '오후',
        evening: '저녁',
        night: '밤'
      }
    };

    var ordinalNumber$d = function (dirtyNumber, options) {
      var number = Number(dirtyNumber);
      var unit = String(options === null || options === void 0 ? void 0 : options.unit);

      switch (unit) {
        case 'minute':
        case 'second':
          return String(number);

        case 'date':
          return number + '일';

        default:
          return number + '번째';
      }
    };

    var localize$e = {
      ordinalNumber: ordinalNumber$d,
      era: buildLocalizeFn$1({
        values: eraValues$d,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn$1({
        values: quarterValues$d,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn$1({
        values: monthValues$d,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn$1({
        values: dayValues$d,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn$1({
        values: dayPeriodValues$d,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$8,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$d = /^(\d+)(일|번째)?/i;
    var parseOrdinalNumberPattern$d = /\d+/i;
    var matchEraPatterns$d = {
      narrow: /^(b\.?\s?c\.?|b\.?\s?c\.?\s?e\.?|a\.?\s?d\.?|c\.?\s?e\.?)/i,
      abbreviated: /^(b\.?\s?c\.?|b\.?\s?c\.?\s?e\.?|a\.?\s?d\.?|c\.?\s?e\.?)/i,
      wide: /^(기원전|서기)/i
    };
    var parseEraPatterns$d = {
      any: [/^(bc|기원전)/i, /^(ad|서기)/i]
    };
    var matchQuarterPatterns$d = {
      narrow: /^[1234]/i,
      abbreviated: /^q[1234]/i,
      wide: /^[1234]사?분기/i
    };
    var parseQuarterPatterns$d = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$d = {
      narrow: /^(1[012]|[123456789])/,
      abbreviated: /^(1[012]|[123456789])월/i,
      wide: /^(1[012]|[123456789])월/i
    };
    var parseMonthPatterns$d = {
      any: [/^1월?$/, /^2/, /^3/, /^4/, /^5/, /^6/, /^7/, /^8/, /^9/, /^10/, /^11/, /^12/]
    };
    var matchDayPatterns$d = {
      narrow: /^[일월화수목금토]/,
      short: /^[일월화수목금토]/,
      abbreviated: /^[일월화수목금토]/,
      wide: /^[일월화수목금토]요일/
    };
    var parseDayPatterns$d = {
      any: [/^일/, /^월/, /^화/, /^수/, /^목/, /^금/, /^토/]
    };
    var matchDayPeriodPatterns$d = {
      any: /^(am|pm|오전|오후|자정|정오|아침|저녁|밤)/i
    };
    var parseDayPeriodPatterns$d = {
      any: {
        am: /^(am|오전)/i,
        pm: /^(pm|오후)/i,
        midnight: /^자정/i,
        noon: /^정오/i,
        morning: /^아침/i,
        afternoon: /^오후/i,
        evening: /^저녁/i,
        night: /^밤/i
      }
    };
    var match$e = {
      ordinalNumber: buildMatchPatternFn$1({
        matchPattern: matchOrdinalNumberPattern$d,
        parsePattern: parseOrdinalNumberPattern$d,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn$1({
        matchPatterns: matchEraPatterns$d,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$d,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn$1({
        matchPatterns: matchQuarterPatterns$d,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$d,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn$1({
        matchPatterns: matchMonthPatterns$d,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$d,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn$1({
        matchPatterns: matchDayPatterns$d,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$d,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn$1({
        matchPatterns: matchDayPeriodPatterns$d,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$d,
        defaultParseWidth: 'any'
      })
    };

    /**
     * @type {Locale}
     * @category Locales
     * @summary Korean locale.
     * @language Korean
     * @iso-639-2 kor
     * @author Hong Chulju [@angdev]{@link https://github.com/angdev}
     * @author Lee Seoyoen [@iamssen]{@link https://github.com/iamssen}
     * @author Taiki IKeda [@so99ynoodles]{@link https://github.com/so99ynoodles}
     */

    var locale$e = {
      code: 'ko',
      formatDistance: formatDistance$e,
      formatLong: formatLong$f,
      formatRelative: formatRelative$e,
      localize: localize$e,
      match: match$e,
      options: {
        weekStartsOn: 0
        /* Sunday */
        ,
        firstWeekContainsDate: 1
      }
    };

    const dateKoKR = {
      name: "ko-KR",
      locale: locale$e
    };
    var dateKoKR$1 = dateKoKR;

    var formatDistanceLocale$c = {
      lessThanXSeconds: {
        one: 'kurang dari 1 detik',
        other: 'kurang dari {{count}} detik'
      },
      xSeconds: {
        one: '1 detik',
        other: '{{count}} detik'
      },
      halfAMinute: 'setengah menit',
      lessThanXMinutes: {
        one: 'kurang dari 1 menit',
        other: 'kurang dari {{count}} menit'
      },
      xMinutes: {
        one: '1 menit',
        other: '{{count}} menit'
      },
      aboutXHours: {
        one: 'sekitar 1 jam',
        other: 'sekitar {{count}} jam'
      },
      xHours: {
        one: '1 jam',
        other: '{{count}} jam'
      },
      xDays: {
        one: '1 hari',
        other: '{{count}} hari'
      },
      aboutXWeeks: {
        one: 'sekitar 1 minggu',
        other: 'sekitar {{count}} minggu'
      },
      xWeeks: {
        one: '1 minggu',
        other: '{{count}} minggu'
      },
      aboutXMonths: {
        one: 'sekitar 1 bulan',
        other: 'sekitar {{count}} bulan'
      },
      xMonths: {
        one: '1 bulan',
        other: '{{count}} bulan'
      },
      aboutXYears: {
        one: 'sekitar 1 tahun',
        other: 'sekitar {{count}} tahun'
      },
      xYears: {
        one: '1 tahun',
        other: '{{count}} tahun'
      },
      overXYears: {
        one: 'lebih dari 1 tahun',
        other: 'lebih dari {{count}} tahun'
      },
      almostXYears: {
        one: 'hampir 1 tahun',
        other: 'hampir {{count}} tahun'
      }
    };

    var formatDistance$d = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$c[token];

      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', count.toString());
      }

      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'dalam waktu ' + result;
        } else {
          return result + ' yang lalu';
        }
      }

      return result;
    };

    var dateFormats$d = {
      full: 'EEEE, d MMMM yyyy',
      long: 'd MMMM yyyy',
      medium: 'd MMM yyyy',
      short: 'd/M/yyyy'
    };
    var timeFormats$d = {
      full: 'HH.mm.ss',
      long: 'HH.mm.ss',
      medium: 'HH.mm',
      short: 'HH.mm'
    };
    var dateTimeFormats$d = {
      full: "{{date}} 'pukul' {{time}}",
      long: "{{date}} 'pukul' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$e = {
      date: buildFormatLongFn$1({
        formats: dateFormats$d,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn$1({
        formats: timeFormats$d,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn$1({
        formats: dateTimeFormats$d,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$c = {
      lastWeek: "eeee 'lalu pukul' p",
      yesterday: "'Kemarin pukul' p",
      today: "'Hari ini pukul' p",
      tomorrow: "'Besok pukul' p",
      nextWeek: "eeee 'pukul' p",
      other: 'P'
    };

    var formatRelative$d = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$c[token];
    };

    // https://www.unicode.org/cldr/charts/32/summary/id.html

    var eraValues$c = {
      narrow: ['SM', 'M'],
      abbreviated: ['SM', 'M'],
      wide: ['Sebelum Masehi', 'Masehi']
    };
    var quarterValues$c = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['K1', 'K2', 'K3', 'K4'],
      wide: ['Kuartal ke-1', 'Kuartal ke-2', 'Kuartal ke-3', 'Kuartal ke-4']
    }; // Note: in Indonesian, the names of days of the week and months are capitalized.
    // If you are making a new locale based on this one, check if the same is true for the language you're working on.
    // Generally, formatted dates should look like they are in the middle of a sentence,
    // e.g. in Spanish language the weekdays and months should be in the lowercase.

    var monthValues$c = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['Jan', 'Feb', 'Mar', 'Apr', 'Mei', 'Jun', 'Jul', 'Agt', 'Sep', 'Okt', 'Nov', 'Des'],
      wide: ['Januari', 'Februari', 'Maret', 'April', 'Mei', 'Juni', 'Juli', 'Agustus', 'September', 'Oktober', 'November', 'Desember']
    };
    var dayValues$c = {
      narrow: ['M', 'S', 'S', 'R', 'K', 'J', 'S'],
      short: ['Min', 'Sen', 'Sel', 'Rab', 'Kam', 'Jum', 'Sab'],
      abbreviated: ['Min', 'Sen', 'Sel', 'Rab', 'Kam', 'Jum', 'Sab'],
      wide: ['Minggu', 'Senin', 'Selasa', 'Rabu', 'Kamis', 'Jumat', 'Sabtu']
    };
    var dayPeriodValues$c = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'tengah malam',
        noon: 'tengah hari',
        morning: 'pagi',
        afternoon: 'siang',
        evening: 'sore',
        night: 'malam'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'tengah malam',
        noon: 'tengah hari',
        morning: 'pagi',
        afternoon: 'siang',
        evening: 'sore',
        night: 'malam'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'tengah malam',
        noon: 'tengah hari',
        morning: 'pagi',
        afternoon: 'siang',
        evening: 'sore',
        night: 'malam'
      }
    };
    var formattingDayPeriodValues$7 = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'tengah malam',
        noon: 'tengah hari',
        morning: 'pagi',
        afternoon: 'siang',
        evening: 'sore',
        night: 'malam'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'tengah malam',
        noon: 'tengah hari',
        morning: 'pagi',
        afternoon: 'siang',
        evening: 'sore',
        night: 'malam'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'tengah malam',
        noon: 'tengah hari',
        morning: 'pagi',
        afternoon: 'siang',
        evening: 'sore',
        night: 'malam'
      }
    };

    var ordinalNumber$c = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber); // Can't use "pertama", "kedua" because can't be parsed

      return 'ke-' + number;
    };

    var localize$d = {
      ordinalNumber: ordinalNumber$c,
      era: buildLocalizeFn$1({
        values: eraValues$c,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn$1({
        values: quarterValues$c,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn$1({
        values: monthValues$c,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn$1({
        values: dayValues$c,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn$1({
        values: dayPeriodValues$c,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$7,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$c = /^ke-(\d+)?/i;
    var parseOrdinalNumberPattern$c = /\d+/i;
    var matchEraPatterns$c = {
      narrow: /^(sm|m)/i,
      abbreviated: /^(s\.?\s?m\.?|s\.?\s?e\.?\s?u\.?|m\.?|e\.?\s?u\.?)/i,
      wide: /^(sebelum masehi|sebelum era umum|masehi|era umum)/i
    };
    var parseEraPatterns$c = {
      any: [/^s/i, /^(m|e)/i]
    };
    var matchQuarterPatterns$c = {
      narrow: /^[1234]/i,
      abbreviated: /^K-?\s[1234]/i,
      wide: /^Kuartal ke-?\s?[1234]/i
    };
    var parseQuarterPatterns$c = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$c = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(jan|feb|mar|apr|mei|jun|jul|agt|sep|okt|nov|des)/i,
      wide: /^(januari|februari|maret|april|mei|juni|juli|agustus|september|oktober|november|desember)/i
    };
    var parseMonthPatterns$c = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^f/i, /^ma/i, /^ap/i, /^me/i, /^jun/i, /^jul/i, /^ag/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$c = {
      narrow: /^[srkjm]/i,
      short: /^(min|sen|sel|rab|kam|jum|sab)/i,
      abbreviated: /^(min|sen|sel|rab|kam|jum|sab)/i,
      wide: /^(minggu|senin|selasa|rabu|kamis|jumat|sabtu)/i
    };
    var parseDayPatterns$c = {
      narrow: [/^m/i, /^s/i, /^s/i, /^r/i, /^k/i, /^j/i, /^s/i],
      any: [/^m/i, /^sen/i, /^sel/i, /^r/i, /^k/i, /^j/i, /^sa/i]
    };
    var matchDayPeriodPatterns$c = {
      narrow: /^(a|p|tengah m|tengah h|(di(\swaktu)?) (pagi|siang|sore|malam))/i,
      any: /^([ap]\.?\s?m\.?|tengah malam|tengah hari|(di(\swaktu)?) (pagi|siang|sore|malam))/i
    };
    var parseDayPeriodPatterns$c = {
      any: {
        am: /^a/i,
        pm: /^pm/i,
        midnight: /^tengah m/i,
        noon: /^tengah h/i,
        morning: /pagi/i,
        afternoon: /siang/i,
        evening: /sore/i,
        night: /malam/i
      }
    };
    var match$d = {
      ordinalNumber: buildMatchPatternFn$1({
        matchPattern: matchOrdinalNumberPattern$c,
        parsePattern: parseOrdinalNumberPattern$c,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn$1({
        matchPatterns: matchEraPatterns$c,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$c,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn$1({
        matchPatterns: matchQuarterPatterns$c,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$c,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn$1({
        matchPatterns: matchMonthPatterns$c,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$c,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn$1({
        matchPatterns: matchDayPatterns$c,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$c,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn$1({
        matchPatterns: matchDayPeriodPatterns$c,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$c,
        defaultParseWidth: 'any'
      })
    };

    /**
     * @type {Locale}
     * @category Locales
     * @summary Indonesian locale.
     * @language Indonesian
     * @iso-639-2 ind
     * @author Rahmat Budiharso [@rbudiharso]{@link https://github.com/rbudiharso}
     * @author Benget Nata [@bentinata]{@link https://github.com/bentinata}
     * @author Budi Irawan [@deerawan]{@link https://github.com/deerawan}
     * @author Try Ajitiono [@imballinst]{@link https://github.com/imballinst}
     */

    var locale$d = {
      code: 'id',
      formatDistance: formatDistance$d,
      formatLong: formatLong$e,
      formatRelative: formatRelative$d,
      localize: localize$d,
      match: match$d,
      options: {
        weekStartsOn: 1
        /* Monday */
        ,
        firstWeekContainsDate: 1
      }
    };

    const dateIdID = {
      name: "id-ID",
      locale: locale$d
    };
    var dateIdID$1 = dateIdID;

    var formatDistanceLocale$b = {
      lessThanXSeconds: {
        standalone: {
          one: 'weniger als 1 Sekunde',
          other: 'weniger als {{count}} Sekunden'
        },
        withPreposition: {
          one: 'weniger als 1 Sekunde',
          other: 'weniger als {{count}} Sekunden'
        }
      },
      xSeconds: {
        standalone: {
          one: '1 Sekunde',
          other: '{{count}} Sekunden'
        },
        withPreposition: {
          one: '1 Sekunde',
          other: '{{count}} Sekunden'
        }
      },
      halfAMinute: {
        standalone: 'halbe Minute',
        withPreposition: 'halben Minute'
      },
      lessThanXMinutes: {
        standalone: {
          one: 'weniger als 1 Minute',
          other: 'weniger als {{count}} Minuten'
        },
        withPreposition: {
          one: 'weniger als 1 Minute',
          other: 'weniger als {{count}} Minuten'
        }
      },
      xMinutes: {
        standalone: {
          one: '1 Minute',
          other: '{{count}} Minuten'
        },
        withPreposition: {
          one: '1 Minute',
          other: '{{count}} Minuten'
        }
      },
      aboutXHours: {
        standalone: {
          one: 'etwa 1 Stunde',
          other: 'etwa {{count}} Stunden'
        },
        withPreposition: {
          one: 'etwa 1 Stunde',
          other: 'etwa {{count}} Stunden'
        }
      },
      xHours: {
        standalone: {
          one: '1 Stunde',
          other: '{{count}} Stunden'
        },
        withPreposition: {
          one: '1 Stunde',
          other: '{{count}} Stunden'
        }
      },
      xDays: {
        standalone: {
          one: '1 Tag',
          other: '{{count}} Tage'
        },
        withPreposition: {
          one: '1 Tag',
          other: '{{count}} Tagen'
        }
      },
      aboutXWeeks: {
        standalone: {
          one: 'etwa 1 Woche',
          other: 'etwa {{count}} Wochen'
        },
        withPreposition: {
          one: 'etwa 1 Woche',
          other: 'etwa {{count}} Wochen'
        }
      },
      xWeeks: {
        standalone: {
          one: '1 Woche',
          other: '{{count}} Wochen'
        },
        withPreposition: {
          one: '1 Woche',
          other: '{{count}} Wochen'
        }
      },
      aboutXMonths: {
        standalone: {
          one: 'etwa 1 Monat',
          other: 'etwa {{count}} Monate'
        },
        withPreposition: {
          one: 'etwa 1 Monat',
          other: 'etwa {{count}} Monaten'
        }
      },
      xMonths: {
        standalone: {
          one: '1 Monat',
          other: '{{count}} Monate'
        },
        withPreposition: {
          one: '1 Monat',
          other: '{{count}} Monaten'
        }
      },
      aboutXYears: {
        standalone: {
          one: 'etwa 1 Jahr',
          other: 'etwa {{count}} Jahre'
        },
        withPreposition: {
          one: 'etwa 1 Jahr',
          other: 'etwa {{count}} Jahren'
        }
      },
      xYears: {
        standalone: {
          one: '1 Jahr',
          other: '{{count}} Jahre'
        },
        withPreposition: {
          one: '1 Jahr',
          other: '{{count}} Jahren'
        }
      },
      overXYears: {
        standalone: {
          one: 'mehr als 1 Jahr',
          other: 'mehr als {{count}} Jahre'
        },
        withPreposition: {
          one: 'mehr als 1 Jahr',
          other: 'mehr als {{count}} Jahren'
        }
      },
      almostXYears: {
        standalone: {
          one: 'fast 1 Jahr',
          other: 'fast {{count}} Jahre'
        },
        withPreposition: {
          one: 'fast 1 Jahr',
          other: 'fast {{count}} Jahren'
        }
      }
    };

    var formatDistance$c = function (token, count, options) {
      var result;
      var tokenValue = options !== null && options !== void 0 && options.addSuffix ? formatDistanceLocale$b[token].withPreposition : formatDistanceLocale$b[token].standalone;

      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }

      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'in ' + result;
        } else {
          return 'vor ' + result;
        }
      }

      return result;
    };

    var dateFormats$c = {
      full: 'EEEE, do MMMM y',
      // Montag, 7. Januar 2018
      long: 'do MMMM y',
      // 7. Januar 2018
      medium: 'do MMM y',
      // 7. Jan. 2018
      short: 'dd.MM.y' // 07.01.2018

    };
    var timeFormats$c = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$c = {
      full: "{{date}} 'um' {{time}}",
      long: "{{date}} 'um' {{time}}",
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$d = {
      date: buildFormatLongFn$1({
        formats: dateFormats$c,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn$1({
        formats: timeFormats$c,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn$1({
        formats: dateTimeFormats$c,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$b = {
      lastWeek: "'letzten' eeee 'um' p",
      yesterday: "'gestern um' p",
      today: "'heute um' p",
      tomorrow: "'morgen um' p",
      nextWeek: "eeee 'um' p",
      other: 'P'
    };

    var formatRelative$c = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$b[token];
    };

    var eraValues$b = {
      narrow: ['v.Chr.', 'n.Chr.'],
      abbreviated: ['v.Chr.', 'n.Chr.'],
      wide: ['vor Christus', 'nach Christus']
    };
    var quarterValues$b = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['1. Quartal', '2. Quartal', '3. Quartal', '4. Quartal']
    }; // Note: in German, the names of days of the week and months are capitalized.
    // If you are making a new locale based on this one, check if the same is true for the language you're working on.
    // Generally, formatted dates should look like they are in the middle of a sentence,
    // e.g. in Spanish language the weekdays and months should be in the lowercase.

    var monthValues$b = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['Jan', 'Feb', 'Mär', 'Apr', 'Mai', 'Jun', 'Jul', 'Aug', 'Sep', 'Okt', 'Nov', 'Dez'],
      wide: ['Januar', 'Februar', 'März', 'April', 'Mai', 'Juni', 'Juli', 'August', 'September', 'Oktober', 'November', 'Dezember']
    }; // https://st.unicode.org/cldr-apps/v#/de/Gregorian/

    var formattingMonthValues$2 = {
      narrow: monthValues$b.narrow,
      abbreviated: ['Jan.', 'Feb.', 'März', 'Apr.', 'Mai', 'Juni', 'Juli', 'Aug.', 'Sep.', 'Okt.', 'Nov.', 'Dez.'],
      wide: monthValues$b.wide
    };
    var dayValues$b = {
      narrow: ['S', 'M', 'D', 'M', 'D', 'F', 'S'],
      short: ['So', 'Mo', 'Di', 'Mi', 'Do', 'Fr', 'Sa'],
      abbreviated: ['So.', 'Mo.', 'Di.', 'Mi.', 'Do.', 'Fr.', 'Sa.'],
      wide: ['Sonntag', 'Montag', 'Dienstag', 'Mittwoch', 'Donnerstag', 'Freitag', 'Samstag']
    }; // https://www.unicode.org/cldr/charts/32/summary/de.html#1881

    var dayPeriodValues$b = {
      narrow: {
        am: 'vm.',
        pm: 'nm.',
        midnight: 'Mitternacht',
        noon: 'Mittag',
        morning: 'Morgen',
        afternoon: 'Nachm.',
        evening: 'Abend',
        night: 'Nacht'
      },
      abbreviated: {
        am: 'vorm.',
        pm: 'nachm.',
        midnight: 'Mitternacht',
        noon: 'Mittag',
        morning: 'Morgen',
        afternoon: 'Nachmittag',
        evening: 'Abend',
        night: 'Nacht'
      },
      wide: {
        am: 'vormittags',
        pm: 'nachmittags',
        midnight: 'Mitternacht',
        noon: 'Mittag',
        morning: 'Morgen',
        afternoon: 'Nachmittag',
        evening: 'Abend',
        night: 'Nacht'
      }
    };
    var formattingDayPeriodValues$6 = {
      narrow: {
        am: 'vm.',
        pm: 'nm.',
        midnight: 'Mitternacht',
        noon: 'Mittag',
        morning: 'morgens',
        afternoon: 'nachm.',
        evening: 'abends',
        night: 'nachts'
      },
      abbreviated: {
        am: 'vorm.',
        pm: 'nachm.',
        midnight: 'Mitternacht',
        noon: 'Mittag',
        morning: 'morgens',
        afternoon: 'nachmittags',
        evening: 'abends',
        night: 'nachts'
      },
      wide: {
        am: 'vormittags',
        pm: 'nachmittags',
        midnight: 'Mitternacht',
        noon: 'Mittag',
        morning: 'morgens',
        afternoon: 'nachmittags',
        evening: 'abends',
        night: 'nachts'
      }
    };

    var ordinalNumber$b = function (dirtyNumber) {
      var number = Number(dirtyNumber);
      return number + '.';
    };

    var localize$c = {
      ordinalNumber: ordinalNumber$b,
      era: buildLocalizeFn$1({
        values: eraValues$b,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn$1({
        values: quarterValues$b,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn$1({
        values: monthValues$b,
        formattingValues: formattingMonthValues$2,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn$1({
        values: dayValues$b,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn$1({
        values: dayPeriodValues$b,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$6,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$b = /^(\d+)(\.)?/i;
    var parseOrdinalNumberPattern$b = /\d+/i;
    var matchEraPatterns$b = {
      narrow: /^(v\.? ?Chr\.?|n\.? ?Chr\.?)/i,
      abbreviated: /^(v\.? ?Chr\.?|n\.? ?Chr\.?)/i,
      wide: /^(vor Christus|vor unserer Zeitrechnung|nach Christus|unserer Zeitrechnung)/i
    };
    var parseEraPatterns$b = {
      any: [/^v/i, /^n/i]
    };
    var matchQuarterPatterns$b = {
      narrow: /^[1234]/i,
      abbreviated: /^q[1234]/i,
      wide: /^[1234](\.)? Quartal/i
    };
    var parseQuarterPatterns$b = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$b = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(j[aä]n|feb|mär[z]?|apr|mai|jun[i]?|jul[i]?|aug|sep|okt|nov|dez)\.?/i,
      wide: /^(januar|februar|märz|april|mai|juni|juli|august|september|oktober|november|dezember)/i
    };
    var parseMonthPatterns$b = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^j[aä]/i, /^f/i, /^mär/i, /^ap/i, /^mai/i, /^jun/i, /^jul/i, /^au/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$b = {
      narrow: /^[smdmf]/i,
      short: /^(so|mo|di|mi|do|fr|sa)/i,
      abbreviated: /^(son?|mon?|die?|mit?|don?|fre?|sam?)\.?/i,
      wide: /^(sonntag|montag|dienstag|mittwoch|donnerstag|freitag|samstag)/i
    };
    var parseDayPatterns$b = {
      any: [/^so/i, /^mo/i, /^di/i, /^mi/i, /^do/i, /^f/i, /^sa/i]
    };
    var matchDayPeriodPatterns$b = {
      narrow: /^(vm\.?|nm\.?|Mitternacht|Mittag|morgens|nachm\.?|abends|nachts)/i,
      abbreviated: /^(vorm\.?|nachm\.?|Mitternacht|Mittag|morgens|nachm\.?|abends|nachts)/i,
      wide: /^(vormittags|nachmittags|Mitternacht|Mittag|morgens|nachmittags|abends|nachts)/i
    };
    var parseDayPeriodPatterns$b = {
      any: {
        am: /^v/i,
        pm: /^n/i,
        midnight: /^Mitte/i,
        noon: /^Mitta/i,
        morning: /morgens/i,
        afternoon: /nachmittags/i,
        // will never be matched. Afternoon is matched by `pm`
        evening: /abends/i,
        night: /nachts/i // will never be matched. Night is matched by `pm`

      }
    };
    var match$c = {
      ordinalNumber: buildMatchPatternFn$1({
        matchPattern: matchOrdinalNumberPattern$b,
        parsePattern: parseOrdinalNumberPattern$b,
        valueCallback: function (value) {
          return parseInt(value);
        }
      }),
      era: buildMatchFn$1({
        matchPatterns: matchEraPatterns$b,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$b,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn$1({
        matchPatterns: matchQuarterPatterns$b,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$b,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn$1({
        matchPatterns: matchMonthPatterns$b,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$b,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn$1({
        matchPatterns: matchDayPatterns$b,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$b,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn$1({
        matchPatterns: matchDayPeriodPatterns$b,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPeriodPatterns$b,
        defaultParseWidth: 'any'
      })
    };

    /**
     * @type {Locale}
     * @category Locales
     * @summary German locale.
     * @language German
     * @iso-639-2 deu
     * @author Thomas Eilmsteiner [@DeMuu]{@link https://github.com/DeMuu}
     * @author Asia [@asia-t]{@link https://github.com/asia-t}
     * @author Van Vuong Ngo [@vanvuongngo]{@link https://github.com/vanvuongngo}
     * @author RomanErnst [@pex]{@link https://github.com/pex}
     * @author Philipp Keck [@Philipp91]{@link https://github.com/Philipp91}
     */

    var locale$c = {
      code: 'de',
      formatDistance: formatDistance$c,
      formatLong: formatLong$d,
      formatRelative: formatRelative$c,
      localize: localize$c,
      match: match$c,
      options: {
        weekStartsOn: 1
        /* Monday */
        ,
        firstWeekContainsDate: 4
      }
    };

    const dateDeDE = {
      name: "de-DE",
      locale: locale$c
    };
    var dateDeDE$1 = dateDeDE;

    var formatDistanceLocale$a = {
      lessThanXSeconds: {
        one: 'mindre enn ett sekund',
        other: 'mindre enn {{count}} sekunder'
      },
      xSeconds: {
        one: 'ett sekund',
        other: '{{count}} sekunder'
      },
      halfAMinute: 'et halvt minutt',
      lessThanXMinutes: {
        one: 'mindre enn ett minutt',
        other: 'mindre enn {{count}} minutter'
      },
      xMinutes: {
        one: 'ett minutt',
        other: '{{count}} minutter'
      },
      aboutXHours: {
        one: 'omtrent en time',
        other: 'omtrent {{count}} timer'
      },
      xHours: {
        one: 'en time',
        other: '{{count}} timer'
      },
      xDays: {
        one: 'en dag',
        other: '{{count}} dager'
      },
      aboutXWeeks: {
        one: 'omtrent en uke',
        other: 'omtrent {{count}} uker'
      },
      xWeeks: {
        one: 'en uke',
        other: '{{count}} uker'
      },
      aboutXMonths: {
        one: 'omtrent en måned',
        other: 'omtrent {{count}} måneder'
      },
      xMonths: {
        one: 'en måned',
        other: '{{count}} måneder'
      },
      aboutXYears: {
        one: 'omtrent ett år',
        other: 'omtrent {{count}} år'
      },
      xYears: {
        one: 'ett år',
        other: '{{count}} år'
      },
      overXYears: {
        one: 'over ett år',
        other: 'over {{count}} år'
      },
      almostXYears: {
        one: 'nesten ett år',
        other: 'nesten {{count}} år'
      }
    };

    var formatDistance$b = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$a[token];

      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }

      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'om ' + result;
        } else {
          return result + ' siden';
        }
      }

      return result;
    };

    var dateFormats$b = {
      full: 'EEEE d. MMMM y',
      long: 'd. MMMM y',
      medium: 'd. MMM y',
      short: 'dd.MM.y'
    };
    var timeFormats$b = {
      full: "'kl'. HH:mm:ss zzzz",
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$b = {
      full: "{{date}} 'kl.' {{time}}",
      long: "{{date}} 'kl.' {{time}}",
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$c = {
      date: buildFormatLongFn$1({
        formats: dateFormats$b,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn$1({
        formats: timeFormats$b,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn$1({
        formats: dateTimeFormats$b,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$a = {
      lastWeek: "'forrige' eeee 'kl.' p",
      yesterday: "'i går kl.' p",
      today: "'i dag kl.' p",
      tomorrow: "'i morgen kl.' p",
      nextWeek: "EEEE 'kl.' p",
      other: 'P'
    };

    var formatRelative$b = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$a[token];
    };

    var eraValues$a = {
      narrow: ['f.Kr.', 'e.Kr.'],
      abbreviated: ['f.Kr.', 'e.Kr.'],
      wide: ['før Kristus', 'etter Kristus']
    };
    var quarterValues$a = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['1. kvartal', '2. kvartal', '3. kvartal', '4. kvartal']
    };
    var monthValues$a = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['jan.', 'feb.', 'mars', 'apr.', 'mai', 'juni', 'juli', 'aug.', 'sep.', 'okt.', 'nov.', 'des.'],
      wide: ['januar', 'februar', 'mars', 'april', 'mai', 'juni', 'juli', 'august', 'september', 'oktober', 'november', 'desember']
    };
    var dayValues$a = {
      narrow: ['S', 'M', 'T', 'O', 'T', 'F', 'L'],
      short: ['sø', 'ma', 'ti', 'on', 'to', 'fr', 'lø'],
      abbreviated: ['søn', 'man', 'tir', 'ons', 'tor', 'fre', 'lør'],
      wide: ['søndag', 'mandag', 'tirsdag', 'onsdag', 'torsdag', 'fredag', 'lørdag']
    };
    var dayPeriodValues$a = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'midnatt',
        noon: 'middag',
        morning: 'på morg.',
        afternoon: 'på etterm.',
        evening: 'på kvelden',
        night: 'på natten'
      },
      abbreviated: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'midnatt',
        noon: 'middag',
        morning: 'på morg.',
        afternoon: 'på etterm.',
        evening: 'på kvelden',
        night: 'på natten'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'midnatt',
        noon: 'middag',
        morning: 'på morgenen',
        afternoon: 'på ettermiddagen',
        evening: 'på kvelden',
        night: 'på natten'
      }
    };

    var ordinalNumber$a = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + '.';
    };

    var localize$b = {
      ordinalNumber: ordinalNumber$a,
      era: buildLocalizeFn$1({
        values: eraValues$a,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn$1({
        values: quarterValues$a,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn$1({
        values: monthValues$a,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn$1({
        values: dayValues$a,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn$1({
        values: dayPeriodValues$a,
        defaultWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$a = /^(\d+)\.?/i;
    var parseOrdinalNumberPattern$a = /\d+/i;
    var matchEraPatterns$a = {
      narrow: /^(f\.? ?Kr\.?|fvt\.?|e\.? ?Kr\.?|evt\.?)/i,
      abbreviated: /^(f\.? ?Kr\.?|fvt\.?|e\.? ?Kr\.?|evt\.?)/i,
      wide: /^(før Kristus|før vår tid|etter Kristus|vår tid)/i
    };
    var parseEraPatterns$a = {
      any: [/^f/i, /^e/i]
    };
    var matchQuarterPatterns$a = {
      narrow: /^[1234]/i,
      abbreviated: /^q[1234]/i,
      wide: /^[1234](\.)? kvartal/i
    };
    var parseQuarterPatterns$a = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$a = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(jan|feb|mars?|apr|mai|juni?|juli?|aug|sep|okt|nov|des)\.?/i,
      wide: /^(januar|februar|mars|april|mai|juni|juli|august|september|oktober|november|desember)/i
    };
    var parseMonthPatterns$a = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^f/i, /^mar/i, /^ap/i, /^mai/i, /^jun/i, /^jul/i, /^aug/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$a = {
      narrow: /^[smtofl]/i,
      short: /^(sø|ma|ti|on|to|fr|lø)/i,
      abbreviated: /^(søn|man|tir|ons|tor|fre|lør)/i,
      wide: /^(søndag|mandag|tirsdag|onsdag|torsdag|fredag|lørdag)/i
    };
    var parseDayPatterns$a = {
      any: [/^s/i, /^m/i, /^ti/i, /^o/i, /^to/i, /^f/i, /^l/i]
    };
    var matchDayPeriodPatterns$a = {
      narrow: /^(midnatt|middag|(på) (morgenen|ettermiddagen|kvelden|natten)|[ap])/i,
      any: /^([ap]\.?\s?m\.?|midnatt|middag|(på) (morgenen|ettermiddagen|kvelden|natten))/i
    };
    var parseDayPeriodPatterns$a = {
      any: {
        am: /^a(\.?\s?m\.?)?$/i,
        pm: /^p(\.?\s?m\.?)?$/i,
        midnight: /^midn/i,
        noon: /^midd/i,
        morning: /morgen/i,
        afternoon: /ettermiddag/i,
        evening: /kveld/i,
        night: /natt/i
      }
    };
    var match$b = {
      ordinalNumber: buildMatchPatternFn$1({
        matchPattern: matchOrdinalNumberPattern$a,
        parsePattern: parseOrdinalNumberPattern$a,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn$1({
        matchPatterns: matchEraPatterns$a,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$a,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn$1({
        matchPatterns: matchQuarterPatterns$a,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$a,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn$1({
        matchPatterns: matchMonthPatterns$a,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$a,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn$1({
        matchPatterns: matchDayPatterns$a,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$a,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn$1({
        matchPatterns: matchDayPeriodPatterns$a,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$a,
        defaultParseWidth: 'any'
      })
    };

    /**
     * @type {Locale}
     * @category Locales
     * @summary Norwegian Bokmål locale.
     * @language Norwegian Bokmål
     * @iso-639-2 nob
     * @author Hans-Kristian Koren [@Hanse]{@link https://github.com/Hanse}
     * @author Mikolaj Grzyb [@mikolajgrzyb]{@link https://github.com/mikolajgrzyb}
     * @author Dag Stuan [@dagstuan]{@link https://github.com/dagstuan}
     */

    var locale$b = {
      code: 'nb',
      formatDistance: formatDistance$b,
      formatLong: formatLong$c,
      formatRelative: formatRelative$b,
      localize: localize$b,
      match: match$b,
      options: {
        weekStartsOn: 1
        /* Monday */
        ,
        firstWeekContainsDate: 4
      }
    };

    const dateNbNO = {
      name: "nb-NO",
      locale: locale$b
    };
    var dateNbNO$1 = dateNbNO;

    var formatDistanceLocale$9 = {
      lessThanXSeconds: {
        one: 'minder dan een seconde',
        other: 'minder dan {{count}} seconden'
      },
      xSeconds: {
        one: '1 seconde',
        other: '{{count}} seconden'
      },
      halfAMinute: 'een halve minuut',
      lessThanXMinutes: {
        one: 'minder dan een minuut',
        other: 'minder dan {{count}} minuten'
      },
      xMinutes: {
        one: 'een minuut',
        other: '{{count}} minuten'
      },
      aboutXHours: {
        one: 'ongeveer 1 uur',
        other: 'ongeveer {{count}} uur'
      },
      xHours: {
        one: '1 uur',
        other: '{{count}} uur'
      },
      xDays: {
        one: '1 dag',
        other: '{{count}} dagen'
      },
      aboutXWeeks: {
        one: 'ongeveer 1 week',
        other: 'ongeveer {{count}} weken'
      },
      xWeeks: {
        one: '1 week',
        other: '{{count}} weken'
      },
      aboutXMonths: {
        one: 'ongeveer 1 maand',
        other: 'ongeveer {{count}} maanden'
      },
      xMonths: {
        one: '1 maand',
        other: '{{count}} maanden'
      },
      aboutXYears: {
        one: 'ongeveer 1 jaar',
        other: 'ongeveer {{count}} jaar'
      },
      xYears: {
        one: '1 jaar',
        other: '{{count}} jaar'
      },
      overXYears: {
        one: 'meer dan 1 jaar',
        other: 'meer dan {{count}} jaar'
      },
      almostXYears: {
        one: 'bijna 1 jaar',
        other: 'bijna {{count}} jaar'
      }
    };

    var formatDistance$a = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$9[token];

      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }

      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'over ' + result;
        } else {
          return result + ' geleden';
        }
      }

      return result;
    };

    var dateFormats$a = {
      full: 'EEEE d MMMM y',
      long: 'd MMMM y',
      medium: 'd MMM y',
      short: 'dd-MM-y'
    };
    var timeFormats$a = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$a = {
      full: "{{date}} 'om' {{time}}",
      long: "{{date}} 'om' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$b = {
      date: buildFormatLongFn$1({
        formats: dateFormats$a,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn$1({
        formats: timeFormats$a,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn$1({
        formats: dateTimeFormats$a,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$9 = {
      lastWeek: "'afgelopen' eeee 'om' p",
      yesterday: "'gisteren om' p",
      today: "'vandaag om' p",
      tomorrow: "'morgen om' p",
      nextWeek: "eeee 'om' p",
      other: 'P'
    };

    var formatRelative$a = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$9[token];
    };

    var eraValues$9 = {
      narrow: ['v.C.', 'n.C.'],
      abbreviated: ['v.Chr.', 'n.Chr.'],
      wide: ['voor Christus', 'na Christus']
    };
    var quarterValues$9 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['K1', 'K2', 'K3', 'K4'],
      wide: ['1e kwartaal', '2e kwartaal', '3e kwartaal', '4e kwartaal']
    };
    var monthValues$9 = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['jan.', 'feb.', 'mrt.', 'apr.', 'mei', 'jun.', 'jul.', 'aug.', 'sep.', 'okt.', 'nov.', 'dec.'],
      wide: ['januari', 'februari', 'maart', 'april', 'mei', 'juni', 'juli', 'augustus', 'september', 'oktober', 'november', 'december']
    };
    var dayValues$9 = {
      narrow: ['Z', 'M', 'D', 'W', 'D', 'V', 'Z'],
      short: ['zo', 'ma', 'di', 'wo', 'do', 'vr', 'za'],
      abbreviated: ['zon', 'maa', 'din', 'woe', 'don', 'vri', 'zat'],
      wide: ['zondag', 'maandag', 'dinsdag', 'woensdag', 'donderdag', 'vrijdag', 'zaterdag']
    };
    var dayPeriodValues$9 = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'middernacht',
        noon: 'het middaguur',
        morning: "'s ochtends",
        afternoon: "'s middags",
        evening: "'s avonds",
        night: "'s nachts"
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'middernacht',
        noon: 'het middaguur',
        morning: "'s ochtends",
        afternoon: "'s middags",
        evening: "'s avonds",
        night: "'s nachts"
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'middernacht',
        noon: 'het middaguur',
        morning: "'s ochtends",
        afternoon: "'s middags",
        evening: "'s avonds",
        night: "'s nachts"
      }
    };

    var ordinalNumber$9 = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + 'e';
    };

    var localize$a = {
      ordinalNumber: ordinalNumber$9,
      era: buildLocalizeFn$1({
        values: eraValues$9,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn$1({
        values: quarterValues$9,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn$1({
        values: monthValues$9,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn$1({
        values: dayValues$9,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn$1({
        values: dayPeriodValues$9,
        defaultWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$9 = /^(\d+)e?/i;
    var parseOrdinalNumberPattern$9 = /\d+/i;
    var matchEraPatterns$9 = {
      narrow: /^([vn]\.? ?C\.?)/,
      abbreviated: /^([vn]\. ?Chr\.?)/,
      wide: /^((voor|na) Christus)/
    };
    var parseEraPatterns$9 = {
      any: [/^v/, /^n/]
    };
    var matchQuarterPatterns$9 = {
      narrow: /^[1234]/i,
      abbreviated: /^K[1234]/i,
      wide: /^[1234]e kwartaal/i
    };
    var parseQuarterPatterns$9 = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$9 = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(jan.|feb.|mrt.|apr.|mei|jun.|jul.|aug.|sep.|okt.|nov.|dec.)/i,
      wide: /^(januari|februari|maart|april|mei|juni|juli|augustus|september|oktober|november|december)/i
    };
    var parseMonthPatterns$9 = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^jan/i, /^feb/i, /^m(r|a)/i, /^apr/i, /^mei/i, /^jun/i, /^jul/i, /^aug/i, /^sep/i, /^okt/i, /^nov/i, /^dec/i]
    };
    var matchDayPatterns$9 = {
      narrow: /^[zmdwv]/i,
      short: /^(zo|ma|di|wo|do|vr|za)/i,
      abbreviated: /^(zon|maa|din|woe|don|vri|zat)/i,
      wide: /^(zondag|maandag|dinsdag|woensdag|donderdag|vrijdag|zaterdag)/i
    };
    var parseDayPatterns$9 = {
      narrow: [/^z/i, /^m/i, /^d/i, /^w/i, /^d/i, /^v/i, /^z/i],
      any: [/^zo/i, /^ma/i, /^di/i, /^wo/i, /^do/i, /^vr/i, /^za/i]
    };
    var matchDayPeriodPatterns$9 = {
      any: /^(am|pm|middernacht|het middaguur|'s (ochtends|middags|avonds|nachts))/i
    };
    var parseDayPeriodPatterns$9 = {
      any: {
        am: /^am/i,
        pm: /^pm/i,
        midnight: /^middernacht/i,
        noon: /^het middaguur/i,
        morning: /ochtend/i,
        afternoon: /middag/i,
        evening: /avond/i,
        night: /nacht/i
      }
    };
    var match$a = {
      ordinalNumber: buildMatchPatternFn$1({
        matchPattern: matchOrdinalNumberPattern$9,
        parsePattern: parseOrdinalNumberPattern$9,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn$1({
        matchPatterns: matchEraPatterns$9,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$9,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn$1({
        matchPatterns: matchQuarterPatterns$9,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$9,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn$1({
        matchPatterns: matchMonthPatterns$9,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$9,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn$1({
        matchPatterns: matchDayPatterns$9,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$9,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn$1({
        matchPatterns: matchDayPeriodPatterns$9,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$9,
        defaultParseWidth: 'any'
      })
    };

    /**
     * @type {Locale}
     * @category Locales
     * @summary Dutch locale.
     * @language Dutch
     * @iso-639-2 nld
     * @author Jorik Tangelder [@jtangelder]{@link https://github.com/jtangelder}
     * @author Ruben Stolk [@rubenstolk]{@link https://github.com/rubenstolk}
     * @author Lode Vanhove [@bitcrumb]{@link https://github.com/bitcrumb}
     * @author Edo Rivai [@edorivai]{@link https://github.com/edorivai}
     * @author Niels Keurentjes [@curry684]{@link https://github.com/curry684}
     * @author Stefan Vermaas [@stefanvermaas]{@link https://github.com/stefanvermaas}
     */

    var locale$a = {
      code: 'nl',
      formatDistance: formatDistance$a,
      formatLong: formatLong$b,
      formatRelative: formatRelative$a,
      localize: localize$a,
      match: match$a,
      options: {
        weekStartsOn: 1
        /* Monday */
        ,
        firstWeekContainsDate: 4
      }
    };

    const dateNlNL = {
      name: "nl-NL",
      locale: locale$a
    };
    var dateNlNL$1 = dateNlNL;

    var formatDistanceLocale$8 = {
      lessThanXSeconds: {
        one: 'moins d’une seconde',
        other: 'moins de {{count}} secondes'
      },
      xSeconds: {
        one: '1 seconde',
        other: '{{count}} secondes'
      },
      halfAMinute: '30 secondes',
      lessThanXMinutes: {
        one: 'moins d’une minute',
        other: 'moins de {{count}} minutes'
      },
      xMinutes: {
        one: '1 minute',
        other: '{{count}} minutes'
      },
      aboutXHours: {
        one: 'environ 1 heure',
        other: 'environ {{count}} heures'
      },
      xHours: {
        one: '1 heure',
        other: '{{count}} heures'
      },
      xDays: {
        one: '1 jour',
        other: '{{count}} jours'
      },
      aboutXWeeks: {
        one: 'environ 1 semaine',
        other: 'environ {{count}} semaines'
      },
      xWeeks: {
        one: '1 semaine',
        other: '{{count}} semaines'
      },
      aboutXMonths: {
        one: 'environ 1 mois',
        other: 'environ {{count}} mois'
      },
      xMonths: {
        one: '1 mois',
        other: '{{count}} mois'
      },
      aboutXYears: {
        one: 'environ 1 an',
        other: 'environ {{count}} ans'
      },
      xYears: {
        one: '1 an',
        other: '{{count}} ans'
      },
      overXYears: {
        one: 'plus d’un an',
        other: 'plus de {{count}} ans'
      },
      almostXYears: {
        one: 'presqu’un an',
        other: 'presque {{count}} ans'
      }
    };

    var formatDistance$9 = function (token, count, options) {
      var result;
      var form = formatDistanceLocale$8[token];

      if (typeof form === 'string') {
        result = form;
      } else if (count === 1) {
        result = form.one;
      } else {
        result = form.other.replace('{{count}}', String(count));
      }

      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'dans ' + result;
        } else {
          return 'il y a ' + result;
        }
      }

      return result;
    };

    var dateFormats$9 = {
      full: 'EEEE d MMMM y',
      long: 'd MMMM y',
      medium: 'd MMM y',
      short: 'dd/MM/y'
    };
    var timeFormats$9 = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$9 = {
      full: "{{date}} 'à' {{time}}",
      long: "{{date}} 'à' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$a = {
      date: buildFormatLongFn$1({
        formats: dateFormats$9,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn$1({
        formats: timeFormats$9,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn$1({
        formats: dateTimeFormats$9,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$8 = {
      lastWeek: "eeee 'dernier à' p",
      yesterday: "'hier à' p",
      today: "'aujourd’hui à' p",
      tomorrow: "'demain à' p'",
      nextWeek: "eeee 'prochain à' p",
      other: 'P'
    };

    var formatRelative$9 = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$8[token];
    };

    var eraValues$8 = {
      narrow: ['av. J.-C', 'ap. J.-C'],
      abbreviated: ['av. J.-C', 'ap. J.-C'],
      wide: ['avant Jésus-Christ', 'après Jésus-Christ']
    };
    var quarterValues$8 = {
      narrow: ['T1', 'T2', 'T3', 'T4'],
      abbreviated: ['1er trim.', '2ème trim.', '3ème trim.', '4ème trim.'],
      wide: ['1er trimestre', '2ème trimestre', '3ème trimestre', '4ème trimestre']
    };
    var monthValues$8 = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['janv.', 'févr.', 'mars', 'avr.', 'mai', 'juin', 'juil.', 'août', 'sept.', 'oct.', 'nov.', 'déc.'],
      wide: ['janvier', 'février', 'mars', 'avril', 'mai', 'juin', 'juillet', 'août', 'septembre', 'octobre', 'novembre', 'décembre']
    };
    var dayValues$8 = {
      narrow: ['D', 'L', 'M', 'M', 'J', 'V', 'S'],
      short: ['di', 'lu', 'ma', 'me', 'je', 've', 'sa'],
      abbreviated: ['dim.', 'lun.', 'mar.', 'mer.', 'jeu.', 'ven.', 'sam.'],
      wide: ['dimanche', 'lundi', 'mardi', 'mercredi', 'jeudi', 'vendredi', 'samedi']
    };
    var dayPeriodValues$8 = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'minuit',
        noon: 'midi',
        morning: 'mat.',
        afternoon: 'ap.m.',
        evening: 'soir',
        night: 'mat.'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'minuit',
        noon: 'midi',
        morning: 'matin',
        afternoon: 'après-midi',
        evening: 'soir',
        night: 'matin'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'minuit',
        noon: 'midi',
        morning: 'du matin',
        afternoon: 'de l’après-midi',
        evening: 'du soir',
        night: 'du matin'
      }
    };

    var ordinalNumber$8 = function (dirtyNumber, options) {
      var number = Number(dirtyNumber);
      var unit = options === null || options === void 0 ? void 0 : options.unit;
      if (number === 0) return '0';
      var feminineUnits = ['year', 'week', 'hour', 'minute', 'second'];
      var suffix;

      if (number === 1) {
        suffix = unit && feminineUnits.includes(unit) ? 'ère' : 'er';
      } else {
        suffix = 'ème';
      }

      return number + suffix;
    };

    var localize$9 = {
      ordinalNumber: ordinalNumber$8,
      era: buildLocalizeFn$1({
        values: eraValues$8,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn$1({
        values: quarterValues$8,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn$1({
        values: monthValues$8,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn$1({
        values: dayValues$8,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn$1({
        values: dayPeriodValues$8,
        defaultWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$8 = /^(\d+)(ième|ère|ème|er|e)?/i;
    var parseOrdinalNumberPattern$8 = /\d+/i;
    var matchEraPatterns$8 = {
      narrow: /^(av\.J\.C|ap\.J\.C|ap\.J\.-C)/i,
      abbreviated: /^(av\.J\.-C|av\.J-C|apr\.J\.-C|apr\.J-C|ap\.J-C)/i,
      wide: /^(avant Jésus-Christ|après Jésus-Christ)/i
    };
    var parseEraPatterns$8 = {
      any: [/^av/i, /^ap/i]
    };
    var matchQuarterPatterns$8 = {
      narrow: /^T?[1234]/i,
      abbreviated: /^[1234](er|ème|e)? trim\.?/i,
      wide: /^[1234](er|ème|e)? trimestre/i
    };
    var parseQuarterPatterns$8 = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$8 = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(janv|févr|mars|avr|mai|juin|juill|juil|août|sept|oct|nov|déc)\.?/i,
      wide: /^(janvier|février|mars|avril|mai|juin|juillet|août|septembre|octobre|novembre|décembre)/i
    };
    var parseMonthPatterns$8 = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^f/i, /^mar/i, /^av/i, /^ma/i, /^juin/i, /^juil/i, /^ao/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$8 = {
      narrow: /^[lmjvsd]/i,
      short: /^(di|lu|ma|me|je|ve|sa)/i,
      abbreviated: /^(dim|lun|mar|mer|jeu|ven|sam)\.?/i,
      wide: /^(dimanche|lundi|mardi|mercredi|jeudi|vendredi|samedi)/i
    };
    var parseDayPatterns$8 = {
      narrow: [/^d/i, /^l/i, /^m/i, /^m/i, /^j/i, /^v/i, /^s/i],
      any: [/^di/i, /^lu/i, /^ma/i, /^me/i, /^je/i, /^ve/i, /^sa/i]
    };
    var matchDayPeriodPatterns$8 = {
      narrow: /^(a|p|minuit|midi|mat\.?|ap\.?m\.?|soir|nuit)/i,
      any: /^([ap]\.?\s?m\.?|du matin|de l'après[-\s]midi|du soir|de la nuit)/i
    };
    var parseDayPeriodPatterns$8 = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^min/i,
        noon: /^mid/i,
        morning: /mat/i,
        afternoon: /ap/i,
        evening: /soir/i,
        night: /nuit/i
      }
    };
    var match$9 = {
      ordinalNumber: buildMatchPatternFn$1({
        matchPattern: matchOrdinalNumberPattern$8,
        parsePattern: parseOrdinalNumberPattern$8,
        valueCallback: function (value) {
          return parseInt(value);
        }
      }),
      era: buildMatchFn$1({
        matchPatterns: matchEraPatterns$8,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$8,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn$1({
        matchPatterns: matchQuarterPatterns$8,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$8,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn$1({
        matchPatterns: matchMonthPatterns$8,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$8,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn$1({
        matchPatterns: matchDayPatterns$8,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$8,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn$1({
        matchPatterns: matchDayPeriodPatterns$8,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$8,
        defaultParseWidth: 'any'
      })
    };

    /**
     * @type {Locale}
     * @category Locales
     * @summary French locale.
     * @language French
     * @iso-639-2 fra
     * @author Jean Dupouy [@izeau]{@link https://github.com/izeau}
     * @author François B [@fbonzon]{@link https://github.com/fbonzon}
     */

    var locale$9 = {
      code: 'fr',
      formatDistance: formatDistance$9,
      formatLong: formatLong$a,
      formatRelative: formatRelative$9,
      localize: localize$9,
      match: match$9,
      options: {
        weekStartsOn: 1
        /* Monday */
        ,
        firstWeekContainsDate: 4
      }
    };

    const dateFrFR = {
      name: "fr-FR",
      locale: locale$9
    };
    var dateFrFR$1 = dateFrFR;

    var formatDistanceLocale$7 = {
      lessThanXSeconds: {
        one: 'menos de un segundo',
        other: 'menos de {{count}} segundos'
      },
      xSeconds: {
        one: '1 segundo',
        other: '{{count}} segundos'
      },
      halfAMinute: 'medio minuto',
      lessThanXMinutes: {
        one: 'menos de un minuto',
        other: 'menos de {{count}} minutos'
      },
      xMinutes: {
        one: '1 minuto',
        other: '{{count}} minutos'
      },
      aboutXHours: {
        one: 'alrededor de 1 hora',
        other: 'alrededor de {{count}} horas'
      },
      xHours: {
        one: '1 hora',
        other: '{{count}} horas'
      },
      xDays: {
        one: '1 día',
        other: '{{count}} días'
      },
      aboutXWeeks: {
        one: 'alrededor de 1 semana',
        other: 'alrededor de {{count}} semanas'
      },
      xWeeks: {
        one: '1 semana',
        other: '{{count}} semanas'
      },
      aboutXMonths: {
        one: 'alrededor de 1 mes',
        other: 'alrededor de {{count}} meses'
      },
      xMonths: {
        one: '1 mes',
        other: '{{count}} meses'
      },
      aboutXYears: {
        one: 'alrededor de 1 año',
        other: 'alrededor de {{count}} años'
      },
      xYears: {
        one: '1 año',
        other: '{{count}} años'
      },
      overXYears: {
        one: 'más de 1 año',
        other: 'más de {{count}} años'
      },
      almostXYears: {
        one: 'casi 1 año',
        other: 'casi {{count}} años'
      }
    };

    var formatDistance$8 = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$7[token];

      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', count.toString());
      }

      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'en ' + result;
        } else {
          return 'hace ' + result;
        }
      }

      return result;
    };

    var dateFormats$8 = {
      full: "EEEE, d 'de' MMMM 'de' y",
      long: "d 'de' MMMM 'de' y",
      medium: 'd MMM y',
      short: 'dd/MM/y'
    };
    var timeFormats$8 = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$8 = {
      full: "{{date}} 'a las' {{time}}",
      long: "{{date}} 'a las' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$9 = {
      date: buildFormatLongFn$1({
        formats: dateFormats$8,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn$1({
        formats: timeFormats$8,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn$1({
        formats: dateTimeFormats$8,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$7 = {
      lastWeek: "'el' eeee 'pasado a la' p",
      yesterday: "'ayer a la' p",
      today: "'hoy a la' p",
      tomorrow: "'mañana a la' p",
      nextWeek: "eeee 'a la' p",
      other: 'P'
    };
    var formatRelativeLocalePlural = {
      lastWeek: "'el' eeee 'pasado a las' p",
      yesterday: "'ayer a las' p",
      today: "'hoy a las' p",
      tomorrow: "'mañana a las' p",
      nextWeek: "eeee 'a las' p",
      other: 'P'
    };

    var formatRelative$8 = function (token, date, _baseDate, _options) {
      if (date.getUTCHours() !== 1) {
        return formatRelativeLocalePlural[token];
      } else {
        return formatRelativeLocale$7[token];
      }
    };

    var eraValues$7 = {
      narrow: ['AC', 'DC'],
      abbreviated: ['AC', 'DC'],
      wide: ['antes de cristo', 'después de cristo']
    };
    var quarterValues$7 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['T1', 'T2', 'T3', 'T4'],
      wide: ['1º trimestre', '2º trimestre', '3º trimestre', '4º trimestre']
    };
    var monthValues$7 = {
      narrow: ['e', 'f', 'm', 'a', 'm', 'j', 'j', 'a', 's', 'o', 'n', 'd'],
      abbreviated: ['ene', 'feb', 'mar', 'abr', 'may', 'jun', 'jul', 'ago', 'sep', 'oct', 'nov', 'dic'],
      wide: ['enero', 'febrero', 'marzo', 'abril', 'mayo', 'junio', 'julio', 'agosto', 'septiembre', 'octubre', 'noviembre', 'diciembre']
    };
    var dayValues$7 = {
      narrow: ['d', 'l', 'm', 'm', 'j', 'v', 's'],
      short: ['do', 'lu', 'ma', 'mi', 'ju', 'vi', 'sá'],
      abbreviated: ['dom', 'lun', 'mar', 'mié', 'jue', 'vie', 'sáb'],
      wide: ['domingo', 'lunes', 'martes', 'miércoles', 'jueves', 'viernes', 'sábado']
    };
    var dayPeriodValues$7 = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'mn',
        noon: 'md',
        morning: 'mañana',
        afternoon: 'tarde',
        evening: 'tarde',
        night: 'noche'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'medianoche',
        noon: 'mediodia',
        morning: 'mañana',
        afternoon: 'tarde',
        evening: 'tarde',
        night: 'noche'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'medianoche',
        noon: 'mediodia',
        morning: 'mañana',
        afternoon: 'tarde',
        evening: 'tarde',
        night: 'noche'
      }
    };
    var formattingDayPeriodValues$5 = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'mn',
        noon: 'md',
        morning: 'de la mañana',
        afternoon: 'de la tarde',
        evening: 'de la tarde',
        night: 'de la noche'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'medianoche',
        noon: 'mediodia',
        morning: 'de la mañana',
        afternoon: 'de la tarde',
        evening: 'de la tarde',
        night: 'de la noche'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'medianoche',
        noon: 'mediodia',
        morning: 'de la mañana',
        afternoon: 'de la tarde',
        evening: 'de la tarde',
        night: 'de la noche'
      }
    };

    var ordinalNumber$7 = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + 'º';
    };

    var localize$8 = {
      ordinalNumber: ordinalNumber$7,
      era: buildLocalizeFn$1({
        values: eraValues$7,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn$1({
        values: quarterValues$7,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return Number(quarter) - 1;
        }
      }),
      month: buildLocalizeFn$1({
        values: monthValues$7,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn$1({
        values: dayValues$7,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn$1({
        values: dayPeriodValues$7,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$5,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$7 = /^(\d+)(º)?/i;
    var parseOrdinalNumberPattern$7 = /\d+/i;
    var matchEraPatterns$7 = {
      narrow: /^(ac|dc|a|d)/i,
      abbreviated: /^(a\.?\s?c\.?|a\.?\s?e\.?\s?c\.?|d\.?\s?c\.?|e\.?\s?c\.?)/i,
      wide: /^(antes de cristo|antes de la era com[uú]n|despu[eé]s de cristo|era com[uú]n)/i
    };
    var parseEraPatterns$7 = {
      any: [/^ac/i, /^dc/i],
      wide: [/^(antes de cristo|antes de la era com[uú]n)/i, /^(despu[eé]s de cristo|era com[uú]n)/i]
    };
    var matchQuarterPatterns$7 = {
      narrow: /^[1234]/i,
      abbreviated: /^T[1234]/i,
      wide: /^[1234](º)? trimestre/i
    };
    var parseQuarterPatterns$7 = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$7 = {
      narrow: /^[efmajsond]/i,
      abbreviated: /^(ene|feb|mar|abr|may|jun|jul|ago|sep|oct|nov|dic)/i,
      wide: /^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre)/i
    };
    var parseMonthPatterns$7 = {
      narrow: [/^e/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^en/i, /^feb/i, /^mar/i, /^abr/i, /^may/i, /^jun/i, /^jul/i, /^ago/i, /^sep/i, /^oct/i, /^nov/i, /^dic/i]
    };
    var matchDayPatterns$7 = {
      narrow: /^[dlmjvs]/i,
      short: /^(do|lu|ma|mi|ju|vi|s[áa])/i,
      abbreviated: /^(dom|lun|mar|mi[ée]|jue|vie|s[áa]b)/i,
      wide: /^(domingo|lunes|martes|mi[ée]rcoles|jueves|viernes|s[áa]bado)/i
    };
    var parseDayPatterns$7 = {
      narrow: [/^d/i, /^l/i, /^m/i, /^m/i, /^j/i, /^v/i, /^s/i],
      any: [/^do/i, /^lu/i, /^ma/i, /^mi/i, /^ju/i, /^vi/i, /^sa/i]
    };
    var matchDayPeriodPatterns$7 = {
      narrow: /^(a|p|mn|md|(de la|a las) (mañana|tarde|noche))/i,
      any: /^([ap]\.?\s?m\.?|medianoche|mediodia|(de la|a las) (mañana|tarde|noche))/i
    };
    var parseDayPeriodPatterns$7 = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^mn/i,
        noon: /^md/i,
        morning: /mañana/i,
        afternoon: /tarde/i,
        evening: /tarde/i,
        night: /noche/i
      }
    };
    var match$8 = {
      ordinalNumber: buildMatchPatternFn$1({
        matchPattern: matchOrdinalNumberPattern$7,
        parsePattern: parseOrdinalNumberPattern$7,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn$1({
        matchPatterns: matchEraPatterns$7,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$7,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn$1({
        matchPatterns: matchQuarterPatterns$7,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$7,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn$1({
        matchPatterns: matchMonthPatterns$7,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$7,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn$1({
        matchPatterns: matchDayPatterns$7,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$7,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn$1({
        matchPatterns: matchDayPeriodPatterns$7,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$7,
        defaultParseWidth: 'any'
      })
    };

    /**
     * @type {Locale}
     * @category Locales
     * @summary Spanish locale.
     * @language Spanish
     * @iso-639-2 spa
     * @author Juan Angosto [@juanangosto]{@link https://github.com/juanangosto}
     * @author Guillermo Grau [@guigrpa]{@link https://github.com/guigrpa}
     * @author Fernando Agüero [@fjaguero]{@link https://github.com/fjaguero}
     * @author Gastón Haro [@harogaston]{@link https://github.com/harogaston}
     * @author Yago Carballo [@YagoCarballo]{@link https://github.com/YagoCarballo}
     */

    var locale$8 = {
      code: 'es',
      formatDistance: formatDistance$8,
      formatLong: formatLong$9,
      formatRelative: formatRelative$8,
      localize: localize$8,
      match: match$8,
      options: {
        weekStartsOn: 1
        /* Monday */
        ,
        firstWeekContainsDate: 1
      }
    };

    const dateEsAR = {
      name: "es-AR",
      locale: locale$8
    };
    var dateEsAR$1 = dateEsAR;

    var formatDistanceLocale$6 = {
      lessThanXSeconds: {
        one: 'meno di un secondo',
        other: 'meno di {{count}} secondi'
      },
      xSeconds: {
        one: 'un secondo',
        other: '{{count}} secondi'
      },
      halfAMinute: 'alcuni secondi',
      lessThanXMinutes: {
        one: 'meno di un minuto',
        other: 'meno di {{count}} minuti'
      },
      xMinutes: {
        one: 'un minuto',
        other: '{{count}} minuti'
      },
      aboutXHours: {
        one: "circa un'ora",
        other: 'circa {{count}} ore'
      },
      xHours: {
        one: "un'ora",
        other: '{{count}} ore'
      },
      xDays: {
        one: 'un giorno',
        other: '{{count}} giorni'
      },
      aboutXWeeks: {
        one: 'circa una settimana',
        other: 'circa {{count}} settimane'
      },
      xWeeks: {
        one: 'una settimana',
        other: '{{count}} settimane'
      },
      aboutXMonths: {
        one: 'circa un mese',
        other: 'circa {{count}} mesi'
      },
      xMonths: {
        one: 'un mese',
        other: '{{count}} mesi'
      },
      aboutXYears: {
        one: 'circa un anno',
        other: 'circa {{count}} anni'
      },
      xYears: {
        one: 'un anno',
        other: '{{count}} anni'
      },
      overXYears: {
        one: 'più di un anno',
        other: 'più di {{count}} anni'
      },
      almostXYears: {
        one: 'quasi un anno',
        other: 'quasi {{count}} anni'
      }
    };

    var formatDistance$7 = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$6[token];

      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', count.toString());
      }

      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'tra ' + result;
        } else {
          return result + ' fa';
        }
      }

      return result;
    };

    var dateFormats$7 = {
      full: 'EEEE d MMMM y',
      long: 'd MMMM y',
      medium: 'd MMM y',
      short: 'dd/MM/y'
    };
    var timeFormats$7 = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$7 = {
      full: '{{date}} {{time}}',
      long: '{{date}} {{time}}',
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$8 = {
      date: buildFormatLongFn$1({
        formats: dateFormats$7,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn$1({
        formats: timeFormats$7,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn$1({
        formats: dateTimeFormats$7,
        defaultWidth: 'full'
      })
    };

    var weekdays = ['domenica', 'lunedì', 'martedì', 'mercoledì', 'giovedì', 'venerdì', 'sabato'];

    function lastWeek$1(day) {
      switch (day) {
        case 0:
          return "'domenica scorsa alle' p";

        default:
          return "'" + weekdays[day] + " scorso alle' p";
      }
    }

    function thisWeek$1(day) {
      return "'" + weekdays[day] + " alle' p";
    }

    function nextWeek$1(day) {
      switch (day) {
        case 0:
          return "'domenica prossima alle' p";

        default:
          return "'" + weekdays[day] + " prossimo alle' p";
      }
    }

    var formatRelativeLocale$6 = {
      lastWeek: function (date, baseDate, options) {
        var day = date.getUTCDay();

        if (isSameUTCWeek(date, baseDate, options)) {
          return thisWeek$1(day);
        } else {
          return lastWeek$1(day);
        }
      },
      yesterday: "'ieri alle' p",
      today: "'oggi alle' p",
      tomorrow: "'domani alle' p",
      nextWeek: function (date, baseDate, options) {
        var day = date.getUTCDay();

        if (isSameUTCWeek(date, baseDate, options)) {
          return thisWeek$1(day);
        } else {
          return nextWeek$1(day);
        }
      },
      other: 'P'
    };

    var formatRelative$7 = function (token, date, baseDate, options) {
      var format = formatRelativeLocale$6[token];

      if (typeof format === 'function') {
        return format(date, baseDate, options);
      }

      return format;
    };

    var eraValues$6 = {
      narrow: ['aC', 'dC'],
      abbreviated: ['a.C.', 'd.C.'],
      wide: ['avanti Cristo', 'dopo Cristo']
    };
    var quarterValues$6 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['T1', 'T2', 'T3', 'T4'],
      wide: ['1º trimestre', '2º trimestre', '3º trimestre', '4º trimestre']
    };
    var monthValues$6 = {
      narrow: ['G', 'F', 'M', 'A', 'M', 'G', 'L', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['gen', 'feb', 'mar', 'apr', 'mag', 'giu', 'lug', 'ago', 'set', 'ott', 'nov', 'dic'],
      wide: ['gennaio', 'febbraio', 'marzo', 'aprile', 'maggio', 'giugno', 'luglio', 'agosto', 'settembre', 'ottobre', 'novembre', 'dicembre']
    };
    var dayValues$6 = {
      narrow: ['D', 'L', 'M', 'M', 'G', 'V', 'S'],
      short: ['dom', 'lun', 'mar', 'mer', 'gio', 'ven', 'sab'],
      abbreviated: ['dom', 'lun', 'mar', 'mer', 'gio', 'ven', 'sab'],
      wide: ['domenica', 'lunedì', 'martedì', 'mercoledì', 'giovedì', 'venerdì', 'sabato']
    };
    var dayPeriodValues$6 = {
      narrow: {
        am: 'm.',
        pm: 'p.',
        midnight: 'mezzanotte',
        noon: 'mezzogiorno',
        morning: 'mattina',
        afternoon: 'pomeriggio',
        evening: 'sera',
        night: 'notte'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'mezzanotte',
        noon: 'mezzogiorno',
        morning: 'mattina',
        afternoon: 'pomeriggio',
        evening: 'sera',
        night: 'notte'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'mezzanotte',
        noon: 'mezzogiorno',
        morning: 'mattina',
        afternoon: 'pomeriggio',
        evening: 'sera',
        night: 'notte'
      }
    };
    var formattingDayPeriodValues$4 = {
      narrow: {
        am: 'm.',
        pm: 'p.',
        midnight: 'mezzanotte',
        noon: 'mezzogiorno',
        morning: 'di mattina',
        afternoon: 'del pomeriggio',
        evening: 'di sera',
        night: 'di notte'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'mezzanotte',
        noon: 'mezzogiorno',
        morning: 'di mattina',
        afternoon: 'del pomeriggio',
        evening: 'di sera',
        night: 'di notte'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'mezzanotte',
        noon: 'mezzogiorno',
        morning: 'di mattina',
        afternoon: 'del pomeriggio',
        evening: 'di sera',
        night: 'di notte'
      }
    };

    var ordinalNumber$6 = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return String(number);
    };

    var localize$7 = {
      ordinalNumber: ordinalNumber$6,
      era: buildLocalizeFn$1({
        values: eraValues$6,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn$1({
        values: quarterValues$6,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn$1({
        values: monthValues$6,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn$1({
        values: dayValues$6,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn$1({
        values: dayPeriodValues$6,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$4,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$6 = /^(\d+)(º)?/i;
    var parseOrdinalNumberPattern$6 = /\d+/i;
    var matchEraPatterns$6 = {
      narrow: /^(aC|dC)/i,
      abbreviated: /^(a\.?\s?C\.?|a\.?\s?e\.?\s?v\.?|d\.?\s?C\.?|e\.?\s?v\.?)/i,
      wide: /^(avanti Cristo|avanti Era Volgare|dopo Cristo|Era Volgare)/i
    };
    var parseEraPatterns$6 = {
      any: [/^a/i, /^(d|e)/i]
    };
    var matchQuarterPatterns$6 = {
      narrow: /^[1234]/i,
      abbreviated: /^t[1234]/i,
      wide: /^[1234](º)? trimestre/i
    };
    var parseQuarterPatterns$6 = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$6 = {
      narrow: /^[gfmalsond]/i,
      abbreviated: /^(gen|feb|mar|apr|mag|giu|lug|ago|set|ott|nov|dic)/i,
      wide: /^(gennaio|febbraio|marzo|aprile|maggio|giugno|luglio|agosto|settembre|ottobre|novembre|dicembre)/i
    };
    var parseMonthPatterns$6 = {
      narrow: [/^g/i, /^f/i, /^m/i, /^a/i, /^m/i, /^g/i, /^l/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ge/i, /^f/i, /^mar/i, /^ap/i, /^mag/i, /^gi/i, /^l/i, /^ag/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$6 = {
      narrow: /^[dlmgvs]/i,
      short: /^(do|lu|ma|me|gi|ve|sa)/i,
      abbreviated: /^(dom|lun|mar|mer|gio|ven|sab)/i,
      wide: /^(domenica|luned[i|ì]|marted[i|ì]|mercoled[i|ì]|gioved[i|ì]|venerd[i|ì]|sabato)/i
    };
    var parseDayPatterns$6 = {
      narrow: [/^d/i, /^l/i, /^m/i, /^m/i, /^g/i, /^v/i, /^s/i],
      any: [/^d/i, /^l/i, /^ma/i, /^me/i, /^g/i, /^v/i, /^s/i]
    };
    var matchDayPeriodPatterns$6 = {
      narrow: /^(a|m\.|p|mezzanotte|mezzogiorno|(di|del) (mattina|pomeriggio|sera|notte))/i,
      any: /^([ap]\.?\s?m\.?|mezzanotte|mezzogiorno|(di|del) (mattina|pomeriggio|sera|notte))/i
    };
    var parseDayPeriodPatterns$6 = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^mezza/i,
        noon: /^mezzo/i,
        morning: /mattina/i,
        afternoon: /pomeriggio/i,
        evening: /sera/i,
        night: /notte/i
      }
    };
    var match$7 = {
      ordinalNumber: buildMatchPatternFn$1({
        matchPattern: matchOrdinalNumberPattern$6,
        parsePattern: parseOrdinalNumberPattern$6,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn$1({
        matchPatterns: matchEraPatterns$6,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$6,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn$1({
        matchPatterns: matchQuarterPatterns$6,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$6,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn$1({
        matchPatterns: matchMonthPatterns$6,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$6,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn$1({
        matchPatterns: matchDayPatterns$6,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$6,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn$1({
        matchPatterns: matchDayPeriodPatterns$6,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$6,
        defaultParseWidth: 'any'
      })
    };

    /**
     * @type {Locale}
     * @category Locales
     * @summary Italian locale.
     * @language Italian
     * @iso-639-2 ita
     * @author Alberto Restifo [@albertorestifo]{@link https://github.com/albertorestifo}
     * @author Giovanni Polimeni [@giofilo]{@link https://github.com/giofilo}
     * @author Vincenzo Carrese [@vin-car]{@link https://github.com/vin-car}
     */

    var locale$7 = {
      code: 'it',
      formatDistance: formatDistance$7,
      formatLong: formatLong$8,
      formatRelative: formatRelative$7,
      localize: localize$7,
      match: match$7,
      options: {
        weekStartsOn: 1
        /* Monday */
        ,
        firstWeekContainsDate: 4
      }
    };

    const dateItIT = {
      name: "it-IT",
      locale: locale$7
    };
    var dateItIT$1 = dateItIT;

    function declensionGroup$1(scheme, count) {
      if (count === 1 && scheme.one) {
        return scheme.one;
      }

      if (count >= 2 && count <= 4 && scheme.twoFour) {
        return scheme.twoFour;
      } // if count === null || count === 0 || count >= 5


      return scheme.other;
    }

    function declension$1(scheme, count, time) {
      var group = declensionGroup$1(scheme, count);
      var finalText = group[time];
      return finalText.replace('{{count}}', String(count));
    }

    function extractPreposition(token) {
      var result = ['lessThan', 'about', 'over', 'almost'].filter(function (preposition) {
        return !!token.match(new RegExp('^' + preposition));
      });
      return result[0];
    }

    function prefixPreposition(preposition) {
      var translation = '';

      if (preposition === 'almost') {
        translation = 'takmer';
      }

      if (preposition === 'about') {
        translation = 'približne';
      }

      return translation.length > 0 ? translation + ' ' : '';
    }

    function suffixPreposition(preposition) {
      var translation = '';

      if (preposition === 'lessThan') {
        translation = 'menej než';
      }

      if (preposition === 'over') {
        translation = 'viac než';
      }

      return translation.length > 0 ? translation + ' ' : '';
    }

    function lowercaseFirstLetter(string) {
      return string.charAt(0).toLowerCase() + string.slice(1);
    }

    var formatDistanceLocale$5 = {
      xSeconds: {
        one: {
          present: 'sekunda',
          past: 'sekundou',
          future: 'sekundu'
        },
        twoFour: {
          present: '{{count}} sekundy',
          past: '{{count}} sekundami',
          future: '{{count}} sekundy'
        },
        other: {
          present: '{{count}} sekúnd',
          past: '{{count}} sekundami',
          future: '{{count}} sekúnd'
        }
      },
      halfAMinute: {
        other: {
          present: 'pol minúty',
          past: 'pol minútou',
          future: 'pol minúty'
        }
      },
      xMinutes: {
        one: {
          present: 'minúta',
          past: 'minútou',
          future: 'minútu'
        },
        twoFour: {
          present: '{{count}} minúty',
          past: '{{count}} minútami',
          future: '{{count}} minúty'
        },
        other: {
          present: '{{count}} minút',
          past: '{{count}} minútami',
          future: '{{count}} minút'
        }
      },
      xHours: {
        one: {
          present: 'hodina',
          past: 'hodinou',
          future: 'hodinu'
        },
        twoFour: {
          present: '{{count}} hodiny',
          past: '{{count}} hodinami',
          future: '{{count}} hodiny'
        },
        other: {
          present: '{{count}} hodín',
          past: '{{count}} hodinami',
          future: '{{count}} hodín'
        }
      },
      xDays: {
        one: {
          present: 'deň',
          past: 'dňom',
          future: 'deň'
        },
        twoFour: {
          present: '{{count}} dni',
          past: '{{count}} dňami',
          future: '{{count}} dni'
        },
        other: {
          present: '{{count}} dní',
          past: '{{count}} dňami',
          future: '{{count}} dní'
        }
      },
      xWeeks: {
        one: {
          present: 'týždeň',
          past: 'týždňom',
          future: 'týždeň'
        },
        twoFour: {
          present: '{{count}} týždne',
          past: '{{count}} týždňami',
          future: '{{count}} týždne'
        },
        other: {
          present: '{{count}} týždňov',
          past: '{{count}} týždňami',
          future: '{{count}} týždňov'
        }
      },
      xMonths: {
        one: {
          present: 'mesiac',
          past: 'mesiacom',
          future: 'mesiac'
        },
        twoFour: {
          present: '{{count}} mesiace',
          past: '{{count}} mesiacmi',
          future: '{{count}} mesiace'
        },
        other: {
          present: '{{count}} mesiacov',
          past: '{{count}} mesiacmi',
          future: '{{count}} mesiacov'
        }
      },
      xYears: {
        one: {
          present: 'rok',
          past: 'rokom',
          future: 'rok'
        },
        twoFour: {
          present: '{{count}} roky',
          past: '{{count}} rokmi',
          future: '{{count}} roky'
        },
        other: {
          present: '{{count}} rokov',
          past: '{{count}} rokmi',
          future: '{{count}} rokov'
        }
      }
    };

    var formatDistance$6 = function (token, count, options) {
      var preposition = extractPreposition(token) || '';
      var key = lowercaseFirstLetter(token.substring(preposition.length));
      var scheme = formatDistanceLocale$5[key];

      if (!(options !== null && options !== void 0 && options.addSuffix)) {
        return prefixPreposition(preposition) + suffixPreposition(preposition) + declension$1(scheme, count, 'present');
      }

      if (options.comparison && options.comparison > 0) {
        return prefixPreposition(preposition) + 'o ' + suffixPreposition(preposition) + declension$1(scheme, count, 'future');
      } else {
        return prefixPreposition(preposition) + 'pred ' + suffixPreposition(preposition) + declension$1(scheme, count, 'past');
      }
    };

    var dateFormats$6 = {
      full: 'EEEE d. MMMM y',
      long: 'd. MMMM y',
      medium: 'd. M. y',
      short: 'd. M. y'
    }; // https://www.unicode.org/cldr/charts/32/summary/sk.html?hide#2149

    var timeFormats$6 = {
      full: 'H:mm:ss zzzz',
      long: 'H:mm:ss z',
      medium: 'H:mm:ss',
      short: 'H:mm'
    }; // https://www.unicode.org/cldr/charts/32/summary/sk.html?hide#1994

    var dateTimeFormats$6 = {
      full: '{{date}}, {{time}}',
      long: '{{date}}, {{time}}',
      medium: '{{date}}, {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$7 = {
      date: buildFormatLongFn$1({
        formats: dateFormats$6,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn$1({
        formats: timeFormats$6,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn$1({
        formats: dateTimeFormats$6,
        defaultWidth: 'full'
      })
    };

    var accusativeWeekdays = ['nedeľu', 'pondelok', 'utorok', 'stredu', 'štvrtok', 'piatok', 'sobotu'];

    function lastWeek(day) {
      var weekday = accusativeWeekdays[day];

      switch (day) {
        case 0:
        /* Sun */

        case 3:
        /* Wed */

        case 6
        /* Sat */
        :
          return "'minulú " + weekday + " o' p";

        default:
          return "'minulý' eeee 'o' p";
      }
    }

    function thisWeek(day) {
      var weekday = accusativeWeekdays[day];

      if (day === 4
      /* Thu */
      ) {
        return "'vo' eeee 'o' p";
      } else {
        return "'v " + weekday + " o' p";
      }
    }

    function nextWeek(day) {
      var weekday = accusativeWeekdays[day];

      switch (day) {
        case 0:
        /* Sun */

        case 4:
        /* Wed */

        case 6
        /* Sat */
        :
          return "'budúcu " + weekday + " o' p";

        default:
          return "'budúci' eeee 'o' p";
      }
    }

    var formatRelativeLocale$5 = {
      lastWeek: function (date, baseDate, options) {
        var day = date.getUTCDay();

        if (isSameUTCWeek(date, baseDate, options)) {
          return thisWeek(day);
        } else {
          return lastWeek(day);
        }
      },
      yesterday: "'včera o' p",
      today: "'dnes o' p",
      tomorrow: "'zajtra o' p",
      nextWeek: function (date, baseDate, options) {
        var day = date.getUTCDay();

        if (isSameUTCWeek(date, baseDate, options)) {
          return thisWeek(day);
        } else {
          return nextWeek(day);
        }
      },
      other: 'P'
    };

    var formatRelative$6 = function (token, date, baseDate, options) {
      var format = formatRelativeLocale$5[token];

      if (typeof format === 'function') {
        return format(date, baseDate, options);
      }

      return format;
    };

    var eraValues$5 = {
      narrow: ['pred Kr.', 'po Kr.'],
      abbreviated: ['pred Kr.', 'po Kr.'],
      wide: ['pred Kristom', 'po Kristovi']
    }; // https://www.unicode.org/cldr/charts/32/summary/sk.html#1780

    var quarterValues$5 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['1. štvrťrok', '2. štvrťrok', '3. štvrťrok', '4. štvrťrok']
    }; // https://www.unicode.org/cldr/charts/32/summary/sk.html#1804

    var monthValues$5 = {
      narrow: ['j', 'f', 'm', 'a', 'm', 'j', 'j', 'a', 's', 'o', 'n', 'd'],
      abbreviated: ['jan', 'feb', 'mar', 'apr', 'máj', 'jún', 'júl', 'aug', 'sep', 'okt', 'nov', 'dec'],
      wide: ['január', 'február', 'marec', 'apríl', 'máj', 'jún', 'júl', 'august', 'september', 'október', 'november', 'december']
    };
    var formattingMonthValues$1 = {
      narrow: ['j', 'f', 'm', 'a', 'm', 'j', 'j', 'a', 's', 'o', 'n', 'd'],
      abbreviated: ['jan', 'feb', 'mar', 'apr', 'máj', 'jún', 'júl', 'aug', 'sep', 'okt', 'nov', 'dec'],
      wide: ['januára', 'februára', 'marca', 'apríla', 'mája', 'júna', 'júla', 'augusta', 'septembra', 'októbra', 'novembra', 'decembra']
    }; // https://www.unicode.org/cldr/charts/32/summary/sk.html#1876

    var dayValues$5 = {
      narrow: ['n', 'p', 'u', 's', 'š', 'p', 's'],
      short: ['ne', 'po', 'ut', 'st', 'št', 'pi', 'so'],
      abbreviated: ['ne', 'po', 'ut', 'st', 'št', 'pi', 'so'],
      wide: ['nedeľa', 'pondelok', 'utorok', 'streda', 'štvrtok', 'piatok', 'sobota']
    }; // https://www.unicode.org/cldr/charts/32/summary/sk.html#1932

    var dayPeriodValues$5 = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'poln.',
        noon: 'pol.',
        morning: 'ráno',
        afternoon: 'pop.',
        evening: 'več.',
        night: 'noc'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'poln.',
        noon: 'pol.',
        morning: 'ráno',
        afternoon: 'popol.',
        evening: 'večer',
        night: 'noc'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'polnoc',
        noon: 'poludnie',
        morning: 'ráno',
        afternoon: 'popoludnie',
        evening: 'večer',
        night: 'noc'
      }
    };
    var formattingDayPeriodValues$3 = {
      narrow: {
        am: 'AM',
        pm: 'PM',
        midnight: 'o poln.',
        noon: 'nap.',
        morning: 'ráno',
        afternoon: 'pop.',
        evening: 'več.',
        night: 'v n.'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'o poln.',
        noon: 'napol.',
        morning: 'ráno',
        afternoon: 'popol.',
        evening: 'večer',
        night: 'v noci'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'o polnoci',
        noon: 'napoludnie',
        morning: 'ráno',
        afternoon: 'popoludní',
        evening: 'večer',
        night: 'v noci'
      }
    };

    var ordinalNumber$5 = function (dirtyNumber, _options) {
      var number = Number(dirtyNumber);
      return number + '.';
    };

    var localize$6 = {
      ordinalNumber: ordinalNumber$5,
      era: buildLocalizeFn$1({
        values: eraValues$5,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn$1({
        values: quarterValues$5,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn$1({
        values: monthValues$5,
        defaultWidth: 'wide',
        formattingValues: formattingMonthValues$1,
        defaultFormattingWidth: 'wide'
      }),
      day: buildLocalizeFn$1({
        values: dayValues$5,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn$1({
        values: dayPeriodValues$5,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$3,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$5 = /^(\d+)\.?/i;
    var parseOrdinalNumberPattern$5 = /\d+/i;
    var matchEraPatterns$5 = {
      narrow: /^(pred Kr\.|pred n\. l\.|po Kr\.|n\. l\.)/i,
      abbreviated: /^(pred Kr\.|pred n\. l\.|po Kr\.|n\. l\.)/i,
      wide: /^(pred Kristom|pred na[šs][íi]m letopo[čc]tom|po Kristovi|n[áa][šs]ho letopo[čc]tu)/i
    };
    var parseEraPatterns$5 = {
      any: [/^pr/i, /^(po|n)/i]
    };
    var matchQuarterPatterns$5 = {
      narrow: /^[1234]/i,
      abbreviated: /^q[1234]/i,
      wide: /^[1234]\. [šs]tvr[ťt]rok/i
    };
    var parseQuarterPatterns$5 = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$5 = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(jan|feb|mar|apr|m[áa]j|j[úu]n|j[úu]l|aug|sep|okt|nov|dec)/i,
      wide: /^(janu[áa]ra?|febru[áa]ra?|(marec|marca)|apr[íi]la?|m[áa]ja?|j[úu]na?|j[úu]la?|augusta?|(september|septembra)|(okt[óo]ber|okt[óo]bra)|(november|novembra)|(december|decembra))/i
    };
    var parseMonthPatterns$5 = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^f/i, /^mar/i, /^ap/i, /^m[áa]j/i, /^j[úu]n/i, /^j[úu]l/i, /^au/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$5 = {
      narrow: /^[npusšp]/i,
      short: /^(ne|po|ut|st|št|pi|so)/i,
      abbreviated: /^(ne|po|ut|st|št|pi|so)/i,
      wide: /^(nede[ľl]a|pondelok|utorok|streda|[šs]tvrtok|piatok|sobota])/i
    };
    var parseDayPatterns$5 = {
      narrow: [/^n/i, /^p/i, /^u/i, /^s/i, /^š/i, /^p/i, /^s/i],
      any: [/^n/i, /^po/i, /^u/i, /^st/i, /^(št|stv)/i, /^pi/i, /^so/i]
    };
    var matchDayPeriodPatterns$5 = {
      narrow: /^(am|pm|(o )?poln\.?|(nap\.?|pol\.?)|r[áa]no|pop\.?|ve[čc]\.?|(v n\.?|noc))/i,
      abbreviated: /^(am|pm|(o )?poln\.?|(napol\.?|pol\.?)|r[áa]no|pop\.?|ve[čc]er|(v )?noci?)/i,
      any: /^(am|pm|(o )?polnoci?|(na)?poludnie|r[áa]no|popoludn(ie|í|i)|ve[čc]er|(v )?noci?)/i
    };
    var parseDayPeriodPatterns$5 = {
      any: {
        am: /^am/i,
        pm: /^pm/i,
        midnight: /poln/i,
        noon: /^(nap|(na)?pol(\.|u))/i,
        morning: /^r[áa]no/i,
        afternoon: /^pop/i,
        evening: /^ve[čc]/i,
        night: /^(noc|v n\.)/i
      }
    };
    var match$6 = {
      ordinalNumber: buildMatchPatternFn$1({
        matchPattern: matchOrdinalNumberPattern$5,
        parsePattern: parseOrdinalNumberPattern$5,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn$1({
        matchPatterns: matchEraPatterns$5,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$5,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn$1({
        matchPatterns: matchQuarterPatterns$5,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$5,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn$1({
        matchPatterns: matchMonthPatterns$5,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$5,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn$1({
        matchPatterns: matchDayPatterns$5,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$5,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn$1({
        matchPatterns: matchDayPeriodPatterns$5,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$5,
        defaultParseWidth: 'any'
      })
    };

    /**
     * @type {Locale}
     * @category Locales
     * @summary Slovak locale.
     * @language Slovak
     * @iso-639-2 slk
     * @author Marek Suscak [@mareksuscak]{@link https://github.com/mareksuscak}
     */

    var locale$6 = {
      code: 'sk',
      formatDistance: formatDistance$6,
      formatLong: formatLong$7,
      formatRelative: formatRelative$6,
      localize: localize$6,
      match: match$6,
      options: {
        weekStartsOn: 1
        /* Monday */
        ,
        firstWeekContainsDate: 4
      }
    };

    const dateSkSK = {
      name: "sk-SK",
      locale: locale$6
    };
    var dateSkSK$1 = dateSkSK;

    var dateFormats$5 = {
      full: 'EEEE, d MMMM yyyy',
      long: 'd MMMM yyyy',
      medium: 'd MMM yyyy',
      short: 'dd/MM/yyyy'
    };
    var timeFormats$5 = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$5 = {
      full: "{{date}} 'at' {{time}}",
      long: "{{date}} 'at' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$6 = {
      date: buildFormatLongFn$1({
        formats: dateFormats$5,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn$1({
        formats: timeFormats$5,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn$1({
        formats: dateTimeFormats$5,
        defaultWidth: 'full'
      })
    };

    /**
     * @type {Locale}
     * @category Locales
     * @summary English locale (United Kingdom).
     * @language English
     * @iso-639-2 eng
     * @author Alex [@glintik]{@link https://github.com/glintik}
     */

    var locale$5 = {
      code: 'en-GB',
      formatDistance: formatDistance$i,
      formatLong: formatLong$6,
      formatRelative: formatRelative$i,
      localize: localize$i,
      match: match$i,
      options: {
        weekStartsOn: 1
        /* Monday */
        ,
        firstWeekContainsDate: 4
      }
    };

    const dateEnGB = {
      name: "en-GB",
      locale: locale$5
    };
    var dateEnGB$1 = dateEnGB;

    var formatDistanceLocale$4 = {
      lessThanXSeconds: {
        one: {
          regular: 'mniej niż sekunda',
          past: 'mniej niż sekundę',
          future: 'mniej niż sekundę'
        },
        twoFour: 'mniej niż {{count}} sekundy',
        other: 'mniej niż {{count}} sekund'
      },
      xSeconds: {
        one: {
          regular: 'sekunda',
          past: 'sekundę',
          future: 'sekundę'
        },
        twoFour: '{{count}} sekundy',
        other: '{{count}} sekund'
      },
      halfAMinute: {
        one: 'pół minuty',
        twoFour: 'pół minuty',
        other: 'pół minuty'
      },
      lessThanXMinutes: {
        one: {
          regular: 'mniej niż minuta',
          past: 'mniej niż minutę',
          future: 'mniej niż minutę'
        },
        twoFour: 'mniej niż {{count}} minuty',
        other: 'mniej niż {{count}} minut'
      },
      xMinutes: {
        one: {
          regular: 'minuta',
          past: 'minutę',
          future: 'minutę'
        },
        twoFour: '{{count}} minuty',
        other: '{{count}} minut'
      },
      aboutXHours: {
        one: {
          regular: 'około godziny',
          past: 'około godziny',
          future: 'około godzinę'
        },
        twoFour: 'około {{count}} godziny',
        other: 'około {{count}} godzin'
      },
      xHours: {
        one: {
          regular: 'godzina',
          past: 'godzinę',
          future: 'godzinę'
        },
        twoFour: '{{count}} godziny',
        other: '{{count}} godzin'
      },
      xDays: {
        one: {
          regular: 'dzień',
          past: 'dzień',
          future: '1 dzień'
        },
        twoFour: '{{count}} dni',
        other: '{{count}} dni'
      },
      aboutXWeeks: {
        one: 'około tygodnia',
        twoFour: 'około {{count}} tygodni',
        other: 'około {{count}} tygodni'
      },
      xWeeks: {
        one: 'tydzień',
        twoFour: '{{count}} tygodnie',
        other: '{{count}} tygodni'
      },
      aboutXMonths: {
        one: 'około miesiąc',
        twoFour: 'około {{count}} miesiące',
        other: 'około {{count}} miesięcy'
      },
      xMonths: {
        one: 'miesiąc',
        twoFour: '{{count}} miesiące',
        other: '{{count}} miesięcy'
      },
      aboutXYears: {
        one: 'około rok',
        twoFour: 'około {{count}} lata',
        other: 'około {{count}} lat'
      },
      xYears: {
        one: 'rok',
        twoFour: '{{count}} lata',
        other: '{{count}} lat'
      },
      overXYears: {
        one: 'ponad rok',
        twoFour: 'ponad {{count}} lata',
        other: 'ponad {{count}} lat'
      },
      almostXYears: {
        one: 'prawie rok',
        twoFour: 'prawie {{count}} lata',
        other: 'prawie {{count}} lat'
      }
    };

    function declensionGroup(scheme, count) {
      if (count === 1) {
        return scheme.one;
      }

      var rem100 = count % 100; // ends with 11-20

      if (rem100 <= 20 && rem100 > 10) {
        return scheme.other;
      }

      var rem10 = rem100 % 10; // ends with 2, 3, 4

      if (rem10 >= 2 && rem10 <= 4) {
        return scheme.twoFour;
      }

      return scheme.other;
    }

    function declension(scheme, count, time) {
      var group = declensionGroup(scheme, count);
      var finalText = typeof group === 'string' ? group : group[time];
      return finalText.replace('{{count}}', String(count));
    }

    var formatDistance$5 = function (token, count, options) {
      var scheme = formatDistanceLocale$4[token];

      if (!(options !== null && options !== void 0 && options.addSuffix)) {
        return declension(scheme, count, 'regular');
      }

      if (options.comparison && options.comparison > 0) {
        return 'za ' + declension(scheme, count, 'future');
      } else {
        return declension(scheme, count, 'past') + ' temu';
      }
    };

    var dateFormats$4 = {
      full: 'EEEE, do MMMM y',
      long: 'do MMMM y',
      medium: 'do MMM y',
      short: 'dd.MM.y'
    };
    var timeFormats$4 = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$4 = {
      full: '{{date}} {{time}}',
      long: '{{date}} {{time}}',
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$5 = {
      date: buildFormatLongFn$1({
        formats: dateFormats$4,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn$1({
        formats: timeFormats$4,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn$1({
        formats: dateTimeFormats$4,
        defaultWidth: 'full'
      })
    };

    var adjectivesLastWeek = {
      masculine: 'ostatni',
      feminine: 'ostatnia'
    };
    var adjectivesThisWeek = {
      masculine: 'ten',
      feminine: 'ta'
    };
    var adjectivesNextWeek = {
      masculine: 'następny',
      feminine: 'następna'
    };
    var dayGrammaticalGender = {
      0: 'feminine',
      1: 'masculine',
      2: 'masculine',
      3: 'feminine',
      4: 'masculine',
      5: 'masculine',
      6: 'feminine'
    };

    function dayAndTimeWithAdjective(token, date, baseDate, options) {
      var adjectives;

      if (isSameUTCWeek(date, baseDate, options)) {
        adjectives = adjectivesThisWeek;
      } else if (token === 'lastWeek') {
        adjectives = adjectivesLastWeek;
      } else if (token === 'nextWeek') {
        adjectives = adjectivesNextWeek;
      } else {
        throw new Error("Cannot determine adjectives for token ".concat(token));
      }

      var day = date.getUTCDay();
      var grammaticalGender = dayGrammaticalGender[day];
      var adjective = adjectives[grammaticalGender];
      return "'".concat(adjective, "' eeee 'o' p");
    }

    var formatRelativeLocale$4 = {
      lastWeek: dayAndTimeWithAdjective,
      yesterday: "'wczoraj o' p",
      today: "'dzisiaj o' p",
      tomorrow: "'jutro o' p",
      nextWeek: dayAndTimeWithAdjective,
      other: 'P'
    };

    var formatRelative$5 = function (token, date, baseDate, options) {
      var format = formatRelativeLocale$4[token];

      if (typeof format === 'function') {
        return format(token, date, baseDate, options);
      }

      return format;
    };

    var eraValues$4 = {
      narrow: ['p.n.e.', 'n.e.'],
      abbreviated: ['p.n.e.', 'n.e.'],
      wide: ['przed naszą erą', 'naszej ery']
    };
    var quarterValues$4 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['I kw.', 'II kw.', 'III kw.', 'IV kw.'],
      wide: ['I kwartał', 'II kwartał', 'III kwartał', 'IV kwartał']
    };
    var monthValues$4 = {
      narrow: ['S', 'L', 'M', 'K', 'M', 'C', 'L', 'S', 'W', 'P', 'L', 'G'],
      abbreviated: ['sty', 'lut', 'mar', 'kwi', 'maj', 'cze', 'lip', 'sie', 'wrz', 'paź', 'lis', 'gru'],
      wide: ['styczeń', 'luty', 'marzec', 'kwiecień', 'maj', 'czerwiec', 'lipiec', 'sierpień', 'wrzesień', 'październik', 'listopad', 'grudzień']
    };
    var monthFormattingValues = {
      narrow: ['s', 'l', 'm', 'k', 'm', 'c', 'l', 's', 'w', 'p', 'l', 'g'],
      abbreviated: ['sty', 'lut', 'mar', 'kwi', 'maj', 'cze', 'lip', 'sie', 'wrz', 'paź', 'lis', 'gru'],
      wide: ['stycznia', 'lutego', 'marca', 'kwietnia', 'maja', 'czerwca', 'lipca', 'sierpnia', 'września', 'października', 'listopada', 'grudnia']
    };
    var dayValues$4 = {
      narrow: ['N', 'P', 'W', 'Ś', 'C', 'P', 'S'],
      short: ['nie', 'pon', 'wto', 'śro', 'czw', 'pią', 'sob'],
      abbreviated: ['niedz.', 'pon.', 'wt.', 'śr.', 'czw.', 'pt.', 'sob.'],
      wide: ['niedziela', 'poniedziałek', 'wtorek', 'środa', 'czwartek', 'piątek', 'sobota']
    };
    var dayFormattingValues = {
      narrow: ['n', 'p', 'w', 'ś', 'c', 'p', 's'],
      short: ['nie', 'pon', 'wto', 'śro', 'czw', 'pią', 'sob'],
      abbreviated: ['niedz.', 'pon.', 'wt.', 'śr.', 'czw.', 'pt.', 'sob.'],
      wide: ['niedziela', 'poniedziałek', 'wtorek', 'środa', 'czwartek', 'piątek', 'sobota']
    };
    var dayPeriodValues$4 = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'półn.',
        noon: 'poł',
        morning: 'rano',
        afternoon: 'popoł.',
        evening: 'wiecz.',
        night: 'noc'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'północ',
        noon: 'południe',
        morning: 'rano',
        afternoon: 'popołudnie',
        evening: 'wieczór',
        night: 'noc'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'północ',
        noon: 'południe',
        morning: 'rano',
        afternoon: 'popołudnie',
        evening: 'wieczór',
        night: 'noc'
      }
    };
    var dayPeriodFormattingValues = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'o półn.',
        noon: 'w poł.',
        morning: 'rano',
        afternoon: 'po poł.',
        evening: 'wiecz.',
        night: 'w nocy'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'o północy',
        noon: 'w południe',
        morning: 'rano',
        afternoon: 'po południu',
        evening: 'wieczorem',
        night: 'w nocy'
      },
      wide: {
        am: 'AM',
        pm: 'PM',
        midnight: 'o północy',
        noon: 'w południe',
        morning: 'rano',
        afternoon: 'po południu',
        evening: 'wieczorem',
        night: 'w nocy'
      }
    };

    var ordinalNumber$4 = function (dirtyNumber, _options) {
      return String(dirtyNumber);
    };

    var localize$5 = {
      ordinalNumber: ordinalNumber$4,
      era: buildLocalizeFn$1({
        values: eraValues$4,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn$1({
        values: quarterValues$4,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn$1({
        values: monthValues$4,
        defaultWidth: 'wide',
        formattingValues: monthFormattingValues,
        defaultFormattingWidth: 'wide'
      }),
      day: buildLocalizeFn$1({
        values: dayValues$4,
        defaultWidth: 'wide',
        formattingValues: dayFormattingValues,
        defaultFormattingWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn$1({
        values: dayPeriodValues$4,
        defaultWidth: 'wide',
        formattingValues: dayPeriodFormattingValues,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$4 = /^(\d+)?/i;
    var parseOrdinalNumberPattern$4 = /\d+/i;
    var matchEraPatterns$4 = {
      narrow: /^(p\.?\s*n\.?\s*e\.?\s*|n\.?\s*e\.?\s*)/i,
      abbreviated: /^(p\.?\s*n\.?\s*e\.?\s*|n\.?\s*e\.?\s*)/i,
      wide: /^(przed\s*nasz(ą|a)\s*er(ą|a)|naszej\s*ery)/i
    };
    var parseEraPatterns$4 = {
      any: [/^p/i, /^n/i]
    };
    var matchQuarterPatterns$4 = {
      narrow: /^[1234]/i,
      abbreviated: /^(I|II|III|IV)\s*kw\.?/i,
      wide: /^(I|II|III|IV)\s*kwarta(ł|l)/i
    };
    var parseQuarterPatterns$4 = {
      narrow: [/1/i, /2/i, /3/i, /4/i],
      any: [/^I kw/i, /^II kw/i, /^III kw/i, /^IV kw/i]
    };
    var matchMonthPatterns$4 = {
      narrow: /^[slmkcwpg]/i,
      abbreviated: /^(sty|lut|mar|kwi|maj|cze|lip|sie|wrz|pa(ź|z)|lis|gru)/i,
      wide: /^(stycznia|stycze(ń|n)|lutego|luty|marca|marzec|kwietnia|kwiecie(ń|n)|maja|maj|czerwca|czerwiec|lipca|lipiec|sierpnia|sierpie(ń|n)|wrze(ś|s)nia|wrzesie(ń|n)|pa(ź|z)dziernika|pa(ź|z)dziernik|listopada|listopad|grudnia|grudzie(ń|n))/i
    };
    var parseMonthPatterns$4 = {
      narrow: [/^s/i, /^l/i, /^m/i, /^k/i, /^m/i, /^c/i, /^l/i, /^s/i, /^w/i, /^p/i, /^l/i, /^g/i],
      any: [/^st/i, /^lu/i, /^mar/i, /^k/i, /^maj/i, /^c/i, /^lip/i, /^si/i, /^w/i, /^p/i, /^lis/i, /^g/i]
    };
    var matchDayPatterns$4 = {
      narrow: /^[npwścs]/i,
      short: /^(nie|pon|wto|(ś|s)ro|czw|pi(ą|a)|sob)/i,
      abbreviated: /^(niedz|pon|wt|(ś|s)r|czw|pt|sob)\.?/i,
      wide: /^(niedziela|poniedzia(ł|l)ek|wtorek|(ś|s)roda|czwartek|pi(ą|a)tek|sobota)/i
    };
    var parseDayPatterns$4 = {
      narrow: [/^n/i, /^p/i, /^w/i, /^ś/i, /^c/i, /^p/i, /^s/i],
      abbreviated: [/^n/i, /^po/i, /^w/i, /^(ś|s)r/i, /^c/i, /^pt/i, /^so/i],
      any: [/^n/i, /^po/i, /^w/i, /^(ś|s)r/i, /^c/i, /^pi/i, /^so/i]
    };
    var matchDayPeriodPatterns$4 = {
      narrow: /^(^a$|^p$|pó(ł|l)n\.?|o\s*pó(ł|l)n\.?|po(ł|l)\.?|w\s*po(ł|l)\.?|po\s*po(ł|l)\.?|rano|wiecz\.?|noc|w\s*nocy)/i,
      any: /^(am|pm|pó(ł|l)noc|o\s*pó(ł|l)nocy|po(ł|l)udnie|w\s*po(ł|l)udnie|popo(ł|l)udnie|po\s*po(ł|l)udniu|rano|wieczór|wieczorem|noc|w\s*nocy)/i
    };
    var parseDayPeriodPatterns$4 = {
      narrow: {
        am: /^a$/i,
        pm: /^p$/i,
        midnight: /pó(ł|l)n/i,
        noon: /po(ł|l)/i,
        morning: /rano/i,
        afternoon: /po\s*po(ł|l)/i,
        evening: /wiecz/i,
        night: /noc/i
      },
      any: {
        am: /^am/i,
        pm: /^pm/i,
        midnight: /pó(ł|l)n/i,
        noon: /po(ł|l)/i,
        morning: /rano/i,
        afternoon: /po\s*po(ł|l)/i,
        evening: /wiecz/i,
        night: /noc/i
      }
    };
    var match$5 = {
      ordinalNumber: buildMatchPatternFn$1({
        matchPattern: matchOrdinalNumberPattern$4,
        parsePattern: parseOrdinalNumberPattern$4,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn$1({
        matchPatterns: matchEraPatterns$4,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$4,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn$1({
        matchPatterns: matchQuarterPatterns$4,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$4,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn$1({
        matchPatterns: matchMonthPatterns$4,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$4,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn$1({
        matchPatterns: matchDayPatterns$4,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$4,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn$1({
        matchPatterns: matchDayPeriodPatterns$4,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$4,
        defaultParseWidth: 'any'
      })
    };

    /**
     * @type {Locale}
     * @category Locales
     * @summary Polish locale.
     * @language Polish
     * @iso-639-2 pol
     * @author Mateusz Derks [@ertrzyiks]{@link https://github.com/ertrzyiks}
     * @author Just RAG [@justrag]{@link https://github.com/justrag}
     * @author Mikolaj Grzyb [@mikolajgrzyb]{@link https://github.com/mikolajgrzyb}
     * @author Mateusz Tokarski [@mutisz]{@link https://github.com/mutisz}
     */

    var locale$4 = {
      code: 'pl',
      formatDistance: formatDistance$5,
      formatLong: formatLong$5,
      formatRelative: formatRelative$5,
      localize: localize$5,
      match: match$5,
      options: {
        weekStartsOn: 1
        /* Monday */
        ,
        firstWeekContainsDate: 4
      }
    };

    const datePlPL = {
      name: "pl-PL",
      locale: locale$4
    };
    var datePlPL$1 = datePlPL;

    var formatDistanceLocale$3 = {
      lessThanXSeconds: {
        one: 'menos de um segundo',
        other: 'menos de {{count}} segundos'
      },
      xSeconds: {
        one: '1 segundo',
        other: '{{count}} segundos'
      },
      halfAMinute: 'meio minuto',
      lessThanXMinutes: {
        one: 'menos de um minuto',
        other: 'menos de {{count}} minutos'
      },
      xMinutes: {
        one: '1 minuto',
        other: '{{count}} minutos'
      },
      aboutXHours: {
        one: 'cerca de 1 hora',
        other: 'cerca de {{count}} horas'
      },
      xHours: {
        one: '1 hora',
        other: '{{count}} horas'
      },
      xDays: {
        one: '1 dia',
        other: '{{count}} dias'
      },
      aboutXWeeks: {
        one: 'cerca de 1 semana',
        other: 'cerca de {{count}} semanas'
      },
      xWeeks: {
        one: '1 semana',
        other: '{{count}} semanas'
      },
      aboutXMonths: {
        one: 'cerca de 1 mês',
        other: 'cerca de {{count}} meses'
      },
      xMonths: {
        one: '1 mês',
        other: '{{count}} meses'
      },
      aboutXYears: {
        one: 'cerca de 1 ano',
        other: 'cerca de {{count}} anos'
      },
      xYears: {
        one: '1 ano',
        other: '{{count}} anos'
      },
      overXYears: {
        one: 'mais de 1 ano',
        other: 'mais de {{count}} anos'
      },
      almostXYears: {
        one: 'quase 1 ano',
        other: 'quase {{count}} anos'
      }
    };

    var formatDistance$4 = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$3[token];

      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }

      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return 'em ' + result;
        } else {
          return 'há ' + result;
        }
      }

      return result;
    };

    var dateFormats$3 = {
      full: "EEEE, d 'de' MMMM 'de' y",
      long: "d 'de' MMMM 'de' y",
      medium: 'd MMM y',
      short: 'dd/MM/yyyy'
    };
    var timeFormats$3 = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$3 = {
      full: "{{date}} 'às' {{time}}",
      long: "{{date}} 'às' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$4 = {
      date: buildFormatLongFn$1({
        formats: dateFormats$3,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn$1({
        formats: timeFormats$3,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn$1({
        formats: dateTimeFormats$3,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$3 = {
      lastWeek: function (date) {
        var weekday = date.getUTCDay();
        var last = weekday === 0 || weekday === 6 ? 'último' : 'última';
        return "'" + last + "' eeee 'às' p";
      },
      yesterday: "'ontem às' p",
      today: "'hoje às' p",
      tomorrow: "'amanhã às' p",
      nextWeek: "eeee 'às' p",
      other: 'P'
    };

    var formatRelative$4 = function (token, date, _baseDate, _options) {
      var format = formatRelativeLocale$3[token];

      if (typeof format === 'function') {
        return format(date);
      }

      return format;
    };

    var eraValues$3 = {
      narrow: ['AC', 'DC'],
      abbreviated: ['AC', 'DC'],
      wide: ['antes de cristo', 'depois de cristo']
    };
    var quarterValues$3 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['T1', 'T2', 'T3', 'T4'],
      wide: ['1º trimestre', '2º trimestre', '3º trimestre', '4º trimestre']
    };
    var monthValues$3 = {
      narrow: ['j', 'f', 'm', 'a', 'm', 'j', 'j', 'a', 's', 'o', 'n', 'd'],
      abbreviated: ['jan', 'fev', 'mar', 'abr', 'mai', 'jun', 'jul', 'ago', 'set', 'out', 'nov', 'dez'],
      wide: ['janeiro', 'fevereiro', 'março', 'abril', 'maio', 'junho', 'julho', 'agosto', 'setembro', 'outubro', 'novembro', 'dezembro']
    };
    var dayValues$3 = {
      narrow: ['D', 'S', 'T', 'Q', 'Q', 'S', 'S'],
      short: ['dom', 'seg', 'ter', 'qua', 'qui', 'sex', 'sab'],
      abbreviated: ['domingo', 'segunda', 'terça', 'quarta', 'quinta', 'sexta', 'sábado'],
      wide: ['domingo', 'segunda-feira', 'terça-feira', 'quarta-feira', 'quinta-feira', 'sexta-feira', 'sábado']
    };
    var dayPeriodValues$3 = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'mn',
        noon: 'md',
        morning: 'manhã',
        afternoon: 'tarde',
        evening: 'tarde',
        night: 'noite'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'meia-noite',
        noon: 'meio-dia',
        morning: 'manhã',
        afternoon: 'tarde',
        evening: 'tarde',
        night: 'noite'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'meia-noite',
        noon: 'meio-dia',
        morning: 'manhã',
        afternoon: 'tarde',
        evening: 'tarde',
        night: 'noite'
      }
    };
    var formattingDayPeriodValues$2 = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'mn',
        noon: 'md',
        morning: 'da manhã',
        afternoon: 'da tarde',
        evening: 'da tarde',
        night: 'da noite'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'meia-noite',
        noon: 'meio-dia',
        morning: 'da manhã',
        afternoon: 'da tarde',
        evening: 'da tarde',
        night: 'da noite'
      },
      wide: {
        am: 'a.m.',
        pm: 'p.m.',
        midnight: 'meia-noite',
        noon: 'meio-dia',
        morning: 'da manhã',
        afternoon: 'da tarde',
        evening: 'da tarde',
        night: 'da noite'
      }
    };

    var ordinalNumber$3 = function (dirtyNumber, options) {
      var number = Number(dirtyNumber);

      if ((options === null || options === void 0 ? void 0 : options.unit) === 'week') {
        return number + 'ª';
      }

      return number + 'º';
    };

    var localize$4 = {
      ordinalNumber: ordinalNumber$3,
      era: buildLocalizeFn$1({
        values: eraValues$3,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn$1({
        values: quarterValues$3,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn$1({
        values: monthValues$3,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn$1({
        values: dayValues$3,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn$1({
        values: dayPeriodValues$3,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$2,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$3 = /^(\d+)[ºªo]?/i;
    var parseOrdinalNumberPattern$3 = /\d+/i;
    var matchEraPatterns$3 = {
      narrow: /^(ac|dc|a|d)/i,
      abbreviated: /^(a\.?\s?c\.?|d\.?\s?c\.?)/i,
      wide: /^(antes de cristo|depois de cristo)/i
    };
    var parseEraPatterns$3 = {
      any: [/^ac/i, /^dc/i],
      wide: [/^antes de cristo/i, /^depois de cristo/i]
    };
    var matchQuarterPatterns$3 = {
      narrow: /^[1234]/i,
      abbreviated: /^T[1234]/i,
      wide: /^[1234](º)? trimestre/i
    };
    var parseQuarterPatterns$3 = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$3 = {
      narrow: /^[jfmajsond]/i,
      abbreviated: /^(jan|fev|mar|abr|mai|jun|jul|ago|set|out|nov|dez)/i,
      wide: /^(janeiro|fevereiro|março|abril|maio|junho|julho|agosto|setembro|outubro|novembro|dezembro)/i
    };
    var parseMonthPatterns$3 = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^fev/i, /^mar/i, /^abr/i, /^mai/i, /^jun/i, /^jul/i, /^ago/i, /^set/i, /^out/i, /^nov/i, /^dez/i]
    };
    var matchDayPatterns$3 = {
      narrow: /^(dom|[23456]ª?|s[aá]b)/i,
      short: /^(dom|[23456]ª?|s[aá]b)/i,
      abbreviated: /^(dom|seg|ter|qua|qui|sex|s[aá]b)/i,
      wide: /^(domingo|(segunda|ter[cç]a|quarta|quinta|sexta)([- ]feira)?|s[aá]bado)/i
    };
    var parseDayPatterns$3 = {
      short: [/^d/i, /^2/i, /^3/i, /^4/i, /^5/i, /^6/i, /^s[aá]/i],
      narrow: [/^d/i, /^2/i, /^3/i, /^4/i, /^5/i, /^6/i, /^s[aá]/i],
      any: [/^d/i, /^seg/i, /^t/i, /^qua/i, /^qui/i, /^sex/i, /^s[aá]b/i]
    };
    var matchDayPeriodPatterns$3 = {
      narrow: /^(a|p|mn|md|(da) (manhã|tarde|noite))/i,
      any: /^([ap]\.?\s?m\.?|meia[-\s]noite|meio[-\s]dia|(da) (manhã|tarde|noite))/i
    };
    var parseDayPeriodPatterns$3 = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^mn|^meia[-\s]noite/i,
        noon: /^md|^meio[-\s]dia/i,
        morning: /manhã/i,
        afternoon: /tarde/i,
        evening: /tarde/i,
        night: /noite/i
      }
    };
    var match$4 = {
      ordinalNumber: buildMatchPatternFn$1({
        matchPattern: matchOrdinalNumberPattern$3,
        parsePattern: parseOrdinalNumberPattern$3,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn$1({
        matchPatterns: matchEraPatterns$3,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$3,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn$1({
        matchPatterns: matchQuarterPatterns$3,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$3,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn$1({
        matchPatterns: matchMonthPatterns$3,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$3,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn$1({
        matchPatterns: matchDayPatterns$3,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$3,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn$1({
        matchPatterns: matchDayPeriodPatterns$3,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$3,
        defaultParseWidth: 'any'
      })
    };

    /**
     * @type {Locale}
     * @category Locales
     * @summary Portuguese locale (Brazil).
     * @language Portuguese
     * @iso-639-2 por
     * @author Lucas Duailibe [@duailibe]{@link https://github.com/duailibe}
     * @author Yago Carballo [@yagocarballo]{@link https://github.com/YagoCarballo}
     */

    var locale$3 = {
      code: 'pt-BR',
      formatDistance: formatDistance$4,
      formatLong: formatLong$4,
      formatRelative: formatRelative$4,
      localize: localize$4,
      match: match$4,
      options: {
        weekStartsOn: 0
        /* Sunday */
        ,
        firstWeekContainsDate: 1
      }
    };

    const datePtBr = {
      name: "pt-BR",
      locale: locale$3
    };
    var datePtBr$1 = datePtBr;

    var formatDistanceLocale$2 = {
      lessThanXSeconds: {
        one: 'น้อยกว่า 1 วินาที',
        other: 'น้อยกว่า {{count}} วินาที'
      },
      xSeconds: {
        one: '1 วินาที',
        other: '{{count}} วินาที'
      },
      halfAMinute: 'ครึ่งนาที',
      lessThanXMinutes: {
        one: 'น้อยกว่า 1 นาที',
        other: 'น้อยกว่า {{count}} นาที'
      },
      xMinutes: {
        one: '1 นาที',
        other: '{{count}} นาที'
      },
      aboutXHours: {
        one: 'ประมาณ 1 ชั่วโมง',
        other: 'ประมาณ {{count}} ชั่วโมง'
      },
      xHours: {
        one: '1 ชั่วโมง',
        other: '{{count}} ชั่วโมง'
      },
      xDays: {
        one: '1 วัน',
        other: '{{count}} วัน'
      },
      aboutXWeeks: {
        one: 'ประมาณ 1 สัปดาห์',
        other: 'ประมาณ {{count}} สัปดาห์'
      },
      xWeeks: {
        one: '1 สัปดาห์',
        other: '{{count}} สัปดาห์'
      },
      aboutXMonths: {
        one: 'ประมาณ 1 เดือน',
        other: 'ประมาณ {{count}} เดือน'
      },
      xMonths: {
        one: '1 เดือน',
        other: '{{count}} เดือน'
      },
      aboutXYears: {
        one: 'ประมาณ 1 ปี',
        other: 'ประมาณ {{count}} ปี'
      },
      xYears: {
        one: '1 ปี',
        other: '{{count}} ปี'
      },
      overXYears: {
        one: 'มากกว่า 1 ปี',
        other: 'มากกว่า {{count}} ปี'
      },
      almostXYears: {
        one: 'เกือบ 1 ปี',
        other: 'เกือบ {{count}} ปี'
      }
    };

    var formatDistance$3 = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$2[token];

      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }

      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          if (token === 'halfAMinute') {
            return 'ใน' + result;
          } else {
            return 'ใน ' + result;
          }
        } else {
          return result + 'ที่ผ่านมา';
        }
      }

      return result;
    };

    var dateFormats$2 = {
      full: 'วันEEEEที่ do MMMM y',
      long: 'do MMMM y',
      medium: 'd MMM y',
      short: 'dd/MM/yyyy'
    };
    var timeFormats$2 = {
      full: 'H:mm:ss น. zzzz',
      long: 'H:mm:ss น. z',
      medium: 'H:mm:ss น.',
      short: 'H:mm น.'
    };
    var dateTimeFormats$2 = {
      full: "{{date}} 'เวลา' {{time}}",
      long: "{{date}} 'เวลา' {{time}}",
      medium: '{{date}}, {{time}}',
      short: '{{date}}, {{time}}'
    };
    var formatLong$3 = {
      date: buildFormatLongFn$1({
        formats: dateFormats$2,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn$1({
        formats: timeFormats$2,
        defaultWidth: 'medium'
      }),
      dateTime: buildFormatLongFn$1({
        formats: dateTimeFormats$2,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale$2 = {
      lastWeek: "eeee'ที่แล้วเวลา' p",
      yesterday: "'เมื่อวานนี้เวลา' p",
      today: "'วันนี้เวลา' p",
      tomorrow: "'พรุ่งนี้เวลา' p",
      nextWeek: "eeee 'เวลา' p",
      other: 'P'
    };

    var formatRelative$3 = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$2[token];
    };

    var eraValues$2 = {
      narrow: ['B', 'คศ'],
      abbreviated: ['BC', 'ค.ศ.'],
      wide: ['ปีก่อนคริสตกาล', 'คริสต์ศักราช']
    };
    var quarterValues$2 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['ไตรมาสแรก', 'ไตรมาสที่สอง', 'ไตรมาสที่สาม', 'ไตรมาสที่สี่']
    };
    var dayValues$2 = {
      narrow: ['อา.', 'จ.', 'อ.', 'พ.', 'พฤ.', 'ศ.', 'ส.'],
      short: ['อา.', 'จ.', 'อ.', 'พ.', 'พฤ.', 'ศ.', 'ส.'],
      abbreviated: ['อา.', 'จ.', 'อ.', 'พ.', 'พฤ.', 'ศ.', 'ส.'],
      wide: ['อาทิตย์', 'จันทร์', 'อังคาร', 'พุธ', 'พฤหัสบดี', 'ศุกร์', 'เสาร์']
    };
    var monthValues$2 = {
      narrow: ['ม.ค.', 'ก.พ.', 'มี.ค.', 'เม.ย.', 'พ.ค.', 'มิ.ย.', 'ก.ค.', 'ส.ค.', 'ก.ย.', 'ต.ค.', 'พ.ย.', 'ธ.ค.'],
      abbreviated: ['ม.ค.', 'ก.พ.', 'มี.ค.', 'เม.ย.', 'พ.ค.', 'มิ.ย.', 'ก.ค.', 'ส.ค.', 'ก.ย.', 'ต.ค.', 'พ.ย.', 'ธ.ค.'],
      wide: ['มกราคม', 'กุมภาพันธ์', 'มีนาคม', 'เมษายน', 'พฤษภาคม', 'มิถุนายน', 'กรกฎาคม', 'สิงหาคม', 'กันยายน', 'ตุลาคม', 'พฤศจิกายน', 'ธันวาคม']
    };
    var dayPeriodValues$2 = {
      narrow: {
        am: 'ก่อนเที่ยง',
        pm: 'หลังเที่ยง',
        midnight: 'เที่ยงคืน',
        noon: 'เที่ยง',
        morning: 'เช้า',
        afternoon: 'บ่าย',
        evening: 'เย็น',
        night: 'กลางคืน'
      },
      abbreviated: {
        am: 'ก่อนเที่ยง',
        pm: 'หลังเที่ยง',
        midnight: 'เที่ยงคืน',
        noon: 'เที่ยง',
        morning: 'เช้า',
        afternoon: 'บ่าย',
        evening: 'เย็น',
        night: 'กลางคืน'
      },
      wide: {
        am: 'ก่อนเที่ยง',
        pm: 'หลังเที่ยง',
        midnight: 'เที่ยงคืน',
        noon: 'เที่ยง',
        morning: 'เช้า',
        afternoon: 'บ่าย',
        evening: 'เย็น',
        night: 'กลางคืน'
      }
    };
    var formattingDayPeriodValues$1 = {
      narrow: {
        am: 'ก่อนเที่ยง',
        pm: 'หลังเที่ยง',
        midnight: 'เที่ยงคืน',
        noon: 'เที่ยง',
        morning: 'ตอนเช้า',
        afternoon: 'ตอนกลางวัน',
        evening: 'ตอนเย็น',
        night: 'ตอนกลางคืน'
      },
      abbreviated: {
        am: 'ก่อนเที่ยง',
        pm: 'หลังเที่ยง',
        midnight: 'เที่ยงคืน',
        noon: 'เที่ยง',
        morning: 'ตอนเช้า',
        afternoon: 'ตอนกลางวัน',
        evening: 'ตอนเย็น',
        night: 'ตอนกลางคืน'
      },
      wide: {
        am: 'ก่อนเที่ยง',
        pm: 'หลังเที่ยง',
        midnight: 'เที่ยงคืน',
        noon: 'เที่ยง',
        morning: 'ตอนเช้า',
        afternoon: 'ตอนกลางวัน',
        evening: 'ตอนเย็น',
        night: 'ตอนกลางคืน'
      }
    };

    var ordinalNumber$2 = function (dirtyNumber, _options) {
      return String(dirtyNumber);
    };

    var localize$3 = {
      ordinalNumber: ordinalNumber$2,
      era: buildLocalizeFn$1({
        values: eraValues$2,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn$1({
        values: quarterValues$2,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn$1({
        values: monthValues$2,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn$1({
        values: dayValues$2,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn$1({
        values: dayPeriodValues$2,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues$1,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$2 = /^\d+/i;
    var parseOrdinalNumberPattern$2 = /\d+/i;
    var matchEraPatterns$2 = {
      narrow: /^([bB]|[aA]|คศ)/i,
      abbreviated: /^([bB]\.?\s?[cC]\.?|b\.?\s?c\.?\s?e\.?|a\.?\s?d\.?|c\.?\s?e\.?|ค\.?ศ\.?)/i,
      wide: /^(ก่อนคริสตกาล|คริสต์ศักราช|คริสตกาล)/i
    };
    var parseEraPatterns$2 = {
      any: [/^[bB]/i, /^(^[aA]|ค\.?ศ\.?|คริสตกาล|คริสต์ศักราช|)/i]
    };
    var matchQuarterPatterns$2 = {
      narrow: /^[1234]/i,
      abbreviated: /^q[1234]/i,
      wide: /^ไตรมาส(ที่)? ?[1234]/i
    };
    var parseQuarterPatterns$2 = {
      any: [/(1|แรก|หนึ่ง)/i, /(2|สอง)/i, /(3|สาม)/i, /(4|สี่)/i]
    };
    var matchMonthPatterns$2 = {
      narrow: /^(ม\.?ค\.?|ก\.?พ\.?|มี\.?ค\.?|เม\.?ย\.?|พ\.?ค\.?|มิ\.?ย\.?|ก\.?ค\.?|ส\.?ค\.?|ก\.?ย\.?|ต\.?ค\.?|พ\.?ย\.?|ธ\.?ค\.?)/i,
      abbreviated: /^(ม\.?ค\.?|ก\.?พ\.?|มี\.?ค\.?|เม\.?ย\.?|พ\.?ค\.?|มิ\.?ย\.?|ก\.?ค\.?|ส\.?ค\.?|ก\.?ย\.?|ต\.?ค\.?|พ\.?ย\.?|ธ\.?ค\.?')/i,
      wide: /^(มกราคม|กุมภาพันธ์|มีนาคม|เมษายน|พฤษภาคม|มิถุนายน|กรกฎาคม|สิงหาคม|กันยายน|ตุลาคม|พฤศจิกายน|ธันวาคม)/i
    };
    var parseMonthPatterns$2 = {
      wide: [/^มก/i, /^กุม/i, /^มี/i, /^เม/i, /^พฤษ/i, /^มิ/i, /^กรก/i, /^ส/i, /^กัน/i, /^ต/i, /^พฤศ/i, /^ธ/i],
      any: [/^ม\.?ค\.?/i, /^ก\.?พ\.?/i, /^มี\.?ค\.?/i, /^เม\.?ย\.?/i, /^พ\.?ค\.?/i, /^มิ\.?ย\.?/i, /^ก\.?ค\.?/i, /^ส\.?ค\.?/i, /^ก\.?ย\.?/i, /^ต\.?ค\.?/i, /^พ\.?ย\.?/i, /^ธ\.?ค\.?/i]
    };
    var matchDayPatterns$2 = {
      narrow: /^(อา\.?|จ\.?|อ\.?|พฤ\.?|พ\.?|ศ\.?|ส\.?)/i,
      short: /^(อา\.?|จ\.?|อ\.?|พฤ\.?|พ\.?|ศ\.?|ส\.?)/i,
      abbreviated: /^(อา\.?|จ\.?|อ\.?|พฤ\.?|พ\.?|ศ\.?|ส\.?)/i,
      wide: /^(อาทิตย์|จันทร์|อังคาร|พุธ|พฤหัสบดี|ศุกร์|เสาร์)/i
    };
    var parseDayPatterns$2 = {
      wide: [/^อา/i, /^จั/i, /^อั/i, /^พุธ/i, /^พฤ/i, /^ศ/i, /^เส/i],
      any: [/^อา/i, /^จ/i, /^อ/i, /^พ(?!ฤ)/i, /^พฤ/i, /^ศ/i, /^ส/i]
    };
    var matchDayPeriodPatterns$2 = {
      any: /^(ก่อนเที่ยง|หลังเที่ยง|เที่ยงคืน|เที่ยง|(ตอน.*?)?.*(เที่ยง|เช้า|บ่าย|เย็น|กลางคืน))/i
    };
    var parseDayPeriodPatterns$2 = {
      any: {
        am: /^ก่อนเที่ยง/i,
        pm: /^หลังเที่ยง/i,
        midnight: /^เที่ยงคืน/i,
        noon: /^เที่ยง/i,
        morning: /เช้า/i,
        afternoon: /บ่าย/i,
        evening: /เย็น/i,
        night: /กลางคืน/i
      }
    };
    var match$3 = {
      ordinalNumber: buildMatchPatternFn$1({
        matchPattern: matchOrdinalNumberPattern$2,
        parsePattern: parseOrdinalNumberPattern$2,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn$1({
        matchPatterns: matchEraPatterns$2,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$2,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn$1({
        matchPatterns: matchQuarterPatterns$2,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$2,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn$1({
        matchPatterns: matchMonthPatterns$2,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$2,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn$1({
        matchPatterns: matchDayPatterns$2,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$2,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn$1({
        matchPatterns: matchDayPeriodPatterns$2,
        defaultMatchWidth: 'any',
        parsePatterns: parseDayPeriodPatterns$2,
        defaultParseWidth: 'any'
      })
    };

    /**
     * @type {Locale}
     * @category Locales
     * @summary Thai locale.
     * @language Thai
     * @iso-639-2 tha
     * @author Athiwat Hirunworawongkun [@athivvat]{@link https://github.com/athivvat}
     * @author [@hawkup]{@link https://github.com/hawkup}
     * @author  Jirawat I. [@nodtem66]{@link https://github.com/nodtem66}
     */

    var locale$2 = {
      code: 'th',
      formatDistance: formatDistance$3,
      formatLong: formatLong$3,
      formatRelative: formatRelative$3,
      localize: localize$3,
      match: match$3,
      options: {
        weekStartsOn: 0
        /* Sunday */
        ,
        firstWeekContainsDate: 1
      }
    };

    const dateThTH = {
      name: "thTH",
      locale: locale$2
    };
    var dateThTH$1 = dateThTH;

    var formatDistanceLocale$1 = {
      lessThanXSeconds: {
        one: 'malpli ol sekundo',
        other: 'malpli ol {{count}} sekundoj'
      },
      xSeconds: {
        one: '1 sekundo',
        other: '{{count}} sekundoj'
      },
      halfAMinute: 'duonminuto',
      lessThanXMinutes: {
        one: 'malpli ol minuto',
        other: 'malpli ol {{count}} minutoj'
      },
      xMinutes: {
        one: '1 minuto',
        other: '{{count}} minutoj'
      },
      aboutXHours: {
        one: 'proksimume 1 horo',
        other: 'proksimume {{count}} horoj'
      },
      xHours: {
        one: '1 horo',
        other: '{{count}} horoj'
      },
      xDays: {
        one: '1 tago',
        other: '{{count}} tagoj'
      },
      aboutXMonths: {
        one: 'proksimume 1 monato',
        other: 'proksimume {{count}} monatoj'
      },
      xWeeks: {
        one: '1 semajno',
        other: '{{count}} semajnoj'
      },
      aboutXWeeks: {
        one: 'proksimume 1 semajno',
        other: 'proksimume {{count}} semajnoj'
      },
      xMonths: {
        one: '1 monato',
        other: '{{count}} monatoj'
      },
      aboutXYears: {
        one: 'proksimume 1 jaro',
        other: 'proksimume {{count}} jaroj'
      },
      xYears: {
        one: '1 jaro',
        other: '{{count}} jaroj'
      },
      overXYears: {
        one: 'pli ol 1 jaro',
        other: 'pli ol {{count}} jaroj'
      },
      almostXYears: {
        one: 'preskaŭ 1 jaro',
        other: 'preskaŭ {{count}} jaroj'
      }
    };

    var formatDistance$2 = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale$1[token];

      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }

      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options !== null && options !== void 0 && options.comparison && options.comparison > 0) {
          return 'post ' + result;
        } else {
          return 'antaŭ ' + result;
        }
      }

      return result;
    };

    var dateFormats$1 = {
      full: "EEEE, do 'de' MMMM y",
      long: 'y-MMMM-dd',
      medium: 'y-MMM-dd',
      short: 'yyyy-MM-dd'
    };
    var timeFormats$1 = {
      full: "Ho 'horo kaj' m:ss zzzz",
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats$1 = {
      any: '{{date}} {{time}}'
    };
    var formatLong$2 = {
      date: buildFormatLongFn$1({
        formats: dateFormats$1,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn$1({
        formats: timeFormats$1,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn$1({
        formats: dateTimeFormats$1,
        defaultWidth: 'any'
      })
    };

    var formatRelativeLocale$1 = {
      lastWeek: "'pasinta' eeee 'je' p",
      yesterday: "'hieraŭ je' p",
      today: "'hodiaŭ je' p",
      tomorrow: "'morgaŭ je' p",
      nextWeek: "eeee 'je' p",
      other: 'P'
    };

    var formatRelative$2 = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale$1[token];
    };

    var eraValues$1 = {
      narrow: ['aK', 'pK'],
      abbreviated: ['a.K.E.', 'p.K.E.'],
      wide: ['antaŭ Komuna Erao', 'Komuna Erao']
    };
    var quarterValues$1 = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['K1', 'K2', 'K3', 'K4'],
      wide: ['1-a kvaronjaro', '2-a kvaronjaro', '3-a kvaronjaro', '4-a kvaronjaro']
    };
    var monthValues$1 = {
      narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
      abbreviated: ['jan', 'feb', 'mar', 'apr', 'maj', 'jun', 'jul', 'aŭg', 'sep', 'okt', 'nov', 'dec'],
      wide: ['januaro', 'februaro', 'marto', 'aprilo', 'majo', 'junio', 'julio', 'aŭgusto', 'septembro', 'oktobro', 'novembro', 'decembro']
    };
    var dayValues$1 = {
      narrow: ['D', 'L', 'M', 'M', 'Ĵ', 'V', 'S'],
      short: ['di', 'lu', 'ma', 'me', 'ĵa', 've', 'sa'],
      abbreviated: ['dim', 'lun', 'mar', 'mer', 'ĵaŭ', 'ven', 'sab'],
      wide: ['dimanĉo', 'lundo', 'mardo', 'merkredo', 'ĵaŭdo', 'vendredo', 'sabato']
    };
    var dayPeriodValues$1 = {
      narrow: {
        am: 'a',
        pm: 'p',
        midnight: 'noktomezo',
        noon: 'tagmezo',
        morning: 'matene',
        afternoon: 'posttagmeze',
        evening: 'vespere',
        night: 'nokte'
      },
      abbreviated: {
        am: 'a.t.m.',
        pm: 'p.t.m.',
        midnight: 'noktomezo',
        noon: 'tagmezo',
        morning: 'matene',
        afternoon: 'posttagmeze',
        evening: 'vespere',
        night: 'nokte'
      },
      wide: {
        am: 'antaŭtagmeze',
        pm: 'posttagmeze',
        midnight: 'noktomezo',
        noon: 'tagmezo',
        morning: 'matene',
        afternoon: 'posttagmeze',
        evening: 'vespere',
        night: 'nokte'
      }
    };

    var ordinalNumber$1 = function (dirtyNumber) {
      var number = Number(dirtyNumber);
      return number + '-a';
    };

    var localize$2 = {
      ordinalNumber: ordinalNumber$1,
      era: buildLocalizeFn$1({
        values: eraValues$1,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn$1({
        values: quarterValues$1,
        defaultWidth: 'wide',
        argumentCallback: function (quarter) {
          return Number(quarter) - 1;
        }
      }),
      month: buildLocalizeFn$1({
        values: monthValues$1,
        defaultWidth: 'wide'
      }),
      day: buildLocalizeFn$1({
        values: dayValues$1,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn$1({
        values: dayPeriodValues$1,
        defaultWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern$1 = /^(\d+)(-?a)?/i;
    var parseOrdinalNumberPattern$1 = /\d+/i;
    var matchEraPatterns$1 = {
      narrow: /^([ap]k)/i,
      abbreviated: /^([ap]\.?\s?k\.?\s?e\.?)/i,
      wide: /^((antaǔ |post )?komuna erao)/i
    };
    var parseEraPatterns$1 = {
      any: [/^a/i, /^[kp]/i]
    };
    var matchQuarterPatterns$1 = {
      narrow: /^[1234]/i,
      abbreviated: /^k[1234]/i,
      wide: /^[1234](-?a)? kvaronjaro/i
    };
    var parseQuarterPatterns$1 = {
      any: [/1/i, /2/i, /3/i, /4/i]
    };
    var matchMonthPatterns$1 = {
      narrow: /^[jfmasond]/i,
      abbreviated: /^(jan|feb|mar|apr|maj|jun|jul|a(ŭ|ux|uh|u)g|sep|okt|nov|dec)/i,
      wide: /^(januaro|februaro|marto|aprilo|majo|junio|julio|a(ŭ|ux|uh|u)gusto|septembro|oktobro|novembro|decembro)/i
    };
    var parseMonthPatterns$1 = {
      narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
      any: [/^ja/i, /^f/i, /^mar/i, /^ap/i, /^maj/i, /^jun/i, /^jul/i, /^a(u|ŭ)/i, /^s/i, /^o/i, /^n/i, /^d/i]
    };
    var matchDayPatterns$1 = {
      narrow: /^[dlmĵjvs]/i,
      short: /^(di|lu|ma|me|(ĵ|jx|jh|j)a|ve|sa)/i,
      abbreviated: /^(dim|lun|mar|mer|(ĵ|jx|jh|j)a(ŭ|ux|uh|u)|ven|sab)/i,
      wide: /^(diman(ĉ|cx|ch|c)o|lundo|mardo|merkredo|(ĵ|jx|jh|j)a(ŭ|ux|uh|u)do|vendredo|sabato)/i
    };
    var parseDayPatterns$1 = {
      narrow: [/^d/i, /^l/i, /^m/i, /^m/i, /^(j|ĵ)/i, /^v/i, /^s/i],
      any: [/^d/i, /^l/i, /^ma/i, /^me/i, /^(j|ĵ)/i, /^v/i, /^s/i]
    };
    var matchDayPeriodPatterns$1 = {
      narrow: /^([ap]|(posttagmez|noktomez|tagmez|maten|vesper|nokt)[eo])/i,
      abbreviated: /^([ap][.\s]?t[.\s]?m[.\s]?|(posttagmez|noktomez|tagmez|maten|vesper|nokt)[eo])/i,
      wide: /^(anta(ŭ|ux)tagmez|posttagmez|noktomez|tagmez|maten|vesper|nokt)[eo]/i
    };
    var parseDayPeriodPatterns$1 = {
      any: {
        am: /^a/i,
        pm: /^p/i,
        midnight: /^noktom/i,
        noon: /^t/i,
        morning: /^m/i,
        afternoon: /^posttagmeze/i,
        evening: /^v/i,
        night: /^n/i
      }
    };
    var match$2 = {
      ordinalNumber: buildMatchPatternFn$1({
        matchPattern: matchOrdinalNumberPattern$1,
        parsePattern: parseOrdinalNumberPattern$1,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn$1({
        matchPatterns: matchEraPatterns$1,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns$1,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn$1({
        matchPatterns: matchQuarterPatterns$1,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns$1,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn$1({
        matchPatterns: matchMonthPatterns$1,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns$1,
        defaultParseWidth: 'any'
      }),
      day: buildMatchFn$1({
        matchPatterns: matchDayPatterns$1,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns$1,
        defaultParseWidth: 'any'
      }),
      dayPeriod: buildMatchFn$1({
        matchPatterns: matchDayPeriodPatterns$1,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPeriodPatterns$1,
        defaultParseWidth: 'any'
      })
    };

    /**
     * @type {Locale}
     * @category Locales
     * @summary Esperanto locale.
     * @language Esperanto
     * @iso-639-2 epo
     * @author date-fns
     */

    var locale$1 = {
      code: 'eo',
      formatDistance: formatDistance$2,
      formatLong: formatLong$2,
      formatRelative: formatRelative$2,
      localize: localize$2,
      match: match$2,
      options: {
        weekStartsOn: 1
        /* Monday */
        ,
        firstWeekContainsDate: 4
      }
    };

    const dateEo = {
      name: "eo",
      locale: locale$1
    };
    var dateEo$1 = dateEo;

    var formatDistanceLocale = {
      lessThanXSeconds: {
        one: 'dưới 1 giây',
        other: 'dưới {{count}} giây'
      },
      xSeconds: {
        one: '1 giây',
        other: '{{count}} giây'
      },
      halfAMinute: 'nửa phút',
      lessThanXMinutes: {
        one: 'dưới 1 phút',
        other: 'dưới {{count}} phút'
      },
      xMinutes: {
        one: '1 phút',
        other: '{{count}} phút'
      },
      aboutXHours: {
        one: 'khoảng 1 giờ',
        other: 'khoảng {{count}} giờ'
      },
      xHours: {
        one: '1 giờ',
        other: '{{count}} giờ'
      },
      xDays: {
        one: '1 ngày',
        other: '{{count}} ngày'
      },
      aboutXWeeks: {
        one: 'khoảng 1 tuần',
        other: 'khoảng {{count}} tuần'
      },
      xWeeks: {
        one: '1 tuần',
        other: '{{count}} tuần'
      },
      aboutXMonths: {
        one: 'khoảng 1 tháng',
        other: 'khoảng {{count}} tháng'
      },
      xMonths: {
        one: '1 tháng',
        other: '{{count}} tháng'
      },
      aboutXYears: {
        one: 'khoảng 1 năm',
        other: 'khoảng {{count}} năm'
      },
      xYears: {
        one: '1 năm',
        other: '{{count}} năm'
      },
      overXYears: {
        one: 'hơn 1 năm',
        other: 'hơn {{count}} năm'
      },
      almostXYears: {
        one: 'gần 1 năm',
        other: 'gần {{count}} năm'
      }
    };

    var formatDistance$1 = function (token, count, options) {
      var result;
      var tokenValue = formatDistanceLocale[token];

      if (typeof tokenValue === 'string') {
        result = tokenValue;
      } else if (count === 1) {
        result = tokenValue.one;
      } else {
        result = tokenValue.other.replace('{{count}}', String(count));
      }

      if (options !== null && options !== void 0 && options.addSuffix) {
        if (options.comparison && options.comparison > 0) {
          return result + ' nữa';
        } else {
          return result + ' trước';
        }
      }

      return result;
    };

    var dateFormats = {
      // thứ Sáu, ngày 25 tháng 08 năm 2017
      full: "EEEE, 'ngày' d MMMM 'năm' y",
      // ngày 25 tháng 08 năm 2017
      long: "'ngày' d MMMM 'năm' y",
      // 25 thg 08 năm 2017
      medium: "d MMM 'năm' y",
      // 25/08/2017
      short: 'dd/MM/y'
    };
    var timeFormats = {
      full: 'HH:mm:ss zzzz',
      long: 'HH:mm:ss z',
      medium: 'HH:mm:ss',
      short: 'HH:mm'
    };
    var dateTimeFormats = {
      // thứ Sáu, ngày 25 tháng 08 năm 2017 23:25:59
      full: '{{date}} {{time}}',
      // ngày 25 tháng 08 năm 2017 23:25
      long: '{{date}} {{time}}',
      medium: '{{date}} {{time}}',
      short: '{{date}} {{time}}'
    };
    var formatLong$1 = {
      date: buildFormatLongFn$1({
        formats: dateFormats,
        defaultWidth: 'full'
      }),
      time: buildFormatLongFn$1({
        formats: timeFormats,
        defaultWidth: 'full'
      }),
      dateTime: buildFormatLongFn$1({
        formats: dateTimeFormats,
        defaultWidth: 'full'
      })
    };

    var formatRelativeLocale = {
      lastWeek: "eeee 'tuần trước vào lúc' p",
      yesterday: "'hôm qua vào lúc' p",
      today: "'hôm nay vào lúc' p",
      tomorrow: "'ngày mai vào lúc' p",
      nextWeek: "eeee 'tới vào lúc' p",
      other: 'P'
    };

    var formatRelative$1 = function (token, _date, _baseDate, _options) {
      return formatRelativeLocale[token];
    };

    // Capitalization reference: http://hcmup.edu.vn/index.php?option=com_content&view=article&id=4106%3Avit-hoa-trong-vn-bn-hanh-chinh&catid=2345%3Atham-kho&Itemid=4103&lang=vi&site=134

    var eraValues = {
      narrow: ['TCN', 'SCN'],
      abbreviated: ['trước CN', 'sau CN'],
      wide: ['trước Công Nguyên', 'sau Công Nguyên']
    };
    var quarterValues = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      wide: ['Quý 1', 'Quý 2', 'Quý 3', 'Quý 4']
    };
    var formattingQuarterValues = {
      narrow: ['1', '2', '3', '4'],
      abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
      // I notice many news outlet use this "quý II/2018"
      wide: ['quý I', 'quý II', 'quý III', 'quý IV']
    }; // Note: in English, the names of days of the week and months are capitalized.
    // If you are making a new locale based on this one, check if the same is true for the language you're working on.
    // Generally, formatted dates should look like they are in the middle of a sentence,
    // e.g. in Spanish language the weekdays and months should be in the lowercase.

    var monthValues = {
      narrow: ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12'],
      abbreviated: ['Thg 1', 'Thg 2', 'Thg 3', 'Thg 4', 'Thg 5', 'Thg 6', 'Thg 7', 'Thg 8', 'Thg 9', 'Thg 10', 'Thg 11', 'Thg 12'],
      wide: ['Tháng Một', 'Tháng Hai', 'Tháng Ba', 'Tháng Tư', 'Tháng Năm', 'Tháng Sáu', 'Tháng Bảy', 'Tháng Tám', 'Tháng Chín', 'Tháng Mười', 'Tháng Mười Một', 'Tháng Mười Hai']
    }; // In Vietnamese date formatting, month number less than 10 expected to have leading zero

    var formattingMonthValues = {
      narrow: ['01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12'],
      abbreviated: ['thg 1', 'thg 2', 'thg 3', 'thg 4', 'thg 5', 'thg 6', 'thg 7', 'thg 8', 'thg 9', 'thg 10', 'thg 11', 'thg 12'],
      wide: ['tháng 01', 'tháng 02', 'tháng 03', 'tháng 04', 'tháng 05', 'tháng 06', 'tháng 07', 'tháng 08', 'tháng 09', 'tháng 10', 'tháng 11', 'tháng 12']
    };
    var dayValues = {
      narrow: ['CN', 'T2', 'T3', 'T4', 'T5', 'T6', 'T7'],
      short: ['CN', 'Th 2', 'Th 3', 'Th 4', 'Th 5', 'Th 6', 'Th 7'],
      abbreviated: ['CN', 'Thứ 2', 'Thứ 3', 'Thứ 4', 'Thứ 5', 'Thứ 6', 'Thứ 7'],
      wide: ['Chủ Nhật', 'Thứ Hai', 'Thứ Ba', 'Thứ Tư', 'Thứ Năm', 'Thứ Sáu', 'Thứ Bảy']
    }; // Vietnamese are used to AM/PM borrowing from English, hence `narrow` and
    // `abbreviated` are just like English but I'm leaving the `wide`
    // format being localized with abbreviations found in some systems (SÁng / CHiều);
    // however, personally, I don't think `Chiều` sounds appropriate for `PM`

    var dayPeriodValues = {
      // narrow date period is extremely rare in Vietnamese
      // I used abbreviated form for noon, morning and afternoon
      // which are regconizable by Vietnamese, others cannot be any shorter
      narrow: {
        am: 'am',
        pm: 'pm',
        midnight: 'nửa đêm',
        noon: 'tr',
        morning: 'sg',
        afternoon: 'ch',
        evening: 'tối',
        night: 'đêm'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'nửa đêm',
        noon: 'trưa',
        morning: 'sáng',
        afternoon: 'chiều',
        evening: 'tối',
        night: 'đêm'
      },
      wide: {
        am: 'SA',
        pm: 'CH',
        midnight: 'nửa đêm',
        noon: 'trưa',
        morning: 'sáng',
        afternoon: 'chiều',
        evening: 'tối',
        night: 'đêm'
      }
    };
    var formattingDayPeriodValues = {
      narrow: {
        am: 'am',
        pm: 'pm',
        midnight: 'nửa đêm',
        noon: 'tr',
        morning: 'sg',
        afternoon: 'ch',
        evening: 'tối',
        night: 'đêm'
      },
      abbreviated: {
        am: 'AM',
        pm: 'PM',
        midnight: 'nửa đêm',
        noon: 'trưa',
        morning: 'sáng',
        afternoon: 'chiều',
        evening: 'tối',
        night: 'đêm'
      },
      wide: {
        am: 'SA',
        pm: 'CH',
        midnight: 'nửa đêm',
        noon: 'giữa trưa',
        morning: 'vào buổi sáng',
        afternoon: 'vào buổi chiều',
        evening: 'vào buổi tối',
        night: 'vào ban đêm'
      }
    };

    var ordinalNumber = function (dirtyNumber, options) {
      var number = Number(dirtyNumber);
      var unit = options === null || options === void 0 ? void 0 : options.unit;

      if (unit === 'quarter') {
        // many news outlets use "quý I"...
        switch (number) {
          case 1:
            return 'I';

          case 2:
            return 'II';

          case 3:
            return 'III';

          case 4:
            return 'IV';
        }
      } else if (unit === 'day') {
        // day of week in Vietnamese has ordinal number meaning,
        // so we should use them, else it'll sound weird
        switch (number) {
          case 1:
            return 'thứ 2';
          // meaning 2nd day but it's the first day of the week :D

          case 2:
            return 'thứ 3';
          // meaning 3rd day

          case 3:
            return 'thứ 4';
          // meaning 4th day and so on

          case 4:
            return 'thứ 5';

          case 5:
            return 'thứ 6';

          case 6:
            return 'thứ 7';

          case 7:
            return 'chủ nhật';
          // meaning Sunday, there's no 8th day :D
        }
      } else if (unit === 'week') {
        if (number === 1) {
          return 'thứ nhất';
        } else {
          return 'thứ ' + number;
        }
      } else if (unit === 'dayOfYear') {
        if (number === 1) {
          return 'đầu tiên';
        } else {
          return 'thứ ' + number;
        }
      } // there are no different forms of ordinal numbers in Vietnamese


      return String(number);
    };

    var localize$1 = {
      ordinalNumber: ordinalNumber,
      era: buildLocalizeFn$1({
        values: eraValues,
        defaultWidth: 'wide'
      }),
      quarter: buildLocalizeFn$1({
        values: quarterValues,
        defaultWidth: 'wide',
        formattingValues: formattingQuarterValues,
        defaultFormattingWidth: 'wide',
        argumentCallback: function (quarter) {
          return quarter - 1;
        }
      }),
      month: buildLocalizeFn$1({
        values: monthValues,
        defaultWidth: 'wide',
        formattingValues: formattingMonthValues,
        defaultFormattingWidth: 'wide'
      }),
      day: buildLocalizeFn$1({
        values: dayValues,
        defaultWidth: 'wide'
      }),
      dayPeriod: buildLocalizeFn$1({
        values: dayPeriodValues,
        defaultWidth: 'wide',
        formattingValues: formattingDayPeriodValues,
        defaultFormattingWidth: 'wide'
      })
    };

    var matchOrdinalNumberPattern = /^(\d+)/i;
    var parseOrdinalNumberPattern = /\d+/i;
    var matchEraPatterns = {
      narrow: /^(tcn|scn)/i,
      abbreviated: /^(trước CN|sau CN)/i,
      wide: /^(trước Công Nguyên|sau Công Nguyên)/i
    };
    var parseEraPatterns = {
      any: [/^t/i, /^s/i]
    };
    var matchQuarterPatterns = {
      narrow: /^([1234]|i{1,3}v?)/i,
      abbreviated: /^q([1234]|i{1,3}v?)/i,
      wide: /^quý ([1234]|i{1,3}v?)/i
    };
    var parseQuarterPatterns = {
      any: [/(1|i)$/i, /(2|ii)$/i, /(3|iii)$/i, /(4|iv)$/i]
    };
    var matchMonthPatterns = {
      // month number may contain leading 0, 'thg' prefix may have space, underscore or empty before number
      // note the order of '1' since it is a sub-string of '10', so must be lower priority
      narrow: /^(0?[2-9]|10|11|12|0?1)/i,
      // note the order of 'thg 1' since it is sub-string of 'thg 10', so must be lower priority
      abbreviated: /^thg[ _]?(0?[1-9](?!\d)|10|11|12)/i,
      // note the order of 'Mười' since it is sub-string of Mười Một, so must be lower priority
      wide: /^tháng ?(Một|Hai|Ba|Tư|Năm|Sáu|Bảy|Tám|Chín|Mười|Mười ?Một|Mười ?Hai|0?[1-9](?!\d)|10|11|12)/i
    };
    var parseMonthPatterns = {
      narrow: [/0?1$/i, /0?2/i, /3/, /4/, /5/, /6/, /7/, /8/, /9/, /10/, /11/, /12/],
      abbreviated: [/^thg[ _]?0?1(?!\d)/i, /^thg[ _]?0?2/i, /^thg[ _]?0?3/i, /^thg[ _]?0?4/i, /^thg[ _]?0?5/i, /^thg[ _]?0?6/i, /^thg[ _]?0?7/i, /^thg[ _]?0?8/i, /^thg[ _]?0?9/i, /^thg[ _]?10/i, /^thg[ _]?11/i, /^thg[ _]?12/i],
      wide: [/^tháng ?(Một|0?1(?!\d))/i, /^tháng ?(Hai|0?2)/i, /^tháng ?(Ba|0?3)/i, /^tháng ?(Tư|0?4)/i, /^tháng ?(Năm|0?5)/i, /^tháng ?(Sáu|0?6)/i, /^tháng ?(Bảy|0?7)/i, /^tháng ?(Tám|0?8)/i, /^tháng ?(Chín|0?9)/i, /^tháng ?(Mười|10)/i, /^tháng ?(Mười ?Một|11)/i, /^tháng ?(Mười ?Hai|12)/i]
    };
    var matchDayPatterns = {
      narrow: /^(CN|T2|T3|T4|T5|T6|T7)/i,
      short: /^(CN|Th ?2|Th ?3|Th ?4|Th ?5|Th ?6|Th ?7)/i,
      abbreviated: /^(CN|Th ?2|Th ?3|Th ?4|Th ?5|Th ?6|Th ?7)/i,
      wide: /^(Chủ ?Nhật|Chúa ?Nhật|thứ ?Hai|thứ ?Ba|thứ ?Tư|thứ ?Năm|thứ ?Sáu|thứ ?Bảy)/i
    };
    var parseDayPatterns = {
      narrow: [/CN/i, /2/i, /3/i, /4/i, /5/i, /6/i, /7/i],
      short: [/CN/i, /2/i, /3/i, /4/i, /5/i, /6/i, /7/i],
      abbreviated: [/CN/i, /2/i, /3/i, /4/i, /5/i, /6/i, /7/i],
      wide: [/(Chủ|Chúa) ?Nhật/i, /Hai/i, /Ba/i, /Tư/i, /Năm/i, /Sáu/i, /Bảy/i]
    };
    var matchDayPeriodPatterns = {
      narrow: /^(a|p|nửa đêm|trưa|(giờ) (sáng|chiều|tối|đêm))/i,
      abbreviated: /^(am|pm|nửa đêm|trưa|(giờ) (sáng|chiều|tối|đêm))/i,
      wide: /^(ch[^i]*|sa|nửa đêm|trưa|(giờ) (sáng|chiều|tối|đêm))/i
    };
    var parseDayPeriodPatterns = {
      any: {
        am: /^(a|sa)/i,
        pm: /^(p|ch[^i]*)/i,
        midnight: /nửa đêm/i,
        noon: /trưa/i,
        morning: /sáng/i,
        afternoon: /chiều/i,
        evening: /tối/i,
        night: /^đêm/i
      }
    };
    var match$1 = {
      ordinalNumber: buildMatchPatternFn$1({
        matchPattern: matchOrdinalNumberPattern,
        parsePattern: parseOrdinalNumberPattern,
        valueCallback: function (value) {
          return parseInt(value, 10);
        }
      }),
      era: buildMatchFn$1({
        matchPatterns: matchEraPatterns,
        defaultMatchWidth: 'wide',
        parsePatterns: parseEraPatterns,
        defaultParseWidth: 'any'
      }),
      quarter: buildMatchFn$1({
        matchPatterns: matchQuarterPatterns,
        defaultMatchWidth: 'wide',
        parsePatterns: parseQuarterPatterns,
        defaultParseWidth: 'any',
        valueCallback: function (index) {
          return index + 1;
        }
      }),
      month: buildMatchFn$1({
        matchPatterns: matchMonthPatterns,
        defaultMatchWidth: 'wide',
        parsePatterns: parseMonthPatterns,
        defaultParseWidth: 'wide'
      }),
      day: buildMatchFn$1({
        matchPatterns: matchDayPatterns,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPatterns,
        defaultParseWidth: 'wide'
      }),
      dayPeriod: buildMatchFn$1({
        matchPatterns: matchDayPeriodPatterns,
        defaultMatchWidth: 'wide',
        parsePatterns: parseDayPeriodPatterns,
        defaultParseWidth: 'any'
      })
    };

    /**
     * @type {Locale}
     * @category Locales
     * @summary Vietnamese locale (Vietnam).
     * @language Vietnamese
     * @iso-639-2 vie
     * @author Thanh Tran [@trongthanh]{@link https://github.com/trongthanh}
     * @author Leroy Hopson [@lihop]{@link https://github.com/lihop}
     */

    var locale = {
      code: 'vi',
      formatDistance: formatDistance$1,
      formatLong: formatLong$1,
      formatRelative: formatRelative$1,
      localize: localize$1,
      match: match$1,
      options: {
        weekStartsOn: 1
        /* Monday */
        ,
        firstWeekContainsDate: 1
        /* First week of new year contains Jan 1st  */

      }
    };

    const dateVi = {
      name: "vi-VN",
      locale: locale
    };
    var dateVi$1 = dateVi;

    function createLocale(locale, fallbackLocale) {
      return lodash.exports.merge({}, fallbackLocale, locale);
    }

    function useLocale(ns) {
      const {
        mergedLocaleRef,
        mergedDateLocaleRef
      } = vue.inject(configProviderInjectionKey, null) || {};
      const localeRef = vue.computed(() => {
        var _mergedLocaleRef$valu;

        return (mergedLocaleRef === null || mergedLocaleRef === void 0 ? void 0 : (_mergedLocaleRef$valu = mergedLocaleRef.value) === null || _mergedLocaleRef$valu === void 0 ? void 0 : _mergedLocaleRef$valu[ns]) ?? enUS$2[ns];
      });
      const dateLocaleRef = vue.computed(() => {
        return (mergedDateLocaleRef === null || mergedDateLocaleRef === void 0 ? void 0 : mergedDateLocaleRef.value) ?? dateEnUS;
      });
      return {
        dateLocaleRef,
        localeRef
      };
    }

    function useStyle(mountId, style, clsPrefixRef) {
      if (!style) {
        throwError("use-style", "No style is specified.");
        return;
      }

      const ssrAdapter = useSsrAdapter();
      const NConfigProvider = vue.inject(configProviderInjectionKey, null);

      const mountStyle = () => {
        const clsPrefix = clsPrefixRef === null || clsPrefixRef === void 0 ? void 0 : clsPrefixRef.value;
        style.mount({
          id: clsPrefix === void 0 ? mountId : clsPrefix + mountId,
          head: true,
          anchorMetaName: cssrAnchorMetaName,
          props: {
            bPrefix: clsPrefix ? `.${clsPrefix}-` : void 0
          },
          ssr: ssrAdapter
        });

        if (!(NConfigProvider !== null && NConfigProvider !== void 0 && NConfigProvider.preflightStyleDisabled)) {
          globalStyle.mount({
            id: "n-global",
            head: true,
            anchorMetaName: cssrAnchorMetaName,
            ssr: ssrAdapter
          });
        }
      };

      if (ssrAdapter) {
        mountStyle();
      } else {
        vue.onBeforeMount(mountStyle);
      }
    }

    function useHljs(props, shouldHighlightRef) {
      const NConfigProvider = vue.inject(configProviderInjectionKey, null);

      {
        const warnHljs = () => {
          if (!props.hljs && !(NConfigProvider !== null && NConfigProvider !== void 0 && NConfigProvider.mergedHljsRef.value)) {
            warn$2("code", "hljs is not set.");
          }
        };

        if (!shouldHighlightRef) {
          warnHljs();
        } else {
          vue.watchEffect(() => {
            if (shouldHighlightRef.value) {
              warnHljs();
            }
          });
        }
      }

      return vue.computed(() => {
        return props.hljs || (NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.mergedHljsRef.value);
      });
    }

    function useThemeClass(componentName, hashRef, cssVarsRef, props) {
      var _inject;

      if (!cssVarsRef) throwError("useThemeClass", "cssVarsRef is not passed");
      const mergedThemeHashRef = (_inject = vue.inject(configProviderInjectionKey, null)) === null || _inject === void 0 ? void 0 : _inject.mergedThemeHashRef;
      const themeClassRef = vue.ref("");
      const ssrAdapter = useSsrAdapter();
      let renderCallback;
      const hashClassPrefix = `__${componentName}`;

      const mountStyle = () => {
        let finalThemeHash = hashClassPrefix;
        const hashValue = hashRef ? hashRef.value : void 0;
        const themeHash = mergedThemeHashRef === null || mergedThemeHashRef === void 0 ? void 0 : mergedThemeHashRef.value;
        if (themeHash) finalThemeHash += "-" + themeHash;
        if (hashValue) finalThemeHash += "-" + hashValue;
        const {
          themeOverrides,
          builtinThemeOverrides
        } = props;

        if (themeOverrides) {
          finalThemeHash += "-" + murmur2(JSON.stringify(themeOverrides));
        }

        if (builtinThemeOverrides) {
          finalThemeHash += "-" + murmur2(JSON.stringify(builtinThemeOverrides));
        }

        themeClassRef.value = finalThemeHash;

        renderCallback = () => {
          const cssVars = cssVarsRef.value;
          let style = "";

          for (const key in cssVars) {
            style += `${key}: ${cssVars[key]};`;
          }

          c$1(`.${finalThemeHash}`, style).mount({
            id: finalThemeHash,
            ssr: ssrAdapter
          });
          renderCallback = void 0;
        };
      };

      vue.watchEffect(() => {
        mountStyle();
      });
      return {
        themeClass: themeClassRef,
        onRender: () => {
          var _renderCallback;

          (_renderCallback = renderCallback) === null || _renderCallback === void 0 ? void 0 : _renderCallback();
        }
      };
    }

    function useRtl(mountId, rtlStateRef, clsPrefixRef) {
      if (!rtlStateRef) return void 0;
      const ssrAdapter = useSsrAdapter();
      const componentRtlStateRef = vue.computed(() => {
        const {
          value: rtlState
        } = rtlStateRef;

        if (!rtlState) {
          return void 0;
        }

        const componentRtlState = rtlState[mountId];

        if (!componentRtlState) {
          return void 0;
        }

        return componentRtlState;
      });

      const mountStyle = () => {
        vue.watchEffect(() => {
          const {
            value: clsPrefix
          } = clsPrefixRef;
          const id = `${clsPrefix}${mountId}Rtl`;
          if (exists(id, ssrAdapter)) return;
          const {
            value: componentRtlState
          } = componentRtlStateRef;
          if (!componentRtlState) return;
          componentRtlState.style.mount({
            id,
            head: true,
            anchorMetaName: cssrAnchorMetaName,
            props: {
              bPrefix: clsPrefix ? `.${clsPrefix}-` : void 0
            },
            ssr: ssrAdapter
          });
        });
      };

      if (ssrAdapter) {
        mountStyle();
      } else {
        vue.onBeforeMount(mountStyle);
      }

      return componentRtlStateRef;
    }

    function getScrollTop(target) {
      return target instanceof HTMLElement ? target.scrollTop : window.scrollY;
    }
    function getRect(target) {
      return target instanceof HTMLElement ? target.getBoundingClientRect() : {
        top: 0,
        bottom: window.innerHeight
      };
    }

    var style$1z = cB("affix", [cM("affixed", {
      position: "fixed"
    }, [cM("absolute-positioned", {
      position: "absolute"
    })])]);

    const affixProps = {
      listenTo: [String, Object, Function],
      top: Number,
      bottom: Number,
      triggerTop: Number,
      triggerBottom: Number,
      position: {
        type: String,
        default: "fix"
      },
      offsetTop: {
        type: Number,
        validator: () => {
          {
            warn$2(
              "affix",
              "`offset-top` is deprecated, please use `trigger-top` instead."
            );
          }
          return true;
        },
        default: void 0
      },
      offsetBottom: {
        type: Number,
        validator: () => {
          {
            warn$2(
              "affix",
              "`offset-bottom` is deprecated, please use `trigger-bottom` instead."
            );
          }
          return true;
        },
        default: void 0
      },
      target: {
        type: Function,
        validator: () => {
          {
            warn$2("affix", "`target` is deprecated, please use `listen-to` instead.");
          }
          return true;
        },
        default: void 0
      }
    };
    const affixPropKeys = keysOf(affixProps);
    var NAffix = vue.defineComponent({
      name: "Affix",
      props: affixProps,
      setup(props) {
        const { mergedClsPrefixRef } = useConfig(props);
        useStyle("-affix", style$1z, mergedClsPrefixRef);
        let scrollTarget = null;
        const stickToTopRef = vue.ref(false);
        const stickToBottomRef = vue.ref(false);
        const bottomAffixedTriggerScrollTopRef = vue.ref(null);
        const topAffixedTriggerScrollTopRef = vue.ref(null);
        const affixedRef = vue.computed(() => {
          return stickToBottomRef.value || stickToTopRef.value;
        });
        const mergedOffsetTopRef = vue.computed(() => {
          return props.triggerTop ?? props.offsetTop ?? props.top;
        });
        const mergedTopRef = vue.computed(() => {
          return props.top ?? props.triggerTop ?? props.offsetTop;
        });
        const mergedBottomRef = vue.computed(() => {
          return props.bottom ?? props.triggerBottom ?? props.offsetBottom;
        });
        const mergedOffsetBottomRef = vue.computed(() => {
          return props.triggerBottom ?? props.offsetBottom ?? props.bottom;
        });
        const selfRef = vue.ref(null);
        const init = () => {
          const { target: getScrollTarget, listenTo } = props;
          if (getScrollTarget) {
            scrollTarget = getScrollTarget();
          } else if (listenTo) {
            scrollTarget = unwrapElement(listenTo);
          } else {
            scrollTarget = document;
          }
          if (scrollTarget) {
            scrollTarget.addEventListener("scroll", handleScroll);
            handleScroll();
          } else {
            warn$2("affix", "Target to be listened to is not valid.");
          }
        };
        function handleScroll() {
          beforeNextFrameOnce(_handleScroll);
        }
        function _handleScroll() {
          const { value: selfEl } = selfRef;
          if (!scrollTarget || !selfEl)
            return;
          const scrollTop = getScrollTop(scrollTarget);
          if (affixedRef.value) {
            if (scrollTop < topAffixedTriggerScrollTopRef.value) {
              stickToTopRef.value = false;
              topAffixedTriggerScrollTopRef.value = null;
            }
            if (scrollTop > bottomAffixedTriggerScrollTopRef.value) {
              stickToBottomRef.value = false;
              bottomAffixedTriggerScrollTopRef.value = null;
            }
            return;
          }
          const containerRect = getRect(scrollTarget);
          const affixRect = selfEl.getBoundingClientRect();
          const pxToTop = affixRect.top - containerRect.top;
          const pxToBottom = containerRect.bottom - affixRect.bottom;
          const mergedOffsetTop = mergedOffsetTopRef.value;
          const mergedOffsetBottom = mergedOffsetBottomRef.value;
          if (mergedOffsetTop !== void 0 && pxToTop <= mergedOffsetTop) {
            stickToTopRef.value = true;
            topAffixedTriggerScrollTopRef.value = scrollTop - (mergedOffsetTop - pxToTop);
          } else {
            stickToTopRef.value = false;
            topAffixedTriggerScrollTopRef.value = null;
          }
          if (mergedOffsetBottom !== void 0 && pxToBottom <= mergedOffsetBottom) {
            stickToBottomRef.value = true;
            bottomAffixedTriggerScrollTopRef.value = scrollTop + mergedOffsetBottom - pxToBottom;
          } else {
            stickToBottomRef.value = false;
            bottomAffixedTriggerScrollTopRef.value = null;
          }
        }
        vue.onMounted(() => {
          init();
        });
        vue.onBeforeUnmount(() => {
          if (!scrollTarget)
            return;
          scrollTarget.removeEventListener("scroll", handleScroll);
        });
        return {
          selfRef,
          affixed: affixedRef,
          mergedClsPrefix: mergedClsPrefixRef,
          mergedstyle: vue.computed(() => {
            const style2 = {};
            if (stickToTopRef.value && mergedOffsetTopRef.value !== void 0 && mergedTopRef.value !== void 0) {
              style2.top = `${mergedTopRef.value}px`;
            }
            if (stickToBottomRef.value && mergedOffsetBottomRef.value !== void 0 && mergedBottomRef.value !== void 0) {
              style2.bottom = `${mergedBottomRef.value}px`;
            }
            return style2;
          })
        };
      },
      render() {
        const { mergedClsPrefix } = this;
        return /* @__PURE__ */ React.createElement("div", {
          ref: "selfRef",
          class: [
            `${mergedClsPrefix}-affix`,
            {
              [`${mergedClsPrefix}-affix--affixed`]: this.affixed,
              [`${mergedClsPrefix}-affix--absolute-positioned`]: this.position === "absolute"
            }
          ],
          style: this.mergedstyle
        }, this.$slots);
      }
    });

    var AddIcon = vue.defineComponent({
      name: "Add",
      render() {
        return /* @__PURE__ */ React.createElement("svg", {
          width: "512",
          height: "512",
          viewBox: "0 0 512 512",
          fill: "none",
          xmlns: "http://www.w3.org/2000/svg"
        }, /* @__PURE__ */ React.createElement("path", {
          d: "M256 112V400M400 256H112",
          stroke: "currentColor",
          "stroke-width": "32",
          "stroke-linecap": "round",
          "stroke-linejoin": "round"
        }));
      }
    });

    var ArrowDownIcon = vue.defineComponent({
      name: "ArrowDown",
      render() {
        return /* @__PURE__ */ React.createElement("svg", {
          viewBox: "0 0 28 28",
          version: "1.1",
          xmlns: "http://www.w3.org/2000/svg"
        }, /* @__PURE__ */ React.createElement("g", {
          stroke: "none",
          "stroke-width": "1",
          "fill-rule": "evenodd"
        }, /* @__PURE__ */ React.createElement("g", {
          "fill-rule": "nonzero"
        }, /* @__PURE__ */ React.createElement("path", {
          d: "M23.7916,15.2664 C24.0788,14.9679 24.0696,14.4931 23.7711,14.206 C23.4726,13.9188 22.9978,13.928 22.7106,14.2265 L14.7511,22.5007 L14.7511,3.74792 C14.7511,3.33371 14.4153,2.99792 14.0011,2.99792 C13.5869,2.99792 13.2511,3.33371 13.2511,3.74793 L13.2511,22.4998 L5.29259,14.2265 C5.00543,13.928 4.53064,13.9188 4.23213,14.206 C3.93361,14.4931 3.9244,14.9679 4.21157,15.2664 L13.2809,24.6944 C13.6743,25.1034 14.3289,25.1034 14.7223,24.6944 L23.7916,15.2664 Z"
        }))));
      }
    });

    var ArrowUpIcon = vue.defineComponent({
      name: "ArrowUp",
      render() {
        return /* @__PURE__ */ React.createElement("svg", {
          xmlns: "http://www.w3.org/2000/svg",
          viewBox: "0 0 20 20"
        }, /* @__PURE__ */ React.createElement("g", {
          fill: "none"
        }, /* @__PURE__ */ React.createElement("path", {
          d: "M3.13 9.163a.5.5 0 1 0 .74.674L9.5 3.67V17.5a.5.5 0 0 0 1 0V3.672l5.63 6.165a.5.5 0 0 0 .738-.674l-6.315-6.916a.746.746 0 0 0-.632-.24a.746.746 0 0 0-.476.24L3.131 9.163z",
          fill: "currentColor"
        })));
      }
    });

    function replaceable(name, icon) {
      return vue.defineComponent({
        name: lodash.exports.upperFirst(name),
        setup() {
          const mergedIconsRef = vue.inject(
            configProviderInjectionKey,
            null
          )?.mergedIconsRef;
          return () => {
            const iconOverride = mergedIconsRef?.value?.[name];
            return iconOverride ? iconOverride() : icon;
          };
        }
      });
    }

    var AttachIcon = replaceable(
      "attach",
      /* @__PURE__ */ React.createElement("svg", {
        viewBox: "0 0 16 16",
        version: "1.1",
        xmlns: "http://www.w3.org/2000/svg"
      }, /* @__PURE__ */ React.createElement("g", {
        stroke: "none",
        "stroke-width": "1",
        fill: "none",
        "fill-rule": "evenodd"
      }, /* @__PURE__ */ React.createElement("g", {
        fill: "currentColor",
        "fill-rule": "nonzero"
      }, /* @__PURE__ */ React.createElement("path", {
        d: "M3.25735931,8.70710678 L7.85355339,4.1109127 C8.82986412,3.13460197 10.4127766,3.13460197 11.3890873,4.1109127 C12.365398,5.08722343 12.365398,6.67013588 11.3890873,7.64644661 L6.08578644,12.9497475 C5.69526215,13.3402718 5.06209717,13.3402718 4.67157288,12.9497475 C4.28104858,12.5592232 4.28104858,11.9260582 4.67157288,11.5355339 L9.97487373,6.23223305 C10.1701359,6.0369709 10.1701359,5.72038841 9.97487373,5.52512627 C9.77961159,5.32986412 9.4630291,5.32986412 9.26776695,5.52512627 L3.96446609,10.8284271 C3.18341751,11.6094757 3.18341751,12.8758057 3.96446609,13.6568542 C4.74551468,14.4379028 6.01184464,14.4379028 6.79289322,13.6568542 L12.0961941,8.35355339 C13.4630291,6.98671837 13.4630291,4.77064094 12.0961941,3.40380592 C10.7293591,2.0369709 8.51328163,2.0369709 7.14644661,3.40380592 L2.55025253,8 C2.35499039,8.19526215 2.35499039,8.51184464 2.55025253,8.70710678 C2.74551468,8.90236893 3.06209717,8.90236893 3.25735931,8.70710678 Z"
      }))))
    );

    var BackwardIcon = vue.defineComponent({
      name: "Backward",
      render() {
        return /* @__PURE__ */ React.createElement("svg", {
          viewBox: "0 0 20 20",
          fill: "none",
          xmlns: "http://www.w3.org/2000/svg"
        }, /* @__PURE__ */ React.createElement("path", {
          d: "M12.2674 15.793C11.9675 16.0787 11.4927 16.0672 11.2071 15.7673L6.20572 10.5168C5.9298 10.2271 5.9298 9.7719 6.20572 9.48223L11.2071 4.23177C11.4927 3.93184 11.9675 3.92031 12.2674 4.206C12.5673 4.49169 12.5789 4.96642 12.2932 5.26634L7.78458 9.99952L12.2932 14.7327C12.5789 15.0326 12.5673 15.5074 12.2674 15.793Z",
          fill: "currentColor"
        }));
      }
    });

    var DateIcon = replaceable(
      "date",
      /* @__PURE__ */ React.createElement("svg", {
        width: "28px",
        height: "28px",
        viewBox: "0 0 28 28",
        version: "1.1",
        xmlns: "http://www.w3.org/2000/svg"
      }, /* @__PURE__ */ React.createElement("g", {
        stroke: "none",
        "stroke-width": "1",
        "fill-rule": "evenodd"
      }, /* @__PURE__ */ React.createElement("g", {
        "fill-rule": "nonzero"
      }, /* @__PURE__ */ React.createElement("path", {
        d: "M21.75,3 C23.5449254,3 25,4.45507456 25,6.25 L25,21.75 C25,23.5449254 23.5449254,25 21.75,25 L6.25,25 C4.45507456,25 3,23.5449254 3,21.75 L3,6.25 C3,4.45507456 4.45507456,3 6.25,3 L21.75,3 Z M23.5,9.503 L4.5,9.503 L4.5,21.75 C4.5,22.7164983 5.28350169,23.5 6.25,23.5 L21.75,23.5 C22.7164983,23.5 23.5,22.7164983 23.5,21.75 L23.5,9.503 Z M21.75,4.5 L6.25,4.5 C5.28350169,4.5 4.5,5.28350169 4.5,6.25 L4.5,8.003 L23.5,8.003 L23.5,6.25 C23.5,5.28350169 22.7164983,4.5 21.75,4.5 Z"
      }))))
    );

    var FinishedIcon = vue.defineComponent({
      name: "Checkmark",
      render() {
        return /* @__PURE__ */ React.createElement("svg", {
          xmlns: "http://www.w3.org/2000/svg",
          viewBox: "0 0 16 16"
        }, /* @__PURE__ */ React.createElement("g", {
          fill: "none"
        }, /* @__PURE__ */ React.createElement("path", {
          d: "M14.046 3.486a.75.75 0 0 1-.032 1.06l-7.93 7.474a.85.85 0 0 1-1.188-.022l-2.68-2.72a.75.75 0 1 1 1.068-1.053l2.234 2.267l7.468-7.038a.75.75 0 0 1 1.06.032z",
          fill: "currentColor"
        })));
      }
    });

    var ChevronLeftIcon = vue.defineComponent({
      name: "ChevronLeft",
      render() {
        return /* @__PURE__ */ React.createElement("svg", {
          viewBox: "0 0 16 16",
          fill: "none",
          xmlns: "http://www.w3.org/2000/svg"
        }, /* @__PURE__ */ React.createElement("path", {
          d: "M10.3536 3.14645C10.5488 3.34171 10.5488 3.65829 10.3536 3.85355L6.20711 8L10.3536 12.1464C10.5488 12.3417 10.5488 12.6583 10.3536 12.8536C10.1583 13.0488 9.84171 13.0488 9.64645 12.8536L5.14645 8.35355C4.95118 8.15829 4.95118 7.84171 5.14645 7.64645L9.64645 3.14645C9.84171 2.95118 10.1583 2.95118 10.3536 3.14645Z",
          fill: "currentColor"
        }));
      }
    });

    var ChevronRightIcon = vue.defineComponent({
      name: "ChevronRight",
      render() {
        return /* @__PURE__ */ React.createElement("svg", {
          viewBox: "0 0 16 16",
          fill: "none",
          xmlns: "http://www.w3.org/2000/svg"
        }, /* @__PURE__ */ React.createElement("path", {
          d: "M5.64645 3.14645C5.45118 3.34171 5.45118 3.65829 5.64645 3.85355L9.79289 8L5.64645 12.1464C5.45118 12.3417 5.45118 12.6583 5.64645 12.8536C5.84171 13.0488 6.15829 13.0488 6.35355 12.8536L10.8536 8.35355C11.0488 8.15829 11.0488 7.84171 10.8536 7.64645L6.35355 3.14645C6.15829 2.95118 5.84171 2.95118 5.64645 3.14645Z",
          fill: "currentColor"
        }));
      }
    });

    var ErrorIcon$1 = replaceable(
      "close",
      /* @__PURE__ */ React.createElement("svg", {
        viewBox: "0 0 12 12",
        version: "1.1",
        xmlns: "http://www.w3.org/2000/svg",
        "aria-hidden": true
      }, /* @__PURE__ */ React.createElement("g", {
        stroke: "none",
        "stroke-width": "1",
        fill: "none",
        "fill-rule": "evenodd"
      }, /* @__PURE__ */ React.createElement("g", {
        fill: "currentColor",
        "fill-rule": "nonzero"
      }, /* @__PURE__ */ React.createElement("path", {
        d: "M2.08859116,2.2156945 L2.14644661,2.14644661 C2.32001296,1.97288026 2.58943736,1.95359511 2.7843055,2.08859116 L2.85355339,2.14644661 L6,5.293 L9.14644661,2.14644661 C9.34170876,1.95118446 9.65829124,1.95118446 9.85355339,2.14644661 C10.0488155,2.34170876 10.0488155,2.65829124 9.85355339,2.85355339 L6.707,6 L9.85355339,9.14644661 C10.0271197,9.32001296 10.0464049,9.58943736 9.91140884,9.7843055 L9.85355339,9.85355339 C9.67998704,10.0271197 9.41056264,10.0464049 9.2156945,9.91140884 L9.14644661,9.85355339 L6,6.707 L2.85355339,9.85355339 C2.65829124,10.0488155 2.34170876,10.0488155 2.14644661,9.85355339 C1.95118446,9.65829124 1.95118446,9.34170876 2.14644661,9.14644661 L5.293,6 L2.14644661,2.85355339 C1.97288026,2.67998704 1.95359511,2.41056264 2.08859116,2.2156945 L2.14644661,2.14644661 L2.08859116,2.2156945 Z"
      }))))
    );

    var EyeIcon = vue.defineComponent({
      name: "Eye",
      render() {
        return /* @__PURE__ */ React.createElement("svg", {
          xmlns: "http://www.w3.org/2000/svg",
          viewBox: "0 0 512 512"
        }, /* @__PURE__ */ React.createElement("path", {
          d: "M255.66 112c-77.94 0-157.89 45.11-220.83 135.33a16 16 0 0 0-.27 17.77C82.92 340.8 161.8 400 255.66 400c92.84 0 173.34-59.38 221.79-135.25a16.14 16.14 0 0 0 0-17.47C428.89 172.28 347.8 112 255.66 112z",
          fill: "none",
          stroke: "currentColor",
          "stroke-linecap": "round",
          "stroke-linejoin": "round",
          "stroke-width": "32"
        }), /* @__PURE__ */ React.createElement("circle", {
          cx: "256",
          cy: "256",
          r: "80",
          fill: "none",
          stroke: "currentColor",
          "stroke-miterlimit": "10",
          "stroke-width": "32"
        }));
      }
    });

    var EyeOffIcon = vue.defineComponent({
      name: "EyeOff",
      render() {
        return /* @__PURE__ */ React.createElement("svg", {
          xmlns: "http://www.w3.org/2000/svg",
          viewBox: "0 0 512 512"
        }, /* @__PURE__ */ React.createElement("path", {
          d: "M432 448a15.92 15.92 0 0 1-11.31-4.69l-352-352a16 16 0 0 1 22.62-22.62l352 352A16 16 0 0 1 432 448z",
          fill: "currentColor"
        }), /* @__PURE__ */ React.createElement("path", {
          d: "M255.66 384c-41.49 0-81.5-12.28-118.92-36.5c-34.07-22-64.74-53.51-88.7-91v-.08c19.94-28.57 41.78-52.73 65.24-72.21a2 2 0 0 0 .14-2.94L93.5 161.38a2 2 0 0 0-2.71-.12c-24.92 21-48.05 46.76-69.08 76.92a31.92 31.92 0 0 0-.64 35.54c26.41 41.33 60.4 76.14 98.28 100.65C162 402 207.9 416 255.66 416a239.13 239.13 0 0 0 75.8-12.58a2 2 0 0 0 .77-3.31l-21.58-21.58a4 4 0 0 0-3.83-1a204.8 204.8 0 0 1-51.16 6.47z",
          fill: "currentColor"
        }), /* @__PURE__ */ React.createElement("path", {
          d: "M490.84 238.6c-26.46-40.92-60.79-75.68-99.27-100.53C349 110.55 302 96 255.66 96a227.34 227.34 0 0 0-74.89 12.83a2 2 0 0 0-.75 3.31l21.55 21.55a4 4 0 0 0 3.88 1a192.82 192.82 0 0 1 50.21-6.69c40.69 0 80.58 12.43 118.55 37c34.71 22.4 65.74 53.88 89.76 91a.13.13 0 0 1 0 .16a310.72 310.72 0 0 1-64.12 72.73a2 2 0 0 0-.15 2.95l19.9 19.89a2 2 0 0 0 2.7.13a343.49 343.49 0 0 0 68.64-78.48a32.2 32.2 0 0 0-.1-34.78z",
          fill: "currentColor"
        }), /* @__PURE__ */ React.createElement("path", {
          d: "M256 160a95.88 95.88 0 0 0-21.37 2.4a2 2 0 0 0-1 3.38l112.59 112.56a2 2 0 0 0 3.38-1A96 96 0 0 0 256 160z",
          fill: "currentColor"
        }), /* @__PURE__ */ React.createElement("path", {
          d: "M165.78 233.66a2 2 0 0 0-3.38 1a96 96 0 0 0 115 115a2 2 0 0 0 1-3.38z",
          fill: "currentColor"
        }));
      }
    });

    var TrashIcon = replaceable(
      "trash",
      /* @__PURE__ */ React.createElement("svg", {
        xmlns: "http://www.w3.org/2000/svg",
        viewBox: "0 0 512 512"
      }, /* @__PURE__ */ React.createElement("path", {
        d: "M432,144,403.33,419.74A32,32,0,0,1,371.55,448H140.46a32,32,0,0,1-31.78-28.26L80,144",
        style: "fill: none; stroke: currentcolor; stroke-linecap: round; stroke-linejoin: round; stroke-width: 32px;"
      }), /* @__PURE__ */ React.createElement("rect", {
        x: "32",
        y: "64",
        width: "448",
        height: "80",
        rx: "16",
        ry: "16",
        style: "fill: none; stroke: currentcolor; stroke-linecap: round; stroke-linejoin: round; stroke-width: 32px;"
      }), /* @__PURE__ */ React.createElement("line", {
        x1: "312",
        y1: "240",
        x2: "200",
        y2: "352",
        style: "fill: none; stroke: currentcolor; stroke-linecap: round; stroke-linejoin: round; stroke-width: 32px;"
      }), /* @__PURE__ */ React.createElement("line", {
        x1: "312",
        y1: "352",
        x2: "200",
        y2: "240",
        style: "fill: none; stroke: currentcolor; stroke-linecap: round; stroke-linejoin: round; stroke-width: 32px;"
      }))
    );

    var DownloadIcon = replaceable(
      "download",
      /* @__PURE__ */ React.createElement("svg", {
        viewBox: "0 0 16 16",
        version: "1.1",
        xmlns: "http://www.w3.org/2000/svg"
      }, /* @__PURE__ */ React.createElement("g", {
        stroke: "none",
        "stroke-width": "1",
        fill: "none",
        "fill-rule": "evenodd"
      }, /* @__PURE__ */ React.createElement("g", {
        fill: "currentColor",
        "fill-rule": "nonzero"
      }, /* @__PURE__ */ React.createElement("path", {
        d: "M3.5,13 L12.5,13 C12.7761424,13 13,13.2238576 13,13.5 C13,13.7454599 12.8231248,13.9496084 12.5898756,13.9919443 L12.5,14 L3.5,14 C3.22385763,14 3,13.7761424 3,13.5 C3,13.2545401 3.17687516,13.0503916 3.41012437,13.0080557 L3.5,13 L12.5,13 L3.5,13 Z M7.91012437,1.00805567 L8,1 C8.24545989,1 8.44960837,1.17687516 8.49194433,1.41012437 L8.5,1.5 L8.5,10.292 L11.1819805,7.6109127 C11.3555469,7.43734635 11.6249713,7.4180612 11.8198394,7.55305725 L11.8890873,7.6109127 C12.0626536,7.78447906 12.0819388,8.05390346 11.9469427,8.2487716 L11.8890873,8.31801948 L8.35355339,11.8535534 C8.17998704,12.0271197 7.91056264,12.0464049 7.7156945,11.9114088 L7.64644661,11.8535534 L4.1109127,8.31801948 C3.91565056,8.12275734 3.91565056,7.80617485 4.1109127,7.6109127 C4.28447906,7.43734635 4.55390346,7.4180612 4.7487716,7.55305725 L4.81801948,7.6109127 L7.5,10.292 L7.5,1.5 C7.5,1.25454011 7.67687516,1.05039163 7.91012437,1.00805567 L8,1 L7.91012437,1.00805567 Z"
      }))))
    );

    var EmptyIcon = vue.defineComponent({
      name: "Empty",
      render() {
        return /* @__PURE__ */ React.createElement("svg", {
          viewBox: "0 0 28 28",
          fill: "none",
          xmlns: "http://www.w3.org/2000/svg"
        }, /* @__PURE__ */ React.createElement("path", {
          d: "M26 7.5C26 11.0899 23.0899 14 19.5 14C15.9101 14 13 11.0899 13 7.5C13 3.91015 15.9101 1 19.5 1C23.0899 1 26 3.91015 26 7.5ZM16.8536 4.14645C16.6583 3.95118 16.3417 3.95118 16.1464 4.14645C15.9512 4.34171 15.9512 4.65829 16.1464 4.85355L18.7929 7.5L16.1464 10.1464C15.9512 10.3417 15.9512 10.6583 16.1464 10.8536C16.3417 11.0488 16.6583 11.0488 16.8536 10.8536L19.5 8.20711L22.1464 10.8536C22.3417 11.0488 22.6583 11.0488 22.8536 10.8536C23.0488 10.6583 23.0488 10.3417 22.8536 10.1464L20.2071 7.5L22.8536 4.85355C23.0488 4.65829 23.0488 4.34171 22.8536 4.14645C22.6583 3.95118 22.3417 3.95118 22.1464 4.14645L19.5 6.79289L16.8536 4.14645Z",
          fill: "currentColor"
        }), /* @__PURE__ */ React.createElement("path", {
          d: "M25 22.75V12.5991C24.5572 13.0765 24.053 13.4961 23.5 13.8454V16H17.5L17.3982 16.0068C17.0322 16.0565 16.75 16.3703 16.75 16.75C16.75 18.2688 15.5188 19.5 14 19.5C12.4812 19.5 11.25 18.2688 11.25 16.75L11.2432 16.6482C11.1935 16.2822 10.8797 16 10.5 16H4.5V7.25C4.5 6.2835 5.2835 5.5 6.25 5.5H12.2696C12.4146 4.97463 12.6153 4.47237 12.865 4H6.25C4.45507 4 3 5.45507 3 7.25V22.75C3 24.5449 4.45507 26 6.25 26H21.75C23.5449 26 25 24.5449 25 22.75ZM4.5 22.75V17.5H9.81597L9.85751 17.7041C10.2905 19.5919 11.9808 21 14 21L14.215 20.9947C16.2095 20.8953 17.842 19.4209 18.184 17.5H23.5V22.75C23.5 23.7165 22.7165 24.5 21.75 24.5H6.25C5.2835 24.5 4.5 23.7165 4.5 22.75Z",
          fill: "currentColor"
        }));
      }
    });

    var ErrorIcon = replaceable(
      "error",
      /* @__PURE__ */ React.createElement("svg", {
        viewBox: "0 0 48 48",
        version: "1.1",
        xmlns: "http://www.w3.org/2000/svg"
      }, /* @__PURE__ */ React.createElement("g", {
        stroke: "none",
        "stroke-width": "1",
        "fill-rule": "evenodd"
      }, /* @__PURE__ */ React.createElement("g", {
        "fill-rule": "nonzero"
      }, /* @__PURE__ */ React.createElement("path", {
        d: "M24,4 C35.045695,4 44,12.954305 44,24 C44,35.045695 35.045695,44 24,44 C12.954305,44 4,35.045695 4,24 C4,12.954305 12.954305,4 24,4 Z M17.8838835,16.1161165 L17.7823881,16.0249942 C17.3266086,15.6583353 16.6733914,15.6583353 16.2176119,16.0249942 L16.1161165,16.1161165 L16.0249942,16.2176119 C15.6583353,16.6733914 15.6583353,17.3266086 16.0249942,17.7823881 L16.1161165,17.8838835 L22.233,24 L16.1161165,30.1161165 L16.0249942,30.2176119 C15.6583353,30.6733914 15.6583353,31.3266086 16.0249942,31.7823881 L16.1161165,31.8838835 L16.2176119,31.9750058 C16.6733914,32.3416647 17.3266086,32.3416647 17.7823881,31.9750058 L17.8838835,31.8838835 L24,25.767 L30.1161165,31.8838835 L30.2176119,31.9750058 C30.6733914,32.3416647 31.3266086,32.3416647 31.7823881,31.9750058 L31.8838835,31.8838835 L31.9750058,31.7823881 C32.3416647,31.3266086 32.3416647,30.6733914 31.9750058,30.2176119 L31.8838835,30.1161165 L25.767,24 L31.8838835,17.8838835 L31.9750058,17.7823881 C32.3416647,17.3266086 32.3416647,16.6733914 31.9750058,16.2176119 L31.8838835,16.1161165 L31.7823881,16.0249942 C31.3266086,15.6583353 30.6733914,15.6583353 30.2176119,16.0249942 L30.1161165,16.1161165 L24,22.233 L17.8838835,16.1161165 L17.7823881,16.0249942 L17.8838835,16.1161165 Z"
      }))))
    );

    var FastBackwardIcon = vue.defineComponent({
      name: "FastBackward",
      render() {
        return /* @__PURE__ */ React.createElement("svg", {
          viewBox: "0 0 20 20",
          version: "1.1",
          xmlns: "http://www.w3.org/2000/svg"
        }, /* @__PURE__ */ React.createElement("g", {
          stroke: "none",
          "stroke-width": "1",
          fill: "none",
          "fill-rule": "evenodd"
        }, /* @__PURE__ */ React.createElement("g", {
          fill: "currentColor",
          "fill-rule": "nonzero"
        }, /* @__PURE__ */ React.createElement("path", {
          d: "M8.73171,16.7949 C9.03264,17.0795 9.50733,17.0663 9.79196,16.7654 C10.0766,16.4644 10.0634,15.9897 9.76243,15.7051 L4.52339,10.75 L17.2471,10.75 C17.6613,10.75 17.9971,10.4142 17.9971,10 C17.9971,9.58579 17.6613,9.25 17.2471,9.25 L4.52112,9.25 L9.76243,4.29275 C10.0634,4.00812 10.0766,3.53343 9.79196,3.2325 C9.50733,2.93156 9.03264,2.91834 8.73171,3.20297 L2.31449,9.27241 C2.14819,9.4297 2.04819,9.62981 2.01448,9.8386 C2.00308,9.89058 1.99707,9.94459 1.99707,10 C1.99707,10.0576 2.00356,10.1137 2.01585,10.1675 C2.05084,10.3733 2.15039,10.5702 2.31449,10.7254 L8.73171,16.7949 Z"
        }))));
      }
    });

    var FastForwardIcon = vue.defineComponent({
      name: "FastForward",
      render() {
        return /* @__PURE__ */ React.createElement("svg", {
          viewBox: "0 0 20 20",
          version: "1.1",
          xmlns: "http://www.w3.org/2000/svg"
        }, /* @__PURE__ */ React.createElement("g", {
          stroke: "none",
          "stroke-width": "1",
          fill: "none",
          "fill-rule": "evenodd"
        }, /* @__PURE__ */ React.createElement("g", {
          fill: "currentColor",
          "fill-rule": "nonzero"
        }, /* @__PURE__ */ React.createElement("path", {
          d: "M11.2654,3.20511 C10.9644,2.92049 10.4897,2.93371 10.2051,3.23464 C9.92049,3.53558 9.93371,4.01027 10.2346,4.29489 L15.4737,9.25 L2.75,9.25 C2.33579,9.25 2,9.58579 2,10.0000012 C2,10.4142 2.33579,10.75 2.75,10.75 L15.476,10.75 L10.2346,15.7073 C9.93371,15.9919 9.92049,16.4666 10.2051,16.7675 C10.4897,17.0684 10.9644,17.0817 11.2654,16.797 L17.6826,10.7276 C17.8489,10.5703 17.9489,10.3702 17.9826,10.1614 C17.994,10.1094 18,10.0554 18,10.0000012 C18,9.94241 17.9935,9.88633 17.9812,9.83246 C17.9462,9.62667 17.8467,9.42976 17.6826,9.27455 L11.2654,3.20511 Z"
        }))));
      }
    });

    var FilterIcon = vue.defineComponent({
      name: "Filter",
      render() {
        return /* @__PURE__ */ React.createElement("svg", {
          viewBox: "0 0 28 28",
          version: "1.1",
          xmlns: "http://www.w3.org/2000/svg"
        }, /* @__PURE__ */ React.createElement("g", {
          stroke: "none",
          "stroke-width": "1",
          "fill-rule": "evenodd"
        }, /* @__PURE__ */ React.createElement("g", {
          "fill-rule": "nonzero"
        }, /* @__PURE__ */ React.createElement("path", {
          d: "M17,19 C17.5522847,19 18,19.4477153 18,20 C18,20.5522847 17.5522847,21 17,21 L11,21 C10.4477153,21 10,20.5522847 10,20 C10,19.4477153 10.4477153,19 11,19 L17,19 Z M21,13 C21.5522847,13 22,13.4477153 22,14 C22,14.5522847 21.5522847,15 21,15 L7,15 C6.44771525,15 6,14.5522847 6,14 C6,13.4477153 6.44771525,13 7,13 L21,13 Z M24,7 C24.5522847,7 25,7.44771525 25,8 C25,8.55228475 24.5522847,9 24,9 L4,9 C3.44771525,9 3,8.55228475 3,8 C3,7.44771525 3.44771525,7 4,7 L24,7 Z"
        }))));
      }
    });

    var ForwardIcon = vue.defineComponent({
      name: "Forward",
      render() {
        return /* @__PURE__ */ React.createElement("svg", {
          viewBox: "0 0 20 20",
          fill: "none",
          xmlns: "http://www.w3.org/2000/svg"
        }, /* @__PURE__ */ React.createElement("path", {
          d: "M7.73271 4.20694C8.03263 3.92125 8.50737 3.93279 8.79306 4.23271L13.7944 9.48318C14.0703 9.77285 14.0703 10.2281 13.7944 10.5178L8.79306 15.7682C8.50737 16.0681 8.03263 16.0797 7.73271 15.794C7.43279 15.5083 7.42125 15.0336 7.70694 14.7336L12.2155 10.0005L7.70694 5.26729C7.42125 4.96737 7.43279 4.49264 7.73271 4.20694Z",
          fill: "currentColor"
        }));
      }
    });

    var InfoIcon = replaceable(
      "info",
      /* @__PURE__ */ React.createElement("svg", {
        viewBox: "0 0 28 28",
        version: "1.1",
        xmlns: "http://www.w3.org/2000/svg"
      }, /* @__PURE__ */ React.createElement("g", {
        stroke: "none",
        "stroke-width": "1",
        "fill-rule": "evenodd"
      }, /* @__PURE__ */ React.createElement("g", {
        "fill-rule": "nonzero"
      }, /* @__PURE__ */ React.createElement("path", {
        d: "M14,2 C20.6274,2 26,7.37258 26,14 C26,20.6274 20.6274,26 14,26 C7.37258,26 2,20.6274 2,14 C2,7.37258 7.37258,2 14,2 Z M14,11 C13.4477,11 13,11.4477 13,12 L13,12 L13,20 C13,20.5523 13.4477,21 14,21 C14.5523,21 15,20.5523 15,20 L15,20 L15,12 C15,11.4477 14.5523,11 14,11 Z M14,6.75 C13.3096,6.75 12.75,7.30964 12.75,8 C12.75,8.69036 13.3096,9.25 14,9.25 C14.6904,9.25 15.25,8.69036 15.25,8 C15.25,7.30964 14.6904,6.75 14,6.75 Z"
      }))))
    );

    var MoreIcon = vue.defineComponent({
      name: "More",
      render() {
        return /* @__PURE__ */ React.createElement("svg", {
          viewBox: "0 0 16 16",
          version: "1.1",
          xmlns: "http://www.w3.org/2000/svg"
        }, /* @__PURE__ */ React.createElement("g", {
          stroke: "none",
          "stroke-width": "1",
          fill: "none",
          "fill-rule": "evenodd"
        }, /* @__PURE__ */ React.createElement("g", {
          fill: "currentColor",
          "fill-rule": "nonzero"
        }, /* @__PURE__ */ React.createElement("path", {
          d: "M4,7 C4.55228,7 5,7.44772 5,8 C5,8.55229 4.55228,9 4,9 C3.44772,9 3,8.55229 3,8 C3,7.44772 3.44772,7 4,7 Z M8,7 C8.55229,7 9,7.44772 9,8 C9,8.55229 8.55229,9 8,9 C7.44772,9 7,8.55229 7,8 C7,7.44772 7.44772,7 8,7 Z M12,7 C12.5523,7 13,7.44772 13,8 C13,8.55229 12.5523,9 12,9 C11.4477,9 11,8.55229 11,8 C11,7.44772 11.4477,7 12,7 Z"
        }))));
      }
    });

    var RemoveIcon = vue.defineComponent({
      name: "Remove",
      render() {
        return /* @__PURE__ */ React.createElement("svg", {
          xmlns: "http://www.w3.org/2000/svg",
          viewBox: "0 0 512 512"
        }, /* @__PURE__ */ React.createElement("line", {
          x1: "400",
          y1: "256",
          x2: "112",
          y2: "256",
          style: "\n        fill: none;\n        stroke: currentColor;\n        stroke-linecap: round;\n        stroke-linejoin: round;\n        stroke-width: 32px;\n      "
        }));
      }
    });

    var SearchIcon = vue.defineComponent({
      name: "Search",
      render() {
        return /* @__PURE__ */ React.createElement("svg", {
          version: "1.1",
          xmlns: "http://www.w3.org/2000/svg",
          viewBox: "0 0 512 512",
          style: "enable-background: new 0 0 512 512"
        }, /* @__PURE__ */ React.createElement("path", {
          d: "M443.5,420.2L336.7,312.4c20.9-26.2,33.5-59.4,33.5-95.5c0-84.5-68.5-153-153.1-153S64,132.5,64,217s68.5,153,153.1,153\n  c36.6,0,70.1-12.8,96.5-34.2l106.1,107.1c3.2,3.4,7.6,5.1,11.9,5.1c4.1,0,8.2-1.5,11.3-4.5C449.5,437.2,449.7,426.8,443.5,420.2z\n   M217.1,337.1c-32.1,0-62.3-12.5-85-35.2c-22.7-22.7-35.2-52.9-35.2-84.9c0-32.1,12.5-62.3,35.2-84.9c22.7-22.7,52.9-35.2,85-35.2\n  c32.1,0,62.3,12.5,85,35.2c22.7,22.7,35.2,52.9,35.2,84.9c0,32.1-12.5,62.3-35.2,84.9C279.4,324.6,249.2,337.1,217.1,337.1z"
        }));
      }
    });

    var SuccessIcon = replaceable(
      "success",
      /* @__PURE__ */ React.createElement("svg", {
        viewBox: "0 0 48 48",
        version: "1.1",
        xmlns: "http://www.w3.org/2000/svg"
      }, /* @__PURE__ */ React.createElement("g", {
        stroke: "none",
        "stroke-width": "1",
        "fill-rule": "evenodd"
      }, /* @__PURE__ */ React.createElement("g", {
        "fill-rule": "nonzero"
      }, /* @__PURE__ */ React.createElement("path", {
        d: "M24,4 C35.045695,4 44,12.954305 44,24 C44,35.045695 35.045695,44 24,44 C12.954305,44 4,35.045695 4,24 C4,12.954305 12.954305,4 24,4 Z M32.6338835,17.6161165 C32.1782718,17.1605048 31.4584514,17.1301307 30.9676119,17.5249942 L30.8661165,17.6161165 L20.75,27.732233 L17.1338835,24.1161165 C16.6457281,23.6279612 15.8542719,23.6279612 15.3661165,24.1161165 C14.9105048,24.5717282 14.8801307,25.2915486 15.2749942,25.7823881 L15.3661165,25.8838835 L19.8661165,30.3838835 C20.3217282,30.8394952 21.0415486,30.8698693 21.5323881,30.4750058 L21.6338835,30.3838835 L32.6338835,19.3838835 C33.1220388,18.8957281 33.1220388,18.1042719 32.6338835,17.6161165 Z"
      }))))
    );

    var SwitcherIcon = vue.defineComponent({
      name: "Switcher",
      render() {
        return /* @__PURE__ */ React.createElement("svg", {
          xmlns: "http://www.w3.org/2000/svg",
          viewBox: "0 0 32 32"
        }, /* @__PURE__ */ React.createElement("path", {
          d: "M12 8l10 8l-10 8z"
        }));
      }
    });

    var TimeIcon = replaceable(
      "time",
      /* @__PURE__ */ React.createElement("svg", {
        xmlns: "http://www.w3.org/2000/svg",
        viewBox: "0 0 512 512"
      }, /* @__PURE__ */ React.createElement("path", {
        d: "M256,64C150,64,64,150,64,256s86,192,192,192,192-86,192-192S362,64,256,64Z",
        style: "\n        fill: none;\n        stroke: currentColor;\n        stroke-miterlimit: 10;\n        stroke-width: 32px;\n      "
      }), /* @__PURE__ */ React.createElement("polyline", {
        points: "256 128 256 272 352 272",
        style: "\n        fill: none;\n        stroke: currentColor;\n        stroke-linecap: round;\n        stroke-linejoin: round;\n        stroke-width: 32px;\n      "
      }))
    );

    var WarningIcon = replaceable(
      "warning",
      /* @__PURE__ */ React.createElement("svg", {
        viewBox: "0 0 24 24",
        version: "1.1",
        xmlns: "http://www.w3.org/2000/svg"
      }, /* @__PURE__ */ React.createElement("g", {
        stroke: "none",
        "stroke-width": "1",
        "fill-rule": "evenodd"
      }, /* @__PURE__ */ React.createElement("g", {
        "fill-rule": "nonzero"
      }, /* @__PURE__ */ React.createElement("path", {
        d: "M12,2 C17.523,2 22,6.478 22,12 C22,17.522 17.523,22 12,22 C6.477,22 2,17.522 2,12 C2,6.478 6.477,2 12,2 Z M12.0018002,15.0037242 C11.450254,15.0037242 11.0031376,15.4508407 11.0031376,16.0023869 C11.0031376,16.553933 11.450254,17.0010495 12.0018002,17.0010495 C12.5533463,17.0010495 13.0004628,16.553933 13.0004628,16.0023869 C13.0004628,15.4508407 12.5533463,15.0037242 12.0018002,15.0037242 Z M11.99964,7 C11.4868042,7.00018474 11.0642719,7.38637706 11.0066858,7.8837365 L11,8.00036004 L11.0018003,13.0012393 L11.00857,13.117858 C11.0665141,13.6151758 11.4893244,14.0010638 12.0021602,14.0008793 C12.514996,14.0006946 12.9375283,13.6145023 12.9951144,13.1171428 L13.0018002,13.0005193 L13,7.99964009 L12.9932303,7.8830214 C12.9352861,7.38570354 12.5124758,6.99981552 11.99964,7 Z"
      }))))
    );

    var CancelIcon = replaceable(
      "cancel",
      /* @__PURE__ */ React.createElement("svg", {
        viewBox: "0 0 16 16",
        version: "1.1",
        xmlns: "http://www.w3.org/2000/svg"
      }, /* @__PURE__ */ React.createElement("g", {
        stroke: "none",
        "stroke-width": "1",
        fill: "none",
        "fill-rule": "evenodd"
      }, /* @__PURE__ */ React.createElement("g", {
        fill: "currentColor",
        "fill-rule": "nonzero"
      }, /* @__PURE__ */ React.createElement("path", {
        d: "M2.58859116,2.7156945 L2.64644661,2.64644661 C2.82001296,2.47288026 3.08943736,2.45359511 3.2843055,2.58859116 L3.35355339,2.64644661 L8,7.293 L12.6464466,2.64644661 C12.8417088,2.45118446 13.1582912,2.45118446 13.3535534,2.64644661 C13.5488155,2.84170876 13.5488155,3.15829124 13.3535534,3.35355339 L8.707,8 L13.3535534,12.6464466 C13.5271197,12.820013 13.5464049,13.0894374 13.4114088,13.2843055 L13.3535534,13.3535534 C13.179987,13.5271197 12.9105626,13.5464049 12.7156945,13.4114088 L12.6464466,13.3535534 L8,8.707 L3.35355339,13.3535534 C3.15829124,13.5488155 2.84170876,13.5488155 2.64644661,13.3535534 C2.45118446,13.1582912 2.45118446,12.8417088 2.64644661,12.6464466 L7.293,8 L2.64644661,3.35355339 C2.47288026,3.17998704 2.45359511,2.91056264 2.58859116,2.7156945 L2.64644661,2.64644661 L2.58859116,2.7156945 Z"
      }))))
    );

    var ChevronDownIcon = vue.defineComponent({
      name: "ChevronDown",
      render() {
        return /* @__PURE__ */ React.createElement("svg", {
          viewBox: "0 0 16 16",
          fill: "none",
          xmlns: "http://www.w3.org/2000/svg"
        }, /* @__PURE__ */ React.createElement("path", {
          d: "M3.14645 5.64645C3.34171 5.45118 3.65829 5.45118 3.85355 5.64645L8 9.79289L12.1464 5.64645C12.3417 5.45118 12.6583 5.45118 12.8536 5.64645C13.0488 5.84171 13.0488 6.15829 12.8536 6.35355L8.35355 10.8536C8.15829 11.0488 7.84171 11.0488 7.64645 10.8536L3.14645 6.35355C2.95118 6.15829 2.95118 5.84171 3.14645 5.64645Z",
          fill: "currentColor"
        }));
      }
    });

    var ClearIcon = replaceable(
      "clear",
      /* @__PURE__ */ React.createElement("svg", {
        viewBox: "0 0 16 16",
        version: "1.1",
        xmlns: "http://www.w3.org/2000/svg"
      }, /* @__PURE__ */ React.createElement("g", {
        stroke: "none",
        "stroke-width": "1",
        fill: "none",
        "fill-rule": "evenodd"
      }, /* @__PURE__ */ React.createElement("g", {
        fill: "currentColor",
        "fill-rule": "nonzero"
      }, /* @__PURE__ */ React.createElement("path", {
        d: "M8,2 C11.3137085,2 14,4.6862915 14,8 C14,11.3137085 11.3137085,14 8,14 C4.6862915,14 2,11.3137085 2,8 C2,4.6862915 4.6862915,2 8,2 Z M6.5343055,5.83859116 C6.33943736,5.70359511 6.07001296,5.72288026 5.89644661,5.89644661 L5.89644661,5.89644661 L5.83859116,5.9656945 C5.70359511,6.16056264 5.72288026,6.42998704 5.89644661,6.60355339 L5.89644661,6.60355339 L7.293,8 L5.89644661,9.39644661 L5.83859116,9.4656945 C5.70359511,9.66056264 5.72288026,9.92998704 5.89644661,10.1035534 L5.89644661,10.1035534 L5.9656945,10.1614088 C6.16056264,10.2964049 6.42998704,10.2771197 6.60355339,10.1035534 L6.60355339,10.1035534 L8,8.707 L9.39644661,10.1035534 L9.4656945,10.1614088 C9.66056264,10.2964049 9.92998704,10.2771197 10.1035534,10.1035534 L10.1035534,10.1035534 L10.1614088,10.0343055 C10.2964049,9.83943736 10.2771197,9.57001296 10.1035534,9.39644661 L10.1035534,9.39644661 L8.707,8 L10.1035534,6.60355339 L10.1614088,6.5343055 C10.2964049,6.33943736 10.2771197,6.07001296 10.1035534,5.89644661 L10.1035534,5.89644661 L10.0343055,5.83859116 C9.83943736,5.70359511 9.57001296,5.72288026 9.39644661,5.89644661 L9.39644661,5.89644661 L8,7.293 L6.60355339,5.89644661 Z"
      }))))
    );

    var ChevronDownFilledIcon = vue.defineComponent({
      name: "ChevronDownFilled",
      render() {
        return /* @__PURE__ */ React.createElement("svg", {
          viewBox: "0 0 16 16",
          fill: "none",
          xmlns: "http://www.w3.org/2000/svg"
        }, /* @__PURE__ */ React.createElement("path", {
          d: "M3.20041 5.73966C3.48226 5.43613 3.95681 5.41856 4.26034 5.70041L8 9.22652L11.7397 5.70041C12.0432 5.41856 12.5177 5.43613 12.7996 5.73966C13.0815 6.0432 13.0639 6.51775 12.7603 6.7996L8.51034 10.7996C8.22258 11.0668 7.77743 11.0668 7.48967 10.7996L3.23966 6.7996C2.93613 6.51775 2.91856 6.0432 3.20041 5.73966Z",
          fill: "currentColor"
        }));
      }
    });

    var ToIcon = replaceable(
      "to",
      /* @__PURE__ */ React.createElement("svg", {
        viewBox: "0 0 20 20",
        version: "1.1",
        xmlns: "http://www.w3.org/2000/svg"
      }, /* @__PURE__ */ React.createElement("g", {
        stroke: "none",
        "stroke-width": "1",
        fill: "none",
        "fill-rule": "evenodd"
      }, /* @__PURE__ */ React.createElement("g", {
        fill: "currentColor",
        "fill-rule": "nonzero"
      }, /* @__PURE__ */ React.createElement("path", {
        d: "M11.2654,3.20511 C10.9644,2.92049 10.4897,2.93371 10.2051,3.23464 C9.92049,3.53558 9.93371,4.01027 10.2346,4.29489 L15.4737,9.25 L2.75,9.25 C2.33579,9.25 2,9.58579 2,10.0000012 C2,10.4142 2.33579,10.75 2.75,10.75 L15.476,10.75 L10.2346,15.7073 C9.93371,15.9919 9.92049,16.4666 10.2051,16.7675 C10.4897,17.0684 10.9644,17.0817 11.2654,16.797 L17.6826,10.7276 C17.8489,10.5703 17.9489,10.3702 17.9826,10.1614 C17.994,10.1094 18,10.0554 18,10.0000012 C18,9.94241 17.9935,9.88633 17.9812,9.83246 C17.9462,9.62667 17.8467,9.42976 17.6826,9.27455 L11.2654,3.20511 Z"
      }))))
    );

    var RetryIcon = replaceable(
      "retry",
      /* @__PURE__ */ React.createElement("svg", {
        xmlns: "http://www.w3.org/2000/svg",
        viewBox: "0 0 512 512"
      }, /* @__PURE__ */ React.createElement("path", {
        d: "M320,146s24.36-12-64-12A160,160,0,1,0,416,294",
        style: "fill: none; stroke: currentcolor; stroke-linecap: round; stroke-miterlimit: 10; stroke-width: 32px;"
      }), /* @__PURE__ */ React.createElement("polyline", {
        points: "256 58 336 138 256 218",
        style: "fill: none; stroke: currentcolor; stroke-linecap: round; stroke-linejoin: round; stroke-width: 32px;"
      }))
    );

    var ArrowBackIcon = vue.defineComponent({
      name: "ArrowBack",
      render() {
        return /* @__PURE__ */ React.createElement("svg", {
          xmlns: "http://www.w3.org/2000/svg",
          viewBox: "0 0 24 24"
        }, /* @__PURE__ */ React.createElement("path", {
          d: "M0 0h24v24H0V0z",
          fill: "none"
        }), /* @__PURE__ */ React.createElement("path", {
          d: "M19 11H7.83l4.88-4.88c.39-.39.39-1.03 0-1.42-.39-.39-1.02-.39-1.41 0l-6.59 6.59c-.39.39-.39 1.02 0 1.41l6.59 6.59c.39.39 1.02.39 1.41 0 .39-.39.39-1.02 0-1.41L7.83 13H19c.55 0 1-.45 1-1s-.45-1-1-1z"
        }));
      }
    });

    var RotateClockwiseIcon = replaceable(
      "rotateClockwise",
      /* @__PURE__ */ React.createElement("svg", {
        viewBox: "0 0 20 20",
        fill: "none",
        xmlns: "http://www.w3.org/2000/svg"
      }, /* @__PURE__ */ React.createElement("path", {
        d: "M3 10C3 6.13401 6.13401 3 10 3C13.866 3 17 6.13401 17 10C17 12.7916 15.3658 15.2026 13 16.3265V14.5C13 14.2239 12.7761 14 12.5 14C12.2239 14 12 14.2239 12 14.5V17.5C12 17.7761 12.2239 18 12.5 18H15.5C15.7761 18 16 17.7761 16 17.5C16 17.2239 15.7761 17 15.5 17H13.8758C16.3346 15.6357 18 13.0128 18 10C18 5.58172 14.4183 2 10 2C5.58172 2 2 5.58172 2 10C2 10.2761 2.22386 10.5 2.5 10.5C2.77614 10.5 3 10.2761 3 10Z",
        fill: "currentColor"
      }), /* @__PURE__ */ React.createElement("path", {
        d: "M10 12C11.1046 12 12 11.1046 12 10C12 8.89543 11.1046 8 10 8C8.89543 8 8 8.89543 8 10C8 11.1046 8.89543 12 10 12ZM10 11C9.44772 11 9 10.5523 9 10C9 9.44772 9.44772 9 10 9C10.5523 9 11 9.44772 11 10C11 10.5523 10.5523 11 10 11Z",
        fill: "currentColor"
      }))
    );

    var RotateCounterclockwiseIcon = replaceable(
      "rotateClockwise",
      /* @__PURE__ */ React.createElement("svg", {
        viewBox: "0 0 20 20",
        fill: "none",
        xmlns: "http://www.w3.org/2000/svg"
      }, /* @__PURE__ */ React.createElement("path", {
        d: "M17 10C17 6.13401 13.866 3 10 3C6.13401 3 3 6.13401 3 10C3 12.7916 4.63419 15.2026 7 16.3265V14.5C7 14.2239 7.22386 14 7.5 14C7.77614 14 8 14.2239 8 14.5V17.5C8 17.7761 7.77614 18 7.5 18H4.5C4.22386 18 4 17.7761 4 17.5C4 17.2239 4.22386 17 4.5 17H6.12422C3.66539 15.6357 2 13.0128 2 10C2 5.58172 5.58172 2 10 2C14.4183 2 18 5.58172 18 10C18 10.2761 17.7761 10.5 17.5 10.5C17.2239 10.5 17 10.2761 17 10Z",
        fill: "currentColor"
      }), /* @__PURE__ */ React.createElement("path", {
        d: "M10 12C8.89543 12 8 11.1046 8 10C8 8.89543 8.89543 8 10 8C11.1046 8 12 8.89543 12 10C12 11.1046 11.1046 12 10 12ZM10 11C10.5523 11 11 10.5523 11 10C11 9.44772 10.5523 9 10 9C9.44772 9 9 9.44772 9 10C9 10.5523 9.44772 11 10 11Z",
        fill: "currentColor"
      }))
    );

    var ZoomInIcon = replaceable(
      "zoomIn",
      /* @__PURE__ */ React.createElement("svg", {
        viewBox: "0 0 20 20",
        fill: "none",
        xmlns: "http://www.w3.org/2000/svg"
      }, /* @__PURE__ */ React.createElement("path", {
        d: "M11.5 8.5C11.5 8.22386 11.2761 8 11 8H9V6C9 5.72386 8.77614 5.5 8.5 5.5C8.22386 5.5 8 5.72386 8 6V8H6C5.72386 8 5.5 8.22386 5.5 8.5C5.5 8.77614 5.72386 9 6 9H8V11C8 11.2761 8.22386 11.5 8.5 11.5C8.77614 11.5 9 11.2761 9 11V9H11C11.2761 9 11.5 8.77614 11.5 8.5Z",
        fill: "currentColor"
      }), /* @__PURE__ */ React.createElement("path", {
        d: "M8.5 3C11.5376 3 14 5.46243 14 8.5C14 9.83879 13.5217 11.0659 12.7266 12.0196L16.8536 16.1464C17.0488 16.3417 17.0488 16.6583 16.8536 16.8536C16.68 17.0271 16.4106 17.0464 16.2157 16.9114L16.1464 16.8536L12.0196 12.7266C11.0659 13.5217 9.83879 14 8.5 14C5.46243 14 3 11.5376 3 8.5C3 5.46243 5.46243 3 8.5 3ZM8.5 4C6.01472 4 4 6.01472 4 8.5C4 10.9853 6.01472 13 8.5 13C10.9853 13 13 10.9853 13 8.5C13 6.01472 10.9853 4 8.5 4Z",
        fill: "currentColor"
      }))
    );

    var ZoomOutIcon = replaceable(
      "zoomOut",
      /* @__PURE__ */ React.createElement("svg", {
        viewBox: "0 0 20 20",
        fill: "none",
        xmlns: "http://www.w3.org/2000/svg"
      }, /* @__PURE__ */ React.createElement("path", {
        d: "M11 8C11.2761 8 11.5 8.22386 11.5 8.5C11.5 8.77614 11.2761 9 11 9H6C5.72386 9 5.5 8.77614 5.5 8.5C5.5 8.22386 5.72386 8 6 8H11Z",
        fill: "currentColor"
      }), /* @__PURE__ */ React.createElement("path", {
        d: "M14 8.5C14 5.46243 11.5376 3 8.5 3C5.46243 3 3 5.46243 3 8.5C3 11.5376 5.46243 14 8.5 14C9.83879 14 11.0659 13.5217 12.0196 12.7266L16.1464 16.8536L16.2157 16.9114C16.4106 17.0464 16.68 17.0271 16.8536 16.8536C17.0488 16.6583 17.0488 16.3417 16.8536 16.1464L12.7266 12.0196C13.5217 11.0659 14 9.83879 14 8.5ZM4 8.5C4 6.01472 6.01472 4 8.5 4C10.9853 4 13 6.01472 13 8.5C13 10.9853 10.9853 13 8.5 13C6.01472 13 4 10.9853 4 8.5Z",
        fill: "currentColor"
      }))
    );

    var ResizeSmallIcon = vue.defineComponent({
      name: "ResizeSmall",
      render() {
        return /* @__PURE__ */ React.createElement("svg", {
          xmlns: "http://www.w3.org/2000/svg",
          viewBox: "0 0 20 20"
        }, /* @__PURE__ */ React.createElement("g", {
          fill: "none"
        }, /* @__PURE__ */ React.createElement("path", {
          d: "M5.5 4A1.5 1.5 0 0 0 4 5.5v1a.5.5 0 0 1-1 0v-1A2.5 2.5 0 0 1 5.5 3h1a.5.5 0 0 1 0 1h-1zM16 5.5A1.5 1.5 0 0 0 14.5 4h-1a.5.5 0 0 1 0-1h1A2.5 2.5 0 0 1 17 5.5v1a.5.5 0 0 1-1 0v-1zm0 9a1.5 1.5 0 0 1-1.5 1.5h-1a.5.5 0 0 0 0 1h1a2.5 2.5 0 0 0 2.5-2.5v-1a.5.5 0 0 0-1 0v1zm-12 0A1.5 1.5 0 0 0 5.5 16h1.25a.5.5 0 0 1 0 1H5.5A2.5 2.5 0 0 1 3 14.5v-1.25a.5.5 0 0 1 1 0v1.25zM8.5 7A1.5 1.5 0 0 0 7 8.5v3A1.5 1.5 0 0 0 8.5 13h3a1.5 1.5 0 0 0 1.5-1.5v-3A1.5 1.5 0 0 0 11.5 7h-3zM8 8.5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5v-3z",
          fill: "currentColor"
        })));
      }
    });

    var NIconSwitchTransition = vue.defineComponent({
      name: "BaseIconSwitchTransition",
      setup(_, { slots }) {
        const isMountedRef = isMounted();
        return () => /* @__PURE__ */ React.createElement(vue.Transition, {
          name: "icon-switch-transition",
          appear: isMountedRef.value
        }, slots);
      }
    });

    var NFadeInExpandTransition = vue.defineComponent({
      name: "FadeInExpandTransition",
      props: {
        appear: Boolean,
        group: Boolean,
        mode: String,
        onLeave: Function,
        onAfterLeave: Function,
        onAfterEnter: Function,
        width: Boolean,
        reverse: Boolean
      },

      setup(props, _ref) {
        let {
          slots
        } = _ref;

        function handleBeforeLeave(el) {
          if (props.width) {
            el.style.maxWidth = `${el.offsetWidth}px`;
          } else {
            el.style.maxHeight = `${el.offsetHeight}px`;
          }

          void el.offsetWidth;
        }

        function handleLeave(el) {
          if (props.width) {
            el.style.maxWidth = "0";
          } else {
            el.style.maxHeight = "0";
          }

          void el.offsetWidth;
          const {
            onLeave
          } = props;
          if (onLeave) onLeave();
        }

        function handleAfterLeave(el) {
          if (props.width) {
            el.style.maxWidth = "";
          } else {
            el.style.maxHeight = "";
          }

          const {
            onAfterLeave
          } = props;
          if (onAfterLeave) onAfterLeave();
        }

        function handleEnter(el) {
          el.style.transition = "none";

          if (props.width) {
            const memorizedWidth = el.offsetWidth;
            el.style.maxWidth = "0";
            void el.offsetWidth;
            el.style.transition = "";
            el.style.maxWidth = `${memorizedWidth}px`;
          } else {
            if (props.reverse) {
              el.style.maxHeight = `${el.offsetHeight}px`;
              void el.offsetHeight;
              el.style.transition = "";
              el.style.maxHeight = "0";
            } else {
              const memorizedHeight = el.offsetHeight;
              el.style.maxHeight = "0";
              void el.offsetWidth;
              el.style.transition = "";
              el.style.maxHeight = `${memorizedHeight}px`;
            }
          }

          void el.offsetWidth;
        }

        function handleAfterEnter(el) {
          var _props$onAfterEnter;

          if (props.width) {
            el.style.maxWidth = "";
          } else {
            if (!props.reverse) {
              el.style.maxHeight = "";
            }
          }

          (_props$onAfterEnter = props.onAfterEnter) === null || _props$onAfterEnter === void 0 ? void 0 : _props$onAfterEnter.call(props);
        }

        return () => {
          const type = props.group ? vue.TransitionGroup : vue.Transition;
          return vue.h(type, {
            name: props.width ? "fade-in-width-expand-transition" : "fade-in-height-expand-transition",
            mode: props.mode,
            appear: props.appear,
            onEnter: handleEnter,
            onAfterEnter: handleAfterEnter,
            onBeforeLeave: handleBeforeLeave,
            onLeave: handleLeave,
            onAfterLeave: handleAfterLeave
          }, slots);
        };
      }

    });

    var style$1y = cB("base-icon", `
  height: 1em;
  width: 1em;
  line-height: 1em;
  text-align: center;
  display: inline-block;
  position: relative;
  fill: currentColor;
  transform: translateZ(0);
`, [c$1("svg", `
    height: 1em;
    width: 1em;
  `)]);

    var NBaseIcon = vue.defineComponent({
      name: "BaseIcon",
      props: {
        role: String,
        ariaLabel: String,
        ariaDisabled: {
          type: Boolean,
          default: void 0
        },
        ariaHidden: {
          type: Boolean,
          default: void 0
        },
        clsPrefix: {
          type: String,
          required: true
        },
        onClick: Function,
        onMousedown: Function,
        onMouseup: Function
      },
      setup(props) {
        useStyle("-base-icon", style$1y, vue.toRef(props, "clsPrefix"));
      },
      render() {
        return /* @__PURE__ */ React.createElement("i", {
          class: `${this.clsPrefix}-base-icon`,
          onClick: this.onClick,
          onMousedown: this.onMousedown,
          onMouseup: this.onMouseup,
          role: this.role,
          "aria-label": this.ariaLabel,
          "aria-hidden": this.ariaHidden,
          "aria-disabled": this.ariaDisabled
        }, this.$slots);
      }
    });

    var style$1x = cB("base-close", `
  display: flex;
  align-items: center;
  justify-content: center;
  cursor: pointer;
  background-color: transparent;
  color: var(--n-close-icon-color);
  border-radius: var(--n-close-border-radius);
  height: var(--n-close-size);
  width: var(--n-close-size);
  font-size: var(--n-close-icon-size);
  outline: none;
  border: none;
  position: relative;
  padding: 0;
`, [cM("absolute", `
    height: var(--n-close-icon-size);
    width: var(--n-close-icon-size);
  `), c$1("&::before", `
    content: "";
    position: absolute;
    width: var(--n-close-size);
    height: var(--n-close-size);
    left: 50%;
    top: 50%;
    transform: translateY(-50%) translateX(-50%);
    transition: inherit;
    border-radius: inherit;
  `), cNotM("disabled", [c$1("&:hover", `
      color: var(--n-close-icon-color-hover);
    `), c$1("&:hover::before", `
      background-color: var(--n-close-color-hover);
    `), c$1("&:focus::before", `
      background-color: var(--n-close-color-hover);
    `), c$1("&:active", `
      color: var(--n-close-icon-color-pressed);
    `), c$1("&:active::before", `
      background-color: var(--n-close-color-pressed);
    `)]), cM("disabled", `
    cursor: not-allowed;
    color: var(--n-close-icon-color-disabled);
    background-color: transparent;
  `), cM("round", [c$1("&::before", `
      border-radius: 50%;
    `)])]);

    var NBaseClose = vue.defineComponent({
      name: "BaseClose",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        disabled: {
          type: Boolean,
          default: void 0
        },
        focusable: {
          type: Boolean,
          default: true
        },
        round: Boolean,
        onClick: Function,
        absolute: Boolean
      },
      setup(props) {
        useStyle("-base-close", style$1x, vue.toRef(props, "clsPrefix"));
        return () => {
          const { clsPrefix, disabled, absolute, round } = props;
          return /* @__PURE__ */ React.createElement("button", {
            type: "button",
            tabindex: disabled || !props.focusable ? -1 : 0,
            "aria-disabled": disabled,
            "aria-label": "close",
            disabled,
            class: [
              `${clsPrefix}-base-close`,
              absolute && `${clsPrefix}-base-close--absolute`,
              disabled && `${clsPrefix}-base-close--disabled`,
              round && `${clsPrefix}-base-close--round`
            ],
            onMousedown: (e) => {
              if (!props.focusable) {
                e.preventDefault();
              }
            },
            onClick: props.onClick
          }, /* @__PURE__ */ React.createElement(NBaseIcon, {
            clsPrefix
          }, {
            default: () => /* @__PURE__ */ React.createElement(ErrorIcon$1, null)
          }));
        };
      }
    });

    var FocusDetector = vue.defineComponent({
      props: {
        onFocus: Function,
        onBlur: Function
      },
      setup(props) {
        return () => /* @__PURE__ */ React.createElement("div", {
          style: "width: 0; height: 0",
          tabindex: 0,
          onFocus: props.onFocus,
          onBlur: props.onBlur
        });
      }
    });

    const {
      cubicBezierEaseInOut: cubicBezierEaseInOut$4
    } = commonVariables$m;
    function iconSwitchTransition() {
      let {
        originalTransform = "",
        left = 0,
        top = 0,
        transition = `all .3s ${cubicBezierEaseInOut$4} !important`
      } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      return [c$1("&.icon-switch-transition-enter-from, &.icon-switch-transition-leave-to", {
        transform: originalTransform + " scale(0.75)",
        left,
        top,
        opacity: 0
      }), c$1("&.icon-switch-transition-enter-to, &.icon-switch-transition-leave-from", {
        transform: `scale(1) ${originalTransform}`,
        left,
        top,
        opacity: 1
      }), c$1("&.icon-switch-transition-enter-active, &.icon-switch-transition-leave-active", {
        transformOrigin: "center",
        position: "absolute",
        left,
        top,
        transition
      })];
    }

    var style$1w = c$1([c$1("@keyframes loading-container-rotate", `
    to {
      -webkit-transform: rotate(360deg);
      transform: rotate(360deg);
    }
  `), c$1("@keyframes loading-layer-rotate", `
    12.5% {
      -webkit-transform: rotate(135deg);
      transform: rotate(135deg);
    }
    25% {
      -webkit-transform: rotate(270deg);
      transform: rotate(270deg);
    }
    37.5% {
      -webkit-transform: rotate(405deg);
      transform: rotate(405deg);
    }
    50% {
      -webkit-transform: rotate(540deg);
      transform: rotate(540deg);
    }
    62.5% {
      -webkit-transform: rotate(675deg);
      transform: rotate(675deg);
    }
    75% {
      -webkit-transform: rotate(810deg);
      transform: rotate(810deg);
    }
    87.5% {
      -webkit-transform: rotate(945deg);
      transform: rotate(945deg);
    }
    100% {
      -webkit-transform: rotate(1080deg);
      transform: rotate(1080deg);
    } 
  `), c$1("@keyframes loading-left-spin", `
    from {
      -webkit-transform: rotate(265deg);
      transform: rotate(265deg);
    }
    50% {
      -webkit-transform: rotate(130deg);
      transform: rotate(130deg);
    }
    to {
      -webkit-transform: rotate(265deg);
      transform: rotate(265deg);
    }
  `), c$1("@keyframes loading-right-spin", `
    from {
      -webkit-transform: rotate(-265deg);
      transform: rotate(-265deg);
    }
    50% {
      -webkit-transform: rotate(-130deg);
      transform: rotate(-130deg);
    }
    to {
      -webkit-transform: rotate(-265deg);
      transform: rotate(-265deg);
    }
  `), cB("base-loading", `
    position: relative;
    line-height: 0;
    width: 1em;
    height: 1em;
  `, [cE("transition-wrapper", `
      position: absolute;
      width: 100%;
      height: 100%;
    `, [iconSwitchTransition()]), cE("container", `
      display: inline-flex;
      position: relative;
      direction: ltr;
      line-height: 0;
      animation: loading-container-rotate 1568.2352941176ms linear infinite;
      font-size: 0;
      letter-spacing: 0;
      white-space: nowrap;
      opacity: 1;
      width: 100%;
      height: 100%;
    `, [cE("svg", `
        stroke: var(--n-text-color);
        fill: transparent;
        position: absolute;
        height: 100%;
        overflow: hidden;
      `), cE("container-layer", `
        position: absolute;
        width: 100%;
        height: 100%;
        animation: loading-layer-rotate 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both;
      `, [cE("container-layer-left", `
          display: inline-flex;
          position: relative;
          width: 50%;
          height: 100%;
          overflow: hidden;
        `, [cE("svg", `
            animation: loading-left-spin 1333ms cubic-bezier(0.4, 0, 0.2, 1) infinite both;
            width: 200%;
          `)]), cE("container-layer-patch", `
          position: absolute;
          top: 0;
          left: 47.5%;
          box-sizing: border-box;
          width: 5%;
          height: 100%;
          overflow: hidden;
        `, [cE("svg", `
            left: -900%;
            width: 2000%;
            transform: rotate(180deg);
          `)]), cE("container-layer-right", `
          display: inline-flex;
          position: relative;
          width: 50%;
          height: 100%;
          overflow: hidden;
        `, [cE("svg", `
            animation: loading-right-spin 1333ms cubic-bezier(0.4, 0, 0.2, 1) infinite both;
            left: -100%;
            width: 200%;
          `)])])]), cE("placeholder", `
      position: absolute;
      left: 50%;
      top: 50%;
      transform: translateX(-50%) translateY(-50%);
    `, [iconSwitchTransition({
      left: "50%",
      top: "50%",
      originalTransform: "translateX(-50%) translateY(-50%)"
    })])])]);

    var NBaseLoading = vue.defineComponent({
      name: "BaseLoading",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        scale: {
          type: Number,
          default: 1
        },
        radius: {
          type: Number,
          default: 100
        },
        strokeWidth: {
          type: Number,
          default: 28
        },
        stroke: {
          type: String,
          default: void 0
        },
        show: {
          type: Boolean,
          default: true
        }
      },
      setup(props) {
        useStyle("-base-loading", style$1w, vue.toRef(props, "clsPrefix"));
      },
      render() {
        const { clsPrefix, radius, strokeWidth, stroke, scale } = this;
        const scaledRadius = radius / scale;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-base-loading`,
          role: "img",
          "aria-label": "loading"
        }, /* @__PURE__ */ React.createElement(NIconSwitchTransition, null, {
          default: () => this.show ? /* @__PURE__ */ React.createElement("div", {
            key: "icon",
            class: `${clsPrefix}-base-loading__transition-wrapper`
          }, /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-base-loading__container`
          }, /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-base-loading__container-layer`
          }, /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-base-loading__container-layer-left`
          }, /* @__PURE__ */ React.createElement("svg", {
            class: `${clsPrefix}-base-loading__svg`,
            viewBox: `0 0 ${2 * scaledRadius} ${2 * scaledRadius}`,
            xmlns: "http://www.w3.org/2000/svg",
            style: { color: stroke }
          }, /* @__PURE__ */ React.createElement("circle", {
            fill: "none",
            stroke: "currentColor",
            "stroke-width": strokeWidth,
            "stroke-linecap": "round",
            cx: scaledRadius,
            cy: scaledRadius,
            r: radius - strokeWidth / 2,
            "stroke-dasharray": 4.91 * radius,
            "stroke-dashoffset": 2.46 * radius
          }))), /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-base-loading__container-layer-patch`
          }, /* @__PURE__ */ React.createElement("svg", {
            class: `${clsPrefix}-base-loading__svg`,
            viewBox: `0 0 ${2 * scaledRadius} ${2 * scaledRadius}`,
            xmlns: "http://www.w3.org/2000/svg",
            style: { color: stroke }
          }, /* @__PURE__ */ React.createElement("circle", {
            fill: "none",
            stroke: "currentColor",
            "stroke-width": strokeWidth,
            "stroke-linecap": "round",
            cx: scaledRadius,
            cy: scaledRadius,
            r: radius - strokeWidth / 2,
            "stroke-dasharray": 4.91 * radius,
            "stroke-dashoffset": 2.46 * radius
          }))), /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-base-loading__container-layer-right`
          }, /* @__PURE__ */ React.createElement("svg", {
            class: `${clsPrefix}-base-loading__svg`,
            viewBox: `0 0 ${2 * scaledRadius} ${2 * scaledRadius}`,
            xmlns: "http://www.w3.org/2000/svg",
            style: { color: stroke }
          }, /* @__PURE__ */ React.createElement("circle", {
            fill: "none",
            stroke: "currentColor",
            "stroke-width": strokeWidth,
            "stroke-linecap": "round",
            cx: scaledRadius,
            cy: scaledRadius,
            r: radius - strokeWidth / 2,
            "stroke-dasharray": 4.91 * radius,
            "stroke-dashoffset": 2.46 * radius
          })))))) : /* @__PURE__ */ React.createElement("div", {
            key: "placeholder",
            class: `${clsPrefix}-base-loading__placeholder`
          }, this.$slots)
        }));
      }
    });

    function toArray(arg) {
      if (Array.isArray(arg)) return arg;
      return [arg];
    } // Do not use enum for lint plugin has error

    const TRAVERSE_COMMAND = {
      STOP: 'STOP'
    };
    function traverseWithCb(treeNode, callback) {
      const command = callback(treeNode);

      if (treeNode.children !== undefined && command !== TRAVERSE_COMMAND.STOP) {
        treeNode.children.forEach(childNode => traverseWithCb(childNode, callback));
      }
    }
    function getNonLeafKeys(treeNodes) {
      let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      const {
        preserveGroup = false
      } = options;
      const keys = [];
      const cb = preserveGroup ? node => {
        if (!node.isLeaf) {
          keys.push(node.key);
          traverse(node.children);
        }
      } : node => {
        if (!node.isLeaf) {
          if (!node.isGroup) keys.push(node.key);
          traverse(node.children);
        }
      };

      function traverse(nodes) {
        nodes.forEach(cb);
      }

      traverse(treeNodes);
      return keys;
    }
    function isLeaf(rawNode, getChildren) {
      const {
        isLeaf
      } = rawNode;
      if (isLeaf !== undefined) return isLeaf;else if (!getChildren(rawNode)) return true;
      return false;
    }
    function defaultGetChildren(node) {
      return node.children;
    }
    function defaultGetKey(node) {
      return node.key;
    }
    function isIgnored() {
      return false;
    }
    function isShallowLoaded(rawNode, getChildren) {
      const {
        isLeaf
      } = rawNode;
      if (isLeaf === false && !Array.isArray(getChildren(rawNode))) return false;
      return true;
    }
    function isDisabled(rawNode) {
      return rawNode.disabled === true;
    }
    function isExpilicitlyNotLoaded(rawNode, getChildren) {
      return rawNode.isLeaf === false && !Array.isArray(getChildren(rawNode));
    }
    function isNodeInvalid(rawNode, getChildren) {
      if (rawNode.isLeaf === true) {
        const children = getChildren(rawNode);
        if (Array.isArray(children) && children.length > 0) return true;
      }

      return false;
    }
    function unwrapCheckedKeys(result) {
      var _a;

      if (result === undefined || result === null) return [];
      if (Array.isArray(result)) return result;
      return (_a = result.checkedKeys) !== null && _a !== void 0 ? _a : [];
    }
    function unwrapIndeterminateKeys(result) {
      var _a;

      if (result === undefined || result === null || Array.isArray(result)) {
        return [];
      }

      return (_a = result.indeterminateKeys) !== null && _a !== void 0 ? _a : [];
    }
    function merge(originalKeys, keysToAdd) {
      const set = new Set(originalKeys);
      keysToAdd.forEach(key => {
        if (!set.has(key)) {
          set.add(key);
        }
      });
      return Array.from(set);
    }
    function minus(originalKeys, keysToRemove) {
      const set = new Set(originalKeys);
      keysToRemove.forEach(key => {
        if (set.has(key)) {
          set.delete(key);
        }
      });
      return Array.from(set);
    }
    function isGroup(rawNode) {
      return (rawNode === null || rawNode === void 0 ? void 0 : rawNode.type) === 'group';
    }
    function createIndexGetter(treeNodes) {
      const map = new Map();
      treeNodes.forEach((treeNode, i) => {
        map.set(treeNode.key, i);
      });
      return key => {
        var _a;

        return (_a = map.get(key)) !== null && _a !== void 0 ? _a : null;
      };
    }

    class SubtreeNotLoadedError extends Error {
      constructor() {
        super();
        this.message = 'SubtreeNotLoadedError: checking a subtree whose required nodes are not fully loaded.';
      }

    }

    function getExtendedCheckedKeySetAfterCheck(checkKeys, currentCheckedKeys, treeMate, allowNotLoaded) {
      return getExtendedCheckedKeySet(currentCheckedKeys.concat(checkKeys), treeMate, allowNotLoaded, false);
    }

    function getAvailableAscendantNodeSet(uncheckedKeys, treeMate) {
      const visitedKeys = new Set();
      uncheckedKeys.forEach(uncheckedKey => {
        const uncheckedTreeNode = treeMate.treeNodeMap.get(uncheckedKey);

        if (uncheckedTreeNode !== undefined) {
          let nodeCursor = uncheckedTreeNode.parent;

          while (nodeCursor !== null) {
            if (nodeCursor.disabled) break;
            if (visitedKeys.has(nodeCursor.key)) break;else {
              visitedKeys.add(nodeCursor.key);
            }
            nodeCursor = nodeCursor.parent;
          }
        }
      });
      return visitedKeys;
    }

    function getExtendedCheckedKeySetAfterUncheck(uncheckedKeys, currentCheckedKeys, treeMate, allowNotLoaded) {
      const extendedCheckedKeySet = getExtendedCheckedKeySet(currentCheckedKeys, treeMate, allowNotLoaded, false);
      const extendedKeySetToUncheck = getExtendedCheckedKeySet(uncheckedKeys, treeMate, allowNotLoaded, true);
      const ascendantKeySet = getAvailableAscendantNodeSet(uncheckedKeys, treeMate);
      const keysToRemove = [];
      extendedCheckedKeySet.forEach(key => {
        if (extendedKeySetToUncheck.has(key) || ascendantKeySet.has(key)) {
          keysToRemove.push(key);
        }
      });
      keysToRemove.forEach(key => extendedCheckedKeySet.delete(key));
      return extendedCheckedKeySet;
    }

    function getCheckedKeys(options, treeMate) {
      const {
        checkedKeys,
        keysToCheck,
        keysToUncheck,
        indeterminateKeys,
        cascade,
        leafOnly,
        checkStrategy,
        allowNotLoaded
      } = options;

      if (!cascade) {
        if (keysToCheck !== undefined) {
          return {
            checkedKeys: merge(checkedKeys, keysToCheck),
            indeterminateKeys: Array.from(indeterminateKeys)
          };
        } else if (keysToUncheck !== undefined) {
          return {
            checkedKeys: minus(checkedKeys, keysToUncheck),
            indeterminateKeys: Array.from(indeterminateKeys)
          };
        } else {
          return {
            checkedKeys: Array.from(checkedKeys),
            indeterminateKeys: Array.from(indeterminateKeys)
          };
        }
      }

      const {
        levelTreeNodeMap
      } = treeMate;
      let extendedCheckedKeySet;

      if (keysToUncheck !== undefined) {
        extendedCheckedKeySet = getExtendedCheckedKeySetAfterUncheck(keysToUncheck, checkedKeys, treeMate, allowNotLoaded);
      } else if (keysToCheck !== undefined) {
        extendedCheckedKeySet = getExtendedCheckedKeySetAfterCheck(keysToCheck, checkedKeys, treeMate, allowNotLoaded);
      } else {
        extendedCheckedKeySet = getExtendedCheckedKeySet(checkedKeys, treeMate, allowNotLoaded, false);
      }

      const checkStrategyIsParent = checkStrategy === 'parent';
      const checkStrategyIsChild = checkStrategy === 'child' || leafOnly;
      const syntheticCheckedKeySet = extendedCheckedKeySet;
      const syntheticIndeterminateKeySet = new Set();
      const maxLevel = Math.max.apply(null, Array.from(levelTreeNodeMap.keys())); // cascade check
      // 1. if tree is fully loaded, it just works
      // 2. if the tree is not fully loaded, we assume that keys which is in not
      //    loaded tree are not in checked keys
      //    for example:
      //    a -- b(fully-loaded)   -- c(fully-loaded)
      //      |- d(partial-loaded) -- ?e(not-loaded)
      //    in the case, `e` is assumed not to be checked, nor we can't calc `d`'s
      //    and `a`'s status

      for (let level = maxLevel; level >= 0; level -= 1) {
        const levelIsZero = level === 0; // it should exists, nor it is a bug

        const levelTreeNodes = levelTreeNodeMap.get(level);

        for (const levelTreeNode of levelTreeNodes) {
          if (levelTreeNode.isLeaf) continue;
          const {
            key: levelTreeNodeKey,
            shallowLoaded
          } = levelTreeNode;

          if (checkStrategyIsChild && shallowLoaded) {
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            levelTreeNode.children.forEach(v => {
              if (!v.disabled && !v.isLeaf && v.shallowLoaded && syntheticCheckedKeySet.has(v.key)) {
                syntheticCheckedKeySet.delete(v.key);
              }
            });
          }

          if (levelTreeNode.disabled || !shallowLoaded) {
            continue;
          }

          let fullyChecked = true;
          let partialChecked = false;
          let allDisabled = true; // it is shallow loaded, so `children` must exist

          for (const childNode of levelTreeNode.children) {
            const childKey = childNode.key;
            if (childNode.disabled) continue;
            if (allDisabled) allDisabled = false;

            if (syntheticCheckedKeySet.has(childKey)) {
              partialChecked = true;
            } else if (syntheticIndeterminateKeySet.has(childKey)) {
              partialChecked = true;
              fullyChecked = false;
              break;
            } else {
              fullyChecked = false;

              if (partialChecked) {
                break;
              }
            }
          }

          if (fullyChecked && !allDisabled) {
            if (checkStrategyIsParent) {
              // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
              levelTreeNode.children.forEach(v => {
                if (!v.disabled && syntheticCheckedKeySet.has(v.key)) {
                  syntheticCheckedKeySet.delete(v.key);
                }
              });
            }

            syntheticCheckedKeySet.add(levelTreeNodeKey);
          } else if (partialChecked) {
            syntheticIndeterminateKeySet.add(levelTreeNodeKey);
          }

          if (levelIsZero && checkStrategyIsChild && syntheticCheckedKeySet.has(levelTreeNodeKey)) {
            syntheticCheckedKeySet.delete(levelTreeNodeKey);
          }
        }
      }

      return {
        checkedKeys: Array.from(syntheticCheckedKeySet),
        indeterminateKeys: Array.from(syntheticIndeterminateKeySet)
      };
    } // unchecking is safe when doing cascade uncheck in async mode

    function getExtendedCheckedKeySet(checkedKeys, treeMate, allowNotLoaded, isUnchecking) {
      const {
        treeNodeMap,
        getChildren
      } = treeMate;
      const visitedKeySet = new Set();
      const extendedKeySet = new Set(checkedKeys);
      checkedKeys.forEach(checkedKey => {
        const checkedTreeNode = treeNodeMap.get(checkedKey);

        if (checkedTreeNode !== undefined) {
          traverseWithCb(checkedTreeNode, treeNode => {
            if (treeNode.disabled) {
              return TRAVERSE_COMMAND.STOP;
            }

            const {
              key
            } = treeNode;
            if (visitedKeySet.has(key)) return;
            visitedKeySet.add(key); // Adding keys before loaded check is okay, since if not valid error
            // would be thrown

            extendedKeySet.add(key);

            if (isExpilicitlyNotLoaded(treeNode.rawNode, getChildren)) {
              if (isUnchecking) {
                return TRAVERSE_COMMAND.STOP;
              } else if (!allowNotLoaded) {
                throw new SubtreeNotLoadedError();
              }
            }
          });
        }
      });
      return extendedKeySet;
    }

    function getPath(key, _ref, treeMate) {
      let {
        includeGroup = false,
        includeSelf = true
      } = _ref;

      var _a;

      const treeNodeMap = treeMate.treeNodeMap;
      let treeNode = key === null || key === undefined ? null : (_a = treeNodeMap.get(key)) !== null && _a !== void 0 ? _a : null;
      const mergedPath = {
        keyPath: [],
        treeNodePath: [],
        treeNode: treeNode
      };

      if (treeNode === null || treeNode === void 0 ? void 0 : treeNode.ignored) {
        mergedPath.treeNode = null;
        return mergedPath;
      }

      while (treeNode) {
        if (!treeNode.ignored && (includeGroup || !treeNode.isGroup)) {
          mergedPath.treeNodePath.push(treeNode);
        }

        treeNode = treeNode.parent;
      }

      mergedPath.treeNodePath.reverse();
      if (!includeSelf) mergedPath.treeNodePath.pop();
      mergedPath.keyPath = mergedPath.treeNodePath.map(treeNode => treeNode.key);
      return mergedPath;
    }

    function getFirstAvailableNode(nodes) {
      if (nodes.length === 0) return null;
      const node = nodes[0];

      if (node.isGroup || node.ignored || node.disabled) {
        return node.getNext();
      }

      return node;
    }

    function rawGetNext(node, loop) {
      const sibs = node.siblings;
      const l = sibs.length;
      const {
        index
      } = node;

      if (loop) {
        return sibs[(index + 1) % l];
      } else {
        if (index === sibs.length - 1) return null;
        return sibs[index + 1];
      }
    }

    function move(fromNode, dir) {
      let {
        loop = false,
        includeDisabled = false
      } = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
      const iterate = dir === 'prev' ? rawGetPrev : rawGetNext;
      const getChildOptions = {
        reverse: dir === 'prev'
      };
      let meet = false;
      let endNode = null;

      function traverse(node) {
        if (node === null) return;

        if (node === fromNode) {
          if (!meet) {
            meet = true;
          } else if (!fromNode.disabled && !fromNode.isGroup) {
            endNode = fromNode;
            return;
          }
        } else {
          if ((!node.disabled || includeDisabled) && !node.ignored && !node.isGroup) {
            endNode = node;
            return;
          }
        }

        if (node.isGroup) {
          const child = getChild(node, getChildOptions);

          if (child !== null) {
            endNode = child;
          } else {
            traverse(iterate(node, loop));
          }
        } else {
          const nextNode = iterate(node, false);

          if (nextNode !== null) {
            traverse(nextNode);
          } else {
            const parent = rawGetParent(node);

            if (parent === null || parent === void 0 ? void 0 : parent.isGroup) {
              traverse(iterate(parent, loop));
            } else if (loop) {
              traverse(iterate(node, true));
            }
          }
        }
      }

      traverse(fromNode);
      return endNode;
    }

    function rawGetPrev(node, loop) {
      const sibs = node.siblings;
      const l = sibs.length;
      const {
        index
      } = node;

      if (loop) {
        return sibs[(index - 1 + l) % l];
      } else {
        if (index === 0) return null;
        return sibs[index - 1];
      }
    }

    function rawGetParent(node) {
      return node.parent;
    }

    function getChild(node) {
      let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      const {
        reverse = false
      } = options;
      const {
        children
      } = node;

      if (children) {
        const {
          length
        } = children;
        const start = reverse ? length - 1 : 0;
        const end = reverse ? -1 : length;
        const delta = reverse ? -1 : 1;

        for (let i = start; i !== end; i += delta) {
          const child = children[i];

          if (!child.disabled && !child.ignored) {
            if (child.isGroup) {
              const childInGroup = getChild(child, options);
              if (childInGroup !== null) return childInGroup;
            } else {
              return child;
            }
          }
        }
      }

      return null;
    }

    const moveMethods = {
      getChild() {
        if (this.ignored) return null;
        return getChild(this);
      },

      getParent() {
        const {
          parent
        } = this;

        if (parent === null || parent === void 0 ? void 0 : parent.isGroup) {
          return parent.getParent();
        }

        return parent;
      },

      getNext() {
        let options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
        return move(this, 'next', options);
      },

      getPrev() {
        let options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
        return move(this, 'prev', options);
      }

    };

    function flatten$1(treeNodes, expandedKeys) {
      const expandedKeySet = expandedKeys ? new Set(expandedKeys) : undefined;
      const flattenedNodes = [];

      function traverse(treeNodes) {
        treeNodes.forEach(treeNode => {
          flattenedNodes.push(treeNode);
          if (treeNode.isLeaf || !treeNode.children || treeNode.ignored) return;

          if (treeNode.isGroup) {
            // group node shouldn't be expanded
            traverse(treeNode.children);
          } else if ( // normal non-leaf node
          expandedKeySet === undefined || expandedKeySet.has(treeNode.key)) {
            traverse(treeNode.children);
          }
        });
      }

      traverse(treeNodes);
      return flattenedNodes;
    }

    function contains(parent, child) {
      const parentKey = parent.key; // eslint-disable-next-line no-unmodified-loop-condition

      while (child) {
        if (child.key === parentKey) return true;
        child = child.parent;
      }

      return false;
    }

    function createTreeNodes(rawNodes, treeNodeMap, levelTreeNodeMap, nodeProto, getChildren) {
      let parent = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : null;
      let level = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : 0;
      const treeNodes = [];
      rawNodes.forEach((rawNode, index) => {
        var _a;

        if (isNodeInvalid(rawNode, getChildren)) {
          console.error('[treemate]: node', rawNode, 'is invalid');
        }

        const treeNode = Object.create(nodeProto);
        treeNode.rawNode = rawNode;
        treeNode.siblings = treeNodes;
        treeNode.level = level;
        treeNode.index = index;
        treeNode.isFirstChild = index === 0;
        treeNode.isLastChild = index + 1 === rawNodes.length;
        treeNode.parent = parent;

        if (!treeNode.ignored) {
          const rawChildren = getChildren(rawNode);

          if (Array.isArray(rawChildren)) {
            treeNode.children = createTreeNodes(rawChildren, treeNodeMap, levelTreeNodeMap, nodeProto, getChildren, treeNode, level + 1);
          }
        }

        treeNodes.push(treeNode);
        treeNodeMap.set(treeNode.key, treeNode);
        if (!levelTreeNodeMap.has(level)) levelTreeNodeMap.set(level, []);
        (_a = levelTreeNodeMap.get(level)) === null || _a === void 0 ? void 0 : _a.push(treeNode);
      });
      return treeNodes;
    }

    function createTreeMate(rawNodes) {
      let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      var _a;

      const treeNodeMap = new Map();
      const levelTreeNodeMap = new Map();
      const {
        getDisabled = isDisabled,
        getIgnored = isIgnored,
        getIsGroup = isGroup,
        getKey = defaultGetKey
      } = options;

      const _getChildren = (_a = options.getChildren) !== null && _a !== void 0 ? _a : defaultGetChildren;

      const getChildren = options.ignoreEmptyChildren ? node => {
        const children = _getChildren(node);

        if (Array.isArray(children)) {
          if (!children.length) return null;
          return children;
        }

        return children;
      } : _getChildren;
      const nodeProto = Object.assign({
        get key() {
          // do not pass parent or related things to it
          // the key need to be specified explicitly
          return getKey(this.rawNode);
        },

        get disabled() {
          return getDisabled(this.rawNode);
        },

        get isGroup() {
          return getIsGroup(this.rawNode);
        },

        get isLeaf() {
          return isLeaf(this.rawNode, getChildren);
        },

        get shallowLoaded() {
          return isShallowLoaded(this.rawNode, getChildren);
        },

        get ignored() {
          return getIgnored(this.rawNode);
        },

        contains(node) {
          return contains(this, node);
        }

      }, moveMethods);
      const treeNodes = createTreeNodes(rawNodes, treeNodeMap, levelTreeNodeMap, nodeProto, getChildren);

      function getNode(key) {
        if (key === null || key === undefined) return null;
        const tmNode = treeNodeMap.get(key);

        if (tmNode && !tmNode.isGroup && !tmNode.ignored) {
          return tmNode;
        }

        return null;
      }

      function _getNode(key) {
        if (key === null || key === undefined) return null;
        const tmNode = treeNodeMap.get(key);

        if (tmNode && !tmNode.ignored) {
          return tmNode;
        }

        return null;
      }

      function getPrev(key, options) {
        const node = _getNode(key);

        if (!node) return null;
        return node.getPrev(options);
      }

      function getNext(key, options) {
        const node = _getNode(key);

        if (!node) return null;
        return node.getNext(options);
      }

      function getParent(key) {
        const node = _getNode(key);

        if (!node) return null;
        return node.getParent();
      }

      function getChild(key) {
        const node = _getNode(key);

        if (!node) return null;
        return node.getChild();
      }

      const treemate = {
        treeNodes,
        treeNodeMap,
        levelTreeNodeMap,
        maxLevel: Math.max(...levelTreeNodeMap.keys()),
        getChildren,

        getFlattenedNodes(expandedKeys) {
          return flatten$1(treeNodes, expandedKeys);
        },

        getNode,
        getPrev,
        getNext,
        getParent,
        getChild,

        getFirstAvailableNode() {
          return getFirstAvailableNode(treeNodes);
        },

        getPath(key) {
          let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
          return getPath(key, options, treemate);
        },

        getCheckedKeys(checkedKeys) {
          let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
          const {
            cascade = true,
            leafOnly = false,
            checkStrategy = 'all',
            allowNotLoaded = false
          } = options;
          return getCheckedKeys({
            checkedKeys: unwrapCheckedKeys(checkedKeys),
            indeterminateKeys: unwrapIndeterminateKeys(checkedKeys),
            cascade,
            leafOnly,
            checkStrategy,
            allowNotLoaded
          }, treemate);
        },

        check(keysToCheck, checkedKeys) {
          let options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
          const {
            cascade = true,
            leafOnly = false,
            checkStrategy = 'all',
            allowNotLoaded = false
          } = options;
          return getCheckedKeys({
            checkedKeys: unwrapCheckedKeys(checkedKeys),
            indeterminateKeys: unwrapIndeterminateKeys(checkedKeys),
            keysToCheck: keysToCheck === undefined || keysToCheck === null ? [] : toArray(keysToCheck),
            cascade,
            leafOnly,
            checkStrategy,
            allowNotLoaded
          }, treemate);
        },

        uncheck(keysToUncheck, checkedKeys) {
          let options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
          const {
            cascade = true,
            leafOnly = false,
            checkStrategy = 'all',
            allowNotLoaded = false
          } = options;
          return getCheckedKeys({
            checkedKeys: unwrapCheckedKeys(checkedKeys),
            indeterminateKeys: unwrapIndeterminateKeys(checkedKeys),
            keysToUncheck: keysToUncheck === null || keysToUncheck === undefined ? [] : toArray(keysToUncheck),
            cascade,
            leafOnly,
            checkStrategy,
            allowNotLoaded
          }, treemate);
        },

        getNonLeafKeys() {
          let options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
          return getNonLeafKeys(treeNodes, options);
        }

      };
      return treemate;
    }

    const base$1 = {
      neutralBase: "#000",
      neutralInvertBase: "#fff",
      neutralTextBase: "#fff",
      neutralPopover: "rgb(72, 72, 78)",
      neutralCard: "rgb(24, 24, 28)",
      neutralModal: "rgb(44, 44, 50)",
      neutralBody: "rgb(16, 16, 20)",
      alpha1: "0.9",
      alpha2: "0.82",
      alpha3: "0.52",
      alpha4: "0.38",
      alpha5: "0.28",
      alphaClose: "0.52",
      alphaDisabled: "0.38",
      alphaDisabledInput: "0.06",
      alphaPending: "0.09",
      alphaTablePending: "0.06",
      alphaTableStriped: "0.05",
      alphaPressed: "0.05",
      alphaAvatar: "0.18",
      alphaRail: "0.2",
      alphaProgressRail: "0.12",
      alphaBorder: "0.24",
      alphaDivider: "0.09",
      alphaInput: "0.1",
      alphaAction: "0.06",
      alphaTab: "0.04",
      alphaScrollbar: "0.2",
      alphaScrollbarHover: "0.3",
      alphaCode: "0.12",
      alphaTag: "0.2",
      primaryHover: "#7fe7c4",
      primaryDefault: "#63e2b7",
      primaryActive: "#5acea7",
      primarySuppl: "rgb(42, 148, 125)",
      infoHover: "#8acbec",
      infoDefault: "#70c0e8",
      infoActive: "#66afd3",
      infoSuppl: "rgb(56, 137, 197)",
      errorHover: "#e98b8b",
      errorDefault: "#e88080",
      errorActive: "#e57272",
      errorSuppl: "rgb(208, 58, 82)",
      warningHover: "#f5d599",
      warningDefault: "#f2c97d",
      warningActive: "#e6c260",
      warningSuppl: "rgb(240, 138, 0)",
      successHover: "#7fe7c4",
      successDefault: "#63e2b7",
      successActive: "#5acea7",
      successSuppl: "rgb(42, 148, 125)"
    };
    const baseBackgroundRgb$1 = rgba(base$1.neutralBase);
    const baseInvertBackgroundRgb$1 = rgba(base$1.neutralInvertBase);
    const overlayPrefix$1 = "rgba(" + baseInvertBackgroundRgb$1.slice(0, 3).join(", ") + ", ";

    function overlay$1(alpha) {
      return overlayPrefix$1 + String(alpha) + ")";
    }

    function neutral$1(alpha) {
      const overlayRgba = Array.from(baseInvertBackgroundRgb$1);
      overlayRgba[3] = Number(alpha);
      return composite(baseBackgroundRgb$1, overlayRgba);
    }

    const derived$1 = {
      name: "common",
      ...commonVariables$m,
      baseColor: base$1.neutralBase,
      primaryColor: base$1.primaryDefault,
      primaryColorHover: base$1.primaryHover,
      primaryColorPressed: base$1.primaryActive,
      primaryColorSuppl: base$1.primarySuppl,
      infoColor: base$1.infoDefault,
      infoColorHover: base$1.infoHover,
      infoColorPressed: base$1.infoActive,
      infoColorSuppl: base$1.infoSuppl,
      successColor: base$1.successDefault,
      successColorHover: base$1.successHover,
      successColorPressed: base$1.successActive,
      successColorSuppl: base$1.successSuppl,
      warningColor: base$1.warningDefault,
      warningColorHover: base$1.warningHover,
      warningColorPressed: base$1.warningActive,
      warningColorSuppl: base$1.warningSuppl,
      errorColor: base$1.errorDefault,
      errorColorHover: base$1.errorHover,
      errorColorPressed: base$1.errorActive,
      errorColorSuppl: base$1.errorSuppl,
      textColorBase: base$1.neutralTextBase,
      textColor1: overlay$1(base$1.alpha1),
      textColor2: overlay$1(base$1.alpha2),
      textColor3: overlay$1(base$1.alpha3),
      textColorDisabled: overlay$1(base$1.alpha4),
      placeholderColor: overlay$1(base$1.alpha4),
      placeholderColorDisabled: overlay$1(base$1.alpha5),
      iconColor: overlay$1(base$1.alpha4),
      iconColorDisabled: overlay$1(base$1.alpha5),
      iconColorHover: overlay$1(Number(base$1.alpha4) * 1.25),
      iconColorPressed: overlay$1(Number(base$1.alpha4) * 0.8),
      opacity1: base$1.alpha1,
      opacity2: base$1.alpha2,
      opacity3: base$1.alpha3,
      opacity4: base$1.alpha4,
      opacity5: base$1.alpha5,
      dividerColor: overlay$1(base$1.alphaDivider),
      borderColor: overlay$1(base$1.alphaBorder),
      closeIconColorHover: overlay$1(Number(base$1.alphaClose)),
      closeIconColor: overlay$1(Number(base$1.alphaClose)),
      closeIconColorPressed: overlay$1(Number(base$1.alphaClose)),
      closeColorHover: "rgba(255, 255, 255, .12)",
      closeColorPressed: "rgba(255, 255, 255, .08)",
      clearColor: overlay$1(base$1.alpha4),
      clearColorHover: scaleColor(overlay$1(base$1.alpha4), {
        alpha: 1.25
      }),
      clearColorPressed: scaleColor(overlay$1(base$1.alpha4), {
        alpha: 0.8
      }),
      scrollbarColor: overlay$1(base$1.alphaScrollbar),
      scrollbarColorHover: overlay$1(base$1.alphaScrollbarHover),
      scrollbarWidth: "5px",
      scrollbarHeight: "5px",
      scrollbarBorderRadius: "5px",
      progressRailColor: overlay$1(base$1.alphaProgressRail),
      railColor: overlay$1(base$1.alphaRail),
      popoverColor: base$1.neutralPopover,
      tableColor: base$1.neutralCard,
      cardColor: base$1.neutralCard,
      modalColor: base$1.neutralModal,
      bodyColor: base$1.neutralBody,
      tagColor: neutral$1(base$1.alphaTag),
      avatarColor: overlay$1(base$1.alphaAvatar),
      invertedColor: base$1.neutralBase,
      inputColor: overlay$1(base$1.alphaInput),
      codeColor: overlay$1(base$1.alphaCode),
      tabColor: overlay$1(base$1.alphaTab),
      actionColor: overlay$1(base$1.alphaAction),
      tableHeaderColor: overlay$1(base$1.alphaAction),
      hoverColor: overlay$1(base$1.alphaPending),
      tableColorHover: overlay$1(base$1.alphaTablePending),
      tableColorStriped: overlay$1(base$1.alphaTableStriped),
      pressedColor: overlay$1(base$1.alphaPressed),
      opacityDisabled: base$1.alphaDisabled,
      inputColorDisabled: overlay$1(base$1.alphaDisabledInput),
      buttonColor2: "rgba(255, 255, 255, .08)",
      buttonColor2Hover: "rgba(255, 255, 255, .12)",
      buttonColor2Pressed: "rgba(255, 255, 255, .08)",
      boxShadow1: "0 1px 2px -2px rgba(0, 0, 0, .24), 0 3px 6px 0 rgba(0, 0, 0, .18), 0 5px 12px 4px rgba(0, 0, 0, .12)",
      boxShadow2: "0 3px 6px -4px rgba(0, 0, 0, .24), 0 6px 12px 0 rgba(0, 0, 0, .16), 0 9px 18px 8px rgba(0, 0, 0, .10)",
      boxShadow3: "0 6px 16px -9px rgba(0, 0, 0, .08), 0 9px 28px 0 rgba(0, 0, 0, .05), 0 12px 48px 16px rgba(0, 0, 0, .03)"
    };
    var commonDark = derived$1;

    const base = {
      neutralBase: "#FFF",
      neutralInvertBase: "#000",
      neutralTextBase: "#000",
      neutralPopover: "#fff",
      neutralCard: "#fff",
      neutralModal: "#fff",
      neutralBody: "#fff",
      alpha1: "0.82",
      alpha2: "0.72",
      alpha3: "0.38",
      alpha4: "0.24",
      alpha5: "0.18",
      alphaClose: "0.6",
      alphaDisabled: "0.5",
      alphaDisabledInput: "0.02",
      alphaPending: "0.05",
      alphaTablePending: "0.02",
      alphaPressed: "0.07",
      alphaAvatar: "0.2",
      alphaRail: "0.14",
      alphaProgressRail: ".08",
      alphaBorder: "0.12",
      alphaDivider: "0.06",
      alphaInput: "0",
      alphaAction: "0.02",
      alphaTab: "0.04",
      alphaScrollbar: "0.25",
      alphaScrollbarHover: "0.4",
      alphaCode: "0.05",
      alphaTag: "0.02",
      primaryHover: "#36ad6a",
      primaryDefault: "#18a058",
      primaryActive: "#0c7a43",
      primarySuppl: "#36ad6a",
      infoHover: "#4098fc",
      infoDefault: "#2080f0",
      infoActive: "#1060c9",
      infoSuppl: "#4098fc",
      errorHover: "#de576d",
      errorDefault: "#d03050",
      errorActive: "#ab1f3f",
      errorSuppl: "#de576d",
      warningHover: "#fcb040",
      warningDefault: "#f0a020",
      warningActive: "#c97c10",
      warningSuppl: "#fcb040",
      successHover: "#36ad6a",
      successDefault: "#18a058",
      successActive: "#0c7a43",
      successSuppl: "#36ad6a"
    };
    const baseBackgroundRgb = rgba(base.neutralBase);
    const baseInvertBackgroundRgb = rgba(base.neutralInvertBase);
    const overlayPrefix = "rgba(" + baseInvertBackgroundRgb.slice(0, 3).join(", ") + ", ";

    function overlay(alpha) {
      return overlayPrefix + String(alpha) + ")";
    }

    function neutral(alpha) {
      const overlayRgba = Array.from(baseInvertBackgroundRgb);
      overlayRgba[3] = Number(alpha);
      return composite(baseBackgroundRgb, overlayRgba);
    }

    const derived = {
      name: "common",
      ...commonVariables$m,
      baseColor: base.neutralBase,
      primaryColor: base.primaryDefault,
      primaryColorHover: base.primaryHover,
      primaryColorPressed: base.primaryActive,
      primaryColorSuppl: base.primarySuppl,
      infoColor: base.infoDefault,
      infoColorHover: base.infoHover,
      infoColorPressed: base.infoActive,
      infoColorSuppl: base.infoSuppl,
      successColor: base.successDefault,
      successColorHover: base.successHover,
      successColorPressed: base.successActive,
      successColorSuppl: base.successSuppl,
      warningColor: base.warningDefault,
      warningColorHover: base.warningHover,
      warningColorPressed: base.warningActive,
      warningColorSuppl: base.warningSuppl,
      errorColor: base.errorDefault,
      errorColorHover: base.errorHover,
      errorColorPressed: base.errorActive,
      errorColorSuppl: base.errorSuppl,
      textColorBase: base.neutralTextBase,
      textColor1: "rgb(31, 34, 37)",
      textColor2: "rgb(51, 54, 57)",
      textColor3: "rgb(118, 124, 130)",
      textColorDisabled: neutral(base.alpha4),
      placeholderColor: neutral(base.alpha4),
      placeholderColorDisabled: neutral(base.alpha5),
      iconColor: neutral(base.alpha4),
      iconColorHover: scaleColor(neutral(base.alpha4), {
        lightness: 0.75
      }),
      iconColorPressed: scaleColor(neutral(base.alpha4), {
        lightness: 0.9
      }),
      iconColorDisabled: neutral(base.alpha5),
      opacity1: base.alpha1,
      opacity2: base.alpha2,
      opacity3: base.alpha3,
      opacity4: base.alpha4,
      opacity5: base.alpha5,
      dividerColor: "rgb(239, 239, 245)",
      borderColor: "rgb(224, 224, 230)",
      closeIconColor: neutral(Number(base.alphaClose)),
      closeIconColorHover: neutral(Number(base.alphaClose)),
      closeIconColorPressed: neutral(Number(base.alphaClose)),
      closeColorHover: "rgba(0, 0, 0, .09)",
      closeColorPressed: "rgba(0, 0, 0, .13)",
      clearColor: neutral(base.alpha4),
      clearColorHover: scaleColor(neutral(base.alpha4), {
        lightness: 0.75
      }),
      clearColorPressed: scaleColor(neutral(base.alpha4), {
        lightness: 0.9
      }),
      scrollbarColor: overlay(base.alphaScrollbar),
      scrollbarColorHover: overlay(base.alphaScrollbarHover),
      scrollbarWidth: "5px",
      scrollbarHeight: "5px",
      scrollbarBorderRadius: "5px",
      progressRailColor: neutral(base.alphaProgressRail),
      railColor: "rgb(219, 219, 223)",
      popoverColor: base.neutralPopover,
      tableColor: base.neutralCard,
      cardColor: base.neutralCard,
      modalColor: base.neutralModal,
      bodyColor: base.neutralBody,
      tagColor: "#eee",
      avatarColor: neutral(base.alphaAvatar),
      invertedColor: "rgb(0, 20, 40)",
      inputColor: neutral(base.alphaInput),
      codeColor: "rgb(244, 244, 248)",
      tabColor: "rgb(247, 247, 250)",
      actionColor: "rgb(250, 250, 252)",
      tableHeaderColor: "rgb(250, 250, 252)",
      hoverColor: "rgb(243, 243, 245)",
      tableColorHover: "rgba(0, 0, 100, 0.03)",
      tableColorStriped: "rgba(0, 0, 100, 0.02)",
      pressedColor: "rgb(237, 237, 239)",
      opacityDisabled: base.alphaDisabled,
      inputColorDisabled: "rgb(250, 250, 252)",
      buttonColor2: "rgba(46, 51, 56, .05)",
      buttonColor2Hover: "rgba(46, 51, 56, .09)",
      buttonColor2Pressed: "rgba(46, 51, 56, .13)",
      boxShadow1: "0 1px 2px -2px rgba(0, 0, 0, .08), 0 3px 6px 0 rgba(0, 0, 0, .06), 0 5px 12px 4px rgba(0, 0, 0, .04)",
      boxShadow2: "0 3px 6px -4px rgba(0, 0, 0, .12), 0 6px 16px 0 rgba(0, 0, 0, .08), 0 9px 28px 8px rgba(0, 0, 0, .05)",
      boxShadow3: "0 6px 16px -9px rgba(0, 0, 0, .08), 0 9px 28px 0 rgba(0, 0, 0, .05), 0 12px 48px 16px rgba(0, 0, 0, .03)"
    };
    var commonLight = derived;

    var commonVars$c = {
      iconSizeSmall: "34px",
      iconSizeMedium: "40px",
      iconSizeLarge: "46px",
      iconSizeHuge: "52px"
    };

    const self$1b = vars => {
      const {
        textColorDisabled,
        iconColor,
        textColor2,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge,
        fontSizeHuge
      } = vars;
      return { ...commonVars$c,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge,
        fontSizeHuge,
        textColor: textColorDisabled,
        iconColor,
        extraTextColor: textColor2
      };
    };
    const emptyLight = {
      name: "Empty",
      common: commonLight,
      self: self$1b
    };
    var emptyLight$1 = emptyLight;

    const emptyDark = {
      name: "Empty",
      common: commonDark,
      self: self$1b
    };
    var emptyDark$1 = emptyDark;

    var style$1v = cB("empty", `
  display: flex;
  flex-direction: column;
  align-items: center;
  font-size: var(--n-font-size);
`, [cE("icon", `
    width: var(--n-icon-size);
    height: var(--n-icon-size);
    font-size: var(--n-icon-size);
    line-height: var(--n-icon-size);
    color: var(--n-icon-color);
    transition:
      color .3s var(--n-bezier);
  `, [c$1("+", [cE("description", `
        margin-top: 8px;
      `)])]), cE("description", `
    transition: color .3s var(--n-bezier);
    color: var(--n-text-color);
  `), cE("extra", `
    text-align: center;
    transition: color .3s var(--n-bezier);
    margin-top: 12px;
    color: var(--n-extra-text-color);
  `)]);

    const emptyProps = {
      ...useTheme.props,
      description: String,
      showDescription: {
        type: Boolean,
        default: true
      },
      showIcon: {
        type: Boolean,
        default: true
      },
      size: {
        type: String,
        default: "medium"
      },
      renderIcon: Function
    };
    var NEmpty = vue.defineComponent({
      name: "Empty",
      props: emptyProps,
      setup(props) {
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Empty",
          "-empty",
          style$1v,
          emptyLight$1,
          props,
          mergedClsPrefixRef
        );
        const { localeRef } = useLocale("Empty");
        const NConfigProvider = vue.inject(configProviderInjectionKey, null);
        const mergedDescriptionRef = vue.computed(() => {
          return props.description ?? NConfigProvider?.mergedComponentPropsRef.value?.Empty?.description;
        });
        const mergedRenderIconRef = vue.computed(
          () => NConfigProvider?.mergedComponentPropsRef.value?.Empty?.renderIcon || (() => /* @__PURE__ */ React.createElement(EmptyIcon, null))
        );
        const cssVarsRef = vue.computed(() => {
          const { size } = props;
          const {
            common: { cubicBezierEaseInOut },
            self: {
              [createKey("iconSize", size)]: iconSize,
              [createKey("fontSize", size)]: fontSize,
              textColor,
              iconColor,
              extraTextColor
            }
          } = themeRef.value;
          return {
            "--n-icon-size": iconSize,
            "--n-font-size": fontSize,
            "--n-bezier": cubicBezierEaseInOut,
            "--n-text-color": textColor,
            "--n-icon-color": iconColor,
            "--n-extra-text-color": extraTextColor
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "empty",
          vue.computed(() => {
            let hash = "";
            const { size } = props;
            hash += size[0];
            return hash;
          }),
          cssVarsRef,
          props
        ) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          mergedRenderIcon: mergedRenderIconRef,
          localizedDescription: vue.computed(() => {
            return mergedDescriptionRef.value || localeRef.value.description;
          }),
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { $slots, mergedClsPrefix, onRender } = this;
        onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          class: [`${mergedClsPrefix}-empty`, this.themeClass],
          style: this.cssVars
        }, this.showIcon ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-empty__icon`
        }, $slots.icon ? $slots.icon() : /* @__PURE__ */ React.createElement(NBaseIcon, {
          clsPrefix: mergedClsPrefix
        }, { default: this.mergedRenderIcon })) : null, this.showDescription ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-empty__description`
        }, $slots.default ? $slots.default() : this.localizedDescription) : null, $slots.extra ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-empty__extra`
        }, $slots.extra()) : null);
      }
    });

    const self$1a = vars => {
      const {
        scrollbarColor,
        scrollbarColorHover
      } = vars;
      return {
        color: scrollbarColor,
        colorHover: scrollbarColorHover
      };
    };
    const scrollbarLight = {
      name: "Scrollbar",
      common: commonLight,
      self: self$1a
    };
    var scrollbarLight$1 = scrollbarLight;

    const scrollbarDark = {
      name: "Scrollbar",
      common: commonDark,
      self: self$1a
    };
    var scrollbarDark$1 = scrollbarDark;

    var rtlStyle$r = cB("scrollbar", [cM("rtl", `
    direction: rtl;
  `, [c$1(">", [cB("scrollbar-rail", [cM("horizontal", [c$1(">", [cE("scrollbar", `
              left: 0;
              right: unset;
            `)])]), cM("vertical", `
          left: 4px;
          right: unset;
        `)])])])]);

    const scrollbarRtl = {
      name: "Scrollbar",
      style: rtlStyle$r
    };
    var scrollbarRtl$1 = scrollbarRtl;

    const {
      cubicBezierEaseInOut: cubicBezierEaseInOut$3
    } = commonVariables$m;
    function fadeInTransition() {
      let {
        name = "fade-in",
        enterDuration = "0.2s",
        leaveDuration = "0.2s",
        enterCubicBezier = cubicBezierEaseInOut$3,
        leaveCubicBezier = cubicBezierEaseInOut$3
      } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      return [c$1(`&.${name}-transition-enter-active`, {
        transition: `all ${enterDuration} ${enterCubicBezier}!important`
      }), c$1(`&.${name}-transition-leave-active`, {
        transition: `all ${leaveDuration} ${leaveCubicBezier}!important`
      }), c$1(`&.${name}-transition-enter-from, &.${name}-transition-leave-to`, {
        opacity: 0
      }), c$1(`&.${name}-transition-leave-from, &.${name}-transition-enter-to`, {
        opacity: 1
      })];
    }

    var style$1u = cB("scrollbar", `
  overflow: hidden;
  position: relative;
  z-index: auto;
  height: 100%;
  width: 100%;
`, [c$1(">", [cB("scrollbar-container", `
      width: 100%;
      overflow: scroll;
      height: 100%;
      max-height: inherit;
      scrollbar-width: none;
    `, [c$1("&::-webkit-scrollbar, &::-webkit-scrollbar-track-piece, &::-webkit-scrollbar-thumb", `
        width: 0;
        height: 0;
        display: none;
      `), c$1(">", [cB("scrollbar-content", `
          box-sizing: border-box;
          min-width: 100%;
        `)])])]), c$1(">, +", [cB("scrollbar-rail", `
      position: absolute;
      pointer-events: none;
      user-select: none;
      -webkit-user-select: none;
    `, [cM("horizontal", `
        left: 2px;
        right: 2px;
        bottom: 4px;
        height: var(--n-scrollbar-height);
      `, [c$1(">", [cE("scrollbar", `
            height: var(--n-scrollbar-height);
            border-radius: var(--n-scrollbar-border-radius);
            right: 0;
          `)])]), cM("vertical", `
        right: 4px;
        top: 2px;
        bottom: 2px;
        width: var(--n-scrollbar-width);
      `, [c$1(">", [cE("scrollbar", `
            width: var(--n-scrollbar-width);
            border-radius: var(--n-scrollbar-border-radius);
            bottom: 0;
          `)])]), cM("disabled", [c$1(">", [cE("scrollbar", {
      pointerEvents: "none"
    })])]), c$1(">", [cE("scrollbar", `
          position: absolute;
          cursor: pointer;
          pointer-events: all;
          background-color: var(--n-scrollbar-color);
          transition: background-color .2s var(--n-scrollbar-bezier);
        `, [fadeInTransition(), c$1("&:hover", {
      backgroundColor: "var(--n-scrollbar-color-hover)"
    })])])])])]);

    const scrollbarProps$1 = {
      ...useTheme.props,
      size: {
        type: Number,
        default: 5
      },
      duration: {
        type: Number,
        default: 0
      },
      scrollable: {
        type: Boolean,
        default: true
      },
      xScrollable: Boolean,
      trigger: {
        type: String,
        default: "hover"
      },
      useUnifiedContainer: Boolean,
      triggerDisplayManually: Boolean,
      container: Function,
      content: Function,
      containerClass: String,
      containerStyle: [String, Object],
      contentClass: String,
      contentStyle: [String, Object],
      horizontalRailStyle: [String, Object],
      verticalRailStyle: [String, Object],
      onScroll: Function,
      onWheel: Function,
      onResize: Function,
      internalOnUpdateScrollLeft: Function,
      internalHoistYRail: Boolean
    };
    const Scrollbar$2 = vue.defineComponent({
      name: "Scrollbar",
      props: scrollbarProps$1,
      inheritAttrs: false,
      setup(props) {
        const { mergedClsPrefixRef, inlineThemeDisabled, mergedRtlRef } = useConfig(props);
        const rtlEnabledRef = useRtl("Scrollbar", mergedRtlRef, mergedClsPrefixRef);
        const wrapperRef = vue.ref(null);
        const containerRef = vue.ref(null);
        const contentRef = vue.ref(null);
        const yRailRef = vue.ref(null);
        const xRailRef = vue.ref(null);
        const contentHeightRef = vue.ref(null);
        const contentWidthRef = vue.ref(null);
        const containerHeightRef = vue.ref(null);
        const containerWidthRef = vue.ref(null);
        const yRailSizeRef = vue.ref(null);
        const xRailSizeRef = vue.ref(null);
        const containerScrollTopRef = vue.ref(0);
        const containerScrollLeftRef = vue.ref(0);
        const isShowXBarRef = vue.ref(false);
        const isShowYBarRef = vue.ref(false);
        let yBarPressed = false;
        let xBarPressed = false;
        let xBarVanishTimerId;
        let yBarVanishTimerId;
        let memoYTop = 0;
        let memoXLeft = 0;
        let memoMouseX = 0;
        let memoMouseY = 0;
        const isIos = useIsIos();
        const yBarSizeRef = vue.computed(() => {
          const { value: containerHeight } = containerHeightRef;
          const { value: contentHeight } = contentHeightRef;
          const { value: yRailSize } = yRailSizeRef;
          if (containerHeight === null || contentHeight === null || yRailSize === null) {
            return 0;
          } else {
            return Math.min(
              containerHeight,
              yRailSize * containerHeight / contentHeight + props.size * 1.5
            );
          }
        });
        const yBarSizePxRef = vue.computed(() => {
          return `${yBarSizeRef.value}px`;
        });
        const xBarSizeRef = vue.computed(() => {
          const { value: containerWidth } = containerWidthRef;
          const { value: contentWidth } = contentWidthRef;
          const { value: xRailSize } = xRailSizeRef;
          if (containerWidth === null || contentWidth === null || xRailSize === null) {
            return 0;
          } else {
            return xRailSize * containerWidth / contentWidth + props.size * 1.5;
          }
        });
        const xBarSizePxRef = vue.computed(() => {
          return `${xBarSizeRef.value}px`;
        });
        const yBarTopRef = vue.computed(() => {
          const { value: containerHeight } = containerHeightRef;
          const { value: containerScrollTop } = containerScrollTopRef;
          const { value: contentHeight } = contentHeightRef;
          const { value: yRailSize } = yRailSizeRef;
          if (containerHeight === null || contentHeight === null || yRailSize === null) {
            return 0;
          } else {
            const heightDiff = contentHeight - containerHeight;
            if (!heightDiff)
              return 0;
            return containerScrollTop / heightDiff * (yRailSize - yBarSizeRef.value);
          }
        });
        const yBarTopPxRef = vue.computed(() => {
          return `${yBarTopRef.value}px`;
        });
        const xBarLeftRef = vue.computed(() => {
          const { value: containerWidth } = containerWidthRef;
          const { value: containerScrollLeft } = containerScrollLeftRef;
          const { value: contentWidth } = contentWidthRef;
          const { value: xRailSize } = xRailSizeRef;
          if (containerWidth === null || contentWidth === null || xRailSize === null) {
            return 0;
          } else {
            const widthDiff = contentWidth - containerWidth;
            if (!widthDiff)
              return 0;
            return containerScrollLeft / widthDiff * (xRailSize - xBarSizeRef.value);
          }
        });
        const xBarLeftPxRef = vue.computed(() => {
          return `${xBarLeftRef.value}px`;
        });
        const needYBarRef = vue.computed(() => {
          const { value: containerHeight } = containerHeightRef;
          const { value: contentHeight } = contentHeightRef;
          return containerHeight !== null && contentHeight !== null && contentHeight > containerHeight;
        });
        const needXBarRef = vue.computed(() => {
          const { value: containerWidth } = containerWidthRef;
          const { value: contentWidth } = contentWidthRef;
          return containerWidth !== null && contentWidth !== null && contentWidth > containerWidth;
        });
        const mergedShowXBarRef = vue.computed(() => {
          const { trigger } = props;
          return trigger === "none" || isShowXBarRef.value;
        });
        const mergedShowYBarRef = vue.computed(() => {
          const { trigger } = props;
          return trigger === "none" || isShowYBarRef.value;
        });
        const mergedContainerRef = vue.computed(() => {
          const { container } = props;
          if (container)
            return container();
          return containerRef.value;
        });
        const mergedContentRef = vue.computed(() => {
          const { content } = props;
          if (content)
            return content();
          return contentRef.value;
        });
        const activateState = useReactivated(() => {
          if (!props.container) {
            scrollTo({
              top: containerScrollTopRef.value,
              left: containerScrollLeftRef.value
            });
          }
        });
        const handleContentResize = () => {
          if (activateState.isDeactivated)
            return;
          sync();
        };
        const handleContainerResize = (e) => {
          if (activateState.isDeactivated)
            return;
          const { onResize } = props;
          if (onResize)
            onResize(e);
          sync();
        };
        const scrollTo = (options, y) => {
          if (!props.scrollable)
            return;
          if (typeof options === "number") {
            scrollToPosition(y ?? 0, options, 0, false, "auto");
            return;
          }
          const {
            left,
            top,
            index,
            elSize,
            position,
            behavior,
            el,
            debounce = true
          } = options;
          if (left !== void 0 || top !== void 0) {
            scrollToPosition(left ?? 0, top ?? 0, 0, false, behavior);
          }
          if (el !== void 0) {
            scrollToPosition(0, el.offsetTop, el.offsetHeight, debounce, behavior);
          } else if (index !== void 0 && elSize !== void 0) {
            scrollToPosition(0, index * elSize, elSize, debounce, behavior);
          } else if (position === "bottom") {
            scrollToPosition(0, Number.MAX_SAFE_INTEGER, 0, false, behavior);
          } else if (position === "top") {
            scrollToPosition(0, 0, 0, false, behavior);
          }
        };
        const scrollBy = (options, y) => {
          if (!props.scrollable)
            return;
          const { value: container } = mergedContainerRef;
          if (!container)
            return;
          if (typeof options === "object") {
            container.scrollBy(options);
          } else {
            container.scrollBy(options, y || 0);
          }
        };
        function scrollToPosition(left, top, elSize, debounce, behavior) {
          const { value: container } = mergedContainerRef;
          if (!container)
            return;
          if (debounce) {
            const { scrollTop, offsetHeight } = container;
            if (top > scrollTop) {
              if (top + elSize <= scrollTop + offsetHeight) ; else {
                container.scrollTo({
                  left,
                  top: top + elSize - offsetHeight,
                  behavior
                });
              }
              return;
            }
          }
          container.scrollTo({
            left,
            top,
            behavior
          });
        }
        function handleMouseEnterWrapper() {
          showXBar();
          showYBar();
          sync();
        }
        function handleMouseLeaveWrapper() {
          hideBar();
        }
        function hideBar() {
          hideYBar();
          hideXBar();
        }
        function hideYBar() {
          if (yBarVanishTimerId !== void 0) {
            window.clearTimeout(yBarVanishTimerId);
          }
          yBarVanishTimerId = window.setTimeout(() => {
            isShowYBarRef.value = false;
          }, props.duration);
        }
        function hideXBar() {
          if (xBarVanishTimerId !== void 0) {
            window.clearTimeout(xBarVanishTimerId);
          }
          xBarVanishTimerId = window.setTimeout(() => {
            isShowXBarRef.value = false;
          }, props.duration);
        }
        function showXBar() {
          if (xBarVanishTimerId !== void 0) {
            window.clearTimeout(xBarVanishTimerId);
          }
          isShowXBarRef.value = true;
        }
        function showYBar() {
          if (yBarVanishTimerId !== void 0) {
            window.clearTimeout(yBarVanishTimerId);
          }
          isShowYBarRef.value = true;
        }
        function handleScroll(e) {
          const { onScroll } = props;
          if (onScroll)
            onScroll(e);
          syncScrollState();
        }
        function syncScrollState() {
          const { value: container } = mergedContainerRef;
          if (container) {
            containerScrollTopRef.value = container.scrollTop;
            containerScrollLeftRef.value = container.scrollLeft * (rtlEnabledRef?.value ? -1 : 1);
          }
        }
        function syncPositionState() {
          const { value: content } = mergedContentRef;
          if (content) {
            contentHeightRef.value = content.offsetHeight;
            contentWidthRef.value = content.offsetWidth;
          }
          const { value: container } = mergedContainerRef;
          if (container) {
            containerHeightRef.value = container.offsetHeight;
            containerWidthRef.value = container.offsetWidth;
          }
          const { value: xRailEl } = xRailRef;
          const { value: yRailEl } = yRailRef;
          if (xRailEl) {
            xRailSizeRef.value = xRailEl.offsetWidth;
          }
          if (yRailEl) {
            yRailSizeRef.value = yRailEl.offsetHeight;
          }
        }
        function syncUnifiedContainer() {
          const { value: container } = mergedContainerRef;
          if (container) {
            containerScrollTopRef.value = container.scrollTop;
            containerScrollLeftRef.value = container.scrollLeft * (rtlEnabledRef?.value ? -1 : 1);
            containerHeightRef.value = container.offsetHeight;
            containerWidthRef.value = container.offsetWidth;
            contentHeightRef.value = container.scrollHeight;
            contentWidthRef.value = container.scrollWidth;
          }
          const { value: xRailEl } = xRailRef;
          const { value: yRailEl } = yRailRef;
          if (xRailEl) {
            xRailSizeRef.value = xRailEl.offsetWidth;
          }
          if (yRailEl) {
            yRailSizeRef.value = yRailEl.offsetHeight;
          }
        }
        function sync() {
          if (!props.scrollable)
            return;
          if (props.useUnifiedContainer) {
            syncUnifiedContainer();
          } else {
            syncPositionState();
            syncScrollState();
          }
        }
        function isMouseUpAway(e) {
          return !wrapperRef.value?.contains(
            getPreciseEventTarget(e)
          );
        }
        function handleXScrollMouseDown(e) {
          e.preventDefault();
          e.stopPropagation();
          xBarPressed = true;
          on("mousemove", window, handleXScrollMouseMove, true);
          on("mouseup", window, handleXScrollMouseUp, true);
          memoXLeft = containerScrollLeftRef.value;
          memoMouseX = rtlEnabledRef?.value ? window.innerWidth - e.clientX : e.clientX;
        }
        function handleXScrollMouseMove(e) {
          if (!xBarPressed)
            return;
          if (xBarVanishTimerId !== void 0) {
            window.clearTimeout(xBarVanishTimerId);
          }
          if (yBarVanishTimerId !== void 0) {
            window.clearTimeout(yBarVanishTimerId);
          }
          const { value: containerWidth } = containerWidthRef;
          const { value: contentWidth } = contentWidthRef;
          const { value: xBarSize } = xBarSizeRef;
          if (containerWidth === null || contentWidth === null)
            return;
          const dX = rtlEnabledRef?.value ? window.innerWidth - e.clientX - memoMouseX : e.clientX - memoMouseX;
          const dScrollLeft = dX * (contentWidth - containerWidth) / (containerWidth - xBarSize);
          const toScrollLeftUpperBound = contentWidth - containerWidth;
          let toScrollLeft = memoXLeft + dScrollLeft;
          toScrollLeft = Math.min(toScrollLeftUpperBound, toScrollLeft);
          toScrollLeft = Math.max(toScrollLeft, 0);
          const { value: container } = mergedContainerRef;
          if (container) {
            container.scrollLeft = toScrollLeft * (rtlEnabledRef?.value ? -1 : 1);
            const { internalOnUpdateScrollLeft } = props;
            if (internalOnUpdateScrollLeft)
              internalOnUpdateScrollLeft(toScrollLeft);
          }
        }
        function handleXScrollMouseUp(e) {
          e.preventDefault();
          e.stopPropagation();
          off("mousemove", window, handleXScrollMouseMove, true);
          off("mouseup", window, handleXScrollMouseUp, true);
          xBarPressed = false;
          sync();
          if (isMouseUpAway(e)) {
            hideBar();
          }
        }
        function handleYScrollMouseDown(e) {
          e.preventDefault();
          e.stopPropagation();
          yBarPressed = true;
          on("mousemove", window, handleYScrollMouseMove, true);
          on("mouseup", window, handleYScrollMouseUp, true);
          memoYTop = containerScrollTopRef.value;
          memoMouseY = e.clientY;
        }
        function handleYScrollMouseMove(e) {
          if (!yBarPressed)
            return;
          if (xBarVanishTimerId !== void 0) {
            window.clearTimeout(xBarVanishTimerId);
          }
          if (yBarVanishTimerId !== void 0) {
            window.clearTimeout(yBarVanishTimerId);
          }
          const { value: containerHeight } = containerHeightRef;
          const { value: contentHeight } = contentHeightRef;
          const { value: yBarSize } = yBarSizeRef;
          if (containerHeight === null || contentHeight === null)
            return;
          const dY = e.clientY - memoMouseY;
          const dScrollTop = dY * (contentHeight - containerHeight) / (containerHeight - yBarSize);
          const toScrollTopUpperBound = contentHeight - containerHeight;
          let toScrollTop = memoYTop + dScrollTop;
          toScrollTop = Math.min(toScrollTopUpperBound, toScrollTop);
          toScrollTop = Math.max(toScrollTop, 0);
          const { value: container } = mergedContainerRef;
          if (container) {
            container.scrollTop = toScrollTop;
          }
        }
        function handleYScrollMouseUp(e) {
          e.preventDefault();
          e.stopPropagation();
          off("mousemove", window, handleYScrollMouseMove, true);
          off("mouseup", window, handleYScrollMouseUp, true);
          yBarPressed = false;
          sync();
          if (isMouseUpAway(e)) {
            hideBar();
          }
        }
        vue.watchEffect(() => {
          const { value: needXBar } = needXBarRef;
          const { value: needYBar } = needYBarRef;
          const { value: mergedClsPrefix } = mergedClsPrefixRef;
          const { value: xRailEl } = xRailRef;
          const { value: yRailEl } = yRailRef;
          if (xRailEl) {
            if (!needXBar) {
              xRailEl.classList.add(`${mergedClsPrefix}-scrollbar-rail--disabled`);
            } else {
              xRailEl.classList.remove(
                `${mergedClsPrefix}-scrollbar-rail--disabled`
              );
            }
          }
          if (yRailEl) {
            if (!needYBar) {
              yRailEl.classList.add(`${mergedClsPrefix}-scrollbar-rail--disabled`);
            } else {
              yRailEl.classList.remove(
                `${mergedClsPrefix}-scrollbar-rail--disabled`
              );
            }
          }
        });
        vue.onMounted(() => {
          if (props.container)
            return;
          sync();
        });
        vue.onBeforeUnmount(() => {
          if (xBarVanishTimerId !== void 0) {
            window.clearTimeout(xBarVanishTimerId);
          }
          if (yBarVanishTimerId !== void 0) {
            window.clearTimeout(yBarVanishTimerId);
          }
          off("mousemove", window, handleYScrollMouseMove, true);
          off("mouseup", window, handleYScrollMouseUp, true);
        });
        const themeRef = useTheme(
          "Scrollbar",
          "-scrollbar",
          style$1u,
          scrollbarLight$1,
          props,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const {
            common: {
              cubicBezierEaseInOut,
              scrollbarBorderRadius,
              scrollbarHeight,
              scrollbarWidth
            },
            self: { color, colorHover }
          } = themeRef.value;
          return {
            "--n-scrollbar-bezier": cubicBezierEaseInOut,
            "--n-scrollbar-color": color,
            "--n-scrollbar-color-hover": colorHover,
            "--n-scrollbar-border-radius": scrollbarBorderRadius,
            "--n-scrollbar-width": scrollbarWidth,
            "--n-scrollbar-height": scrollbarHeight
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("scrollbar", void 0, cssVarsRef, props) : void 0;
        const exposedMethods = {
          scrollTo,
          scrollBy,
          sync,
          syncUnifiedContainer,
          handleMouseEnterWrapper,
          handleMouseLeaveWrapper
        };
        return {
          ...exposedMethods,
          mergedClsPrefix: mergedClsPrefixRef,
          rtlEnabled: rtlEnabledRef,
          containerScrollTop: containerScrollTopRef,
          wrapperRef,
          containerRef,
          contentRef,
          yRailRef,
          xRailRef,
          needYBar: needYBarRef,
          needXBar: needXBarRef,
          yBarSizePx: yBarSizePxRef,
          xBarSizePx: xBarSizePxRef,
          yBarTopPx: yBarTopPxRef,
          xBarLeftPx: xBarLeftPxRef,
          isShowXBar: mergedShowXBarRef,
          isShowYBar: mergedShowYBarRef,
          isIos,
          handleScroll,
          handleContentResize,
          handleContainerResize,
          handleYScrollMouseDown,
          handleXScrollMouseDown,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const {
          $slots,
          mergedClsPrefix,
          triggerDisplayManually,
          rtlEnabled,
          internalHoistYRail
        } = this;
        if (!this.scrollable)
          return $slots.default?.();
        const triggerIsNone = this.trigger === "none";
        const createYRail = () => {
          return /* @__PURE__ */ React.createElement("div", {
            ref: "yRailRef",
            class: [
              `${mergedClsPrefix}-scrollbar-rail`,
              `${mergedClsPrefix}-scrollbar-rail--vertical`
            ],
            "data-scrollbar-rail": true,
            style: this.verticalRailStyle,
            "aria-hidden": true
          }, vue.h(
            triggerIsNone ? Wrapper : vue.Transition,
            triggerIsNone ? null : { name: "fade-in-transition" },
            {
              default: () => this.needYBar && this.isShowYBar && !this.isIos ? /* @__PURE__ */ React.createElement("div", {
                class: `${mergedClsPrefix}-scrollbar-rail__scrollbar`,
                style: {
                  height: this.yBarSizePx,
                  top: this.yBarTopPx
                },
                onMousedown: this.handleYScrollMouseDown
              }) : null
            }
          ));
        };
        const createChildren = () => {
          this.onRender?.();
          return vue.h(
            "div",
            vue.mergeProps(this.$attrs, {
              role: "none",
              ref: "wrapperRef",
              class: [
                `${mergedClsPrefix}-scrollbar`,
                this.themeClass,
                rtlEnabled && `${mergedClsPrefix}-scrollbar--rtl`
              ],
              style: this.cssVars,
              onMouseenter: triggerDisplayManually ? void 0 : this.handleMouseEnterWrapper,
              onMouseleave: triggerDisplayManually ? void 0 : this.handleMouseLeaveWrapper
            }),
            [
              this.container ? $slots.default?.() : /* @__PURE__ */ React.createElement("div", {
                role: "none",
                ref: "containerRef",
                class: [
                  `${mergedClsPrefix}-scrollbar-container`,
                  this.containerClass
                ],
                style: this.containerStyle,
                onScroll: this.handleScroll,
                onWheel: this.onWheel
              }, /* @__PURE__ */ React.createElement(VResizeObserver, {
                onResize: this.handleContentResize
              }, {
                default: () => /* @__PURE__ */ React.createElement("div", {
                  ref: "contentRef",
                  role: "none",
                  style: [
                    {
                      width: this.xScrollable ? "fit-content" : null
                    },
                    this.contentStyle
                  ],
                  class: [
                    `${mergedClsPrefix}-scrollbar-content`,
                    this.contentClass
                  ]
                }, $slots)
              })),
              internalHoistYRail ? null : createYRail(),
              this.xScrollable && /* @__PURE__ */ React.createElement("div", {
                ref: "xRailRef",
                class: [
                  `${mergedClsPrefix}-scrollbar-rail`,
                  `${mergedClsPrefix}-scrollbar-rail--horizontal`
                ],
                style: this.horizontalRailStyle,
                "data-scrollbar-rail": true,
                "aria-hidden": true
              }, vue.h(
                triggerIsNone ? Wrapper : vue.Transition,
                triggerIsNone ? null : { name: "fade-in-transition" },
                {
                  default: () => this.needXBar && this.isShowXBar && !this.isIos ? /* @__PURE__ */ React.createElement("div", {
                    class: `${mergedClsPrefix}-scrollbar-rail__scrollbar`,
                    style: {
                      width: this.xBarSizePx,
                      right: rtlEnabled ? this.xBarLeftPx : void 0,
                      left: rtlEnabled ? void 0 : this.xBarLeftPx
                    },
                    onMousedown: this.handleXScrollMouseDown
                  }) : null
                }
              ))
            ]
          );
        };
        const scrollbarNode = this.container ? createChildren() : /* @__PURE__ */ React.createElement(VResizeObserver, {
          onResize: this.handleContainerResize
        }, {
          default: createChildren
        });
        if (internalHoistYRail) {
          return /* @__PURE__ */ React.createElement(vue.Fragment, null, scrollbarNode, createYRail());
        } else {
          return scrollbarNode;
        }
      }
    });
    var NScrollbar = Scrollbar$2;
    const XScrollbar = Scrollbar$2;

    var commonVariables$l = {
      height: "calc(var(--n-option-height) * 7.6)",
      paddingSmall: "4px 0",
      paddingMedium: "4px 0",
      paddingLarge: "4px 0",
      paddingHuge: "4px 0",
      optionPaddingSmall: "0 12px",
      optionPaddingMedium: "0 12px",
      optionPaddingLarge: "0 12px",
      optionPaddingHuge: "0 12px",
      loadingSize: "18px"
    };

    const self$19 = vars => {
      const {
        borderRadius,
        popoverColor,
        textColor3,
        dividerColor,
        textColor2,
        primaryColorPressed,
        textColorDisabled,
        primaryColor,
        opacityDisabled,
        hoverColor,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge,
        fontSizeHuge,
        heightSmall,
        heightMedium,
        heightLarge,
        heightHuge
      } = vars;
      return { ...commonVariables$l,
        optionFontSizeSmall: fontSizeSmall,
        optionFontSizeMedium: fontSizeMedium,
        optionFontSizeLarge: fontSizeLarge,
        optionFontSizeHuge: fontSizeHuge,
        optionHeightSmall: heightSmall,
        optionHeightMedium: heightMedium,
        optionHeightLarge: heightLarge,
        optionHeightHuge: heightHuge,
        borderRadius,
        color: popoverColor,
        groupHeaderTextColor: textColor3,
        actionDividerColor: dividerColor,
        optionTextColor: textColor2,
        optionTextColorPressed: primaryColorPressed,
        optionTextColorDisabled: textColorDisabled,
        optionTextColorActive: primaryColor,
        optionOpacityDisabled: opacityDisabled,
        optionCheckColor: primaryColor,
        optionColorPending: hoverColor,
        optionColorActive: "rgba(0, 0, 0, 0)",
        optionColorActivePending: hoverColor,
        actionTextColor: textColor2,
        loadingColor: primaryColor
      };
    };
    const internalSelectMenuLight = createTheme$1({
      name: "InternalSelectMenu",
      common: commonLight,
      peers: {
        Scrollbar: scrollbarLight$1,
        Empty: emptyLight$1
      },
      self: self$19
    });
    var internalSelectMenuLight$1 = internalSelectMenuLight;

    const internalSelectMenuDark = {
      name: "InternalSelectMenu",
      common: commonDark,
      peers: {
        Scrollbar: scrollbarDark$1,
        Empty: emptyDark$1
      },
      self: self$19
    };
    var internalSelectMenuDark$1 = internalSelectMenuDark;

    function renderCheckMark(show, clsPrefix) {
      return /* @__PURE__ */ React.createElement(vue.Transition, {
        name: "fade-in-scale-up-transition"
      }, {
        default: () => show ? /* @__PURE__ */ React.createElement(NBaseIcon, {
          clsPrefix,
          class: `${clsPrefix}-base-select-option__check`
        }, {
          default: () => vue.h(FinishedIcon)
        }) : null
      });
    }
    var NSelectOption = vue.defineComponent({
      name: "NBaseSelectOption",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        tmNode: {
          type: Object,
          required: true
        }
      },
      setup(props) {
        const {
          valueRef,
          pendingTmNodeRef,
          multipleRef,
          valueSetRef,
          renderLabelRef,
          renderOptionRef,
          labelFieldRef,
          valueFieldRef,
          showCheckmarkRef,
          nodePropsRef,
          handleOptionClick,
          handleOptionMouseEnter
        } = vue.inject(internalSelectionMenuInjectionKey);
        const isPendingRef = useMemo(() => {
          const { value: pendingTmNode } = pendingTmNodeRef;
          if (!pendingTmNode)
            return false;
          return props.tmNode.key === pendingTmNode.key;
        });
        function handleClick(e) {
          const { tmNode } = props;
          if (tmNode.disabled)
            return;
          handleOptionClick(e, tmNode);
        }
        function handleMouseEnter(e) {
          const { tmNode } = props;
          if (tmNode.disabled)
            return;
          handleOptionMouseEnter(e, tmNode);
        }
        function handleMouseMove(e) {
          const { tmNode } = props;
          const { value: isPending } = isPendingRef;
          if (tmNode.disabled || isPending)
            return;
          handleOptionMouseEnter(e, tmNode);
        }
        return {
          multiple: multipleRef,
          isGrouped: useMemo(() => {
            const { tmNode } = props;
            const { parent } = tmNode;
            return parent && parent.rawNode.type === "group";
          }),
          showCheckmark: showCheckmarkRef,
          nodeProps: nodePropsRef,
          isPending: isPendingRef,
          isSelected: useMemo(() => {
            const { value } = valueRef;
            const { value: multiple } = multipleRef;
            if (value === null)
              return false;
            const optionValue = props.tmNode.rawNode[valueFieldRef.value];
            if (multiple) {
              const { value: valueSet } = valueSetRef;
              return valueSet.has(optionValue);
            } else {
              return value === optionValue;
            }
          }),
          labelField: labelFieldRef,
          renderLabel: renderLabelRef,
          renderOption: renderOptionRef,
          handleMouseMove,
          handleMouseEnter,
          handleClick
        };
      },
      render() {
        const {
          clsPrefix,
          tmNode: { rawNode },
          isSelected,
          isPending,
          isGrouped,
          showCheckmark,
          nodeProps,
          renderOption,
          renderLabel,
          handleClick,
          handleMouseEnter,
          handleMouseMove
        } = this;
        const checkmark = renderCheckMark(isSelected, clsPrefix);
        const children = renderLabel ? [renderLabel(rawNode, isSelected), showCheckmark && checkmark] : [
          render$1(
            rawNode[this.labelField],
            rawNode,
            isSelected
          ),
          showCheckmark && checkmark
        ];
        const attrs = nodeProps?.(rawNode);
        const node = /* @__PURE__ */ React.createElement("div", {
          ...attrs,
          class: [
            `${clsPrefix}-base-select-option`,
            rawNode.class,
            attrs?.class,
            {
              [`${clsPrefix}-base-select-option--disabled`]: rawNode.disabled,
              [`${clsPrefix}-base-select-option--selected`]: isSelected,
              [`${clsPrefix}-base-select-option--grouped`]: isGrouped,
              [`${clsPrefix}-base-select-option--pending`]: isPending,
              [`${clsPrefix}-base-select-option--show-checkmark`]: showCheckmark
            }
          ],
          style: [attrs?.style || "", rawNode.style || ""],
          onClick: mergeEventHandlers([handleClick, attrs?.onClick]),
          onMouseenter: mergeEventHandlers([
            handleMouseEnter,
            attrs?.onMouseenter
          ]),
          onMousemove: mergeEventHandlers([handleMouseMove, attrs?.onMousemove])
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-base-select-option__content`
        }, children));
        return rawNode.render ? rawNode.render({ node, option: rawNode, selected: isSelected }) : renderOption ? renderOption({ node, option: rawNode, selected: isSelected }) : node;
      }
    });

    var NSelectGroupHeader = vue.defineComponent({
      name: "NBaseSelectGroupHeader",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        tmNode: {
          type: Object,
          required: true
        }
      },
      setup() {
        const {
          renderLabelRef,
          renderOptionRef,
          labelFieldRef,
          nodePropsRef
        } = vue.inject(internalSelectionMenuInjectionKey);
        return {
          labelField: labelFieldRef,
          nodeProps: nodePropsRef,
          renderLabel: renderLabelRef,
          renderOption: renderOptionRef
        };
      },
      render() {
        const {
          clsPrefix,
          renderLabel,
          renderOption,
          nodeProps,
          tmNode: { rawNode }
        } = this;
        const attrs = nodeProps?.(rawNode);
        const children = renderLabel ? renderLabel(rawNode, false) : render$1(rawNode[this.labelField], rawNode, false);
        const node = /* @__PURE__ */ React.createElement("div", {
          ...attrs,
          class: [`${clsPrefix}-base-select-group-header`, attrs?.class]
        }, children);
        return rawNode.render ? rawNode.render({ node, option: rawNode }) : renderOption ? renderOption({ node, option: rawNode, selected: false }) : node;
      }
    });

    const {
      cubicBezierEaseIn: cubicBezierEaseIn$5,
      cubicBezierEaseOut: cubicBezierEaseOut$6
    } = commonVariables$m;
    function fadeInScaleUpTransition() {
      let {
        transformOrigin = "inherit",
        duration = ".2s",
        enterScale = ".9",
        originalTransform = "",
        originalTransition = ""
      } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      return [c$1("&.fade-in-scale-up-transition-leave-active", {
        transformOrigin,
        transition: `opacity ${duration} ${cubicBezierEaseIn$5}, transform ${duration} ${cubicBezierEaseIn$5} ${originalTransition && "," + originalTransition}`
      }), c$1("&.fade-in-scale-up-transition-enter-active", {
        transformOrigin,
        transition: `opacity ${duration} ${cubicBezierEaseOut$6}, transform ${duration} ${cubicBezierEaseOut$6} ${originalTransition && "," + originalTransition}`
      }), c$1("&.fade-in-scale-up-transition-enter-from, &.fade-in-scale-up-transition-leave-to", {
        opacity: 0,
        transform: `${originalTransform} scale(${enterScale})`
      }), c$1("&.fade-in-scale-up-transition-leave-from, &.fade-in-scale-up-transition-enter-to", {
        opacity: 1,
        transform: `${originalTransform} scale(1)`
      })];
    }

    var style$1t = cB("base-select-menu", `
  line-height: 1.5;
  outline: none;
  z-index: 0;
  position: relative;
  border-radius: var(--n-border-radius);
  transition:
    background-color .3s var(--n-bezier),
    box-shadow .3s var(--n-bezier);
  background-color: var(--n-color);
`, [cB("scrollbar", `
    max-height: var(--n-height);
  `), cB("virtual-list", `
    max-height: var(--n-height);
  `), cB("base-select-option", `
    min-height: var(--n-option-height);
    font-size: var(--n-option-font-size);
    display: flex;
    align-items: center;
  `, [cE("content", `
      z-index: 1;
      white-space: nowrap;
      text-overflow: ellipsis;
      overflow: hidden;
    `)]), cB("base-select-group-header", `
    min-height: var(--n-option-height);
    font-size: .93em;
    display: flex;
    align-items: center;
  `), cB("base-select-menu-option-wrapper", `
    position: relative;
    width: 100%;
  `), cE("loading, empty", `
    display: flex;
    padding: 12px 32px;
    flex: 1;
    justify-content: center;
  `), cE("loading", `
    color: var(--n-loading-color);
    font-size: var(--n-loading-size);
  `), cE("action", `
    padding: 8px var(--n-option-padding-left);
    font-size: var(--n-option-font-size);
    transition: 
      color .3s var(--n-bezier),
      border-color .3s var(--n-bezier);
    border-top: 1px solid var(--n-action-divider-color);
    color: var(--n-action-text-color);
  `), cB("base-select-group-header", `
    position: relative;
    cursor: default;
    padding: var(--n-option-padding);
    color: var(--n-group-header-text-color);
  `), cB("base-select-option", `
    cursor: pointer;
    position: relative;
    padding: var(--n-option-padding);
    transition:
      color .3s var(--n-bezier),
      opacity .3s var(--n-bezier);
    box-sizing: border-box;
    color: var(--n-option-text-color);
    opacity: 1;
  `, [cM("show-checkmark", `
      padding-right: calc(var(--n-option-padding-right) + 20px);
    `), c$1("&::before", `
      content: "";
      position: absolute;
      left: 4px;
      right: 4px;
      top: 0;
      bottom: 0;
      border-radius: var(--n-border-radius);
      transition: background-color .3s var(--n-bezier);
    `), c$1("&:active", `
      color: var(--n-option-text-color-pressed);
    `), cM("grouped", `
      padding-left: calc(var(--n-option-padding-left) * 1.5);
    `), cM("pending", [c$1("&::before", `
        background-color: var(--n-option-color-pending);
      `)]), cM("selected", `
      color: var(--n-option-text-color-active);
    `, [c$1("&::before", `
        background-color: var(--n-option-color-active);
      `), cM("pending", [c$1("&::before", `
          background-color: var(--n-option-color-active-pending);
        `)])]), cM("disabled", `
      cursor: not-allowed;
    `, [cNotM("selected", `
        color: var(--n-option-text-color-disabled);
      `), cM("selected", `
        opacity: var(--n-option-opacity-disabled);
      `)]), cE("check", `
      font-size: 16px;
      position: absolute;
      right: calc(var(--n-option-padding-right) - 4px);
      top: calc(50% - 7px);
      color: var(--n-option-check-color);
      transition: color .3s var(--n-bezier);
    `, [fadeInScaleUpTransition({
      enterScale: "0.5"
    })])])]);

    var NInternalSelectMenu = vue.defineComponent({
      name: "InternalSelectMenu",
      props: {
        ...useTheme.props,
        clsPrefix: {
          type: String,
          required: true
        },
        scrollable: {
          type: Boolean,
          default: true
        },
        treeMate: {
          type: Object,
          required: true
        },
        multiple: Boolean,
        size: {
          type: String,
          default: "medium"
        },
        value: {
          type: [String, Number, Array],
          default: null
        },
        autoPending: Boolean,
        virtualScroll: {
          type: Boolean,
          default: true
        },
        show: {
          type: Boolean,
          default: true
        },
        labelField: {
          type: String,
          default: "label"
        },
        valueField: {
          type: String,
          default: "value"
        },
        loading: Boolean,
        focusable: Boolean,
        renderLabel: Function,
        renderOption: Function,
        nodeProps: Function,
        showCheckmark: { type: Boolean, default: true },
        onMousedown: Function,
        onScroll: Function,
        onFocus: Function,
        onBlur: Function,
        onKeyup: Function,
        onKeydown: Function,
        onTabOut: Function,
        onMouseenter: Function,
        onMouseleave: Function,
        onResize: Function,
        resetMenuOnOptionsChange: {
          type: Boolean,
          default: true
        },
        inlineThemeDisabled: Boolean,
        onToggle: Function
      },
      setup(props) {
        const themeRef = useTheme(
          "InternalSelectMenu",
          "-internal-select-menu",
          style$1t,
          internalSelectMenuLight$1,
          props,
          vue.toRef(props, "clsPrefix")
        );
        const selfRef = vue.ref(null);
        const virtualListRef = vue.ref(null);
        const scrollbarRef = vue.ref(null);
        const flattenedNodesRef = vue.computed(() => props.treeMate.getFlattenedNodes());
        const fIndexGetterRef = vue.computed(
          () => createIndexGetter(flattenedNodesRef.value)
        );
        const pendingNodeRef = vue.ref(null);
        function initPendingNode() {
          const { treeMate } = props;
          let defaultPendingNode = null;
          const { value } = props;
          if (value === null) {
            defaultPendingNode = treeMate.getFirstAvailableNode();
          } else {
            if (props.multiple) {
              defaultPendingNode = treeMate.getNode(
                (value || [])[(value || []).length - 1]
              );
            } else {
              defaultPendingNode = treeMate.getNode(value);
            }
            if (!defaultPendingNode || defaultPendingNode.disabled) {
              defaultPendingNode = treeMate.getFirstAvailableNode();
            }
          }
          if (defaultPendingNode) {
            setPendingTmNode(defaultPendingNode);
          } else {
            setPendingTmNode(null);
          }
        }
        function clearPendingNodeIfInvalid() {
          const { value: pendingNode } = pendingNodeRef;
          if (pendingNode && !props.treeMate.getNode(pendingNode.key)) {
            pendingNodeRef.value = null;
          }
        }
        let initPendingNodeWatchStopHandle;
        vue.watch(
          () => props.show,
          (show) => {
            if (show) {
              initPendingNodeWatchStopHandle = vue.watch(
                () => props.treeMate,
                () => {
                  if (props.resetMenuOnOptionsChange) {
                    if (props.autoPending) {
                      initPendingNode();
                    } else {
                      clearPendingNodeIfInvalid();
                    }
                    void vue.nextTick(scrollToPendingNode);
                  } else {
                    clearPendingNodeIfInvalid();
                  }
                },
                {
                  immediate: true
                }
              );
            } else {
              initPendingNodeWatchStopHandle?.();
            }
          },
          {
            immediate: true
          }
        );
        vue.onBeforeUnmount(() => {
          initPendingNodeWatchStopHandle?.();
        });
        const itemSizeRef = vue.computed(() => {
          return depx(themeRef.value.self[createKey("optionHeight", props.size)]);
        });
        const paddingRef = vue.computed(() => {
          return getMargin(themeRef.value.self[createKey("padding", props.size)]);
        });
        const valueSetRef = vue.computed(() => {
          if (props.multiple && Array.isArray(props.value)) {
            return new Set(props.value);
          }
          return /* @__PURE__ */ new Set();
        });
        const emptyRef = vue.computed(() => {
          const tmNodes = flattenedNodesRef.value;
          return tmNodes && tmNodes.length === 0;
        });
        function doToggle(tmNode) {
          const { onToggle } = props;
          if (onToggle)
            onToggle(tmNode);
        }
        function doScroll(e) {
          const { onScroll } = props;
          if (onScroll)
            onScroll(e);
        }
        function handleVirtualListScroll(e) {
          scrollbarRef.value?.sync();
          doScroll(e);
        }
        function handleVirtualListResize() {
          scrollbarRef.value?.sync();
        }
        function getPendingTmNode() {
          const { value: pendingTmNode } = pendingNodeRef;
          if (pendingTmNode)
            return pendingTmNode;
          return null;
        }
        function handleOptionMouseEnter(e, tmNode) {
          if (tmNode.disabled)
            return;
          setPendingTmNode(tmNode, false);
        }
        function handleOptionClick(e, tmNode) {
          if (tmNode.disabled)
            return;
          doToggle(tmNode);
        }
        function handleKeyUp(e) {
          if (happensIn(e, "action"))
            return;
          props.onKeyup?.(e);
        }
        function handleKeyDown(e) {
          if (happensIn(e, "action"))
            return;
          props.onKeydown?.(e);
        }
        function handleMouseDown(e) {
          props.onMousedown?.(e);
          if (props.focusable)
            return;
          e.preventDefault();
        }
        function next() {
          const { value: pendingTmNode } = pendingNodeRef;
          if (pendingTmNode) {
            setPendingTmNode(pendingTmNode.getNext({ loop: true }), true);
          }
        }
        function prev() {
          const { value: pendingTmNode } = pendingNodeRef;
          if (pendingTmNode) {
            setPendingTmNode(pendingTmNode.getPrev({ loop: true }), true);
          }
        }
        function setPendingTmNode(tmNode, doScroll2 = false) {
          pendingNodeRef.value = tmNode;
          if (doScroll2)
            scrollToPendingNode();
        }
        function scrollToPendingNode() {
          const tmNode = pendingNodeRef.value;
          if (!tmNode)
            return;
          const fIndex = fIndexGetterRef.value(tmNode.key);
          if (fIndex === null)
            return;
          if (props.virtualScroll) {
            virtualListRef.value?.scrollTo({ index: fIndex });
          } else {
            scrollbarRef.value?.scrollTo({
              index: fIndex,
              elSize: itemSizeRef.value
            });
          }
        }
        function handleFocusin(e) {
          if (selfRef.value?.contains(e.target)) {
            props.onFocus?.(e);
          }
        }
        function handleFocusout(e) {
          if (!selfRef.value?.contains(e.relatedTarget)) {
            props.onBlur?.(e);
          }
        }
        vue.provide(internalSelectionMenuInjectionKey, {
          handleOptionMouseEnter,
          handleOptionClick,
          valueSetRef,
          pendingTmNodeRef: pendingNodeRef,
          nodePropsRef: vue.toRef(props, "nodeProps"),
          showCheckmarkRef: vue.toRef(props, "showCheckmark"),
          multipleRef: vue.toRef(props, "multiple"),
          valueRef: vue.toRef(props, "value"),
          renderLabelRef: vue.toRef(props, "renderLabel"),
          renderOptionRef: vue.toRef(props, "renderOption"),
          labelFieldRef: vue.toRef(props, "labelField"),
          valueFieldRef: vue.toRef(props, "valueField")
        });
        vue.provide(internalSelectionMenuBodyInjectionKey, selfRef);
        vue.onMounted(() => {
          const { value } = scrollbarRef;
          if (value)
            value.sync();
        });
        const cssVarsRef = vue.computed(() => {
          const { size } = props;
          const {
            common: { cubicBezierEaseInOut },
            self: {
              height,
              borderRadius,
              color,
              groupHeaderTextColor,
              actionDividerColor,
              optionTextColorPressed,
              optionTextColor,
              optionTextColorDisabled,
              optionTextColorActive,
              optionOpacityDisabled,
              optionCheckColor,
              actionTextColor,
              optionColorPending,
              optionColorActive,
              loadingColor,
              loadingSize,
              optionColorActivePending,
              [createKey("optionFontSize", size)]: fontSize,
              [createKey("optionHeight", size)]: optionHeight,
              [createKey("optionPadding", size)]: optionPadding
            }
          } = themeRef.value;
          return {
            "--n-height": height,
            "--n-action-divider-color": actionDividerColor,
            "--n-action-text-color": actionTextColor,
            "--n-bezier": cubicBezierEaseInOut,
            "--n-border-radius": borderRadius,
            "--n-color": color,
            "--n-option-font-size": fontSize,
            "--n-group-header-text-color": groupHeaderTextColor,
            "--n-option-check-color": optionCheckColor,
            "--n-option-color-pending": optionColorPending,
            "--n-option-color-active": optionColorActive,
            "--n-option-color-active-pending": optionColorActivePending,
            "--n-option-height": optionHeight,
            "--n-option-opacity-disabled": optionOpacityDisabled,
            "--n-option-text-color": optionTextColor,
            "--n-option-text-color-active": optionTextColorActive,
            "--n-option-text-color-disabled": optionTextColorDisabled,
            "--n-option-text-color-pressed": optionTextColorPressed,
            "--n-option-padding": optionPadding,
            "--n-option-padding-left": getMargin(optionPadding, "left"),
            "--n-option-padding-right": getMargin(optionPadding, "right"),
            "--n-loading-color": loadingColor,
            "--n-loading-size": loadingSize
          };
        });
        const { inlineThemeDisabled } = props;
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "internal-select-menu",
          vue.computed(() => props.size[0]),
          cssVarsRef,
          props
        ) : void 0;
        const exposedProps = {
          selfRef,
          next,
          prev,
          getPendingTmNode
        };
        useOnResize(selfRef, props.onResize);
        return {
          mergedTheme: themeRef,
          virtualListRef,
          scrollbarRef,
          itemSize: itemSizeRef,
          padding: paddingRef,
          flattenedNodes: flattenedNodesRef,
          empty: emptyRef,
          virtualListContainer() {
            const { value } = virtualListRef;
            return value?.listElRef;
          },
          virtualListContent() {
            const { value } = virtualListRef;
            return value?.itemsElRef;
          },
          doScroll,
          handleFocusin,
          handleFocusout,
          handleKeyUp,
          handleKeyDown,
          handleMouseDown,
          handleVirtualListResize,
          handleVirtualListScroll,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender,
          ...exposedProps
        };
      },
      render() {
        const {
          $slots,
          virtualScroll,
          clsPrefix,
          mergedTheme,
          themeClass,
          onRender
        } = this;
        onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          ref: "selfRef",
          tabindex: this.focusable ? 0 : -1,
          class: [
            `${clsPrefix}-base-select-menu`,
            themeClass,
            this.multiple && `${clsPrefix}-base-select-menu--multiple`
          ],
          style: this.cssVars,
          onFocusin: this.handleFocusin,
          onFocusout: this.handleFocusout,
          onKeyup: this.handleKeyUp,
          onKeydown: this.handleKeyDown,
          onMousedown: this.handleMouseDown,
          onMouseenter: this.onMouseenter,
          onMouseleave: this.onMouseleave
        }, this.loading ? /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-base-select-menu__loading`
        }, /* @__PURE__ */ React.createElement(NBaseLoading, {
          clsPrefix,
          strokeWidth: 20
        })) : !this.empty ? /* @__PURE__ */ React.createElement(NScrollbar, {
          ref: "scrollbarRef",
          theme: mergedTheme.peers.Scrollbar,
          themeOverrides: mergedTheme.peerOverrides.Scrollbar,
          scrollable: this.scrollable,
          container: virtualScroll ? this.virtualListContainer : void 0,
          content: virtualScroll ? this.virtualListContent : void 0,
          onScroll: virtualScroll ? void 0 : this.doScroll
        }, {
          default: () => {
            return virtualScroll ? /* @__PURE__ */ React.createElement(VVirtualList, {
              ref: "virtualListRef",
              class: `${clsPrefix}-virtual-list`,
              items: this.flattenedNodes,
              itemSize: this.itemSize,
              showScrollbar: false,
              paddingTop: this.padding.top,
              paddingBottom: this.padding.bottom,
              onResize: this.handleVirtualListResize,
              onScroll: this.handleVirtualListScroll,
              itemResizable: true
            }, {
              default: ({
                item: tmNode
              }) => {
                return tmNode.isGroup ? /* @__PURE__ */ React.createElement(NSelectGroupHeader, {
                  key: tmNode.key,
                  clsPrefix,
                  tmNode
                }) : tmNode.ignored ? null : /* @__PURE__ */ React.createElement(NSelectOption, {
                  clsPrefix,
                  key: tmNode.key,
                  tmNode
                });
              }
            }) : /* @__PURE__ */ React.createElement("div", {
              class: `${clsPrefix}-base-select-menu-option-wrapper`,
              style: {
                paddingTop: this.padding.top,
                paddingBottom: this.padding.bottom
              }
            }, this.flattenedNodes.map(
              (tmNode) => tmNode.isGroup ? /* @__PURE__ */ React.createElement(NSelectGroupHeader, {
                key: tmNode.key,
                clsPrefix,
                tmNode
              }) : /* @__PURE__ */ React.createElement(NSelectOption, {
                clsPrefix,
                key: tmNode.key,
                tmNode
              })
            ));
          }
        }) : /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-base-select-menu__empty`,
          "data-empty": true
        }, resolveSlot($slots.empty, () => [
          /* @__PURE__ */ React.createElement(NEmpty, {
            theme: mergedTheme.peers.Empty,
            themeOverrides: mergedTheme.peerOverrides.Empty
          })
        ])), resolveWrappedSlot(
          $slots.action,
          (children) => children && [
            /* @__PURE__ */ React.createElement("div", {
              class: `${clsPrefix}-base-select-menu__action`,
              "data-action": true,
              key: "action"
            }, children),
            /* @__PURE__ */ React.createElement(FocusDetector, {
              onFocus: this.onTabOut,
              key: "focus-detector"
            })
          ]
        ));
      }
    });

    var style$1s = cB("base-wave", `
  position: absolute;
  left: 0;
  right: 0;
  top: 0;
  bottom: 0;
  border-radius: inherit;
`);

    var NBaseWave = vue.defineComponent({
      name: "BaseWave",
      props: {
        clsPrefix: {
          type: String,
          required: true
        }
      },
      setup(props) {
        useStyle("-base-wave", style$1s, vue.toRef(props, "clsPrefix"));
        const selfRef = vue.ref(null);
        const activeRef = vue.ref(false);
        let animationTimerId = null;
        vue.onBeforeUnmount(() => {
          if (animationTimerId !== null) {
            window.clearTimeout(animationTimerId);
          }
        });
        return {
          active: activeRef,
          selfRef,
          play() {
            if (animationTimerId !== null) {
              window.clearTimeout(animationTimerId);
              activeRef.value = false;
              animationTimerId = null;
            }
            void vue.nextTick(() => {
              void selfRef.value?.offsetHeight;
              activeRef.value = true;
              animationTimerId = window.setTimeout(() => {
                activeRef.value = false;
                animationTimerId = null;
              }, 1e3);
            });
          }
        };
      },
      render() {
        const { clsPrefix } = this;
        return /* @__PURE__ */ React.createElement("div", {
          ref: "selfRef",
          "aria-hidden": true,
          class: [
            `${clsPrefix}-base-wave`,
            this.active && `${clsPrefix}-base-wave--active`
          ]
        });
      }
    });

    var style$1r = cB("base-menu-mask", `
  position: absolute;
  left: 0;
  right: 0;
  top: 0;
  bottom: 0;
  display: flex;
  align-items: center;
  justify-content: center;
  text-align: center;
  padding: 14px;
  overflow: hidden;
`, [fadeInTransition()]);

    var NBaseMenuMask = vue.defineComponent({
      name: "BaseMenuMask",
      props: {
        clsPrefix: {
          type: String,
          required: true
        }
      },
      setup(props) {
        useStyle("-base-menu-mask", style$1r, vue.toRef(props, "clsPrefix"));
        const messageRef = vue.ref(null);
        let timerId = null;
        const uncontrolledShowRef = vue.ref(false);
        vue.onBeforeUnmount(() => {
          if (timerId !== null) {
            window.clearTimeout(timerId);
          }
        });
        const exposedRef = {
          showOnce(message, duration = 1500) {
            if (timerId)
              window.clearTimeout(timerId);
            uncontrolledShowRef.value = true;
            messageRef.value = message;
            timerId = window.setTimeout(() => {
              uncontrolledShowRef.value = false;
              messageRef.value = null;
            }, duration);
          }
        };
        return {
          message: messageRef,
          show: uncontrolledShowRef,
          ...exposedRef
        };
      },
      render() {
        return /* @__PURE__ */ React.createElement(vue.Transition, {
          name: "fade-in-transition"
        }, {
          default: () => this.show ? /* @__PURE__ */ React.createElement("div", {
            class: `${this.clsPrefix}-base-menu-mask`
          }, this.message) : null
        });
      }
    });

    var commonVariables$k = {
      space: "6px",
      spaceArrow: "10px",
      arrowOffset: "10px",
      arrowOffsetVertical: "10px",
      arrowHeight: "6px",
      padding: "8px 14px"
    };

    const self$18 = vars => {
      const {
        boxShadow2,
        popoverColor,
        textColor2,
        borderRadius,
        fontSize,
        dividerColor
      } = vars;
      return { ...commonVariables$k,
        fontSize,
        borderRadius,
        color: popoverColor,
        dividerColor,
        textColor: textColor2,
        boxShadow: boxShadow2
      };
    };
    const popoverLight = {
      name: "Popover",
      common: commonLight,
      self: self$18
    };
    var popoverLight$1 = popoverLight;

    const popoverDark = {
      name: "Popover",
      common: commonDark,
      self: self$18
    };
    var popoverDark$1 = popoverDark;

    const oppositePlacement = {
      top: "bottom",
      bottom: "top",
      left: "right",
      right: "left"
    };
    const arrowSize = "var(--n-arrow-height) * 1.414";
    var style$1q = c$1([cB("popover", `
    transition:
      box-shadow .3s var(--n-bezier),
      background-color .3s var(--n-bezier),
      color .3s var(--n-bezier);
    position: relative;
    font-size: var(--n-font-size);
    color: var(--n-text-color);
    box-shadow: var(--n-box-shadow);
  `, [c$1(">", [cB("scrollbar", `
        height: inherit;
        max-height: inherit;
      `)]), cNotM("raw", `
      background-color: var(--n-color);
      border-radius: var(--n-border-radius);
    `, [cNotM("scrollable", [cNotM("show-header-or-footer", "padding: var(--n-padding);")])]), cE("header", `
      padding: var(--n-padding);
      border-bottom: 1px solid var(--n-divider-color);
      transition: border-color .3s var(--n-bezier);
    `), cE("footer", `
      padding: var(--n-padding);
      border-top: 1px solid var(--n-divider-color);
      transition: border-color .3s var(--n-bezier);
    `), cM("scrollable, show-header-or-footer", [cE("content", `
        padding: var(--n-padding);
      `)])]), cB("popover-shared", `
    transform-origin: inherit;
  `, [cB("popover-arrow-wrapper", `
      position: absolute;
      overflow: hidden;
      pointer-events: none;
    `, [cB("popover-arrow", `
        transition: background-color .3s var(--n-bezier);
        position: absolute;
        display: block;
        width: calc(${arrowSize});
        height: calc(${arrowSize});
        box-shadow: 0 0 8px 0 rgba(0, 0, 0, .12);
        transform: rotate(45deg);
        background-color: var(--n-color);
        pointer-events: all;
      `)]), c$1("&.popover-transition-enter-from, &.popover-transition-leave-to", `
      opacity: 0;
      transform: scale(.85);
    `), c$1("&.popover-transition-enter-to, &.popover-transition-leave-from", `
      transform: scale(1);
      opacity: 1;
    `), c$1("&.popover-transition-enter-active", `
      transition:
        box-shadow .3s var(--n-bezier),
        background-color .3s var(--n-bezier),
        color .3s var(--n-bezier),
        opacity .15s var(--n-bezier-ease-out),
        transform .15s var(--n-bezier-ease-out);
    `), c$1("&.popover-transition-leave-active", `
      transition:
        box-shadow .3s var(--n-bezier),
        background-color .3s var(--n-bezier),
        color .3s var(--n-bezier),
        opacity .15s var(--n-bezier-ease-in),
        transform .15s var(--n-bezier-ease-in);
    `)]), placementStyle("top-start", `
    top: calc(${arrowSize} / -2);
    left: calc(${getArrowOffset("top-start")} - var(--v-offset-left));
  `), placementStyle("top", `
    top: calc(${arrowSize} / -2);
    transform: translateX(calc(${arrowSize} / -2)) rotate(45deg);
    left: 50%;
  `), placementStyle("top-end", `
    top: calc(${arrowSize} / -2);
    right: calc(${getArrowOffset("top-end")} + var(--v-offset-left));
  `), placementStyle("bottom-start", `
    bottom: calc(${arrowSize} / -2);
    left: calc(${getArrowOffset("bottom-start")} - var(--v-offset-left));
  `), placementStyle("bottom", `
    bottom: calc(${arrowSize} / -2);
    transform: translateX(calc(${arrowSize} / -2)) rotate(45deg);
    left: 50%;
  `), placementStyle("bottom-end", `
    bottom: calc(${arrowSize} / -2);
    right: calc(${getArrowOffset("bottom-end")} + var(--v-offset-left));
  `), placementStyle("left-start", `
    left: calc(${arrowSize} / -2);
    top: calc(${getArrowOffset("left-start")} - var(--v-offset-top));
  `), placementStyle("left", `
    left: calc(${arrowSize} / -2);
    transform: translateY(calc(${arrowSize} / -2)) rotate(45deg);
    top: 50%;
  `), placementStyle("left-end", `
    left: calc(${arrowSize} / -2);
    bottom: calc(${getArrowOffset("left-end")} + var(--v-offset-top));
  `), placementStyle("right-start", `
    right: calc(${arrowSize} / -2);
    top: calc(${getArrowOffset("right-start")} - var(--v-offset-top));
  `), placementStyle("right", `
    right: calc(${arrowSize} / -2);
    transform: translateY(calc(${arrowSize} / -2)) rotate(45deg);
    top: 50%;
  `), placementStyle("right-end", `
    right: calc(${arrowSize} / -2);
    bottom: calc(${getArrowOffset("right-end")} + var(--v-offset-top));
  `), ...lodash.exports.map({
      top: ["right-start", "left-start"],
      right: ["top-end", "bottom-end"],
      bottom: ["right-end", "left-end"],
      left: ["top-start", "bottom-start"]
    }, (placements, direction) => {
      const isVertical = ["right", "left"].includes(direction);
      const sizeType = isVertical ? "width" : "height";
      return placements.map(placement => {
        const isReverse = placement.split("-")[1] === "end";
        const targetSize = `var(--v-target-${sizeType}, 0px)`;
        const centerOffset = `calc((${targetSize} - ${arrowSize}) / 2)`;
        const offset = getArrowOffset(placement);
        return c$1(`[v-placement="${placement}"] >`, [cB("popover-shared", [cM("center-arrow", [cB("popover-arrow", `${direction}: calc(max(${centerOffset}, ${offset}) ${isReverse ? "+" : "-"} var(--v-offset-${isVertical ? "left" : "top"}));`)])])]);
      });
    })]);

    function getArrowOffset(placement) {
      return ["top", "bottom"].includes(placement.split("-")[0]) ? "var(--n-arrow-offset)" : "var(--n-arrow-offset-vertical)";
    }

    function placementStyle(placement, arrowStyleLiteral) {
      const position = placement.split("-")[0];
      const sizeStyle = ["top", "bottom"].includes(position) ? "height: var(--n-space-arrow);" : "width: var(--n-space-arrow);";
      return c$1(`[v-placement="${placement}"] >`, [cB("popover-shared", `
      margin-${oppositePlacement[position]}: var(--n-space);
    `, [cM("show-arrow", `
        margin-${oppositePlacement[position]}: var(--n-space-arrow);
      `), cM("overlap", `
        margin: 0;
      `), cCB("popover-arrow-wrapper", `
        right: 0;
        left: 0;
        top: 0;
        bottom: 0;
        ${position}: 100%;
        ${oppositePlacement[position]}: auto;
        ${sizeStyle}
      `, [cB("popover-arrow", arrowStyleLiteral)])])]);
    }

    const popoverBodyProps = {
      ...useTheme.props,
      to: useAdjustedTo.propTo,
      show: Boolean,
      trigger: String,
      showArrow: Boolean,
      delay: Number,
      duration: Number,
      raw: Boolean,
      arrowPointToCenter: Boolean,
      arrowStyle: [String, Object],
      displayDirective: String,
      x: Number,
      y: Number,
      flip: Boolean,
      overlap: Boolean,
      placement: String,
      width: [Number, String],
      keepAliveOnHover: Boolean,
      scrollable: Boolean,
      contentStyle: [Object, String],
      headerStyle: [Object, String],
      footerStyle: [Object, String],
      internalDeactivateImmediately: Boolean,
      animated: Boolean,
      onClickoutside: Function,
      internalTrapFocus: Boolean,
      internalOnAfterLeave: Function,
      minWidth: Number,
      maxWidth: Number
    };
    const renderArrow = ({
      arrowStyle,
      clsPrefix
    }) => {
      return /* @__PURE__ */ React.createElement("div", {
        key: "__popover-arrow__",
        class: `${clsPrefix}-popover-arrow-wrapper`
      }, /* @__PURE__ */ React.createElement("div", {
        class: `${clsPrefix}-popover-arrow`,
        style: arrowStyle
      }));
    };
    var NPopoverBody = vue.defineComponent({
      name: "PopoverBody",
      inheritAttrs: false,
      props: popoverBodyProps,
      setup(props, { slots, attrs }) {
        const { namespaceRef, mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Popover",
          "-popover",
          style$1q,
          popoverLight$1,
          props,
          mergedClsPrefixRef
        );
        const followerRef = vue.ref(null);
        const NPopover = vue.inject("NPopover");
        const bodyRef = vue.ref(null);
        const followerEnabledRef = vue.ref(props.show);
        const displayedRef = vue.ref(false);
        vue.watchEffect(() => {
          const { show } = props;
          if (show && !isJsdom() && !props.internalDeactivateImmediately) {
            displayedRef.value = true;
          }
        });
        const directivesRef = vue.computed(() => {
          const { trigger, onClickoutside } = props;
          const directives = [];
          const {
            positionManuallyRef: { value: positionManually }
          } = NPopover;
          if (!positionManually) {
            if (trigger === "click" && !onClickoutside) {
              directives.push([
                clickoutside$1,
                handleClickOutside,
                void 0,
                { capture: true }
              ]);
            }
            if (trigger === "hover") {
              directives.push([mousemoveoutside$1, handleMouseMoveOutside]);
            }
          }
          if (onClickoutside) {
            directives.push([
              clickoutside$1,
              handleClickOutside,
              void 0,
              { capture: true }
            ]);
          }
          if (props.displayDirective === "show" || props.animated && displayedRef.value) {
            directives.push([vue.vShow, props.show]);
          }
          return directives;
        });
        const styleRef = vue.computed(() => {
          const width = props.width === "trigger" ? void 0 : formatLength(props.width);
          const style2 = [];
          if (width) {
            style2.push({ width });
          }
          const { maxWidth, minWidth } = props;
          if (maxWidth) {
            style2.push({ maxWidth: formatLength(maxWidth) });
          }
          if (minWidth) {
            style2.push({ maxWidth: formatLength(minWidth) });
          }
          if (!inlineThemeDisabled) {
            style2.push(cssVarsRef.value);
          }
          return style2;
        });
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut, cubicBezierEaseIn, cubicBezierEaseOut },
            self: {
              space,
              spaceArrow,
              padding,
              fontSize,
              textColor,
              dividerColor,
              color,
              boxShadow,
              borderRadius,
              arrowHeight,
              arrowOffset,
              arrowOffsetVertical
            }
          } = themeRef.value;
          return {
            "--n-box-shadow": boxShadow,
            "--n-bezier": cubicBezierEaseInOut,
            "--n-bezier-ease-in": cubicBezierEaseIn,
            "--n-bezier-ease-out": cubicBezierEaseOut,
            "--n-font-size": fontSize,
            "--n-text-color": textColor,
            "--n-color": color,
            "--n-divider-color": dividerColor,
            "--n-border-radius": borderRadius,
            "--n-arrow-height": arrowHeight,
            "--n-arrow-offset": arrowOffset,
            "--n-arrow-offset-vertical": arrowOffsetVertical,
            "--n-padding": padding,
            "--n-space": space,
            "--n-space-arrow": spaceArrow
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("popover", void 0, cssVarsRef, props) : void 0;
        NPopover.setBodyInstance({
          syncPosition
        });
        vue.onBeforeUnmount(() => {
          NPopover.setBodyInstance(null);
        });
        vue.watch(vue.toRef(props, "show"), (value) => {
          if (props.animated)
            return;
          if (value) {
            followerEnabledRef.value = true;
          } else {
            followerEnabledRef.value = false;
          }
        });
        function syncPosition() {
          followerRef.value?.syncPosition();
        }
        function handleMouseEnter(e) {
          if (props.trigger === "hover" && props.keepAliveOnHover && props.show) {
            NPopover.handleMouseEnter(e);
          }
        }
        function handleMouseLeave(e) {
          if (props.trigger === "hover" && props.keepAliveOnHover) {
            NPopover.handleMouseLeave(e);
          }
        }
        function handleMouseMoveOutside(e) {
          if (props.trigger === "hover" && !getTriggerElement().contains(getPreciseEventTarget(e))) {
            NPopover.handleMouseMoveOutside(e);
          }
        }
        function handleClickOutside(e) {
          if (props.trigger === "click" && !getTriggerElement().contains(
            getPreciseEventTarget(e)
          ) || props.onClickoutside) {
            NPopover.handleClickOutside(e);
          }
        }
        function getTriggerElement() {
          return NPopover.getTriggerElement();
        }
        vue.provide(popoverBodyInjectionKey, bodyRef);
        vue.provide(drawerBodyInjectionKey, null);
        vue.provide(modalBodyInjectionKey, null);
        function renderContentNode() {
          themeClassHandle?.onRender();
          const shouldRenderDom = props.displayDirective === "show" || props.show || props.animated && displayedRef.value;
          if (!shouldRenderDom) {
            return null;
          }
          let contentNode;
          const renderBody = NPopover.internalRenderBodyRef.value;
          const { value: mergedClsPrefix } = mergedClsPrefixRef;
          if (!renderBody) {
            const { value: extraClass } = NPopover.extraClassRef;
            const { internalTrapFocus } = props;
            const hasHeaderOrFooter = !isSlotEmpty(slots.header) || !isSlotEmpty(slots.footer);
            const renderContentInnerNode = () => {
              const body = hasHeaderOrFooter ? /* @__PURE__ */ React.createElement(React.Fragment, null, resolveWrappedSlot(slots.header, (children) => {
                return children ? /* @__PURE__ */ React.createElement("div", {
                  class: `${mergedClsPrefix}-popover__header`,
                  style: props.headerStyle
                }, children) : null;
              }), resolveWrappedSlot(slots.default, (children) => {
                return children ? /* @__PURE__ */ React.createElement("div", {
                  class: `${mergedClsPrefix}-popover__content`,
                  style: props.contentStyle
                }, slots) : null;
              }), resolveWrappedSlot(slots.footer, (children) => {
                return children ? /* @__PURE__ */ React.createElement("div", {
                  class: `${mergedClsPrefix}-popover__footer`,
                  style: props.footerStyle
                }, children) : null;
              })) : props.scrollable ? slots.default?.() : /* @__PURE__ */ React.createElement("div", {
                class: `${mergedClsPrefix}-popover__content`,
                style: props.contentStyle
              }, slots);
              const maybeScrollableBody = props.scrollable ? /* @__PURE__ */ React.createElement(XScrollbar, {
                contentClass: hasHeaderOrFooter ? void 0 : `${mergedClsPrefix}-popover__content`,
                contentStyle: hasHeaderOrFooter ? void 0 : props.contentStyle
              }, {
                default: () => body
              }) : body;
              const arrow = props.showArrow ? renderArrow({
                arrowStyle: props.arrowStyle,
                clsPrefix: mergedClsPrefix
              }) : null;
              return [maybeScrollableBody, arrow];
            };
            contentNode = vue.h(
              "div",
              vue.mergeProps(
                {
                  class: [
                    `${mergedClsPrefix}-popover`,
                    `${mergedClsPrefix}-popover-shared`,
                    themeClassHandle?.themeClass.value,
                    extraClass.map((v) => `${mergedClsPrefix}-${v}`),
                    {
                      [`${mergedClsPrefix}-popover--scrollable`]: props.scrollable,
                      [`${mergedClsPrefix}-popover--show-header-or-footer`]: hasHeaderOrFooter,
                      [`${mergedClsPrefix}-popover--raw`]: props.raw,
                      [`${mergedClsPrefix}-popover-shared--overlap`]: props.overlap,
                      [`${mergedClsPrefix}-popover-shared--show-arrow`]: props.showArrow,
                      [`${mergedClsPrefix}-popover-shared--center-arrow`]: props.arrowPointToCenter
                    }
                  ],
                  ref: bodyRef,
                  style: styleRef.value,
                  onKeydown: NPopover.handleKeydown,
                  onMouseenter: handleMouseEnter,
                  onMouseleave: handleMouseLeave
                },
                attrs
              ),
              internalTrapFocus ? /* @__PURE__ */ React.createElement(FocusTrap, {
                active: props.show,
                autoFocus: true
              }, { default: renderContentInnerNode }) : renderContentInnerNode()
            );
          } else {
            contentNode = renderBody(
              [
                `${mergedClsPrefix}-popover-shared`,
                themeClassHandle?.themeClass.value,
                props.overlap && `${mergedClsPrefix}-popover-shared--overlap`,
                props.showArrow && `${mergedClsPrefix}-popover-shared--show-arrow`,
                props.arrowPointToCenter && `${mergedClsPrefix}-popover-shared--center-arrow`
              ],
              bodyRef,
              styleRef.value,
              handleMouseEnter,
              handleMouseLeave
            );
          }
          return vue.withDirectives(contentNode, directivesRef.value);
        }
        return {
          displayed: displayedRef,
          namespace: namespaceRef,
          isMounted: NPopover.isMountedRef,
          zIndex: NPopover.zIndexRef,
          followerRef,
          adjustedTo: useAdjustedTo(props),
          followerEnabled: followerEnabledRef,
          renderContentNode
        };
      },
      render() {
        return /* @__PURE__ */ React.createElement(VFollower, {
          ref: "followerRef",
          zIndex: this.zIndex,
          show: this.show,
          enabled: this.followerEnabled,
          to: this.adjustedTo,
          x: this.x,
          y: this.y,
          flip: this.flip,
          placement: this.placement,
          containerClass: this.namespace,
          overlap: this.overlap,
          width: this.width === "trigger" ? "target" : void 0,
          teleportDisabled: this.adjustedTo === useAdjustedTo.tdkey
        }, {
          default: () => {
            return this.animated ? /* @__PURE__ */ React.createElement(vue.Transition, {
              name: "popover-transition",
              appear: this.isMounted,
              onEnter: () => {
                this.followerEnabled = true;
              },
              onAfterLeave: () => {
                this.internalOnAfterLeave?.();
                this.followerEnabled = false;
                this.displayed = false;
              }
            }, {
              default: this.renderContentNode
            }) : this.renderContentNode();
          }
        });
      }
    });

    const bodyPropKeys = Object.keys(popoverBodyProps);
    const triggerEventMap = {
      focus: ["onFocus", "onBlur"],
      click: ["onClick"],
      hover: ["onMouseenter", "onMouseleave"],
      manual: [],
      nested: ["onFocus", "onBlur", "onMouseenter", "onMouseleave", "onClick"]
    };
    function appendEvents(vNode, trigger, events) {
      triggerEventMap[trigger].forEach((eventName) => {
        if (!vNode.props)
          vNode.props = {};
        else {
          vNode.props = Object.assign({}, vNode.props);
        }
        const originalHandler = vNode.props[eventName];
        const handler = events[eventName];
        if (!originalHandler)
          vNode.props[eventName] = handler;
        else {
          vNode.props[eventName] = (...args) => {
            originalHandler(...args);
            handler(...args);
          };
        }
      });
    }
    const textVNodeType = vue.createTextVNode("").type;
    const popoverBaseProps = {
      show: {
        type: Boolean,
        default: void 0
      },
      defaultShow: Boolean,
      showArrow: {
        type: Boolean,
        default: true
      },
      trigger: {
        type: String,
        default: "hover"
      },
      delay: {
        type: Number,
        default: 100
      },
      duration: {
        type: Number,
        default: 100
      },
      raw: Boolean,
      placement: {
        type: String,
        default: "top"
      },
      x: Number,
      y: Number,
      arrowPointToCenter: Boolean,
      disabled: Boolean,
      getDisabled: Function,
      displayDirective: {
        type: String,
        default: "if"
      },
      arrowStyle: [String, Object],
      flip: {
        type: Boolean,
        default: true
      },
      animated: {
        type: Boolean,
        default: true
      },
      width: {
        type: [Number, String],
        default: void 0
      },
      overlap: Boolean,
      keepAliveOnHover: {
        type: Boolean,
        default: true
      },
      zIndex: Number,
      to: useAdjustedTo.propTo,
      scrollable: Boolean,
      contentStyle: [Object, String],
      headerStyle: [Object, String],
      footerStyle: [Object, String],
      onClickoutside: Function,
      "onUpdate:show": [Function, Array],
      onUpdateShow: [Function, Array],
      internalDeactivateImmediately: Boolean,
      internalSyncTargetWithParent: Boolean,
      internalInheritedEventHandlers: {
        type: Array,
        default: () => []
      },
      internalTrapFocus: Boolean,
      internalExtraClass: {
        type: Array,
        default: () => []
      },
      onShow: [Function, Array],
      onHide: [Function, Array],
      arrow: {
        type: Boolean,
        default: void 0
      },
      minWidth: Number,
      maxWidth: Number
    };
    const popoverProps = {
      ...useTheme.props,
      ...popoverBaseProps,
      internalOnAfterLeave: Function,
      internalRenderBody: Function
    };
    var NPopover = vue.defineComponent({
      name: "Popover",
      inheritAttrs: false,
      props: popoverProps,
      __popover__: true,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.maxWidth !== void 0) {
              warnOnce(
                "popover",
                "`max-width` is deprecated, please use `style` instead."
              );
            }
            if (props.minWidth !== void 0) {
              warnOnce(
                "popover",
                "`min-width` is deprecated, please use `style` instead."
              );
            }
            if (props.arrow !== void 0) {
              warnOnce(
                "popover",
                "`arrow` is deprecated, please use `showArrow` instead."
              );
            }
            if (props.onHide !== void 0) {
              warnOnce(
                "popover",
                "`on-hide` is deprecated, please use `on-update:show` instead."
              );
            }
            if (props.onShow !== void 0) {
              warnOnce(
                "popover",
                "`on-show` is deprecated, please use `on-update:show` instead."
              );
            }
          });
        }
        const isMountedRef = isMounted();
        const binderInstRef = vue.ref(null);
        const controlledShowRef = vue.computed(() => props.show);
        const uncontrolledShowRef = vue.ref(props.defaultShow);
        const mergedShowWithoutDisabledRef = useMergedState(
          controlledShowRef,
          uncontrolledShowRef
        );
        const mergedShowConsideringDisabledPropRef = useMemo(() => {
          if (props.disabled)
            return false;
          return mergedShowWithoutDisabledRef.value;
        });
        const getMergedDisabled = () => {
          if (props.disabled)
            return true;
          const { getDisabled } = props;
          if (getDisabled?.())
            return true;
          return false;
        };
        const getMergedShow = () => {
          if (getMergedDisabled())
            return false;
          return mergedShowWithoutDisabledRef.value;
        };
        const compatibleShowArrowRef = useCompitable(props, ["arrow", "showArrow"]);
        const mergedShowArrowRef = vue.computed(() => {
          if (props.overlap)
            return false;
          return compatibleShowArrowRef.value;
        });
        let bodyInstance = null;
        const showTimerIdRef = vue.ref(null);
        const hideTimerIdRef = vue.ref(null);
        const positionManuallyRef = useMemo(() => {
          return props.x !== void 0 && props.y !== void 0;
        });
        function doUpdateShow(value) {
          const {
            "onUpdate:show": _onUpdateShow,
            onUpdateShow,
            onShow,
            onHide
          } = props;
          uncontrolledShowRef.value = value;
          if (_onUpdateShow) {
            call(_onUpdateShow, value);
          }
          if (onUpdateShow) {
            call(onUpdateShow, value);
          }
          if (value && onShow) {
            call(onShow, true);
          }
          if (value && onHide) {
            call(onHide, false);
          }
        }
        function syncPosition() {
          if (bodyInstance) {
            bodyInstance.syncPosition();
          }
        }
        function clearShowTimer() {
          const { value: showTimerId } = showTimerIdRef;
          if (showTimerId) {
            window.clearTimeout(showTimerId);
            showTimerIdRef.value = null;
          }
        }
        function clearHideTimer() {
          const { value: hideTimerId } = hideTimerIdRef;
          if (hideTimerId) {
            window.clearTimeout(hideTimerId);
            hideTimerIdRef.value = null;
          }
        }
        function handleFocus() {
          const mergedDisabled = getMergedDisabled();
          if (props.trigger === "focus" && !mergedDisabled) {
            if (getMergedShow())
              return;
            doUpdateShow(true);
          }
        }
        function handleBlur() {
          const mergedDisabled = getMergedDisabled();
          if (props.trigger === "focus" && !mergedDisabled) {
            if (!getMergedShow())
              return;
            doUpdateShow(false);
          }
        }
        function handleMouseEnter() {
          const mergedDisabled = getMergedDisabled();
          if (props.trigger === "hover" && !mergedDisabled) {
            clearHideTimer();
            if (showTimerIdRef.value !== null)
              return;
            if (getMergedShow())
              return;
            const delayCallback = () => {
              doUpdateShow(true);
              showTimerIdRef.value = null;
            };
            const { delay } = props;
            if (delay === 0) {
              delayCallback();
            } else {
              showTimerIdRef.value = window.setTimeout(delayCallback, delay);
            }
          }
        }
        function handleMouseLeave() {
          const mergedDisabled = getMergedDisabled();
          if (props.trigger === "hover" && !mergedDisabled) {
            clearShowTimer();
            if (hideTimerIdRef.value !== null)
              return;
            if (!getMergedShow())
              return;
            const delayedCallback = () => {
              doUpdateShow(false);
              hideTimerIdRef.value = null;
            };
            const { duration } = props;
            if (duration === 0) {
              delayedCallback();
            } else {
              hideTimerIdRef.value = window.setTimeout(delayedCallback, duration);
            }
          }
        }
        function handleMouseMoveOutside() {
          handleMouseLeave();
        }
        function handleClickOutside(e) {
          if (!getMergedShow())
            return;
          if (props.trigger === "click") {
            clearShowTimer();
            clearHideTimer();
            doUpdateShow(false);
          }
          props.onClickoutside?.(e);
        }
        function handleClick() {
          if (props.trigger === "click" && !getMergedDisabled()) {
            clearShowTimer();
            clearHideTimer();
            const nextShow = !getMergedShow();
            doUpdateShow(nextShow);
          }
        }
        function handleKeydown(e) {
          if (!props.internalTrapFocus)
            return;
          if (e.key === "Escape") {
            clearShowTimer();
            clearHideTimer();
            doUpdateShow(false);
          }
        }
        function setShow(value) {
          uncontrolledShowRef.value = value;
        }
        function getTriggerElement() {
          return binderInstRef.value?.targetRef;
        }
        function setBodyInstance(value) {
          bodyInstance = value;
        }
        vue.provide("NPopover", {
          getTriggerElement,
          handleKeydown,
          handleMouseEnter,
          handleMouseLeave,
          handleClickOutside,
          handleMouseMoveOutside,
          setBodyInstance,
          positionManuallyRef,
          isMountedRef,
          zIndexRef: vue.toRef(props, "zIndex"),
          extraClassRef: vue.toRef(props, "internalExtraClass"),
          internalRenderBodyRef: vue.toRef(props, "internalRenderBody")
        });
        return {
          binderInstRef,
          positionManually: positionManuallyRef,
          mergedShowConsideringDisabledProp: mergedShowConsideringDisabledPropRef,
          uncontrolledShow: uncontrolledShowRef,
          mergedShowArrow: mergedShowArrowRef,
          getMergedShow,
          setShow,
          handleClick,
          handleMouseEnter,
          handleMouseLeave,
          handleFocus,
          handleBlur,
          syncPosition
        };
      },
      render() {
        const { positionManually, $slots: slots } = this;
        let triggerVNode;
        let popoverInside = false;
        if (!positionManually) {
          if (slots.activator) {
            triggerVNode = getFirstSlotVNode(slots, "activator");
          } else {
            triggerVNode = getFirstSlotVNode(slots, "trigger");
          }
          if (triggerVNode) {
            triggerVNode = vue.cloneVNode(triggerVNode);
            triggerVNode = triggerVNode.type === textVNodeType ? vue.h("span", [triggerVNode]) : triggerVNode;
            const handlers = {
              onClick: this.handleClick,
              onMouseenter: this.handleMouseEnter,
              onMouseleave: this.handleMouseLeave,
              onFocus: this.handleFocus,
              onBlur: this.handleBlur
            };
            if (triggerVNode.type?.__popover__) {
              popoverInside = true;
              if (!triggerVNode.props) {
                triggerVNode.props = {
                  internalSyncTargetWithParent: true,
                  internalInheritedEventHandlers: []
                };
              }
              triggerVNode.props.internalSyncTargetWithParent = true;
              if (!triggerVNode.props.internalInheritedEventHandlers) {
                triggerVNode.props.internalInheritedEventHandlers = [handlers];
              } else {
                triggerVNode.props.internalInheritedEventHandlers = [
                  handlers,
                  ...triggerVNode.props.internalInheritedEventHandlers
                ];
              }
            } else {
              const { internalInheritedEventHandlers } = this;
              const ascendantAndCurrentHandlers = [
                handlers,
                ...internalInheritedEventHandlers
              ];
              const mergedHandlers = {
                onBlur: (e) => {
                  ascendantAndCurrentHandlers.forEach((_handlers) => {
                    _handlers.onBlur(e);
                  });
                },
                onFocus: (e) => {
                  ascendantAndCurrentHandlers.forEach((_handlers) => {
                    _handlers.onFocus(e);
                  });
                },
                onClick: (e) => {
                  ascendantAndCurrentHandlers.forEach((_handlers) => {
                    _handlers.onClick(e);
                  });
                },
                onMouseenter: (e) => {
                  ascendantAndCurrentHandlers.forEach((_handlers) => {
                    _handlers.onMouseenter(e);
                  });
                },
                onMouseleave: (e) => {
                  ascendantAndCurrentHandlers.forEach((_handlers) => {
                    _handlers.onMouseleave(e);
                  });
                }
              };
              appendEvents(
                triggerVNode,
                internalInheritedEventHandlers ? "nested" : positionManually ? "manual" : this.trigger,
                mergedHandlers
              );
            }
          }
        }
        return /* @__PURE__ */ React.createElement(VBinder, {
          ref: "binderInstRef",
          syncTarget: !popoverInside,
          syncTargetWithParent: this.internalSyncTargetWithParent
        }, {
          default: () => {
            void this.mergedShowConsideringDisabledProp;
            const mergedShow = this.getMergedShow();
            return [
              this.internalTrapFocus && mergedShow ? vue.withDirectives(
                /* @__PURE__ */ React.createElement("div", {
                  style: { position: "fixed", inset: 0 }
                }),
                [
                  [
                    zindexable$1,
                    {
                      enabled: mergedShow,
                      zIndex: this.zIndex
                    }
                  ]
                ]
              ) : null,
              positionManually ? null : vue.h(VTarget, null, {
                default: () => triggerVNode
              }),
              vue.h(
                NPopoverBody,
                keep(this.$props, bodyPropKeys, {
                  ...this.$attrs,
                  showArrow: this.mergedShowArrow,
                  show: mergedShow
                }),
                {
                  default: () => this.$slots.default?.(),
                  header: () => this.$slots.header?.(),
                  footer: () => this.$slots.footer?.()
                }
              )
            ];
          }
        });
      }
    });

    var commonVariables$j = {
      closeIconSizeTiny: "12px",
      closeIconSizeSmall: "12px",
      closeIconSizeMedium: "14px",
      closeIconSizeLarge: "14px",
      closeSizeTiny: "16px",
      closeSizeSmall: "16px",
      closeSizeMedium: "18px",
      closeSizeLarge: "18px",
      padding: "0 7px",
      closeMargin: "0 0 0 4px",
      closeMarginRtl: "0 4px 0 0"
    };

    const tagDark = {
      name: "Tag",
      common: commonDark,

      self(vars) {
        const {
          textColor2,
          primaryColorHover,
          primaryColorPressed,
          primaryColor,
          infoColor,
          successColor,
          warningColor,
          errorColor,
          baseColor,
          borderColor,
          tagColor,
          opacityDisabled,
          closeIconColor,
          closeIconColorHover,
          closeIconColorPressed,
          closeColorHover,
          closeColorPressed,
          borderRadiusSmall: borderRadius,
          fontSizeMini,
          fontSizeTiny,
          fontSizeSmall,
          fontSizeMedium,
          heightMini,
          heightTiny,
          heightSmall,
          heightMedium,
          buttonColor2Hover,
          buttonColor2Pressed,
          fontWeightStrong
        } = vars;
        return { ...commonVariables$j,
          closeBorderRadius: borderRadius,
          heightTiny: heightMini,
          heightSmall: heightTiny,
          heightMedium: heightSmall,
          heightLarge: heightMedium,
          borderRadius,
          opacityDisabled,
          fontSizeTiny: fontSizeMini,
          fontSizeSmall: fontSizeTiny,
          fontSizeMedium: fontSizeSmall,
          fontSizeLarge: fontSizeMedium,
          fontWeightStrong,
          textColorCheckable: textColor2,
          textColorHoverCheckable: textColor2,
          textColorPressedCheckable: textColor2,
          textColorChecked: baseColor,
          colorCheckable: "#0000",
          colorHoverCheckable: buttonColor2Hover,
          colorPressedCheckable: buttonColor2Pressed,
          colorChecked: primaryColor,
          colorCheckedHover: primaryColorHover,
          colorCheckedPressed: primaryColorPressed,
          border: `1px solid ${borderColor}`,
          textColor: textColor2,
          color: tagColor,
          colorBordered: "#0000",
          closeIconColor,
          closeIconColorHover,
          closeIconColorPressed,
          closeColorHover,
          closeColorPressed,
          borderPrimary: `1px solid ${changeColor(primaryColor, {
        alpha: 0.3
      })}`,
          textColorPrimary: primaryColor,
          colorPrimary: changeColor(primaryColor, {
            alpha: 0.16
          }),
          colorBorderedPrimary: "#0000",
          closeIconColorPrimary: scaleColor(primaryColor, {
            lightness: 0.7
          }),
          closeIconColorHoverPrimary: scaleColor(primaryColor, {
            lightness: 0.7
          }),
          closeIconColorPressedPrimary: scaleColor(primaryColor, {
            lightness: 0.7
          }),
          closeColorHoverPrimary: changeColor(primaryColor, {
            alpha: 0.16
          }),
          closeColorPressedPrimary: changeColor(primaryColor, {
            alpha: 0.12
          }),
          borderInfo: `1px solid ${changeColor(infoColor, {
        alpha: 0.3
      })}`,
          textColorInfo: infoColor,
          colorInfo: changeColor(infoColor, {
            alpha: 0.16
          }),
          colorBorderedInfo: "#0000",
          closeIconColorInfo: scaleColor(infoColor, {
            alpha: 0.7
          }),
          closeIconColorHoverInfo: scaleColor(infoColor, {
            alpha: 0.7
          }),
          closeIconColorPressedInfo: scaleColor(infoColor, {
            alpha: 0.7
          }),
          closeColorHoverInfo: changeColor(infoColor, {
            alpha: 0.16
          }),
          closeColorPressedInfo: changeColor(infoColor, {
            alpha: 0.12
          }),
          borderSuccess: `1px solid ${changeColor(successColor, {
        alpha: 0.3
      })}`,
          textColorSuccess: successColor,
          colorSuccess: changeColor(successColor, {
            alpha: 0.16
          }),
          colorBorderedSuccess: "#0000",
          closeIconColorSuccess: scaleColor(successColor, {
            alpha: 0.7
          }),
          closeIconColorHoverSuccess: scaleColor(successColor, {
            alpha: 0.7
          }),
          closeIconColorPressedSuccess: scaleColor(successColor, {
            alpha: 0.7
          }),
          closeColorHoverSuccess: changeColor(successColor, {
            alpha: 0.16
          }),
          closeColorPressedSuccess: changeColor(successColor, {
            alpha: 0.12
          }),
          borderWarning: `1px solid ${changeColor(warningColor, {
        alpha: 0.3
      })}`,
          textColorWarning: warningColor,
          colorWarning: changeColor(warningColor, {
            alpha: 0.16
          }),
          colorBorderedWarning: "#0000",
          closeIconColorWarning: scaleColor(warningColor, {
            alpha: 0.7
          }),
          closeIconColorHoverWarning: scaleColor(warningColor, {
            alpha: 0.7
          }),
          closeIconColorPressedWarning: scaleColor(warningColor, {
            alpha: 0.7
          }),
          closeColorHoverWarning: changeColor(warningColor, {
            alpha: 0.16
          }),
          closeColorPressedWarning: changeColor(warningColor, {
            alpha: 0.11
          }),
          borderError: `1px solid ${changeColor(errorColor, {
        alpha: 0.3
      })}`,
          textColorError: errorColor,
          colorError: changeColor(errorColor, {
            alpha: 0.16
          }),
          colorBorderedError: "#0000",
          closeIconColorError: scaleColor(errorColor, {
            alpha: 0.7
          }),
          closeIconColorHoverError: scaleColor(errorColor, {
            alpha: 0.7
          }),
          closeIconColorPressedError: scaleColor(errorColor, {
            alpha: 0.7
          }),
          closeColorHoverError: changeColor(errorColor, {
            alpha: 0.16
          }),
          closeColorPressedError: changeColor(errorColor, {
            alpha: 0.12
          })
        };
      }

    };
    var tagDark$1 = tagDark;

    const self$17 = vars => {
      const {
        textColor2,
        primaryColorHover,
        primaryColorPressed,
        primaryColor,
        infoColor,
        successColor,
        warningColor,
        errorColor,
        baseColor,
        borderColor,
        opacityDisabled,
        tagColor,
        closeIconColor,
        closeIconColorHover,
        closeIconColorPressed,
        borderRadiusSmall: borderRadius,
        fontSizeMini,
        fontSizeTiny,
        fontSizeSmall,
        fontSizeMedium,
        heightMini,
        heightTiny,
        heightSmall,
        heightMedium,
        closeColorHover,
        closeColorPressed,
        buttonColor2Hover,
        buttonColor2Pressed,
        fontWeightStrong
      } = vars;
      return { ...commonVariables$j,
        closeBorderRadius: borderRadius,
        heightTiny: heightMini,
        heightSmall: heightTiny,
        heightMedium: heightSmall,
        heightLarge: heightMedium,
        borderRadius,
        opacityDisabled,
        fontSizeTiny: fontSizeMini,
        fontSizeSmall: fontSizeTiny,
        fontSizeMedium: fontSizeSmall,
        fontSizeLarge: fontSizeMedium,
        fontWeightStrong,
        textColorCheckable: textColor2,
        textColorHoverCheckable: textColor2,
        textColorPressedCheckable: textColor2,
        textColorChecked: baseColor,
        colorCheckable: "#0000",
        colorHoverCheckable: buttonColor2Hover,
        colorPressedCheckable: buttonColor2Pressed,
        colorChecked: primaryColor,
        colorCheckedHover: primaryColorHover,
        colorCheckedPressed: primaryColorPressed,
        border: `1px solid ${borderColor}`,
        textColor: textColor2,
        color: tagColor,
        colorBordered: "rgb(250, 250, 252)",
        closeIconColor,
        closeIconColorHover,
        closeIconColorPressed,
        closeColorHover,
        closeColorPressed,
        borderPrimary: `1px solid ${changeColor(primaryColor, {
      alpha: 0.3
    })}`,
        textColorPrimary: primaryColor,
        colorPrimary: changeColor(primaryColor, {
          alpha: 0.12
        }),
        colorBorderedPrimary: changeColor(primaryColor, {
          alpha: 0.1
        }),
        closeIconColorPrimary: primaryColor,
        closeIconColorHoverPrimary: primaryColor,
        closeIconColorPressedPrimary: primaryColor,
        closeColorHoverPrimary: changeColor(primaryColor, {
          alpha: 0.12
        }),
        closeColorPressedPrimary: changeColor(primaryColor, {
          alpha: 0.18
        }),
        borderInfo: `1px solid ${changeColor(infoColor, {
      alpha: 0.3
    })}`,
        textColorInfo: infoColor,
        colorInfo: changeColor(infoColor, {
          alpha: 0.12
        }),
        colorBorderedInfo: changeColor(infoColor, {
          alpha: 0.1
        }),
        closeIconColorInfo: infoColor,
        closeIconColorHoverInfo: infoColor,
        closeIconColorPressedInfo: infoColor,
        closeColorHoverInfo: changeColor(infoColor, {
          alpha: 0.12
        }),
        closeColorPressedInfo: changeColor(infoColor, {
          alpha: 0.18
        }),
        borderSuccess: `1px solid ${changeColor(successColor, {
      alpha: 0.3
    })}`,
        textColorSuccess: successColor,
        colorSuccess: changeColor(successColor, {
          alpha: 0.12
        }),
        colorBorderedSuccess: changeColor(successColor, {
          alpha: 0.1
        }),
        closeIconColorSuccess: successColor,
        closeIconColorHoverSuccess: successColor,
        closeIconColorPressedSuccess: successColor,
        closeColorHoverSuccess: changeColor(successColor, {
          alpha: 0.12
        }),
        closeColorPressedSuccess: changeColor(successColor, {
          alpha: 0.18
        }),
        borderWarning: `1px solid ${changeColor(warningColor, {
      alpha: 0.35
    })}`,
        textColorWarning: warningColor,
        colorWarning: changeColor(warningColor, {
          alpha: 0.15
        }),
        colorBorderedWarning: changeColor(warningColor, {
          alpha: 0.12
        }),
        closeIconColorWarning: warningColor,
        closeIconColorHoverWarning: warningColor,
        closeIconColorPressedWarning: warningColor,
        closeColorHoverWarning: changeColor(warningColor, {
          alpha: 0.12
        }),
        closeColorPressedWarning: changeColor(warningColor, {
          alpha: 0.18
        }),
        borderError: `1px solid ${changeColor(errorColor, {
      alpha: 0.23
    })}`,
        textColorError: errorColor,
        colorError: changeColor(errorColor, {
          alpha: 0.1
        }),
        colorBorderedError: changeColor(errorColor, {
          alpha: 0.08
        }),
        closeIconColorError: errorColor,
        closeIconColorHoverError: errorColor,
        closeIconColorPressedError: errorColor,
        closeColorHoverError: changeColor(errorColor, {
          alpha: 0.12
        }),
        closeColorPressedError: changeColor(errorColor, {
          alpha: 0.18
        })
      };
    };

    const tagLight = {
      name: "Tag",
      common: commonLight,
      self: self$17
    };
    var tagLight$1 = tagLight;

    var rtlStyle$q = cB("tag", [cM("rtl", `
    direction: rtl;
  `, [cE("close", `
      margin: var(--n-close-margin-rtl);
    `), cE("icon", `
      margin: 0 0 0 4px;
    `), cE("avatar", `
      margin: 0 0 0 6px;
    `), cM("round", [cE("icon", `
        margin: 0 calc((var(--n-height) - 8px) / -2) 0 4px;
      `), cE("avatar", `
        margin: 0 calc((var(--n-height) - 8px) / -2) 0 6px;
      `), cM("closable", `
        padding: 0 calc(var(--n-height) / 3) 0 calc(var(--n-height) / 4);
      `)]), cM("icon, avatar", [cM("round", `
        padding: 0 calc(var(--n-height) / 2) 0 calc(var(--n-height) / 3);
      `)])])]);

    const tagRtl = {
      name: "Tag",
      style: rtlStyle$q
    };

    var commonProps = {
      color: Object,
      type: {
        type: String,
        default: "default"
      },
      round: Boolean,
      size: {
        type: String,
        default: "medium"
      },
      closable: Boolean,
      disabled: {
        type: Boolean,
        default: void 0
      }
    };

    var style$1p = cB("tag", `
  white-space: nowrap;
  position: relative;
  box-sizing: border-box;
  cursor: default;
  display: inline-flex;
  align-items: center;
  flex-wrap: nowrap;
  padding: var(--n-padding);
  border-radius: var(--n-border-radius);
  color: var(--n-text-color);
  background-color: var(--n-color);
  transition: 
    border-color .3s var(--n-bezier),
    background-color .3s var(--n-bezier),
    color .3s var(--n-bezier),
    box-shadow .3s var(--n-bezier),
    opacity .3s var(--n-bezier);
  line-height: 1;
  height: var(--n-height);
  font-size: var(--n-font-size);
`, [cM("strong", `
    font-weight: var(--n-font-weight-strong);
  `), cE("border", `
    pointer-events: none;
    position: absolute;
    left: 0;
    right: 0;
    top: 0;
    bottom: 0;
    border-radius: inherit;
    border: var(--n-border);
    transition: border-color .3s var(--n-bezier);
  `), cE("icon", `
    display: flex;
    margin: 0 4px 0 0;
    color: var(--n-text-color);
    transition: color .3s var(--n-bezier);
    font-size: var(--n-avatar-size-override);
  `), cE("avatar", `
    display: flex;
    margin: 0 6px 0 0;
  `), cE("close", `
    margin: var(--n-close-margin);
    transition:
      background-color .3s var(--n-bezier),
      color .3s var(--n-bezier);
  `), cM("round", `
    padding: 0 calc(var(--n-height) / 3);
    border-radius: calc(var(--n-height) / 2);
  `, [cE("icon", `
      margin: 0 4px 0 calc((var(--n-height) - 8px) / -2);
    `), cE("avatar", `
      margin: 0 6px 0 calc((var(--n-height) - 8px) / -2);
    `), cM("closable", `
      padding: 0 calc(var(--n-height) / 4) 0 calc(var(--n-height) / 3);
    `)]), cM("icon, avatar", [cM("round", `
      padding: 0 calc(var(--n-height) / 3) 0 calc(var(--n-height) / 2);
    `)]), cM("disabled", `
    cursor: not-allowed !important;
    opacity: var(--n-opacity-disabled);
  `), cM("checkable", `
    cursor: pointer;
    box-shadow: none;
    color: var(--n-text-color-checkable);
    background-color: var(--n-color-checkable);
  `, [cNotM("disabled", [c$1("&:hover", "background-color: var(--n-color-hover-checkable);", [cNotM("checked", "color: var(--n-text-color-hover-checkable);")]), c$1("&:active", "background-color: var(--n-color-pressed-checkable);", [cNotM("checked", "color: var(--n-text-color-pressed-checkable);")])]), cM("checked", `
      color: var(--n-text-color-checked);
      background-color: var(--n-color-checked);
    `, [cNotM("disabled", [c$1("&:hover", "background-color: var(--n-color-checked-hover);"), c$1("&:active", "background-color: var(--n-color-checked-pressed);")])])])]);

    const tagProps = {
      ...useTheme.props,
      ...commonProps,
      bordered: {
        type: Boolean,
        default: void 0
      },
      checked: Boolean,
      checkable: Boolean,
      strong: Boolean,
      triggerClickOnClose: Boolean,
      onClose: [Array, Function],
      onMouseenter: Function,
      onMouseleave: Function,
      "onUpdate:checked": Function,
      onUpdateChecked: Function,
      internalCloseFocusable: {
        type: Boolean,
        default: true
      },
      onCheckedChange: {
        type: Function,
        validator: () => {
          {
            warn$2(
              "tag",
              "`on-checked-change` is deprecated, please use `on-update:checked` instead"
            );
          }
          return true;
        },
        default: void 0
      }
    };
    const tagInjectionKey = createInjectionKey("n-tag");
    var NTag = vue.defineComponent({
      name: "Tag",
      props: tagProps,
      setup(props) {
        const contentRef = vue.ref(null);
        const {
          mergedBorderedRef,
          mergedClsPrefixRef,
          inlineThemeDisabled,
          mergedRtlRef
        } = useConfig(props);
        const themeRef = useTheme(
          "Tag",
          "-tag",
          style$1p,
          tagLight$1,
          props,
          mergedClsPrefixRef
        );
        vue.provide(tagInjectionKey, {
          roundRef: vue.toRef(props, "round")
        });
        function handleClick(e) {
          if (!props.disabled) {
            if (props.checkable) {
              const {
                checked,
                onCheckedChange,
                onUpdateChecked,
                "onUpdate:checked": _onUpdateChecked
              } = props;
              if (onUpdateChecked)
                onUpdateChecked(!checked);
              if (_onUpdateChecked)
                _onUpdateChecked(!checked);
              if (onCheckedChange)
                onCheckedChange(!checked);
            }
          }
        }
        function handleCloseClick(e) {
          if (!props.triggerClickOnClose) {
            e.stopPropagation();
          }
          if (!props.disabled) {
            const { onClose } = props;
            if (onClose)
              call(onClose, e);
          }
        }
        const tagPublicMethods = {
          setTextContent(textContent) {
            const { value } = contentRef;
            if (value)
              value.textContent = textContent;
          }
        };
        const rtlEnabledRef = useRtl("Tag", mergedRtlRef, mergedClsPrefixRef);
        const cssVarsRef = vue.computed(() => {
          const { type, size, color: { color, textColor } = {} } = props;
          const {
            common: { cubicBezierEaseInOut },
            self: {
              padding,
              closeMargin,
              closeMarginRtl,
              borderRadius,
              opacityDisabled,
              textColorCheckable,
              textColorHoverCheckable,
              textColorPressedCheckable,
              textColorChecked,
              colorCheckable,
              colorHoverCheckable,
              colorPressedCheckable,
              colorChecked,
              colorCheckedHover,
              colorCheckedPressed,
              closeBorderRadius,
              fontWeightStrong,
              [createKey("colorBordered", type)]: colorBordered,
              [createKey("closeSize", size)]: closeSize,
              [createKey("closeIconSize", size)]: closeIconSize,
              [createKey("fontSize", size)]: fontSize,
              [createKey("height", size)]: height,
              [createKey("color", type)]: typedColor,
              [createKey("textColor", type)]: typeTextColor,
              [createKey("border", type)]: border,
              [createKey("closeIconColor", type)]: closeIconColor,
              [createKey("closeIconColorHover", type)]: closeIconColorHover,
              [createKey("closeIconColorPressed", type)]: closeIconColorPressed,
              [createKey("closeColorHover", type)]: closeColorHover,
              [createKey("closeColorPressed", type)]: closeColorPressed
            }
          } = themeRef.value;
          return {
            "--n-font-weight-strong": fontWeightStrong,
            "--n-avatar-size-override": `calc(${height} - 8px)`,
            "--n-bezier": cubicBezierEaseInOut,
            "--n-border-radius": borderRadius,
            "--n-border": border,
            "--n-close-icon-size": closeIconSize,
            "--n-close-color-pressed": closeColorPressed,
            "--n-close-color-hover": closeColorHover,
            "--n-close-border-radius": closeBorderRadius,
            "--n-close-icon-color": closeIconColor,
            "--n-close-icon-color-hover": closeIconColorHover,
            "--n-close-icon-color-pressed": closeIconColorPressed,
            "--n-close-icon-color-disabled": closeIconColor,
            "--n-close-margin": closeMargin,
            "--n-close-margin-rtl": closeMarginRtl,
            "--n-close-size": closeSize,
            "--n-color": color || (mergedBorderedRef.value ? colorBordered : typedColor),
            "--n-color-checkable": colorCheckable,
            "--n-color-checked": colorChecked,
            "--n-color-checked-hover": colorCheckedHover,
            "--n-color-checked-pressed": colorCheckedPressed,
            "--n-color-hover-checkable": colorHoverCheckable,
            "--n-color-pressed-checkable": colorPressedCheckable,
            "--n-font-size": fontSize,
            "--n-height": height,
            "--n-opacity-disabled": opacityDisabled,
            "--n-padding": padding,
            "--n-text-color": textColor || typeTextColor,
            "--n-text-color-checkable": textColorCheckable,
            "--n-text-color-checked": textColorChecked,
            "--n-text-color-hover-checkable": textColorHoverCheckable,
            "--n-text-color-pressed-checkable": textColorPressedCheckable
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "tag",
          vue.computed(() => {
            let hash = "";
            const { type, size, color: { color, textColor } = {} } = props;
            hash += type[0];
            hash += size[0];
            if (color) {
              hash += `a${color2Class(color)}`;
            }
            if (textColor) {
              hash += `b${color2Class(textColor)}`;
            }
            if (mergedBorderedRef.value) {
              hash += "c";
            }
            return hash;
          }),
          cssVarsRef,
          props
        ) : void 0;
        return {
          ...tagPublicMethods,
          rtlEnabled: rtlEnabledRef,
          mergedClsPrefix: mergedClsPrefixRef,
          contentRef,
          mergedBordered: mergedBorderedRef,
          handleClick,
          handleCloseClick,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const {
          mergedClsPrefix,
          rtlEnabled,
          closable,
          color: { borderColor } = {},
          round,
          onRender,
          $slots
        } = this;
        onRender?.();
        const avatarNode = resolveWrappedSlot(
          $slots.avatar,
          (children) => children && /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-tag__avatar`
          }, children)
        );
        const iconNode = resolveWrappedSlot(
          $slots.icon,
          (children) => children && /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-tag__icon`
          }, children)
        );
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-tag`,
            this.themeClass,
            {
              [`${mergedClsPrefix}-tag--rtl`]: rtlEnabled,
              [`${mergedClsPrefix}-tag--strong`]: this.strong,
              [`${mergedClsPrefix}-tag--disabled`]: this.disabled,
              [`${mergedClsPrefix}-tag--checkable`]: this.checkable,
              [`${mergedClsPrefix}-tag--checked`]: this.checkable && this.checked,
              [`${mergedClsPrefix}-tag--round`]: round,
              [`${mergedClsPrefix}-tag--avatar`]: avatarNode,
              [`${mergedClsPrefix}-tag--icon`]: iconNode,
              [`${mergedClsPrefix}-tag--closable`]: closable
            }
          ],
          style: this.cssVars,
          onClick: this.handleClick,
          onMouseenter: this.onMouseenter,
          onMouseleave: this.onMouseleave
        }, iconNode || avatarNode, /* @__PURE__ */ React.createElement("span", {
          class: `${mergedClsPrefix}-tag__content`,
          ref: "contentRef"
        }, this.$slots.default?.()), !this.checkable && closable ? /* @__PURE__ */ React.createElement(NBaseClose, {
          clsPrefix: mergedClsPrefix,
          class: `${mergedClsPrefix}-tag__close`,
          disabled: this.disabled,
          onClick: this.handleCloseClick,
          focusable: this.internalCloseFocusable,
          round,
          absolute: true
        }) : null, !this.checkable && this.mergedBordered ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-tag__border`,
          style: { borderColor }
        }) : null);
      }
    });

    var style$1o = cB("base-clear", `
  flex-shrink: 0;
  height: 1em;
  width: 1em;
  position: relative;
`, [c$1(">", [cE("clear", `
      font-size: var(--n-clear-size);
      height: 1em;
      width: 1em;
      cursor: pointer;
      color: var(--n-clear-color);
      transition: color .3s var(--n-bezier);
      display: flex;
    `, [c$1("&:hover", `
        color: var(--n-clear-color-hover)!important;
      `), c$1("&:active", `
        color: var(--n-clear-color-pressed)!important;
      `)]), cE("placeholder", `
      display: flex;
    `), cE("clear, placeholder", `
      position: absolute;
      left: 50%;
      top: 50%;
      transform: translateX(-50%) translateY(-50%);
    `, [iconSwitchTransition({
      originalTransform: "translateX(-50%) translateY(-50%)",
      left: "50%",
      top: "50%"
    })])])]);

    var NBaseClear = vue.defineComponent({
      name: "BaseClear",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        show: Boolean,
        onClear: Function
      },
      setup(props) {
        useStyle("-base-clear", style$1o, vue.toRef(props, "clsPrefix"));
        return {
          handleMouseDown(e) {
            e.preventDefault();
          }
        };
      },
      render() {
        const { clsPrefix } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-base-clear`
        }, /* @__PURE__ */ React.createElement(NIconSwitchTransition, null, {
          default: () => {
            return this.show ? /* @__PURE__ */ React.createElement("div", {
              key: "dismiss",
              class: `${clsPrefix}-base-clear__clear`,
              onClick: this.onClear,
              onMousedown: this.handleMouseDown,
              "data-clear": true
            }, resolveSlot(this.$slots.icon, () => [
              /* @__PURE__ */ React.createElement(NBaseIcon, {
                clsPrefix
              }, {
                default: () => /* @__PURE__ */ React.createElement(ClearIcon, null)
              })
            ])) : /* @__PURE__ */ React.createElement("div", {
              key: "icon",
              class: `${clsPrefix}-base-clear__placeholder`
            }, this.$slots.placeholder?.());
          }
        }));
      }
    });

    var NBaseSuffix = vue.defineComponent({
      name: "InternalSelectionSuffix",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        showArrow: {
          type: Boolean,
          default: void 0
        },
        showClear: {
          type: Boolean,
          default: void 0
        },
        loading: {
          type: Boolean,
          default: false
        },
        onClear: Function
      },
      setup(props, { slots }) {
        return () => {
          const { clsPrefix } = props;
          return /* @__PURE__ */ React.createElement(NBaseLoading, {
            clsPrefix,
            class: `${clsPrefix}-base-suffix`,
            strokeWidth: 24,
            scale: 0.85,
            show: props.loading
          }, {
            default: () => props.showArrow ? /* @__PURE__ */ React.createElement(NBaseClear, {
              clsPrefix,
              show: props.showClear,
              onClear: props.onClear
            }, {
              placeholder: () => /* @__PURE__ */ React.createElement(NBaseIcon, {
                clsPrefix,
                class: `${clsPrefix}-base-suffix__arrow`
              }, {
                default: () => resolveSlot(slots.default, () => [
                  /* @__PURE__ */ React.createElement(ChevronDownIcon, null)
                ])
              })
            }) : null
          });
        };
      }
    });

    var commonVars$b = {
      paddingSingle: "0 26px 0 12px",
      paddingMultiple: "3px 26px 0 12px",
      clearSize: "16px",
      arrowSize: "16px"
    };

    const self$16 = vars => {
      const {
        borderRadius,
        textColor2,
        textColorDisabled,
        inputColor,
        inputColorDisabled,
        primaryColor,
        primaryColorHover,
        warningColor,
        warningColorHover,
        errorColor,
        errorColorHover,
        borderColor,
        iconColor,
        iconColorDisabled,
        clearColor,
        clearColorHover,
        clearColorPressed,
        placeholderColor,
        placeholderColorDisabled,
        fontSizeTiny,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge,
        heightTiny,
        heightSmall,
        heightMedium,
        heightLarge
      } = vars;
      return { ...commonVars$b,
        fontSizeTiny,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge,
        heightTiny,
        heightSmall,
        heightMedium,
        heightLarge,
        borderRadius,
        textColor: textColor2,
        textColorDisabled,
        placeholderColor,
        placeholderColorDisabled,
        color: inputColor,
        colorDisabled: inputColorDisabled,
        colorActive: inputColor,
        border: `1px solid ${borderColor}`,
        borderHover: `1px solid ${primaryColorHover}`,
        borderActive: `1px solid ${primaryColor}`,
        borderFocus: `1px solid ${primaryColorHover}`,
        boxShadowHover: "none",
        boxShadowActive: `0 0 0 2px ${changeColor(primaryColor, {
      alpha: 0.2
    })}`,
        boxShadowFocus: `0 0 0 2px ${changeColor(primaryColor, {
      alpha: 0.2
    })}`,
        caretColor: primaryColor,
        arrowColor: iconColor,
        arrowColorDisabled: iconColorDisabled,
        loadingColor: primaryColor,
        borderWarning: `1px solid ${warningColor}`,
        borderHoverWarning: `1px solid ${warningColorHover}`,
        borderActiveWarning: `1px solid ${warningColor}`,
        borderFocusWarning: `1px solid ${warningColorHover}`,
        boxShadowHoverWarning: "none",
        boxShadowActiveWarning: `0 0 0 2px ${changeColor(warningColor, {
      alpha: 0.2
    })}`,
        boxShadowFocusWarning: `0 0 0 2px ${changeColor(warningColor, {
      alpha: 0.2
    })}`,
        colorActiveWarning: inputColor,
        caretColorWarning: warningColor,
        borderError: `1px solid ${errorColor}`,
        borderHoverError: `1px solid ${errorColorHover}`,
        borderActiveError: `1px solid ${errorColor}`,
        borderFocusError: `1px solid ${errorColorHover}`,
        boxShadowHoverError: "none",
        boxShadowActiveError: `0 0 0 2px ${changeColor(errorColor, {
      alpha: 0.2
    })}`,
        boxShadowFocusError: `0 0 0 2px ${changeColor(errorColor, {
      alpha: 0.2
    })}`,
        colorActiveError: inputColor,
        caretColorError: errorColor,
        clearColor,
        clearColorHover,
        clearColorPressed
      };
    };

    const internalSelectionLight = createTheme$1({
      name: "InternalSelection",
      common: commonLight,
      peers: {
        Popover: popoverLight$1
      },
      self: self$16
    });
    var internalSelectionLight$1 = internalSelectionLight;

    const internalSelectionDark = {
      name: "InternalSelection",
      common: commonDark,
      peers: {
        Popover: popoverDark$1
      },

      self(vars) {
        const {
          borderRadius,
          textColor2,
          textColorDisabled,
          inputColor,
          inputColorDisabled,
          primaryColor,
          primaryColorHover,
          warningColor,
          warningColorHover,
          errorColor,
          errorColorHover,
          iconColor,
          iconColorDisabled,
          clearColor,
          clearColorHover,
          clearColorPressed,
          placeholderColor,
          placeholderColorDisabled,
          fontSizeTiny,
          fontSizeSmall,
          fontSizeMedium,
          fontSizeLarge,
          heightTiny,
          heightSmall,
          heightMedium,
          heightLarge
        } = vars;
        return { ...commonVars$b,
          fontSizeTiny,
          fontSizeSmall,
          fontSizeMedium,
          fontSizeLarge,
          heightTiny,
          heightSmall,
          heightMedium,
          heightLarge,
          borderRadius,
          textColor: textColor2,
          textColorDisabled,
          placeholderColor,
          placeholderColorDisabled,
          color: inputColor,
          colorDisabled: inputColorDisabled,
          colorActive: changeColor(primaryColor, {
            alpha: 0.1
          }),
          border: "1px solid #0000",
          borderHover: `1px solid ${primaryColorHover}`,
          borderActive: `1px solid ${primaryColor}`,
          borderFocus: `1px solid ${primaryColorHover}`,
          boxShadowHover: "none",
          boxShadowActive: `0 0 8px 0 ${changeColor(primaryColor, {
        alpha: 0.4
      })}`,
          boxShadowFocus: `0 0 8px 0 ${changeColor(primaryColor, {
        alpha: 0.4
      })}`,
          caretColor: primaryColor,
          arrowColor: iconColor,
          arrowColorDisabled: iconColorDisabled,
          loadingColor: primaryColor,
          borderWarning: `1px solid ${warningColor}`,
          borderHoverWarning: `1px solid ${warningColorHover}`,
          borderActiveWarning: `1px solid ${warningColor}`,
          borderFocusWarning: `1px solid ${warningColorHover}`,
          boxShadowHoverWarning: "none",
          boxShadowActiveWarning: `0 0 8px 0 ${changeColor(warningColor, {
        alpha: 0.4
      })}`,
          boxShadowFocusWarning: `0 0 8px 0 ${changeColor(warningColor, {
        alpha: 0.4
      })}`,
          colorActiveWarning: changeColor(warningColor, {
            alpha: 0.1
          }),
          caretColorWarning: warningColor,
          borderError: `1px solid ${errorColor}`,
          borderHoverError: `1px solid ${errorColorHover}`,
          borderActiveError: `1px solid ${errorColor}`,
          borderFocusError: `1px solid ${errorColorHover}`,
          boxShadowHoverError: "none",
          boxShadowActiveError: `0 0 8px 0 ${changeColor(errorColor, {
        alpha: 0.4
      })}`,
          boxShadowFocusError: `0 0 8px 0 ${changeColor(errorColor, {
        alpha: 0.4
      })}`,
          colorActiveError: changeColor(errorColor, {
            alpha: 0.1
          }),
          caretColorError: errorColor,
          clearColor,
          clearColorHover,
          clearColorPressed
        };
      }

    };
    var internalSelectionDark$1 = internalSelectionDark;

    var style$1n = c$1([cB("base-selection", `
    position: relative;
    z-index: auto;
    box-shadow: none;
    width: 100%;
    max-width: 100%;
    display: inline-block;
    vertical-align: bottom;
    border-radius: var(--n-border-radius);
    min-height: var(--n-height);
    line-height: 1.5;
    font-size: var(--n-font-size);
  `, [cB("base-loading", `
      color: var(--n-loading-color);
    `), cB("base-selection-tags", "min-height: var(--n-height);"), cE("border, state-border", `
      position: absolute;
      left: 0;
      right: 0;
      top: 0;
      bottom: 0;
      pointer-events: none;
      border: var(--n-border);
      border-radius: inherit;
      transition:
        box-shadow .3s var(--n-bezier),
        border-color .3s var(--n-bezier);
    `), cE("state-border", `
      z-index: 1;
      border-color: #0000;
    `), cB("base-suffix", `
      cursor: pointer;
      position: absolute;
      top: 50%;
      transform: translateY(-50%);
      right: 10px;
    `, [cE("arrow", `
        font-size: var(--n-arrow-size);
        color: var(--n-arrow-color);
        transition: color .3s var(--n-bezier);
      `)]), cB("base-selection-overlay", `
      display: flex;
      align-items: center;
      white-space: nowrap;
      pointer-events: none;
      position: absolute;
      top: 0;
      right: 0;
      bottom: 0;
      left: 0;
      padding: var(--n-padding-single);
      transition: color .3s var(--n-bezier);
    `, [cE("wrapper", `
        flex-basis: 0;
        flex-grow: 1;
        overflow: hidden;
        text-overflow: ellipsis;
      `)]), cB("base-selection-placeholder", `
      color: var(--n-placeholder-color);
    `, [cE("inner", `
        max-width: 100%;
        overflow: hidden;
      `)]), cB("base-selection-tags", `
      cursor: pointer;
      outline: none;
      box-sizing: border-box;
      position: relative;
      z-index: auto;
      display: flex;
      padding: var(--n-padding-multiple);
      flex-wrap: wrap;
      align-items: center;
      width: 100%;
      vertical-align: bottom;
      background-color: var(--n-color);
      border-radius: inherit;
      transition:
        color .3s var(--n-bezier),
        box-shadow .3s var(--n-bezier),
        background-color .3s var(--n-bezier);
    `), cB("base-selection-label", `
      height: var(--n-height);
      display: inline-flex;
      width: 100%;
      vertical-align: bottom;
      cursor: pointer;
      outline: none;
      z-index: auto;
      box-sizing: border-box;
      position: relative;
      transition:
      color .3s var(--n-bezier),
      box-shadow .3s var(--n-bezier),
      background-color .3s var(--n-bezier);
      border-radius: inherit;
      background-color: var(--n-color);
      align-items: center;
    `, [cB("base-selection-input", `
        font-size: inherit;
        line-height: inherit;
        outline: none;
        cursor: pointer;
        box-sizing: border-box;
        border:none;
        width: 100%;
        padding: var(--n-padding-single);
        background-color: #0000;
        color: var(--n-text-color);
        transition: color .3s var(--n-bezier);
        caret-color: var(--n-caret-color);
      `, [cE("content", `
          text-overflow: ellipsis;
          overflow: hidden;
          white-space: nowrap;  
        `)]), cE("render-label", `
        color: var(--n-text-color);
      `)]), cNotM("disabled", [c$1("&:hover", [cE("state-border", `
          box-shadow: var(--n-box-shadow-hover);
          border: var(--n-border-hover);
        `)]), cM("focus", [cE("state-border", `
          box-shadow: var(--n-box-shadow-focus);
          border: var(--n-border-focus);
        `)]), cM("active", [cE("state-border", `
          box-shadow: var(--n-box-shadow-active);
          border: var(--n-border-active);
        `), cB("base-selection-label", "background-color: var(--n-color-active);"), cB("base-selection-tags", "background-color: var(--n-color-active);")])]), cM("disabled", "cursor: not-allowed;", [cE("arrow", `
        color: var(--n-arrow-color-disabled);
      `), cB("base-selection-label", `
        cursor: not-allowed;
        background-color: var(--n-color-disabled);
      `, [cB("base-selection-input", `
          cursor: not-allowed;
          color: var(--n-text-color-disabled);
        `), cE("render-label", `
          color: var(--n-text-color-disabled);
        `)]), cB("base-selection-tags", `
        cursor: not-allowed;
        background-color: var(--n-color-disabled);
      `), cB("base-selection-placeholder", `
        cursor: not-allowed;
        color: var(--n-placeholder-color-disabled);
      `)]), cB("base-selection-input-tag", `
      height: calc(var(--n-height) - 6px);
      line-height: calc(var(--n-height) - 6px);
      outline: none;
      display: none;
      position: relative;
      margin-bottom: 3px;
      max-width: 100%;
      vertical-align: bottom;
    `, [cE("input", `
        font-size: inherit;
        font-family: inherit;
        min-width: 1px;
        padding: 0;
        background-color: #0000;
        outline: none;
        border: none;
        max-width: 100%;
        overflow: hidden;
        width: 1em;
        line-height: inherit;
        cursor: pointer;
        color: var(--n-text-color);
        caret-color: var(--n-caret-color);
      `), cE("mirror", `
        position: absolute;
        left: 0;
        top: 0;
        white-space: pre;
        visibility: hidden;
        user-select: none;
        -webkit-user-select: none;
        opacity: 0;
      `)]), ["warning", "error"].map(status => cM(`${status}-status`, [cE("state-border", `border: var(--n-border-${status});`), cNotM("disabled", [c$1("&:hover", [cE("state-border", `
            box-shadow: var(--n-box-shadow-hover-${status});
            border: var(--n-border-hover-${status});
          `)]), cM("active", [cE("state-border", `
            box-shadow: var(--n-box-shadow-active-${status});
            border: var(--n-border-active-${status});
          `), cB("base-selection-label", `background-color: var(--n-color-active-${status});`), cB("base-selection-tags", `background-color: var(--n-color-active-${status});`)]), cM("focus", [cE("state-border", `
            box-shadow: var(--n-box-shadow-focus-${status});
            border: var(--n-border-focus-${status});
          `)])])]))]), cB("base-selection-popover", `
    margin-bottom: -3px;
    display: flex;
    flex-wrap: wrap;
    margin-right: -8px;
  `), cB("base-selection-tag-wrapper", `
    max-width: 100%;
    display: inline-flex;
    padding: 0 7px 3px 0;
  `, [c$1("&:last-child", "padding-right: 0;"), cB("tag", `
      font-size: 14px;
      max-width: 100%;
    `, [cE("content", `
        line-height: 1.25;
        text-overflow: ellipsis;
          overflow: hidden;
      `)])])]);

    var NInternalSelection = vue.defineComponent({
      name: "InternalSelection",
      props: {
        ...useTheme.props,
        clsPrefix: {
          type: String,
          required: true
        },
        bordered: {
          type: Boolean,
          default: void 0
        },
        active: Boolean,
        pattern: {
          type: String,
          default: ""
        },
        placeholder: String,
        selectedOption: {
          type: Object,
          default: null
        },
        selectedOptions: {
          type: Array,
          default: null
        },
        labelField: { type: String, default: "label" },
        valueField: {
          type: String,
          default: "value"
        },
        multiple: Boolean,
        filterable: Boolean,
        clearable: Boolean,
        disabled: Boolean,
        size: {
          type: String,
          default: "medium"
        },
        loading: Boolean,
        autofocus: Boolean,
        showArrow: {
          type: Boolean,
          default: true
        },
        inputProps: Object,
        focused: Boolean,
        renderTag: Function,
        onKeydown: Function,
        onClick: Function,
        onBlur: Function,
        onFocus: Function,
        onDeleteOption: Function,
        maxTagCount: [String, Number],
        onClear: Function,
        onPatternInput: Function,
        onPatternFocus: Function,
        onPatternBlur: Function,
        renderLabel: Function,
        status: String,
        inlineThemeDisabled: Boolean,
        onResize: Function
      },
      setup(props) {
        const patternInputMirrorRef = vue.ref(null);
        const patternInputRef = vue.ref(null);
        const selfRef = vue.ref(null);
        const multipleElRef = vue.ref(null);
        const singleElRef = vue.ref(null);
        const patternInputWrapperRef = vue.ref(null);
        const counterRef = vue.ref(null);
        const counterWrapperRef = vue.ref(null);
        const overflowRef = vue.ref(null);
        const inputTagElRef = vue.ref(null);
        const showTagsPopoverRef = vue.ref(false);
        const patternInputFocusedRef = vue.ref(false);
        const hoverRef = vue.ref(false);
        const themeRef = useTheme(
          "InternalSelection",
          "-internal-selection",
          style$1n,
          internalSelectionLight$1,
          props,
          vue.toRef(props, "clsPrefix")
        );
        const mergedClearableRef = vue.computed(() => {
          return props.clearable && !props.disabled && (hoverRef.value || props.active);
        });
        const filterablePlaceholderRef = vue.computed(() => {
          return props.selectedOption ? props.renderTag ? props.renderTag({
            option: props.selectedOption,
            handleClose: () => {
            }
          }) : props.renderLabel ? props.renderLabel(props.selectedOption, true) : render$1(
            props.selectedOption[props.labelField],
            props.selectedOption,
            true
          ) : props.placeholder;
        });
        const labelRef = vue.computed(() => {
          const option = props.selectedOption;
          if (!option)
            return void 0;
          return option[props.labelField];
        });
        const selectedRef = vue.computed(() => {
          if (props.multiple) {
            return !!(Array.isArray(props.selectedOptions) && props.selectedOptions.length);
          } else {
            return props.selectedOption !== null;
          }
        });
        function syncMirrorWidth() {
          const { value: patternInputMirrorEl } = patternInputMirrorRef;
          if (patternInputMirrorEl) {
            const { value: patternInputEl } = patternInputRef;
            if (patternInputEl) {
              patternInputEl.style.width = `${patternInputMirrorEl.offsetWidth}px`;
              if (props.maxTagCount !== "responsive") {
                overflowRef.value?.sync();
              }
            }
          }
        }
        function hideInputTag() {
          const { value: inputTagEl } = inputTagElRef;
          if (inputTagEl)
            inputTagEl.style.display = "none";
        }
        function showInputTag() {
          const { value: inputTagEl } = inputTagElRef;
          if (inputTagEl)
            inputTagEl.style.display = "inline-block";
        }
        vue.watch(vue.toRef(props, "active"), (value) => {
          if (!value)
            hideInputTag();
        });
        vue.watch(vue.toRef(props, "pattern"), () => {
          if (props.multiple) {
            void vue.nextTick(syncMirrorWidth);
          }
        });
        function doFocus(e) {
          const { onFocus } = props;
          if (onFocus)
            onFocus(e);
        }
        function doBlur(e) {
          const { onBlur } = props;
          if (onBlur)
            onBlur(e);
        }
        function doDeleteOption(value) {
          const { onDeleteOption } = props;
          if (onDeleteOption)
            onDeleteOption(value);
        }
        function doClear(e) {
          const { onClear } = props;
          if (onClear)
            onClear(e);
        }
        function doPatternInput(value) {
          const { onPatternInput } = props;
          if (onPatternInput)
            onPatternInput(value);
        }
        function handleFocusin(e) {
          if (!e.relatedTarget || !selfRef.value?.contains(e.relatedTarget)) {
            doFocus(e);
          }
        }
        function handleFocusout(e) {
          if (selfRef.value?.contains(e.relatedTarget))
            return;
          doBlur(e);
        }
        function handleClear(e) {
          doClear(e);
        }
        function handleMouseEnter() {
          hoverRef.value = true;
        }
        function handleMouseLeave() {
          hoverRef.value = false;
        }
        function handleMouseDown(e) {
          if (!props.active || !props.filterable)
            return;
          if (e.target === patternInputRef.value)
            return;
          e.preventDefault();
        }
        function handleDeleteOption(option) {
          doDeleteOption(option);
        }
        function handlePatternKeyDown(e) {
          if (e.key === "Backspace" && !isCompositingRef.value) {
            if (!props.pattern.length) {
              const { selectedOptions } = props;
              if (selectedOptions?.length) {
                handleDeleteOption(selectedOptions[selectedOptions.length - 1]);
              }
            }
          }
        }
        const isCompositingRef = vue.ref(false);
        let cachedInputEvent = null;
        function handlePatternInputInput(e) {
          const { value: patternInputMirrorEl } = patternInputMirrorRef;
          if (patternInputMirrorEl) {
            const inputText = e.target.value;
            patternInputMirrorEl.textContent = inputText;
            syncMirrorWidth();
          }
          if (!isCompositingRef.value) {
            doPatternInput(e);
          } else {
            cachedInputEvent = e;
          }
        }
        function handleCompositionStart() {
          isCompositingRef.value = true;
        }
        function handleCompositionEnd() {
          isCompositingRef.value = false;
          doPatternInput(cachedInputEvent);
          cachedInputEvent = null;
        }
        function handlePatternInputFocus(e) {
          patternInputFocusedRef.value = true;
          props.onPatternFocus?.(e);
        }
        function handlePatternInputBlur(e) {
          patternInputFocusedRef.value = false;
          props.onPatternBlur?.(e);
        }
        function blur() {
          if (props.filterable) {
            patternInputFocusedRef.value = false;
            patternInputWrapperRef.value?.blur();
            patternInputRef.value?.blur();
          } else if (props.multiple) {
            const { value: multipleEl } = multipleElRef;
            multipleEl?.blur();
          } else {
            const { value: singleEl } = singleElRef;
            singleEl?.blur();
          }
        }
        function focus() {
          if (props.filterable) {
            patternInputFocusedRef.value = false;
            patternInputWrapperRef.value?.focus();
          } else if (props.multiple) {
            multipleElRef.value?.focus();
          } else {
            singleElRef.value?.focus();
          }
        }
        function focusInput() {
          const { value: patternInputEl } = patternInputRef;
          if (patternInputEl) {
            showInputTag();
            patternInputEl.focus();
          }
        }
        function blurInput() {
          const { value: patternInputEl } = patternInputRef;
          if (patternInputEl) {
            patternInputEl.blur();
          }
        }
        function updateCounter(count) {
          const { value } = counterRef;
          if (value) {
            value.setTextContent(`+${count}`);
          }
        }
        function getCounter() {
          const { value } = counterWrapperRef;
          return value;
        }
        function getTail() {
          return patternInputRef.value;
        }
        let enterTimerId = null;
        function clearEnterTimer() {
          if (enterTimerId !== null)
            window.clearTimeout(enterTimerId);
        }
        function handleMouseEnterCounter() {
          if (props.disabled || props.active)
            return;
          clearEnterTimer();
          enterTimerId = window.setTimeout(() => {
            showTagsPopoverRef.value = true;
          }, 100);
        }
        function handleMouseLeaveCounter() {
          clearEnterTimer();
        }
        function onPopoverUpdateShow(show) {
          if (!show) {
            clearEnterTimer();
            showTagsPopoverRef.value = false;
          }
        }
        vue.onMounted(() => {
          vue.watchEffect(() => {
            const patternInputWrapperEl = patternInputWrapperRef.value;
            if (!patternInputWrapperEl)
              return;
            patternInputWrapperEl.tabIndex = props.disabled || patternInputFocusedRef.value ? -1 : 0;
          });
        });
        useOnResize(selfRef, props.onResize);
        const { inlineThemeDisabled } = props;
        const cssVarsRef = vue.computed(() => {
          const { size } = props;
          const {
            common: { cubicBezierEaseInOut },
            self: {
              borderRadius,
              color,
              placeholderColor,
              textColor,
              paddingSingle,
              paddingMultiple,
              caretColor,
              colorDisabled,
              textColorDisabled,
              placeholderColorDisabled,
              colorActive,
              boxShadowFocus,
              boxShadowActive,
              boxShadowHover,
              border,
              borderFocus,
              borderHover,
              borderActive,
              arrowColor,
              arrowColorDisabled,
              loadingColor,
              colorActiveWarning,
              boxShadowFocusWarning,
              boxShadowActiveWarning,
              boxShadowHoverWarning,
              borderWarning,
              borderFocusWarning,
              borderHoverWarning,
              borderActiveWarning,
              colorActiveError,
              boxShadowFocusError,
              boxShadowActiveError,
              boxShadowHoverError,
              borderError,
              borderFocusError,
              borderHoverError,
              borderActiveError,
              clearColor,
              clearColorHover,
              clearColorPressed,
              clearSize,
              arrowSize,
              [createKey("height", size)]: height,
              [createKey("fontSize", size)]: fontSize
            }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-border": border,
            "--n-border-active": borderActive,
            "--n-border-focus": borderFocus,
            "--n-border-hover": borderHover,
            "--n-border-radius": borderRadius,
            "--n-box-shadow-active": boxShadowActive,
            "--n-box-shadow-focus": boxShadowFocus,
            "--n-box-shadow-hover": boxShadowHover,
            "--n-caret-color": caretColor,
            "--n-color": color,
            "--n-color-active": colorActive,
            "--n-color-disabled": colorDisabled,
            "--n-font-size": fontSize,
            "--n-height": height,
            "--n-padding-single": paddingSingle,
            "--n-padding-multiple": paddingMultiple,
            "--n-placeholder-color": placeholderColor,
            "--n-placeholder-color-disabled": placeholderColorDisabled,
            "--n-text-color": textColor,
            "--n-text-color-disabled": textColorDisabled,
            "--n-arrow-color": arrowColor,
            "--n-arrow-color-disabled": arrowColorDisabled,
            "--n-loading-color": loadingColor,
            "--n-color-active-warning": colorActiveWarning,
            "--n-box-shadow-focus-warning": boxShadowFocusWarning,
            "--n-box-shadow-active-warning": boxShadowActiveWarning,
            "--n-box-shadow-hover-warning": boxShadowHoverWarning,
            "--n-border-warning": borderWarning,
            "--n-border-focus-warning": borderFocusWarning,
            "--n-border-hover-warning": borderHoverWarning,
            "--n-border-active-warning": borderActiveWarning,
            "--n-color-active-error": colorActiveError,
            "--n-box-shadow-focus-error": boxShadowFocusError,
            "--n-box-shadow-active-error": boxShadowActiveError,
            "--n-box-shadow-hover-error": boxShadowHoverError,
            "--n-border-error": borderError,
            "--n-border-focus-error": borderFocusError,
            "--n-border-hover-error": borderHoverError,
            "--n-border-active-error": borderActiveError,
            "--n-clear-size": clearSize,
            "--n-clear-color": clearColor,
            "--n-clear-color-hover": clearColorHover,
            "--n-clear-color-pressed": clearColorPressed,
            "--n-arrow-size": arrowSize
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "internal-selection",
          vue.computed(() => {
            return props.size[0];
          }),
          cssVarsRef,
          props
        ) : void 0;
        return {
          mergedTheme: themeRef,
          mergedClearable: mergedClearableRef,
          patternInputFocused: patternInputFocusedRef,
          filterablePlaceholder: filterablePlaceholderRef,
          label: labelRef,
          selected: selectedRef,
          showTagsPanel: showTagsPopoverRef,
          isCompositing: isCompositingRef,
          counterRef,
          counterWrapperRef,
          patternInputMirrorRef,
          patternInputRef,
          selfRef,
          multipleElRef,
          singleElRef,
          patternInputWrapperRef,
          overflowRef,
          inputTagElRef,
          handleMouseDown,
          handleFocusin,
          handleClear,
          handleMouseEnter,
          handleMouseLeave,
          handleDeleteOption,
          handlePatternKeyDown,
          handlePatternInputInput,
          handlePatternInputBlur,
          handlePatternInputFocus,
          handleMouseEnterCounter,
          handleMouseLeaveCounter,
          handleFocusout,
          handleCompositionEnd,
          handleCompositionStart,
          onPopoverUpdateShow,
          focus,
          focusInput,
          blur,
          blurInput,
          updateCounter,
          getCounter,
          getTail,
          renderLabel: props.renderLabel,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const {
          status,
          multiple,
          size,
          disabled,
          filterable,
          maxTagCount,
          bordered,
          clsPrefix,
          onRender,
          renderTag,
          renderLabel
        } = this;
        onRender?.();
        const maxTagCountResponsive = maxTagCount === "responsive";
        const maxTagCountNumeric = typeof maxTagCount === "number";
        const useMaxTagCount = maxTagCountResponsive || maxTagCountNumeric;
        const suffix = /* @__PURE__ */ React.createElement(Wrapper, null, {
          default: () => /* @__PURE__ */ React.createElement(NBaseSuffix, {
            clsPrefix,
            loading: this.loading,
            showArrow: this.showArrow,
            showClear: this.mergedClearable && this.selected,
            onClear: this.handleClear
          }, {
            default: () => this.$slots.arrow?.()
          })
        });
        let body;
        if (multiple) {
          const { labelField } = this;
          const createTag = (option) => /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-base-selection-tag-wrapper`,
            key: option.value
          }, renderTag ? renderTag({
            option,
            handleClose: () => this.handleDeleteOption(option)
          }) : /* @__PURE__ */ React.createElement(NTag, {
            size,
            closable: !option.disabled,
            disabled,
            onClose: () => this.handleDeleteOption(option),
            internalCloseFocusable: false
          }, {
            default: () => renderLabel ? renderLabel(option, true) : render$1(option[labelField], option, true)
          }));
          const originalTags = (maxTagCountNumeric ? this.selectedOptions.slice(0, maxTagCount) : this.selectedOptions).map(createTag);
          const input = filterable ? /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-base-selection-input-tag`,
            ref: "inputTagElRef",
            key: "__input-tag__"
          }, /* @__PURE__ */ React.createElement("input", {
            ...this.inputProps,
            ref: "patternInputRef",
            tabindex: -1,
            disabled,
            value: this.pattern,
            autofocus: this.autofocus,
            class: `${clsPrefix}-base-selection-input-tag__input`,
            onBlur: this.handlePatternInputBlur,
            onFocus: this.handlePatternInputFocus,
            onKeydown: this.handlePatternKeyDown,
            onInput: this.handlePatternInputInput,
            onCompositionstart: this.handleCompositionStart,
            onCompositionend: this.handleCompositionEnd
          }), /* @__PURE__ */ React.createElement("span", {
            ref: "patternInputMirrorRef",
            class: `${clsPrefix}-base-selection-input-tag__mirror`
          }, this.pattern)) : null;
          const renderCounter = maxTagCountResponsive ? () => /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-base-selection-tag-wrapper`,
            ref: "counterWrapperRef"
          }, /* @__PURE__ */ React.createElement(NTag, {
            size,
            ref: "counterRef",
            onMouseenter: this.handleMouseEnterCounter,
            onMouseleave: this.handleMouseLeaveCounter,
            disabled
          })) : void 0;
          let counter;
          if (maxTagCountNumeric) {
            const rest = this.selectedOptions.length - maxTagCount;
            if (rest > 0) {
              counter = /* @__PURE__ */ React.createElement("div", {
                class: `${clsPrefix}-base-selection-tag-wrapper`,
                key: "__counter__"
              }, /* @__PURE__ */ React.createElement(NTag, {
                size,
                ref: "counterRef",
                onMouseenter: this.handleMouseEnterCounter,
                disabled
              }, {
                default: () => `+${rest}`
              }));
            }
          }
          const tags = maxTagCountResponsive ? filterable ? /* @__PURE__ */ React.createElement(VOverflow, {
            ref: "overflowRef",
            updateCounter: this.updateCounter,
            getCounter: this.getCounter,
            getTail: this.getTail,
            style: {
              width: "100%",
              display: "flex",
              overflow: "hidden"
            }
          }, {
            default: () => originalTags,
            counter: renderCounter,
            tail: () => input
          }) : /* @__PURE__ */ React.createElement(VOverflow, {
            ref: "overflowRef",
            updateCounter: this.updateCounter,
            getCounter: this.getCounter,
            style: {
              width: "100%",
              display: "flex",
              overflow: "hidden"
            }
          }, {
            default: () => originalTags,
            counter: renderCounter
          }) : maxTagCountNumeric ? originalTags.concat(counter) : originalTags;
          const renderPopover = useMaxTagCount ? () => /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-base-selection-popover`
          }, maxTagCountResponsive ? originalTags : this.selectedOptions.map(createTag)) : void 0;
          const popoverProps = useMaxTagCount ? {
            show: this.showTagsPanel,
            trigger: "hover",
            overlap: true,
            placement: "top",
            width: "trigger",
            onUpdateShow: this.onPopoverUpdateShow,
            theme: this.mergedTheme.peers.Popover,
            themeOverrides: this.mergedTheme.peerOverrides.Popover
          } : null;
          const showPlaceholder = this.selected ? false : this.active ? !this.pattern && !this.isCompositing : true;
          const placeholder = showPlaceholder ? /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-base-selection-placeholder ${clsPrefix}-base-selection-overlay`
          }, /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-base-selection-placeholder__inner`
          }, this.placeholder)) : null;
          const popoverTrigger = filterable ? /* @__PURE__ */ React.createElement("div", {
            ref: "patternInputWrapperRef",
            class: `${clsPrefix}-base-selection-tags`
          }, tags, maxTagCountResponsive ? null : input, suffix) : /* @__PURE__ */ React.createElement("div", {
            ref: "multipleElRef",
            class: `${clsPrefix}-base-selection-tags`,
            tabindex: disabled ? void 0 : 0
          }, tags, suffix);
          body = /* @__PURE__ */ React.createElement(React.Fragment, null, useMaxTagCount ? /* @__PURE__ */ React.createElement(NPopover, {
            ...popoverProps,
            scrollable: true,
            style: "max-height: calc(var(--v-target-height) * 6.6);"
          }, {
            trigger: () => popoverTrigger,
            default: renderPopover
          }) : popoverTrigger, placeholder);
        } else {
          if (filterable) {
            const hasInput = this.pattern || this.isCompositing;
            const showPlaceholder = this.active ? !hasInput : !this.selected;
            const showSelectedLabel = this.active ? false : this.selected;
            body = /* @__PURE__ */ React.createElement("div", {
              ref: "patternInputWrapperRef",
              class: `${clsPrefix}-base-selection-label`
            }, /* @__PURE__ */ React.createElement("input", {
              ...this.inputProps,
              ref: "patternInputRef",
              class: `${clsPrefix}-base-selection-input`,
              value: this.active ? this.pattern : "",
              placeholder: "",
              readonly: disabled,
              disabled,
              tabindex: -1,
              autofocus: this.autofocus,
              onFocus: this.handlePatternInputFocus,
              onBlur: this.handlePatternInputBlur,
              onInput: this.handlePatternInputInput,
              onCompositionstart: this.handleCompositionStart,
              onCompositionend: this.handleCompositionEnd
            }), showSelectedLabel ? /* @__PURE__ */ React.createElement("div", {
              class: `${clsPrefix}-base-selection-label__render-label ${clsPrefix}-base-selection-overlay`,
              key: "input"
            }, /* @__PURE__ */ React.createElement("div", {
              class: `${clsPrefix}-base-selection-overlay__wrapper`
            }, renderTag ? renderTag({
              option: this.selectedOption,
              handleClose: () => {
              }
            }) : renderLabel ? renderLabel(this.selectedOption, true) : render$1(this.label, this.selectedOption, true))) : null, showPlaceholder ? /* @__PURE__ */ React.createElement("div", {
              class: `${clsPrefix}-base-selection-placeholder ${clsPrefix}-base-selection-overlay`,
              key: "placeholder"
            }, /* @__PURE__ */ React.createElement("div", {
              class: `${clsPrefix}-base-selection-overlay__wrapper`
            }, this.filterablePlaceholder)) : null, suffix);
          } else {
            body = /* @__PURE__ */ React.createElement("div", {
              ref: "singleElRef",
              class: `${clsPrefix}-base-selection-label`,
              tabindex: this.disabled ? void 0 : 0
            }, this.label !== void 0 ? /* @__PURE__ */ React.createElement("div", {
              class: `${clsPrefix}-base-selection-input`,
              title: getTitleAttribute(this.label),
              key: "input"
            }, /* @__PURE__ */ React.createElement("div", {
              class: `${clsPrefix}-base-selection-input__content`
            }, renderTag ? renderTag({
              option: this.selectedOption,
              handleClose: () => {
              }
            }) : renderLabel ? renderLabel(this.selectedOption, true) : render$1(this.label, this.selectedOption, true))) : /* @__PURE__ */ React.createElement("div", {
              class: `${clsPrefix}-base-selection-placeholder ${clsPrefix}-base-selection-overlay`,
              key: "placeholder"
            }, /* @__PURE__ */ React.createElement("div", {
              class: `${clsPrefix}-base-selection-placeholder__inner`
            }, this.placeholder)), suffix);
          }
        }
        return /* @__PURE__ */ React.createElement("div", {
          ref: "selfRef",
          class: [
            `${clsPrefix}-base-selection`,
            this.themeClass,
            status && `${clsPrefix}-base-selection--${status}-status`,
            {
              [`${clsPrefix}-base-selection--active`]: this.active,
              [`${clsPrefix}-base-selection--selected`]: this.selected || this.active && this.pattern,
              [`${clsPrefix}-base-selection--disabled`]: this.disabled,
              [`${clsPrefix}-base-selection--multiple`]: this.multiple,
              [`${clsPrefix}-base-selection--focus`]: this.focused
            }
          ],
          style: this.cssVars,
          onClick: this.onClick,
          onMouseenter: this.handleMouseEnter,
          onMouseleave: this.handleMouseLeave,
          onKeydown: this.onKeydown,
          onFocusin: this.handleFocusin,
          onFocusout: this.handleFocusout,
          onMousedown: this.handleMouseDown
        }, body, bordered ? /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-base-selection__border`
        }) : null, bordered ? /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-base-selection__state-border`
        }) : null);
      }
    });

    var SlotMachineNumber = vue.defineComponent({
      name: "SlotMachineNumber",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        value: {
          type: [Number, String],
          required: true
        },
        oldOriginalNumber: {
          type: Number,
          default: void 0
        },
        newOriginalNumber: {
          type: Number,
          default: void 0
        }
      },
      setup(props) {
        const numberRef = vue.ref(null);
        const oldNumberRef = vue.ref(props.value);
        const newNumberRef = vue.ref(props.value);
        const scrollAnimationDirectionRef = vue.ref("up");
        const activeRef = vue.ref(false);
        const newNumberScrollAnimationClassRef = vue.computed(() => {
          return activeRef.value ? `${props.clsPrefix}-base-slot-machine-current-number--${scrollAnimationDirectionRef.value}-scroll` : null;
        });
        const oldNumberScrollAnimationClassRef = vue.computed(() => {
          return activeRef.value ? `${props.clsPrefix}-base-slot-machine-old-number--${scrollAnimationDirectionRef.value}-scroll` : null;
        });
        vue.watch(vue.toRef(props, "value"), (value, oldValue) => {
          oldNumberRef.value = oldValue;
          newNumberRef.value = value;
          void vue.nextTick(scroll);
        });
        function scroll() {
          const newOriginalNumber = props.newOriginalNumber;
          const oldOriginalNumber = props.oldOriginalNumber;
          if (oldOriginalNumber === void 0 || newOriginalNumber === void 0) {
            return;
          }
          if (newOriginalNumber > oldOriginalNumber) {
            scrollByDir("up");
          } else if (oldOriginalNumber > newOriginalNumber) {
            scrollByDir("down");
          }
        }
        function scrollByDir(dir) {
          scrollAnimationDirectionRef.value = dir;
          activeRef.value = false;
          void vue.nextTick(() => {
            void numberRef.value?.offsetWidth;
            activeRef.value = true;
          });
        }
        return () => {
          const { clsPrefix } = props;
          return /* @__PURE__ */ React.createElement("span", {
            ref: numberRef,
            class: `${clsPrefix}-base-slot-machine-number`
          }, oldNumberRef.value !== null ? /* @__PURE__ */ React.createElement("span", {
            class: [
              `${clsPrefix}-base-slot-machine-old-number ${clsPrefix}-base-slot-machine-old-number--top`,
              oldNumberScrollAnimationClassRef.value
            ]
          }, oldNumberRef.value) : null, /* @__PURE__ */ React.createElement("span", {
            class: [
              `${clsPrefix}-base-slot-machine-current-number`,
              newNumberScrollAnimationClassRef.value
            ]
          }, /* @__PURE__ */ React.createElement("span", {
            ref: "numberWrapper",
            class: [
              `${clsPrefix}-base-slot-machine-current-number__inner`,
              typeof props.value !== "number" && `${clsPrefix}-base-slot-machine-current-number__inner--not-number`
            ]
          }, newNumberRef.value)), oldNumberRef.value !== null ? /* @__PURE__ */ React.createElement("span", {
            class: [
              `${clsPrefix}-base-slot-machine-old-number ${clsPrefix}-base-slot-machine-old-number--bottom`,
              oldNumberScrollAnimationClassRef.value
            ]
          }, oldNumberRef.value) : null);
        };
      }
    });

    const {
      cubicBezierEaseInOut: cubicBezierEaseInOut$2
    } = commonVariables$m;
    function fadeInWidthExpandTransition() {
      let {
        duration = ".2s",
        delay = ".1s"
      } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      return [c$1("&.fade-in-width-expand-transition-leave-from, &.fade-in-width-expand-transition-enter-to", {
        opacity: 1
      }), c$1("&.fade-in-width-expand-transition-leave-to, &.fade-in-width-expand-transition-enter-from", `
      opacity: 0!important;
      margin-left: 0!important;
      margin-right: 0!important;
    `), c$1("&.fade-in-width-expand-transition-leave-active", `
      overflow: hidden;
      transition:
        opacity ${duration} ${cubicBezierEaseInOut$2},
        max-width ${duration} ${cubicBezierEaseInOut$2} ${delay},
        margin-left ${duration} ${cubicBezierEaseInOut$2} ${delay},
        margin-right ${duration} ${cubicBezierEaseInOut$2} ${delay};
    `), c$1("&.fade-in-width-expand-transition-enter-active", `
      overflow: hidden;
      transition:
        opacity ${duration} ${cubicBezierEaseInOut$2} ${delay},
        max-width ${duration} ${cubicBezierEaseInOut$2},
        margin-left ${duration} ${cubicBezierEaseInOut$2},
        margin-right ${duration} ${cubicBezierEaseInOut$2};
    `)];
    }

    const {
      cubicBezierEaseOut: cubicBezierEaseOut$5
    } = commonVariables$m;
    function fadeUpWidthExpandTransition() {
      let {
        duration = ".2s"
      } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      return [c$1("&.fade-up-width-expand-transition-leave-active", {
        transition: `
        opacity ${duration} ${cubicBezierEaseOut$5},
        max-width ${duration} ${cubicBezierEaseOut$5},
        transform ${duration} ${cubicBezierEaseOut$5}
      `
      }), c$1("&.fade-up-width-expand-transition-enter-active", {
        transition: `
        opacity ${duration} ${cubicBezierEaseOut$5},
        max-width ${duration} ${cubicBezierEaseOut$5},
        transform ${duration} ${cubicBezierEaseOut$5}
      `
      }), c$1("&.fade-up-width-expand-transition-enter-to", {
        opacity: 1,
        transform: "translateX(0) translateY(0)"
      }), c$1("&.fade-up-width-expand-transition-enter-from", {
        maxWidth: "0 !important",
        opacity: 0,
        transform: "translateY(60%)"
      }), c$1("&.fade-up-width-expand-transition-leave-from", {
        opacity: 1,
        transform: "translateY(0)"
      }), c$1("&.fade-up-width-expand-transition-leave-to", {
        maxWidth: "0 !important",
        opacity: 0,
        transform: "translateY(60%)"
      })];
    }

    var style$1m = c$1([c$1("@keyframes n-base-slot-machine-fade-up-in", `
    from {
      transform: translateY(60%);
      opacity: 0;
    }
    to {
      transform: translateY(0);
      opacity: 1;
    }
  `), c$1("@keyframes n-base-slot-machine-fade-down-in", `
    from {
      transform: translateY(-60%);
      opacity: 0;
    }
    to {
      transform: translateY(0);
      opacity: 1;
    }
  `), c$1("@keyframes n-base-slot-machine-fade-up-out", `
    from {
      transform: translateY(0%);
      opacity: 1;
    }
    to {
      transform: translateY(-60%);
      opacity: 0;
    }
  `), c$1("@keyframes n-base-slot-machine-fade-down-out", `
    from {
      transform: translateY(0%);
      opacity: 1;
    }
    to {
      transform: translateY(60%);
      opacity: 0;
    }
  `), cB("base-slot-machine", `
    overflow: hidden;
    white-space: nowrap;
    display: inline-block;
    height: 18px;
    line-height: 18px;
  `, [cB("base-slot-machine-number", `
      display: inline-block;
      position: relative;
      height: 18px;
      width: .6em;
      max-width: .6em;
    `, [fadeUpWidthExpandTransition({
      duration: ".2s"
    }), fadeInWidthExpandTransition({
      duration: ".2s",
      delay: "0s"
    }), cB("base-slot-machine-old-number", `
        display: inline-block;
        opacity: 0;
        position: absolute;
        left: 0;
        right: 0;
      `, [cM("top", {
      transform: "translateY(-100%)"
    }), cM("bottom", {
      transform: "translateY(100%)"
    }), cM("down-scroll", {
      animation: "n-base-slot-machine-fade-down-out .2s cubic-bezier(0, 0, .2, 1)",
      animationIterationCount: 1
    }), cM("up-scroll", {
      animation: "n-base-slot-machine-fade-up-out .2s cubic-bezier(0, 0, .2, 1)",
      animationIterationCount: 1
    })]), cB("base-slot-machine-current-number", `
        display: inline-block;
        position: absolute;
        left: 0;
        top: 0;
        bottom: 0;
        right: 0;
        opacity: 1;
        transform: translateY(0);
        width: .6em;
      `, [cM("down-scroll", {
      animation: "n-base-slot-machine-fade-down-in .2s cubic-bezier(0, 0, .2, 1)",
      animationIterationCount: 1
    }), cM("up-scroll", {
      animation: "n-base-slot-machine-fade-up-in .2s cubic-bezier(0, 0, .2, 1)",
      animationIterationCount: 1
    }), cE("inner", `
            display: inline-block;
            position: absolute;
            right: 0;
            top: 0;
            width: .6em;
          `, [cM("not-number", `
            right: unset;
            left: 0;
          `)])])])])]);

    var NBaseSlotMachine = vue.defineComponent({
      name: "BaseSlotMachine",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        value: {
          type: [Number, String],
          default: 0
        },
        max: {
          type: Number,
          default: void 0
        },
        appeared: {
          type: Boolean,
          required: true
        }
      },
      setup(props) {
        useStyle("-base-slot-machine", style$1m, vue.toRef(props, "clsPrefix"));
        const oldValueRef = vue.ref();
        const newValueRef = vue.ref();
        const numbersRef = vue.computed(() => {
          if (typeof props.value === "string")
            return [];
          if (props.value < 1)
            return [0];
          const numbers = [];
          let value = props.value;
          if (props.max !== void 0) {
            value = Math.min(props.max, value);
          }
          while (value >= 1) {
            numbers.push(value % 10);
            value /= 10;
            value = Math.floor(value);
          }
          numbers.reverse();
          return numbers;
        });
        vue.watch(vue.toRef(props, "value"), (value, oldValue) => {
          if (typeof value === "string") {
            newValueRef.value = void 0;
            oldValueRef.value = void 0;
          } else {
            if (typeof oldValue === "string") {
              newValueRef.value = value;
              oldValueRef.value = void 0;
            } else {
              newValueRef.value = value;
              oldValueRef.value = oldValue;
            }
          }
        });
        return () => {
          const { value, clsPrefix } = props;
          return typeof value === "number" ? /* @__PURE__ */ React.createElement("span", {
            class: `${clsPrefix}-base-slot-machine`
          }, /* @__PURE__ */ React.createElement(vue.TransitionGroup, {
            name: "fade-up-width-expand-transition",
            tag: "span"
          }, {
            default: () => numbersRef.value.map((number, i) => /* @__PURE__ */ React.createElement(SlotMachineNumber, {
              clsPrefix,
              key: numbersRef.value.length - i - 1,
              oldOriginalNumber: oldValueRef.value,
              newOriginalNumber: newValueRef.value,
              value: number
            }))
          }), /* @__PURE__ */ React.createElement(NFadeInExpandTransition, {
            key: "+",
            width: true
          }, {
            default: () => props.max !== void 0 && props.max < value ? /* @__PURE__ */ React.createElement(SlotMachineNumber, {
              clsPrefix,
              value: "+"
            }) : null
          })) : /* @__PURE__ */ React.createElement("span", {
            class: `${clsPrefix}-base-slot-machine`
          }, value);
        };
      }
    });

    var commonVars$a = {
      iconMargin: "11px 8px 0 12px",
      iconMarginRtl: "11px 12px 0 8px",
      iconSize: "24px",
      closeIconSize: "16px",
      closeSize: "20px",
      closeMargin: "13px 14px 0 0",
      closeMarginRtl: "13px 0 0 14px",
      padding: "13px"
    };

    const alertDark = {
      name: "Alert",
      common: commonDark,

      self(vars) {
        const {
          lineHeight,
          borderRadius,
          fontWeightStrong,
          dividerColor,
          inputColor,
          textColor1,
          textColor2,
          closeColorHover,
          closeColorPressed,
          closeIconColor,
          closeIconColorHover,
          closeIconColorPressed,
          infoColorSuppl,
          successColorSuppl,
          warningColorSuppl,
          errorColorSuppl,
          fontSize
        } = vars;
        return { ...commonVars$a,
          fontSize,
          lineHeight,
          titleFontWeight: fontWeightStrong,
          borderRadius,
          border: `1px solid ${dividerColor}`,
          color: inputColor,
          titleTextColor: textColor1,
          iconColor: textColor2,
          contentTextColor: textColor2,
          closeBorderRadius: borderRadius,
          closeColorHover,
          closeColorPressed,
          closeIconColor,
          closeIconColorHover,
          closeIconColorPressed,
          borderInfo: `1px solid ${changeColor(infoColorSuppl, {
        alpha: 0.35
      })}`,
          colorInfo: changeColor(infoColorSuppl, {
            alpha: 0.25
          }),
          titleTextColorInfo: textColor1,
          iconColorInfo: infoColorSuppl,
          contentTextColorInfo: textColor2,
          closeColorHoverInfo: closeColorHover,
          closeColorPressedInfo: closeColorPressed,
          closeIconColorInfo: closeIconColor,
          closeIconColorHoverInfo: closeIconColorHover,
          closeIconColorPressedInfo: closeIconColorPressed,
          borderSuccess: `1px solid ${changeColor(successColorSuppl, {
        alpha: 0.35
      })}`,
          colorSuccess: changeColor(successColorSuppl, {
            alpha: 0.25
          }),
          titleTextColorSuccess: textColor1,
          iconColorSuccess: successColorSuppl,
          contentTextColorSuccess: textColor2,
          closeColorHoverSuccess: closeColorHover,
          closeColorPressedSuccess: closeColorPressed,
          closeIconColorSuccess: closeIconColor,
          closeIconColorHoverSuccess: closeIconColorHover,
          closeIconColorPressedSuccess: closeIconColorPressed,
          borderWarning: `1px solid ${changeColor(warningColorSuppl, {
        alpha: 0.35
      })}`,
          colorWarning: changeColor(warningColorSuppl, {
            alpha: 0.25
          }),
          titleTextColorWarning: textColor1,
          iconColorWarning: warningColorSuppl,
          contentTextColorWarning: textColor2,
          closeColorHoverWarning: closeColorHover,
          closeColorPressedWarning: closeColorPressed,
          closeIconColorWarning: closeIconColor,
          closeIconColorHoverWarning: closeIconColorHover,
          closeIconColorPressedWarning: closeIconColorPressed,
          borderError: `1px solid ${changeColor(errorColorSuppl, {
        alpha: 0.35
      })}`,
          colorError: changeColor(errorColorSuppl, {
            alpha: 0.25
          }),
          titleTextColorError: textColor1,
          iconColorError: errorColorSuppl,
          contentTextColorError: textColor2,
          closeColorHoverError: closeColorHover,
          closeColorPressedError: closeColorPressed,
          closeIconColorError: closeIconColor,
          closeIconColorHoverError: closeIconColorHover,
          closeIconColorPressedError: closeIconColorPressed
        };
      }

    };
    var alertDark$1 = alertDark;

    const self$15 = vars => {
      const {
        lineHeight,
        borderRadius,
        fontWeightStrong,
        baseColor,
        dividerColor,
        actionColor,
        textColor1,
        textColor2,
        closeColorHover,
        closeColorPressed,
        closeIconColor,
        closeIconColorHover,
        closeIconColorPressed,
        infoColor,
        successColor,
        warningColor,
        errorColor,
        fontSize
      } = vars;
      return { ...commonVars$a,
        fontSize,
        lineHeight,
        titleFontWeight: fontWeightStrong,
        borderRadius,
        border: `1px solid ${dividerColor}`,
        color: actionColor,
        titleTextColor: textColor1,
        iconColor: textColor2,
        contentTextColor: textColor2,
        closeBorderRadius: borderRadius,
        closeColorHover,
        closeColorPressed,
        closeIconColor,
        closeIconColorHover,
        closeIconColorPressed,
        borderInfo: `1px solid ${composite(baseColor, changeColor(infoColor, {
      alpha: 0.25
    }))}`,
        colorInfo: composite(baseColor, changeColor(infoColor, {
          alpha: 0.08
        })),
        titleTextColorInfo: textColor1,
        iconColorInfo: infoColor,
        contentTextColorInfo: textColor2,
        closeColorHoverInfo: closeColorHover,
        closeColorPressedInfo: closeColorPressed,
        closeIconColorInfo: closeIconColor,
        closeIconColorHoverInfo: closeIconColorHover,
        closeIconColorPressedInfo: closeIconColorPressed,
        borderSuccess: `1px solid ${composite(baseColor, changeColor(successColor, {
      alpha: 0.25
    }))}`,
        colorSuccess: composite(baseColor, changeColor(successColor, {
          alpha: 0.08
        })),
        titleTextColorSuccess: textColor1,
        iconColorSuccess: successColor,
        contentTextColorSuccess: textColor2,
        closeColorHoverSuccess: closeColorHover,
        closeColorPressedSuccess: closeColorPressed,
        closeIconColorSuccess: closeIconColor,
        closeIconColorHoverSuccess: closeIconColorHover,
        closeIconColorPressedSuccess: closeIconColorPressed,
        borderWarning: `1px solid ${composite(baseColor, changeColor(warningColor, {
      alpha: 0.33
    }))}`,
        colorWarning: composite(baseColor, changeColor(warningColor, {
          alpha: 0.08
        })),
        titleTextColorWarning: textColor1,
        iconColorWarning: warningColor,
        contentTextColorWarning: textColor2,
        closeColorHoverWarning: closeColorHover,
        closeColorPressedWarning: closeColorPressed,
        closeIconColorWarning: closeIconColor,
        closeIconColorHoverWarning: closeIconColorHover,
        closeIconColorPressedWarning: closeIconColorPressed,
        borderError: `1px solid ${composite(baseColor, changeColor(errorColor, {
      alpha: 0.25
    }))}`,
        colorError: composite(baseColor, changeColor(errorColor, {
          alpha: 0.08
        })),
        titleTextColorError: textColor1,
        iconColorError: errorColor,
        contentTextColorError: textColor2,
        closeColorHoverError: closeColorHover,
        closeColorPressedError: closeColorPressed,
        closeIconColorError: closeIconColor,
        closeIconColorHoverError: closeIconColorHover,
        closeIconColorPressedError: closeIconColorPressed
      };
    };

    const alertLight = {
      name: "Alert",
      common: commonLight,
      self: self$15
    };
    var alertLight$1 = alertLight;

    var rtlStyle$p = cB("alert", [cM("rtl", `
    direction: rtl;
  `, [cE("icon", `
      left: unset;
      right: 0;
      margin: var(--n-icon-margin-rtl);
    `), cM("show-icon", [cB("alert-body", `
        padding-left: var(--n-padding);
        padding-right: calc(var(--n-icon-margin-left) + var(--n-icon-size) + var(--n-icon-margin-right));
      `)]), cE("close", `
      position: absolute;
      right: unset;
      left: 0;
      margin: var(--n-close-margin-rtl);
    `)])]);

    const alertRtl = {
      name: "Alert",
      style: rtlStyle$p
    };

    const {
      cubicBezierEaseInOut: cubicBezierEaseInOut$1,
      cubicBezierEaseOut: cubicBezierEaseOut$4,
      cubicBezierEaseIn: cubicBezierEaseIn$4
    } = commonVariables$m;
    function fadeInHeightExpandTransition() {
      let {
        overflow = "hidden",
        duration = ".3s",
        originalTransition = "",
        leavingDelay = "0s",
        foldPadding = false,
        enterToProps = void 0,
        leaveToProps = void 0,
        reverse = false
      } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      const enterClass = reverse ? "leave" : "enter";
      const leaveClass = reverse ? "enter" : "leave";
      return [c$1(`&.fade-in-height-expand-transition-${leaveClass}-from,
      &.fade-in-height-expand-transition-${enterClass}-to`, { ...enterToProps,
        opacity: 1
      }), c$1(`&.fade-in-height-expand-transition-${leaveClass}-to,
      &.fade-in-height-expand-transition-${enterClass}-from`, { ...leaveToProps,
        opacity: 0,
        marginTop: "0 !important",
        marginBottom: "0 !important",
        paddingTop: foldPadding ? "0 !important" : void 0,
        paddingBottom: foldPadding ? "0 !important" : void 0
      }), c$1(`&.fade-in-height-expand-transition-${leaveClass}-active`, `
      overflow: ${overflow};
      transition:
        max-height ${duration} ${cubicBezierEaseInOut$1} ${leavingDelay},
        opacity ${duration} ${cubicBezierEaseOut$4} ${leavingDelay},
        margin-top ${duration} ${cubicBezierEaseInOut$1} ${leavingDelay},
        margin-bottom ${duration} ${cubicBezierEaseInOut$1} ${leavingDelay},
        padding-top ${duration} ${cubicBezierEaseInOut$1} ${leavingDelay},
        padding-bottom ${duration} ${cubicBezierEaseInOut$1} ${leavingDelay}
        ${originalTransition ? "," + originalTransition : ""}
    `), c$1(`&.fade-in-height-expand-transition-${enterClass}-active`, `
      overflow: ${overflow};
      transition:
        max-height ${duration} ${cubicBezierEaseInOut$1},
        opacity ${duration} ${cubicBezierEaseIn$4},
        margin-top ${duration} ${cubicBezierEaseInOut$1},
        margin-bottom ${duration} ${cubicBezierEaseInOut$1},
        padding-top ${duration} ${cubicBezierEaseInOut$1},
        padding-bottom ${duration} ${cubicBezierEaseInOut$1}
        ${originalTransition ? "," + originalTransition : ""}
    `)];
    }

    var style$1l = cB("alert", `
  line-height: var(--n-line-height);
  border-radius: var(--n-border-radius);
  position: relative;
  transition: background-color .3s var(--n-bezier);
  background-color: var(--n-color);
  text-align: start;
  word-break: break-word;
`, [cE("border", `
    border-radius: inherit;
    position: absolute;
    left: 0;
    right: 0;
    top: 0;
    bottom: 0;
    transition: border-color .3s var(--n-bezier);
    border: var(--n-border);
    pointer-events: none;
  `), cM("closable", [cB("alert-body", [cE("title", `
        padding-right: 24px;
      `)])]), cE("icon", {
      color: "var(--n-icon-color)"
    }), cB("alert-body", {
      padding: "var(--n-padding)"
    }, [cE("title", {
      color: "var(--n-title-text-color)"
    }), cE("content", {
      color: "var(--n-content-text-color)"
    })]), fadeInHeightExpandTransition({
      originalTransition: "transform .3s var(--n-bezier)",
      enterToProps: {
        transform: "scale(1)"
      },
      leaveToProps: {
        transform: "scale(0.9)"
      }
    }), cE("icon", `
    position: absolute;
    left: 0;
    top: 0;
    align-items: center;
    justify-content: center;
    display: flex;
    width: var(--n-icon-size);
    height: var(--n-icon-size);
    font-size: var(--n-icon-size);
    margin: var(--n-icon-margin);
  `), cE("close", `
    transition:
      color .3s var(--n-bezier),
      background-color .3s var(--n-bezier);
    position: absolute;
    right: 0;
    top: 0;
    margin: var(--n-close-margin);
  `), cM("show-icon", [cB("alert-body", {
      paddingLeft: "calc(var(--n-icon-margin-left) + var(--n-icon-size) + var(--n-icon-margin-right))"
    })]), cB("alert-body", `
    border-radius: var(--n-border-radius);
    transition: border-color .3s var(--n-bezier);
  `, [cE("title", `
      transition: color .3s var(--n-bezier);
      font-size: 16px;
      line-height: 19px;
      font-weight: var(--n-title-font-weight);
    `, [c$1("& +", [cE("content", {
      marginTop: "9px"
    })])]), cE("content", {
      transition: "color .3s var(--n-bezier)",
      fontSize: "var(--n-font-size)"
    })]), cE("icon", {
      transition: "color .3s var(--n-bezier)"
    })]);

    const alertProps = {
      ...useTheme.props,
      title: String,
      showIcon: {
        type: Boolean,
        default: true
      },
      type: {
        type: String,
        default: "default"
      },
      bordered: {
        type: Boolean,
        default: true
      },
      closable: Boolean,
      onClose: Function,
      onAfterLeave: Function,
      onAfterHide: Function
    };
    var Alert = vue.defineComponent({
      name: "Alert",
      inheritAttrs: false,
      props: alertProps,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.onAfterHide !== void 0) {
              warnOnce(
                "alert",
                "`on-after-hide` is deprecated, please use `on-after-leave` instead."
              );
            }
          });
        }
        const {
          mergedClsPrefixRef,
          mergedBorderedRef,
          inlineThemeDisabled,
          mergedRtlRef
        } = useConfig(props);
        const themeRef = useTheme(
          "Alert",
          "-alert",
          style$1l,
          alertLight$1,
          props,
          mergedClsPrefixRef
        );
        const rtlEnabledRef = useRtl("Alert", mergedRtlRef, mergedClsPrefixRef);
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self
          } = themeRef.value;
          const {
            fontSize,
            borderRadius,
            titleFontWeight,
            lineHeight,
            iconSize,
            iconMargin,
            iconMarginRtl,
            closeIconSize,
            closeBorderRadius,
            closeSize,
            closeMargin,
            closeMarginRtl,
            padding
          } = self;
          const { type } = props;
          const { left, right } = getMargin(iconMargin);
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-color": self[createKey("color", type)],
            "--n-close-icon-size": closeIconSize,
            "--n-close-border-radius": closeBorderRadius,
            "--n-close-color-hover": self[createKey("closeColorHover", type)],
            "--n-close-color-pressed": self[createKey("closeColorPressed", type)],
            "--n-close-icon-color": self[createKey("closeIconColor", type)],
            "--n-close-icon-color-hover": self[createKey("closeIconColorHover", type)],
            "--n-close-icon-color-pressed": self[createKey("closeIconColorPressed", type)],
            "--n-icon-color": self[createKey("iconColor", type)],
            "--n-border": self[createKey("border", type)],
            "--n-title-text-color": self[createKey("titleTextColor", type)],
            "--n-content-text-color": self[createKey("contentTextColor", type)],
            "--n-line-height": lineHeight,
            "--n-border-radius": borderRadius,
            "--n-font-size": fontSize,
            "--n-title-font-weight": titleFontWeight,
            "--n-icon-size": iconSize,
            "--n-icon-margin": iconMargin,
            "--n-icon-margin-rtl": iconMarginRtl,
            "--n-close-size": closeSize,
            "--n-close-margin": closeMargin,
            "--n-close-margin-rtl": closeMarginRtl,
            "--n-padding": padding,
            "--n-icon-margin-left": left,
            "--n-icon-margin-right": right
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "alert",
          vue.computed(() => {
            return props.type[0];
          }),
          cssVarsRef,
          props
        ) : void 0;
        const visibleRef = vue.ref(true);
        const doAfterLeave = () => {
          const {
            onAfterLeave,
            onAfterHide
          } = props;
          if (onAfterLeave)
            onAfterLeave();
          if (onAfterHide)
            onAfterHide();
        };
        const handleCloseClick = () => {
          void Promise.resolve(props.onClose?.()).then((result) => {
            if (result === false)
              return;
            visibleRef.value = false;
          });
        };
        const handleAfterLeave = () => {
          doAfterLeave();
        };
        return {
          rtlEnabled: rtlEnabledRef,
          mergedClsPrefix: mergedClsPrefixRef,
          mergedBordered: mergedBorderedRef,
          visible: visibleRef,
          handleCloseClick,
          handleAfterLeave,
          mergedTheme: themeRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        this.onRender?.();
        return /* @__PURE__ */ React.createElement(NFadeInExpandTransition, {
          onAfterLeave: this.handleAfterLeave
        }, {
          default: () => {
            const { mergedClsPrefix, $slots } = this;
            const attrs = {
              class: [
                `${mergedClsPrefix}-alert`,
                this.themeClass,
                this.closable && `${mergedClsPrefix}-alert--closable`,
                this.showIcon && `${mergedClsPrefix}-alert--show-icon`,
                this.rtlEnabled && `${mergedClsPrefix}-alert--rtl`
              ],
              style: this.cssVars,
              role: "alert"
            };
            return this.visible ? /* @__PURE__ */ React.createElement("div", {
              ...vue.mergeProps(this.$attrs, attrs)
            }, this.closable && /* @__PURE__ */ React.createElement(NBaseClose, {
              clsPrefix: mergedClsPrefix,
              class: `${mergedClsPrefix}-alert__close`,
              onClick: this.handleCloseClick
            }), this.bordered && /* @__PURE__ */ React.createElement("div", {
              class: `${mergedClsPrefix}-alert__border`
            }), this.showIcon && /* @__PURE__ */ React.createElement("div", {
              class: `${mergedClsPrefix}-alert__icon`,
              "aria-hidden": "true"
            }, resolveSlot($slots.icon, () => [
              /* @__PURE__ */ React.createElement(NBaseIcon, {
                clsPrefix: mergedClsPrefix
              }, {
                default: () => {
                  switch (this.type) {
                    case "success":
                      return /* @__PURE__ */ React.createElement(SuccessIcon, null);
                    case "info":
                      return /* @__PURE__ */ React.createElement(InfoIcon, null);
                    case "warning":
                      return /* @__PURE__ */ React.createElement(WarningIcon, null);
                    case "error":
                      return /* @__PURE__ */ React.createElement(ErrorIcon, null);
                    default:
                      return null;
                  }
                }
              })
            ])), /* @__PURE__ */ React.createElement("div", {
              class: [
                `${mergedClsPrefix}-alert-body`,
                this.mergedBordered && `${mergedClsPrefix}-alert-body--bordered`
              ]
            }, resolveWrappedSlot($slots.header, (children) => {
              const mergedChildren = children || this.title;
              return mergedChildren ? /* @__PURE__ */ React.createElement("div", {
                class: `${mergedClsPrefix}-alert-body__title`
              }, mergedChildren) : null;
            }), $slots.default && /* @__PURE__ */ React.createElement("div", {
              class: `${mergedClsPrefix}-alert-body__content`
            }, $slots))) : null;
          }
        });
      }
    });

    var commonVars$9 = {
      linkFontSize: "13px",
      linkPadding: "0 0 0 16px",
      railWidth: "4px"
    };

    const self$14 = vars => {
      const {
        borderRadius,
        railColor,
        primaryColor,
        primaryColorHover,
        primaryColorPressed,
        textColor2
      } = vars;
      return { ...commonVars$9,
        borderRadius,
        railColor,
        railColorActive: primaryColor,
        linkColor: changeColor(primaryColor, {
          alpha: 0.15
        }),
        linkTextColor: textColor2,
        linkTextColorHover: primaryColorHover,
        linkTextColorPressed: primaryColorPressed,
        linkTextColorActive: primaryColor
      };
    };
    const anchorLight = {
      name: "Anchor",
      common: commonLight,
      self: self$14
    };
    var anchorLight$1 = anchorLight;

    const anchorDark = {
      name: "Anchor",
      common: commonDark,
      self: self$14
    };
    var anchorDark$1 = anchorDark;

    var style$1k = cB("anchor", `
  position: relative;
`, [cNotM("block", `
    padding-left: var(--n-rail-width);
  `, [cB("anchor-link", [c$1("+, >", [cB("anchor-link", `
          margin-top: .5em;
        `)])]), cB("anchor-link-background", `
      max-width: 0;
      border-top-right-radius: 10.5px;
      border-bottom-right-radius: 10.5px;
    `), cNotM("show-rail", [c$1(">", [cB("anchor-link", "padding-left: 0;")])])]), cM("block", [cB("anchor-link", `
      margin-bottom: 4px;
      padding: 2px 8px;
      transition: background-color .3s var(--n-bezier);
      background-color: transparent;
      border-radius: var(--n-link-border-radius);
    `, [cM("active", `
        background-color: var(--n-link-color);
      `)])]), cB("anchor-link-background", `
    position: absolute;
    left: calc(var(--n-rail-width) / 2);
    width: 100%;
    background-color: var(--n-link-color);
    transition:
      top .15s var(--n-bezier),
      max-width .15s var(--n-bezier),
      background-color .3s var(--n-bezier);
  `), cB("anchor-rail", `
    position: absolute;
    left: 0;
    top: 0;
    bottom: 0;
    width: var(--n-rail-width);
    border-radius: calc(var(--n-rail-width) / 2);
    overflow: hidden;
    transition: background-color .3s var(--n-bezier);
    background-color: var(--n-rail-color);
  `, [cE("bar", `
      position: absolute;
      left: 0;
      width: var(--n-rail-width);
      height: 21px;
      background-color: #0000;
      transition: 
        top .15s var(--n-bezier),
        background-color .3s var(--n-bezier);
    `, [cM("active", {
      backgroundColor: "var(--n-rail-color-active)"
    })])]), cB("anchor-link", `
    padding: var(--n-link-padding);
    position: relative;
    line-height: 1.5;
    font-size: var(--n-link-font-size);
    min-height: 1.5em;
    display: flex;
    flex-direction: column;
  `, [cM("active", [c$1(">", [cE("title", `
          color: var(--n-link-text-color-active);
        `)])]), cE("title", `
      outline: none;
      max-width: 100%;
      text-decoration: none;
      white-space: nowrap;
      text-overflow: ellipsis;
      overflow: hidden;
      cursor: pointer;
      display: inline-block;
      padding-right: 16px;
      transition: color .3s var(--n-bezier);
      color: var(--n-link-text-color);
    `, [c$1("&:hover, &:focus", `
        color: var(--n-link-text-color-hover);
      `), c$1("&:active", `
        color: var(--n-link-text-color-pressed);
      `)])])]);

    const anchorInjectionKey = createInjectionKey("n-anchor");
    const anchorLinkProps = {
      title: String,
      href: String
    };
    var Link = vue.defineComponent({
      name: "AnchorLink",
      props: anchorLinkProps,
      setup(props, { slots }) {
        const titleRef = vue.ref(null);
        const NAnchor = vue.inject(anchorInjectionKey);
        const hrefRef = vue.toRef(props, "href");
        const activeRef = useMemo(() => {
          return hrefRef.value && hrefRef.value === NAnchor.activeHref.value;
        });
        useInjectionCollection(anchorInjectionKey, "collectedLinkHrefs", hrefRef);
        useInjectionElementCollection(
          anchorInjectionKey,
          "titleEls",
          () => titleRef.value
        );
        vue.watch(activeRef, (value) => {
          if (value && titleRef.value) {
            NAnchor.updateBarPosition(titleRef.value);
          }
        });
        function handleClick() {
          if (props.href !== void 0) {
            NAnchor.setActiveHref(props.href);
          }
        }
        return () => {
          const { value: mergedClsPrefix } = NAnchor.mergedClsPrefix;
          return /* @__PURE__ */ React.createElement("div", {
            class: [
              `${mergedClsPrefix}-anchor-link`,
              activeRef.value && `${mergedClsPrefix}-anchor-link--active`
            ]
          }, /* @__PURE__ */ React.createElement("a", {
            ref: titleRef,
            class: [`${mergedClsPrefix}-anchor-link__title`],
            href: props.href,
            title: getTitleAttribute(props.title),
            onClick: handleClick
          }, props.title), slots.default?.());
        };
      }
    });

    function getOffset(el, scrollTarget) {
      const {
        top: elTop,
        height
      } = el.getBoundingClientRect();
      const scrollTargetTop = scrollTarget instanceof HTMLElement ? scrollTarget.getBoundingClientRect().top : 0;
      return {
        top: elTop - scrollTargetTop,
        height
      };
    }

    const baseAnchorProps = {
      type: {
        type: String,
        default: "rail"
      },
      showRail: {
        type: Boolean,
        default: true
      },
      showBackground: {
        type: Boolean,
        default: true
      },
      bound: {
        type: Number,
        default: 12
      },
      internalScrollable: Boolean,
      ignoreGap: Boolean,
      offsetTarget: [String, Object, Function]
    };
    const baseAnchorPropKeys = keysOf(baseAnchorProps);
    var NBaseAnchor = vue.defineComponent({
      name: "BaseAnchor",
      props: {
        ...baseAnchorProps,
        mergedClsPrefix: {
          type: String,
          required: true
        }
      },
      setup(props) {
        const collectedLinkHrefs = [];
        const titleEls = [];
        const activeHrefRef = vue.ref(null);
        const slotRef = vue.ref(null);
        const barRef = vue.ref(null);
        const selfRef = vue.ref(null);
        const isBlockTypeRef = vue.computed(() => {
          return props.type === "block";
        });
        const mergedShowRailRef = vue.computed(() => {
          return !isBlockTypeRef.value && props.showRail;
        });
        function disableTransitionOneTick() {
          const { value: barEl } = barRef;
          const { value: slotEl } = slotRef;
          if (barEl) {
            barEl.style.transition = "none";
          }
          if (slotEl) {
            slotEl.style.transition = "none";
          }
          if (titleEls) {
            titleEls.forEach((titleEl) => {
              titleEl.style.transition = "none";
            });
          }
          void vue.nextTick(() => {
            const { value: nextBarEl } = barRef;
            const { value: nextSlotEl } = slotRef;
            if (nextBarEl) {
              void nextBarEl.offsetWidth;
              nextBarEl.style.transition = "";
            }
            if (nextSlotEl) {
              void nextSlotEl.offsetWidth;
              nextSlotEl.style.transition = "";
            }
            if (titleEls) {
              titleEls.forEach((titleEl) => {
                void titleEl.offsetWidth;
                titleEl.style.transition = "";
              });
            }
          });
        }
        function updateBarPosition(linkTitleEl, transition = true) {
          const { value: barEl } = barRef;
          const { value: slotEl } = slotRef;
          const { value: selfEl } = selfRef;
          if (!selfEl || !barEl)
            return;
          if (!transition) {
            barEl.style.transition = "none";
            if (slotEl)
              slotEl.style.transition = "none";
          }
          const { offsetHeight, offsetWidth } = linkTitleEl;
          const { top: linkTitleClientTop, left: linkTitleClientLeft } = linkTitleEl.getBoundingClientRect();
          const { top: anchorClientTop, left: anchorClientLeft } = selfEl.getBoundingClientRect();
          const offsetTop = linkTitleClientTop - anchorClientTop;
          const offsetLeft = linkTitleClientLeft - anchorClientLeft;
          barEl.style.top = `${offsetTop}px`;
          barEl.style.height = `${offsetHeight}px`;
          if (slotEl) {
            slotEl.style.top = `${offsetTop}px`;
            slotEl.style.height = `${offsetHeight}px`;
            slotEl.style.maxWidth = `${offsetWidth + offsetLeft}px`;
          }
          void barEl.offsetHeight;
          if (slotEl)
            void slotEl.offsetHeight;
          if (!transition) {
            barEl.style.transition = "";
            if (slotEl)
              slotEl.style.transition = "";
          }
        }
        function setActiveHref(href, transition = true) {
          const idMatchResult = /^#([^#]+)$/.exec(href);
          if (!idMatchResult)
            return;
          const linkEl = document.getElementById(idMatchResult[1]);
          if (!linkEl)
            return;
          activeHrefRef.value = href;
          linkEl.scrollIntoView();
          if (!transition) {
            disableTransitionOneTick();
          }
          handleScroll();
        }
        const handleScroll = lodash.exports.throttle(() => _handleScroll(true), 128);
        function _handleScroll(transition = true) {
          const links = [];
          const offsetTarget = unwrapElement(props.offsetTarget ?? document);
          collectedLinkHrefs.forEach((href) => {
            const idMatchResult = /#([^#]+)$/.exec(href);
            if (!idMatchResult)
              return;
            const linkEl = document.getElementById(idMatchResult[1]);
            if (linkEl && offsetTarget) {
              const { top, height } = getOffset(linkEl, offsetTarget);
              links.push({
                top,
                height,
                href
              });
            }
          });
          links.sort((a, b) => {
            if (a.top > b.top) {
              return 1;
            } else if (a.top === b.top && a.height < b.height) {
              return -1;
            }
            return -1;
          });
          const currentActiveHref = activeHrefRef.value;
          const { bound, ignoreGap } = props;
          const activeLink = links.reduce((prevLink, link) => {
            if (link.top + link.height < 0) {
              if (ignoreGap) {
                return link;
              } else {
                return prevLink;
              }
            }
            if (link.top <= bound) {
              if (prevLink === null) {
                return link;
              } else if (link.top === prevLink.top) {
                if (link.href === currentActiveHref) {
                  return link;
                } else
                  return prevLink;
              } else if (link.top > prevLink.top) {
                return link;
              } else {
                return prevLink;
              }
            }
            return prevLink;
          }, null);
          if (!transition)
            disableTransitionOneTick();
          if (activeLink) {
            activeHrefRef.value = activeLink.href;
          } else {
            activeHrefRef.value = null;
          }
        }
        vue.provide(anchorInjectionKey, {
          activeHref: activeHrefRef,
          mergedClsPrefix: vue.toRef(props, "mergedClsPrefix"),
          updateBarPosition,
          setActiveHref,
          collectedLinkHrefs,
          titleEls
        });
        vue.onMounted(() => {
          document.addEventListener("scroll", handleScroll, true);
          setActiveHref(window.location.hash);
          _handleScroll(false);
        });
        onFontsReady(() => {
          setActiveHref(window.location.hash);
          _handleScroll(false);
        });
        vue.onBeforeUnmount(() => {
          document.removeEventListener("scroll", handleScroll, true);
        });
        vue.watch(activeHrefRef, (value) => {
          if (value === null) {
            const { value: slotEl } = slotRef;
            if (slotEl && !isBlockTypeRef.value) {
              slotEl.style.maxWidth = "0";
            }
          }
        });
        return {
          selfRef,
          barRef,
          slotRef,
          setActiveHref,
          activeHref: activeHrefRef,
          isBlockType: isBlockTypeRef,
          mergedShowRail: mergedShowRailRef
        };
      },
      render() {
        const { mergedClsPrefix, mergedShowRail, isBlockType, $slots } = this;
        const Anchor = /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-anchor`,
            isBlockType && `${mergedClsPrefix}-anchor--block`,
            mergedShowRail && `${mergedClsPrefix}-anchor--show-rail`
          ],
          ref: "selfRef"
        }, mergedShowRail && this.showBackground ? /* @__PURE__ */ React.createElement("div", {
          ref: "slotRef",
          class: `${mergedClsPrefix}-anchor-link-background`
        }) : null, mergedShowRail ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-anchor-rail`
        }, /* @__PURE__ */ React.createElement("div", {
          ref: "barRef",
          class: [
            `${mergedClsPrefix}-anchor-rail__bar`,
            this.activeHref !== null && `${mergedClsPrefix}-anchor-rail__bar--active`
          ]
        })) : null, $slots.default?.());
        return this.internalScrollable ? /* @__PURE__ */ React.createElement(NScrollbar, null, {
          default: () => Anchor
        }) : Anchor;
      }
    });

    const anchorProps = {
      ...useTheme.props,
      affix: Boolean,
      ...affixProps,
      ...baseAnchorProps
    };
    var AnchorAdapter = vue.defineComponent({
      name: "Anchor",
      props: anchorProps,
      setup(props, { slots }) {
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Anchor",
          "-anchor",
          style$1k,
          anchorLight$1,
          props,
          mergedClsPrefixRef
        );
        const anchorRef = vue.ref(null);
        const cssVarsRef = vue.computed(() => {
          const {
            self: {
              railColor,
              linkColor,
              railColorActive,
              linkTextColor,
              linkTextColorHover,
              linkTextColorPressed,
              linkTextColorActive,
              linkFontSize,
              railWidth,
              linkPadding,
              borderRadius
            },
            common: { cubicBezierEaseInOut }
          } = themeRef.value;
          return {
            "--n-link-border-radius": borderRadius,
            "--n-link-color": linkColor,
            "--n-link-font-size": linkFontSize,
            "--n-link-text-color": linkTextColor,
            "--n-link-text-color-hover": linkTextColorHover,
            "--n-link-text-color-active": linkTextColorActive,
            "--n-link-text-color-pressed": linkTextColorPressed,
            "--n-link-padding": linkPadding,
            "--n-bezier": cubicBezierEaseInOut,
            "--n-rail-color": railColor,
            "--n-rail-color-active": railColorActive,
            "--n-rail-width": railWidth
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("anchor", void 0, cssVarsRef, props) : void 0;
        return {
          scrollTo(href) {
            anchorRef.value?.setActiveHref(href);
          },
          renderAnchor: () => {
            themeClassHandle?.onRender();
            return /* @__PURE__ */ React.createElement(NBaseAnchor, {
              ref: anchorRef,
              style: inlineThemeDisabled ? void 0 : cssVarsRef.value,
              class: themeClassHandle?.themeClass.value,
              ...keep(props, baseAnchorPropKeys),
              mergedClsPrefix: mergedClsPrefixRef.value
            }, slots);
          }
        };
      },
      render() {
        return !this.affix ? this.renderAnchor() : /* @__PURE__ */ React.createElement(NAffix, {
          ...keep(this, affixPropKeys)
        }, { default: this.renderAnchor });
      }
    });

    function getIsGroup(option) {
      return option.type === "group";
    }
    function getIgnored(option) {
      return option.type === "ignored";
    }
    function patternMatched(pattern, value) {
      try {
        return !!(1 + value.toString().toLowerCase().indexOf(pattern.trim().toLowerCase()));
      } catch (err) {
        return false;
      }
    }
    function createTmOptions(valueField, childrenField) {
      const options = {
        getIsGroup,
        getIgnored,

        getKey(option) {
          if (getIsGroup(option)) {
            return option.name || option.key || "key-required";
          }

          return option[valueField];
        },

        getChildren(option) {
          return option[childrenField];
        }

      };
      return options;
    }
    function filterOptions(originalOpts, filter, pattern, childrenField) {
      if (!filter) return originalOpts;

      function traverse(options) {
        if (!Array.isArray(options)) return [];
        const filteredOptions = [];

        for (const option of options) {
          if (getIsGroup(option)) {
            const children = traverse(option[childrenField]);

            if (children.length) {
              filteredOptions.push(Object.assign({}, option, {
                [childrenField]: children
              }));
            }
          } else if (getIgnored(option)) {
            continue;
          } else if (filter(pattern, option)) {
            filteredOptions.push(option);
          }
        }

        return filteredOptions;
      }

      return traverse(originalOpts);
    }
    function createValOptMap(options, valueField, childrenField) {
      const valOptMap = /* @__PURE__ */new Map();
      options.forEach(option => {
        if (getIsGroup(option)) {
          option[childrenField].forEach(selectGroupOption => {
            valOptMap.set(selectGroupOption[valueField], selectGroupOption);
          });
        } else {
          valOptMap.set(option[valueField], option);
        }
      });
      return valOptMap;
    }

    const isChrome = isBrowser$2 && "chrome" in window;
    isBrowser$2 && navigator.userAgent.includes("Firefox");
    const isSafari = isBrowser$2 && navigator.userAgent.includes("Safari") && !isChrome;

    var commonVariables$i = {
      paddingTiny: "0 8px",
      paddingSmall: "0 10px",
      paddingMedium: "0 12px",
      paddingLarge: "0 14px",
      clearSize: "16px"
    };

    const inputDark = {
      name: "Input",
      common: commonDark,

      self(vars) {
        const {
          textColor2,
          textColor3,
          textColorDisabled,
          primaryColor,
          primaryColorHover,
          inputColor,
          inputColorDisabled,
          warningColor,
          warningColorHover,
          errorColor,
          errorColorHover,
          borderRadius,
          lineHeight,
          fontSizeTiny,
          fontSizeSmall,
          fontSizeMedium,
          fontSizeLarge,
          heightTiny,
          heightSmall,
          heightMedium,
          heightLarge,
          clearColor,
          clearColorHover,
          clearColorPressed,
          placeholderColor,
          placeholderColorDisabled,
          iconColor,
          iconColorDisabled,
          iconColorHover,
          iconColorPressed
        } = vars;
        return { ...commonVariables$i,
          countTextColorDisabled: textColorDisabled,
          countTextColor: textColor3,
          heightTiny,
          heightSmall,
          heightMedium,
          heightLarge,
          fontSizeTiny,
          fontSizeSmall,
          fontSizeMedium,
          fontSizeLarge,
          lineHeight,
          lineHeightTextarea: lineHeight,
          borderRadius,
          iconSize: "16px",
          groupLabelColor: inputColor,
          textColor: textColor2,
          textColorDisabled,
          textDecorationColor: textColor2,
          groupLabelTextColor: textColor2,
          caretColor: primaryColor,
          placeholderColor,
          placeholderColorDisabled,
          color: inputColor,
          colorDisabled: inputColorDisabled,
          colorFocus: changeColor(primaryColor, {
            alpha: 0.1
          }),
          groupLabelBorder: "1px solid #0000",
          border: "1px solid #0000",
          borderHover: `1px solid ${primaryColorHover}`,
          borderDisabled: "1px solid #0000",
          borderFocus: `1px solid ${primaryColorHover}`,
          boxShadowFocus: `0 0 8px 0 ${changeColor(primaryColor, {
        alpha: 0.3
      })}`,
          loadingColor: primaryColor,
          loadingColorWarning: warningColor,
          borderWarning: `1px solid ${warningColor}`,
          borderHoverWarning: `1px solid ${warningColorHover}`,
          colorFocusWarning: changeColor(warningColor, {
            alpha: 0.1
          }),
          borderFocusWarning: `1px solid ${warningColorHover}`,
          boxShadowFocusWarning: `0 0 8px 0 ${changeColor(warningColor, {
        alpha: 0.3
      })}`,
          caretColorWarning: warningColor,
          loadingColorError: errorColor,
          borderError: `1px solid ${errorColor}`,
          borderHoverError: `1px solid ${errorColorHover}`,
          colorFocusError: changeColor(errorColor, {
            alpha: 0.1
          }),
          borderFocusError: `1px solid ${errorColorHover}`,
          boxShadowFocusError: `0 0 8px 0 ${changeColor(errorColor, {
        alpha: 0.3
      })}`,
          caretColorError: errorColor,
          clearColor,
          clearColorHover,
          clearColorPressed,
          iconColor,
          iconColorDisabled,
          iconColorHover,
          iconColorPressed,
          suffixTextColor: textColor2
        };
      }

    };
    var inputDark$1 = inputDark;

    const self$13 = vars => {
      const {
        textColor2,
        textColor3,
        textColorDisabled,
        primaryColor,
        primaryColorHover,
        inputColor,
        inputColorDisabled,
        borderColor,
        warningColor,
        warningColorHover,
        errorColor,
        errorColorHover,
        borderRadius,
        lineHeight,
        fontSizeTiny,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge,
        heightTiny,
        heightSmall,
        heightMedium,
        heightLarge,
        actionColor,
        clearColor,
        clearColorHover,
        clearColorPressed,
        placeholderColor,
        placeholderColorDisabled,
        iconColor,
        iconColorDisabled,
        iconColorHover,
        iconColorPressed
      } = vars;
      return { ...commonVariables$i,
        countTextColorDisabled: textColorDisabled,
        countTextColor: textColor3,
        heightTiny,
        heightSmall,
        heightMedium,
        heightLarge,
        fontSizeTiny,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge,
        lineHeight,
        lineHeightTextarea: lineHeight,
        borderRadius,
        iconSize: "16px",
        groupLabelColor: actionColor,
        groupLabelTextColor: textColor2,
        textColor: textColor2,
        textColorDisabled,
        textDecorationColor: textColor2,
        caretColor: primaryColor,
        placeholderColor,
        placeholderColorDisabled,
        color: inputColor,
        colorDisabled: inputColorDisabled,
        colorFocus: inputColor,
        groupLabelBorder: `1px solid ${borderColor}`,
        border: `1px solid ${borderColor}`,
        borderHover: `1px solid ${primaryColorHover}`,
        borderDisabled: `1px solid ${borderColor}`,
        borderFocus: `1px solid ${primaryColorHover}`,
        boxShadowFocus: `0 0 0 2px ${changeColor(primaryColor, {
      alpha: 0.2
    })}`,
        loadingColor: primaryColor,
        loadingColorWarning: warningColor,
        borderWarning: `1px solid ${warningColor}`,
        borderHoverWarning: `1px solid ${warningColorHover}`,
        colorFocusWarning: inputColor,
        borderFocusWarning: `1px solid ${warningColorHover}`,
        boxShadowFocusWarning: `0 0 0 2px ${changeColor(warningColor, {
      alpha: 0.2
    })}`,
        caretColorWarning: warningColor,
        loadingColorError: errorColor,
        borderError: `1px solid ${errorColor}`,
        borderHoverError: `1px solid ${errorColorHover}`,
        colorFocusError: inputColor,
        borderFocusError: `1px solid ${errorColorHover}`,
        boxShadowFocusError: `0 0 0 2px ${changeColor(errorColor, {
      alpha: 0.2
    })}`,
        caretColorError: errorColor,
        clearColor,
        clearColorHover,
        clearColorPressed,
        iconColor,
        iconColorDisabled,
        iconColorHover,
        iconColorPressed,
        suffixTextColor: textColor2
      };
    };

    const inputLight = {
      name: "Input",
      common: commonLight,
      self: self$13
    };
    var inputLight$1 = inputLight;

    var rtlStyle$o = cB("input", [cM("rtl", `
    direction: rtl;
  `, [cE("prefix", {
      marginRight: 0,
      marginLeft: "4px"
    }), cE("suffix", {
      marginRight: "4px",
      marginLeft: 0
    }), cM("textarea", "width: 100%;", [cB("input-word-count", `
      left: var(--n-padding-right);
      right: unset;
    `)]), cB("input-word-count", `
      margin-left: 0;
      margin-right: 4px;
    `)])]);

    const inputRtl = {
      name: "Input",
      style: rtlStyle$o
    };

    const inputInjectionKey = createInjectionKey("n-input");

    function len(s) {
      let count = 0;

      for (const _ of s) {
        count++;
      }

      return count;
    }
    function isEmptyInputValue(value) {
      return value === "" || value == null;
    }
    function useCursor(inputElRef) {
      const selectionRef = vue.ref(null);

      function recordCursor() {
        const {
          value: input
        } = inputElRef;

        if (!(input !== null && input !== void 0 && input.focus)) {
          reset();
          return;
        }

        const {
          selectionStart,
          selectionEnd,
          value
        } = input;

        if (selectionStart == null || selectionEnd == null) {
          reset();
          return;
        }

        selectionRef.value = {
          start: selectionStart,
          end: selectionEnd,
          beforeText: value.slice(0, selectionStart),
          afterText: value.slice(selectionEnd)
        };
      }

      function restoreCursor() {
        var _inputEl$setSelection;

        const {
          value: selection
        } = selectionRef;
        const {
          value: inputEl
        } = inputElRef;

        if (!selection || !inputEl) {
          return;
        }

        const {
          value
        } = inputEl;
        const {
          start,
          beforeText,
          afterText
        } = selection;
        let startPos = value.length;

        if (value.endsWith(afterText)) {
          startPos = value.length - afterText.length;
        } else if (value.startsWith(beforeText)) {
          startPos = beforeText.length;
        } else {
          const beforeLastChar = beforeText[start - 1];
          const newIndex = value.indexOf(beforeLastChar, start - 1);

          if (newIndex !== -1) {
            startPos = newIndex + 1;
          }
        }

        (_inputEl$setSelection = inputEl.setSelectionRange) === null || _inputEl$setSelection === void 0 ? void 0 : _inputEl$setSelection.call(inputEl, startPos, startPos);
      }

      function reset() {
        selectionRef.value = null;
      }

      vue.watch(inputElRef, reset);
      return {
        recordCursor,
        restoreCursor
      };
    }

    var WordCount = vue.defineComponent({
      name: "InputWordCount",
      setup(_, { slots }) {
        const { mergedValueRef, maxlengthRef, mergedClsPrefixRef } = vue.inject(inputInjectionKey);
        const wordCountRef = vue.computed(() => {
          const { value: mergedValue } = mergedValueRef;
          if (mergedValue === null || Array.isArray(mergedValue))
            return 0;
          return len(mergedValue);
        });
        return () => {
          const { value: maxlength } = maxlengthRef;
          const { value: mergedValue } = mergedValueRef;
          return /* @__PURE__ */ React.createElement("span", {
            class: `${mergedClsPrefixRef.value}-input-word-count`
          }, resolveSlotWithProps(
            slots.default,
            {
              value: mergedValue === null || Array.isArray(mergedValue) ? "" : mergedValue
            },
            () => [
              maxlength === void 0 ? wordCountRef.value : `${wordCountRef.value} / ${maxlength}`
            ]
          ));
        };
      }
    });

    var style$1j = cB("input", `
  max-width: 100%;
  cursor: text;
  line-height: 1.5;
  z-index: auto;
  outline: none;
  box-sizing: border-box;
  position: relative;
  display: inline-flex;
  border-radius: var(--n-border-radius);
  background-color: var(--n-color);
  transition: background-color .3s var(--n-bezier);
  font-size: var(--n-font-size);
  --n-padding-vertical: calc((var(--n-height) - 1.5 * var(--n-font-size)) / 2);
`, [cE("input, textarea", `
    overflow: hidden;
    flex-grow: 1;
    position: relative;
  `), cE("input-el, textarea-el, input-mirror, textarea-mirror, separator, placeholder", `
    box-sizing: border-box;
    font-size: inherit;
    line-height: 1.5;
    font-family: inherit;
    border: none;
    outline: none;
    background-color: #0000;
    text-align: inherit;
    transition:
      -webkit-text-fill-color .3s var(--n-bezier),
      caret-color .3s var(--n-bezier),
      color .3s var(--n-bezier),
      text-decoration-color .3s var(--n-bezier);
  `), cE("input-el, textarea-el", `
    -webkit-appearance: none;
    scrollbar-width: none;
    width: 100%;
    min-width: 0;
    text-decoration-color: var(--n-text-decoration-color);
    color: var(--n-text-color);
    caret-color: var(--n-caret-color);
    background-color: transparent;
  `, [c$1("&::-webkit-scrollbar, &::-webkit-scrollbar-track-piece, &::-webkit-scrollbar-thumb", `
      width: 0;
      height: 0;
      display: none;
    `), c$1("&::placeholder", `
      color: #0000;
      -webkit-text-fill-color: transparent !important;
    `), c$1("&:-webkit-autofill ~", [cE("placeholder", "display: none;")])]), cM("round", [cNotM("textarea", "border-radius: calc(var(--n-height) / 2);")]), cE("placeholder", `
    pointer-events: none;
    position: absolute;
    left: 0;
    right: 0;
    top: 0;
    bottom: 0;
    overflow: hidden;
    color: var(--n-placeholder-color);
  `, [c$1("span", `
      width: 100%;
      display: inline-block;
    `)]), cM("textarea", [cE("placeholder", "overflow: visible;")]), cNotM("autosize", "width: 100%;"), cM("autosize", [cE("textarea-el, input-el", `
      position: absolute;
      top: 0;
      left: 0;
      height: 100%;
    `)]), cB("input-wrapper", `
    overflow: hidden;
    display: inline-flex;
    flex-grow: 1;
    position: relative;
    padding-left: var(--n-padding-left);
    padding-right: var(--n-padding-right);
  `), cE("input-mirror", `
    padding: 0;
    height: var(--n-height);
    overflow: hidden;
    visibility: hidden;
    position: static;
    white-space: nowrap;
    pointer-events: none;
  `), cE("input-el", `
    padding: 0;
    height: var(--n-height);
    line-height: var(--n-height);
  `, [c$1("+", [cE("placeholder", `
        display: flex;
        align-items: center;  
      `)])]), cNotM("textarea", [cE("placeholder", "white-space: nowrap;")]), cE("eye", `
    transition: color .3s var(--n-bezier);
  `), cM("textarea", "width: 100%;", [cB("input-word-count", `
      position: absolute;
      right: var(--n-padding-right);
      bottom: var(--n-padding-vertical);
    `), cM("resizable", [cB("input-wrapper", `
        resize: vertical;
        min-height: var(--n-height);
      `)]), cE("textarea-el, textarea-mirror, placeholder", `
      height: 100%;
      padding-left: 0;
      padding-right: 0;
      padding-top: var(--n-padding-vertical);
      padding-bottom: var(--n-padding-vertical);
      word-break: break-word;
      display: inline-block;
      vertical-align: bottom;
      box-sizing: border-box;
      line-height: var(--n-line-height-textarea);
      margin: 0;
      resize: none;
      white-space: pre-wrap;
    `), cE("textarea-mirror", `
      width: 100%;
      pointer-events: none;
      overflow: hidden;
      visibility: hidden;
      position: static;
      white-space: pre-wrap;
      overflow-wrap: break-word;
    `)]), cM("pair", [cE("input-el, placeholder", "text-align: center;"), cE("separator", `
      display: flex;
      align-items: center;
      transition: color .3s var(--n-bezier);
      color: var(--n-text-color);
      white-space: nowrap;
    `, [cB("icon", `
        color: var(--n-icon-color);
      `), cB("base-icon", `
        color: var(--n-icon-color);
      `)])]), cM("disabled", `
    cursor: not-allowed;
    background-color: var(--n-color-disabled);
  `, [cE("border", "border: var(--n-border-disabled);"), cE("input-el, textarea-el", `
      cursor: not-allowed;
      color: var(--n-text-color-disabled);
      text-decoration-color: var(--n-text-color-disabled);
    `), cE("placeholder", "color: var(--n-placeholder-color-disabled);"), cE("separator", "color: var(--n-text-color-disabled);", [cB("icon", `
        color: var(--n-icon-color-disabled);
      `), cB("base-icon", `
        color: var(--n-icon-color-disabled);
      `)]), cB("input-word-count", `
      color: var(--n-count-text-color-disabled);
    `), cE("suffix, prefix", "color: var(--n-text-color-disabled);", [cB("icon", `
        color: var(--n-icon-color-disabled);
      `), cB("internal-icon", `
        color: var(--n-icon-color-disabled);
      `)])]), cNotM("disabled", [cE("eye", `
      display: flex;
      align-items: center;
      justify-content: center;
      color: var(--n-icon-color);
      cursor: pointer;
    `, [c$1("&:hover", `
        color: var(--n-icon-color-hover);
      `), c$1("&:active", `
        color: var(--n-icon-color-pressed);
      `)]), c$1("&:hover", [cE("state-border", "border: var(--n-border-hover);")]), cM("focus", "background-color: var(--n-color-focus);", [cE("state-border", `
        border: var(--n-border-focus);
        box-shadow: var(--n-box-shadow-focus);
      `)])]), cE("border, state-border", `
    box-sizing: border-box;
    position: absolute;
    left: 0;
    right: 0;
    top: 0;
    bottom: 0;
    pointer-events: none;
    border-radius: inherit;
    border: var(--n-border);
    transition:
      box-shadow .3s var(--n-bezier),
      border-color .3s var(--n-bezier);
  `), cE("state-border", `
    border-color: #0000;
    z-index: 1;
  `), cE("prefix", "margin-right: 4px;"), cE("suffix", `
    margin-left: 4px;
  `), cE("suffix, prefix", `
    transition: color .3s var(--n-bezier);
    flex-wrap: nowrap;
    flex-shrink: 0;
    line-height: var(--n-height);
    white-space: nowrap;
    display: inline-flex;
    align-items: center;
    justify-content: center;
    color: var(--n-suffix-text-color);
  `, [cB("base-loading", `
      font-size: var(--n-icon-size);
      margin: 0 2px;
      color: var(--n-loading-color);
    `), cB("base-clear", `
      font-size: var(--n-icon-size);
    `, [cE("placeholder", [cB("base-icon", `
          transition: color .3s var(--n-bezier);
          color: var(--n-icon-color);
          font-size: var(--n-icon-size);
        `)])]), c$1(">", [cB("icon", `
        transition: color .3s var(--n-bezier);
        color: var(--n-icon-color);
        font-size: var(--n-icon-size);
      `)]), cB("base-icon", `
      font-size: var(--n-icon-size);
    `)]), cB("input-word-count", `
    pointer-events: none;
    line-height: 1.5;
    font-size: .85em;
    color: var(--n-count-text-color);
    transition: color .3s var(--n-bezier);
    margin-left: 4px;
    font-variant: tabular-nums;
  `), ["warning", "error"].map(status => cM(`${status}-status`, [cNotM("disabled", [cB("base-loading", `
        color: var(--n-loading-color-${status})
      `), cE("input-el, textarea-el", `
        caret-color: var(--n-caret-color-${status});
      `), cE("state-border", `
        border: var(--n-border-${status});
      `), c$1("&:hover", [cE("state-border", `
          border: var(--n-border-hover-${status});
        `)]), c$1("&:focus", `
        background-color: var(--n-color-focus-${status});
      `, [cE("state-border", `
          box-shadow: var(--n-box-shadow-focus-${status});
          border: var(--n-border-focus-${status});
        `)]), cM("focus", `
        background-color: var(--n-color-focus-${status});
      `, [cE("state-border", `
          box-shadow: var(--n-box-shadow-focus-${status});
          border: var(--n-border-focus-${status});
        `)])])]))]);
    const safariStyle = cB("input", [cM("disabled", [cE("input-el, textarea-el", `
      -webkit-text-fill-color: var(--n-text-color-disabled);
    `)])]);

    const inputProps = {
      ...useTheme.props,
      bordered: {
        type: Boolean,
        default: void 0
      },
      type: {
        type: String,
        default: "text"
      },
      placeholder: [Array, String],
      defaultValue: {
        type: [String, Array],
        default: null
      },
      value: [String, Array],
      disabled: {
        type: Boolean,
        default: void 0
      },
      size: String,
      rows: {
        type: [Number, String],
        default: 3
      },
      round: Boolean,
      minlength: [String, Number],
      maxlength: [String, Number],
      clearable: Boolean,
      autosize: {
        type: [Boolean, Object],
        default: false
      },
      pair: Boolean,
      separator: String,
      readonly: {
        type: [String, Boolean],
        default: false
      },
      passivelyActivated: Boolean,
      showPasswordOn: String,
      stateful: {
        type: Boolean,
        default: true
      },
      autofocus: Boolean,
      inputProps: Object,
      resizable: {
        type: Boolean,
        default: true
      },
      showCount: Boolean,
      loading: {
        type: Boolean,
        default: void 0
      },
      allowInput: Function,
      renderCount: Function,
      onMousedown: Function,
      onKeydown: Function,
      onKeyup: Function,
      onInput: [Function, Array],
      onFocus: [Function, Array],
      onBlur: [Function, Array],
      onClick: [Function, Array],
      onChange: [Function, Array],
      onClear: [Function, Array],
      status: String,
      "onUpdate:value": [Function, Array],
      onUpdateValue: [Function, Array],
      textDecoration: [String, Array],
      attrSize: {
        type: Number,
        default: 20
      },
      onInputBlur: [Function, Array],
      onInputFocus: [Function, Array],
      onDeactivate: [Function, Array],
      onActivate: [Function, Array],
      onWrapperFocus: [Function, Array],
      onWrapperBlur: [Function, Array],
      internalDeactivateOnEnter: Boolean,
      internalForceFocus: Boolean,
      internalLoadingBeforeSuffix: Boolean,
      showPasswordToggle: Boolean
    };
    var NInput = vue.defineComponent({
      name: "Input",
      props: inputProps,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.showPasswordToggle) {
              warnOnce(
                "input",
                '`show-password-toggle` is deprecated, please use `showPasswordOn="click"` instead'
              );
            }
          });
        }
        const {
          mergedClsPrefixRef,
          mergedBorderedRef,
          inlineThemeDisabled,
          mergedRtlRef
        } = useConfig(props);
        const themeRef = useTheme(
          "Input",
          "-input",
          style$1j,
          inputLight$1,
          props,
          mergedClsPrefixRef
        );
        if (isSafari) {
          useStyle("-input-safari", safariStyle, mergedClsPrefixRef);
        }
        const wrapperElRef = vue.ref(null);
        const textareaElRef = vue.ref(null);
        const textareaMirrorElRef = vue.ref(null);
        const inputMirrorElRef = vue.ref(null);
        const inputElRef = vue.ref(null);
        const inputEl2Ref = vue.ref(null);
        const currentFocusedInputRef = vue.ref(null);
        const focusedInputCursorControl = useCursor(currentFocusedInputRef);
        const textareaScrollbarInstRef = vue.ref(null);
        const { localeRef } = useLocale("Input");
        const uncontrolledValueRef = vue.ref(props.defaultValue);
        const controlledValueRef = vue.toRef(props, "value");
        const mergedValueRef = useMergedState(
          controlledValueRef,
          uncontrolledValueRef
        );
        const formItem = useFormItem(props);
        const { mergedSizeRef, mergedDisabledRef, mergedStatusRef } = formItem;
        const focusedRef = vue.ref(false);
        const hoverRef = vue.ref(false);
        const isComposingRef = vue.ref(false);
        const activatedRef = vue.ref(false);
        let syncSource = null;
        const mergedPlaceholderRef = vue.computed(() => {
          const { placeholder, pair } = props;
          if (pair) {
            if (Array.isArray(placeholder)) {
              return placeholder;
            } else if (placeholder === void 0) {
              return ["", ""];
            }
            return [placeholder, placeholder];
          } else if (placeholder === void 0) {
            return [localeRef.value.placeholder];
          } else {
            return [placeholder];
          }
        });
        const showPlaceholder1Ref = vue.computed(() => {
          const { value: isComposing } = isComposingRef;
          const { value: mergedValue } = mergedValueRef;
          const { value: mergedPlaceholder } = mergedPlaceholderRef;
          return !isComposing && (isEmptyInputValue(mergedValue) || Array.isArray(mergedValue) && isEmptyInputValue(mergedValue[0])) && mergedPlaceholder[0];
        });
        const showPlaceholder2Ref = vue.computed(() => {
          const { value: isComposing } = isComposingRef;
          const { value: mergedValue } = mergedValueRef;
          const { value: mergedPlaceholder } = mergedPlaceholderRef;
          return !isComposing && mergedPlaceholder[1] && (isEmptyInputValue(mergedValue) || Array.isArray(mergedValue) && isEmptyInputValue(mergedValue[1]));
        });
        const mergedFocusRef = useMemo(() => {
          return props.internalForceFocus || focusedRef.value;
        });
        const showClearButton = useMemo(() => {
          if (mergedDisabledRef.value || props.readonly || !props.clearable || !mergedFocusRef.value && !hoverRef.value) {
            return false;
          }
          const { value: mergedValue } = mergedValueRef;
          const { value: mergedFocus } = mergedFocusRef;
          if (props.pair) {
            return !!(Array.isArray(mergedValue) && (mergedValue[0] || mergedValue[1])) && (hoverRef.value || mergedFocus);
          } else {
            return !!mergedValue && (hoverRef.value || mergedFocus);
          }
        });
        const mergedShowPasswordOnRef = vue.computed(() => {
          const { showPasswordOn } = props;
          if (showPasswordOn) {
            return showPasswordOn;
          }
          if (props.showPasswordToggle)
            return "click";
          return void 0;
        });
        const passwordVisibleRef = vue.ref(false);
        const textDecorationStyleRef = vue.computed(() => {
          const { textDecoration } = props;
          if (!textDecoration)
            return ["", ""];
          if (Array.isArray(textDecoration)) {
            return textDecoration.map((v) => ({
              textDecoration: v
            }));
          }
          return [
            {
              textDecoration
            }
          ];
        });
        const textAreaScrollContainerWidthRef = vue.ref(void 0);
        const updateTextAreaStyle = () => {
          if (props.type === "textarea") {
            const { autosize } = props;
            if (autosize) {
              textAreaScrollContainerWidthRef.value = textareaScrollbarInstRef.value?.$el?.offsetWidth;
            }
            if (!textareaElRef.value)
              return;
            if (typeof autosize === "boolean")
              return;
            const {
              paddingTop: stylePaddingTop,
              paddingBottom: stylePaddingBottom,
              lineHeight: styleLineHeight
            } = window.getComputedStyle(textareaElRef.value);
            const paddingTop = Number(stylePaddingTop.slice(0, -2));
            const paddingBottom = Number(stylePaddingBottom.slice(0, -2));
            const lineHeight = Number(styleLineHeight.slice(0, -2));
            const { value: textareaMirrorEl } = textareaMirrorElRef;
            if (!textareaMirrorEl)
              return;
            if (autosize.minRows) {
              const minRows = Math.max(autosize.minRows, 1);
              const styleMinHeight = `${paddingTop + paddingBottom + lineHeight * minRows}px`;
              textareaMirrorEl.style.minHeight = styleMinHeight;
            }
            if (autosize.maxRows) {
              const styleMaxHeight = `${paddingTop + paddingBottom + lineHeight * autosize.maxRows}px`;
              textareaMirrorEl.style.maxHeight = styleMaxHeight;
            }
          }
        };
        const maxlengthRef = vue.computed(() => {
          const { maxlength } = props;
          return maxlength === void 0 ? void 0 : Number(maxlength);
        });
        vue.onMounted(() => {
          const { value } = mergedValueRef;
          if (!Array.isArray(value)) {
            syncMirror(value);
          }
        });
        const vm = vue.getCurrentInstance().proxy;
        function doUpdateValue(value) {
          const { onUpdateValue, "onUpdate:value": _onUpdateValue, onInput } = props;
          const { nTriggerFormInput } = formItem;
          if (onUpdateValue)
            call(onUpdateValue, value);
          if (_onUpdateValue)
            call(_onUpdateValue, value);
          if (onInput)
            call(onInput, value);
          uncontrolledValueRef.value = value;
          nTriggerFormInput();
        }
        function doChange(value) {
          const { onChange } = props;
          const { nTriggerFormChange } = formItem;
          if (onChange)
            call(onChange, value);
          uncontrolledValueRef.value = value;
          nTriggerFormChange();
        }
        function doBlur(e) {
          const { onBlur } = props;
          const { nTriggerFormBlur } = formItem;
          if (onBlur)
            call(onBlur, e);
          nTriggerFormBlur();
        }
        function doFocus(e) {
          const { onFocus } = props;
          const { nTriggerFormFocus } = formItem;
          if (onFocus)
            call(onFocus, e);
          nTriggerFormFocus();
        }
        function doClear(e) {
          const { onClear } = props;
          if (onClear)
            call(onClear, e);
        }
        function doUpdateValueBlur(e) {
          const { onInputBlur } = props;
          if (onInputBlur)
            call(onInputBlur, e);
        }
        function doUpdateValueFocus(e) {
          const { onInputFocus } = props;
          if (onInputFocus)
            call(onInputFocus, e);
        }
        function doDeactivate() {
          const { onDeactivate } = props;
          if (onDeactivate)
            call(onDeactivate);
        }
        function doActivate() {
          const { onActivate } = props;
          if (onActivate)
            call(onActivate);
        }
        function doClick(e) {
          const { onClick } = props;
          if (onClick)
            call(onClick, e);
        }
        function doWrapperFocus(e) {
          const { onWrapperFocus } = props;
          if (onWrapperFocus)
            call(onWrapperFocus, e);
        }
        function doWrapperBlur(e) {
          const { onWrapperBlur } = props;
          if (onWrapperBlur)
            call(onWrapperBlur, e);
        }
        function handleCompositionStart() {
          isComposingRef.value = true;
        }
        function handleCompositionEnd(e) {
          isComposingRef.value = false;
          if (e.target === inputEl2Ref.value) {
            handleInput(e, 1);
          } else {
            handleInput(e, 0);
          }
        }
        function handleInput(e, index = 0, event = "input") {
          const targetValue = e.target.value;
          syncMirror(targetValue);
          if (e instanceof InputEvent && !e.isComposing) {
            isComposingRef.value = false;
          }
          if (props.type === "textarea") {
            const { value: textareaScrollbarInst } = textareaScrollbarInstRef;
            if (textareaScrollbarInst) {
              textareaScrollbarInst.syncUnifiedContainer();
            }
          }
          syncSource = targetValue;
          if (isComposingRef.value)
            return;
          focusedInputCursorControl.recordCursor();
          const isIncomingValueValid = allowInput(targetValue);
          if (isIncomingValueValid) {
            if (!props.pair) {
              event === "input" ? doUpdateValue(targetValue) : doChange(targetValue);
            } else {
              let { value } = mergedValueRef;
              if (!Array.isArray(value)) {
                value = ["", ""];
              } else {
                value = [value[0], value[1]];
              }
              value[index] = targetValue;
              event === "input" ? doUpdateValue(value) : doChange(value);
            }
          }
          vm.$forceUpdate();
          if (!isIncomingValueValid) {
            void vue.nextTick(focusedInputCursorControl.restoreCursor);
          }
        }
        function allowInput(value) {
          const { allowInput: allowInput2 } = props;
          if (typeof allowInput2 === "function") {
            return allowInput2(value);
          }
          return true;
        }
        function handleInputBlur(e) {
          doUpdateValueBlur(e);
          if (e.relatedTarget === wrapperElRef.value) {
            doDeactivate();
          }
          if (!(e.relatedTarget !== null && (e.relatedTarget === inputElRef.value || e.relatedTarget === inputEl2Ref.value || e.relatedTarget === textareaElRef.value))) {
            activatedRef.value = false;
          }
          dealWithEvent(e, "blur");
          currentFocusedInputRef.value = null;
        }
        function handleInputFocus(e, index) {
          doUpdateValueFocus(e);
          focusedRef.value = true;
          activatedRef.value = true;
          doActivate();
          dealWithEvent(e, "focus");
          if (index === 0) {
            currentFocusedInputRef.value = inputElRef.value;
          } else if (index === 1) {
            currentFocusedInputRef.value = inputEl2Ref.value;
          } else if (index === 2) {
            currentFocusedInputRef.value = textareaElRef.value;
          }
        }
        function handleWrapperBlur(e) {
          if (props.passivelyActivated) {
            doWrapperBlur(e);
            dealWithEvent(e, "blur");
          }
        }
        function handleWrapperFocus(e) {
          if (props.passivelyActivated) {
            focusedRef.value = true;
            doWrapperFocus(e);
            dealWithEvent(e, "focus");
          }
        }
        function dealWithEvent(e, type) {
          if (e.relatedTarget !== null && (e.relatedTarget === inputElRef.value || e.relatedTarget === inputEl2Ref.value || e.relatedTarget === textareaElRef.value || e.relatedTarget === wrapperElRef.value)) ; else {
            if (type === "focus") {
              doFocus(e);
              focusedRef.value = true;
            } else if (type === "blur") {
              doBlur(e);
              focusedRef.value = false;
            }
          }
        }
        function handleChange(e, index) {
          handleInput(e, index, "change");
        }
        function handleClick(e) {
          doClick(e);
        }
        function handleClear(e) {
          doClear(e);
          if (props.pair) {
            doUpdateValue(["", ""]);
            doChange(["", ""]);
          } else {
            doUpdateValue("");
            doChange("");
          }
        }
        function handleMouseDown(e) {
          const { onMousedown } = props;
          if (onMousedown)
            onMousedown(e);
          const { tagName } = e.target;
          if (tagName !== "INPUT" && tagName !== "TEXTAREA") {
            if (props.resizable) {
              const { value: wrapperEl } = wrapperElRef;
              if (wrapperEl) {
                const { left, top, width, height } = wrapperEl.getBoundingClientRect();
                const resizeHandleSize = 14;
                if (left + width - resizeHandleSize < e.clientX && e.clientX < left + width && top + height - resizeHandleSize < e.clientY && e.clientY < top + height) {
                  return;
                }
              }
            }
            e.preventDefault();
            if (!focusedRef.value) {
              focus();
            }
          }
        }
        function handleMouseEnter() {
          hoverRef.value = true;
          if (props.type === "textarea") {
            textareaScrollbarInstRef.value?.handleMouseEnterWrapper();
          }
        }
        function handleMouseLeave() {
          hoverRef.value = false;
          if (props.type === "textarea") {
            textareaScrollbarInstRef.value?.handleMouseLeaveWrapper();
          }
        }
        function handlePasswordToggleClick() {
          if (mergedDisabledRef.value)
            return;
          if (mergedShowPasswordOnRef.value !== "click")
            return;
          passwordVisibleRef.value = !passwordVisibleRef.value;
        }
        function handlePasswordToggleMousedown(e) {
          if (mergedDisabledRef.value)
            return;
          e.preventDefault();
          const preventDefaultOnce = (e2) => {
            e2.preventDefault();
            off("mouseup", document, preventDefaultOnce);
          };
          on("mouseup", document, preventDefaultOnce);
          if (mergedShowPasswordOnRef.value !== "mousedown")
            return;
          passwordVisibleRef.value = true;
          const hidePassword = () => {
            passwordVisibleRef.value = false;
            off("mouseup", document, hidePassword);
          };
          on("mouseup", document, hidePassword);
        }
        function handleWrapperKeydown(e) {
          props.onKeydown?.(e);
          switch (e.key) {
            case "Escape":
              handleWrapperKeydownEsc();
              break;
            case "Enter":
              handleWrapperKeydownEnter(e);
              break;
          }
        }
        function handleWrapperKeydownEnter(e) {
          if (props.passivelyActivated) {
            const { value: focused } = activatedRef;
            if (focused) {
              if (props.internalDeactivateOnEnter) {
                handleWrapperKeydownEsc();
              }
              return;
            }
            e.preventDefault();
            if (props.type === "textarea") {
              textareaElRef.value?.focus();
            } else {
              inputElRef.value?.focus();
            }
          }
        }
        function handleWrapperKeydownEsc() {
          if (props.passivelyActivated) {
            activatedRef.value = false;
            void vue.nextTick(() => {
              wrapperElRef.value?.focus();
            });
          }
        }
        function focus() {
          if (mergedDisabledRef.value)
            return;
          if (props.passivelyActivated) {
            wrapperElRef.value?.focus();
          } else {
            textareaElRef.value?.focus();
            inputElRef.value?.focus();
          }
        }
        function blur() {
          if (wrapperElRef.value?.contains(document.activeElement)) {
            document.activeElement.blur();
          }
        }
        function select() {
          textareaElRef.value?.select();
          inputElRef.value?.select();
        }
        function activate() {
          if (mergedDisabledRef.value)
            return;
          if (textareaElRef.value)
            textareaElRef.value.focus();
          else if (inputElRef.value)
            inputElRef.value.focus();
        }
        function deactivate() {
          const { value: wrapperEl } = wrapperElRef;
          if (wrapperEl?.contains(document.activeElement) && wrapperEl !== document.activeElement) {
            handleWrapperKeydownEsc();
          }
        }
        function scrollTo(options) {
          if (props.type === "textarea") {
            const { value: textareaEl } = textareaElRef;
            textareaEl?.scrollTo(options);
          } else {
            const { value: inputEl } = inputElRef;
            inputEl?.scrollTo(options);
          }
        }
        function syncMirror(value) {
          const { type, pair, autosize } = props;
          if (!pair && autosize) {
            if (type === "textarea") {
              const { value: textareaMirrorEl } = textareaMirrorElRef;
              if (textareaMirrorEl) {
                textareaMirrorEl.textContent = (value ?? "") + "\r\n";
              }
            } else {
              const { value: inputMirrorEl } = inputMirrorElRef;
              if (inputMirrorEl) {
                if (value) {
                  inputMirrorEl.textContent = value;
                } else {
                  inputMirrorEl.innerHTML = "&nbsp;";
                }
              }
            }
          }
        }
        function handleTextAreaMirrorResize() {
          updateTextAreaStyle();
        }
        const placeholderStyleRef = vue.ref({
          top: "0"
        });
        function handleTextAreaScroll(e) {
          const { scrollTop } = e.target;
          placeholderStyleRef.value.top = `${-scrollTop}px`;
          textareaScrollbarInstRef.value?.syncUnifiedContainer();
        }
        let stopWatchMergedValue1 = null;
        vue.watchEffect(() => {
          const { autosize, type } = props;
          if (autosize && type === "textarea") {
            stopWatchMergedValue1 = vue.watch(mergedValueRef, (value) => {
              if (!Array.isArray(value) && value !== syncSource) {
                syncMirror(value);
              }
            });
          } else {
            stopWatchMergedValue1?.();
          }
        });
        let stopWatchMergedValue2 = null;
        vue.watchEffect(() => {
          if (props.type === "textarea") {
            stopWatchMergedValue2 = vue.watch(mergedValueRef, (value) => {
              if (!Array.isArray(value) && value !== syncSource) {
                textareaScrollbarInstRef.value?.syncUnifiedContainer();
              }
            });
          } else {
            stopWatchMergedValue2?.();
          }
        });
        vue.provide(inputInjectionKey, {
          mergedValueRef,
          maxlengthRef,
          mergedClsPrefixRef
        });
        const exposedProps = {
          wrapperElRef,
          inputElRef,
          textareaElRef,
          isCompositing: isComposingRef,
          focus,
          blur,
          select,
          deactivate,
          activate,
          scrollTo
        };
        const rtlEnabledRef = useRtl("Input", mergedRtlRef, mergedClsPrefixRef);
        const cssVarsRef = vue.computed(() => {
          const { value: size } = mergedSizeRef;
          const {
            common: { cubicBezierEaseInOut },
            self: {
              color,
              borderRadius,
              textColor,
              caretColor,
              caretColorError,
              caretColorWarning,
              textDecorationColor,
              border,
              borderDisabled,
              borderHover,
              borderFocus,
              placeholderColor,
              placeholderColorDisabled,
              lineHeightTextarea,
              colorDisabled,
              colorFocus,
              textColorDisabled,
              boxShadowFocus,
              iconSize,
              colorFocusWarning,
              boxShadowFocusWarning,
              borderWarning,
              borderFocusWarning,
              borderHoverWarning,
              colorFocusError,
              boxShadowFocusError,
              borderError,
              borderFocusError,
              borderHoverError,
              clearSize,
              clearColor,
              clearColorHover,
              clearColorPressed,
              iconColor,
              iconColorDisabled,
              suffixTextColor,
              countTextColor,
              countTextColorDisabled,
              iconColorHover,
              iconColorPressed,
              loadingColor,
              loadingColorError,
              loadingColorWarning,
              [createKey("padding", size)]: padding,
              [createKey("fontSize", size)]: fontSize,
              [createKey("height", size)]: height
            }
          } = themeRef.value;
          const { left: paddingLeft, right: paddingRight } = getMargin(padding);
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-count-text-color": countTextColor,
            "--n-count-text-color-disabled": countTextColorDisabled,
            "--n-color": color,
            "--n-font-size": fontSize,
            "--n-border-radius": borderRadius,
            "--n-height": height,
            "--n-padding-left": paddingLeft,
            "--n-padding-right": paddingRight,
            "--n-text-color": textColor,
            "--n-caret-color": caretColor,
            "--n-text-decoration-color": textDecorationColor,
            "--n-border": border,
            "--n-border-disabled": borderDisabled,
            "--n-border-hover": borderHover,
            "--n-border-focus": borderFocus,
            "--n-placeholder-color": placeholderColor,
            "--n-placeholder-color-disabled": placeholderColorDisabled,
            "--n-icon-size": iconSize,
            "--n-line-height-textarea": lineHeightTextarea,
            "--n-color-disabled": colorDisabled,
            "--n-color-focus": colorFocus,
            "--n-text-color-disabled": textColorDisabled,
            "--n-box-shadow-focus": boxShadowFocus,
            "--n-loading-color": loadingColor,
            "--n-caret-color-warning": caretColorWarning,
            "--n-color-focus-warning": colorFocusWarning,
            "--n-box-shadow-focus-warning": boxShadowFocusWarning,
            "--n-border-warning": borderWarning,
            "--n-border-focus-warning": borderFocusWarning,
            "--n-border-hover-warning": borderHoverWarning,
            "--n-loading-color-warning": loadingColorWarning,
            "--n-caret-color-error": caretColorError,
            "--n-color-focus-error": colorFocusError,
            "--n-box-shadow-focus-error": boxShadowFocusError,
            "--n-border-error": borderError,
            "--n-border-focus-error": borderFocusError,
            "--n-border-hover-error": borderHoverError,
            "--n-loading-color-error": loadingColorError,
            "--n-clear-color": clearColor,
            "--n-clear-size": clearSize,
            "--n-clear-color-hover": clearColorHover,
            "--n-clear-color-pressed": clearColorPressed,
            "--n-icon-color": iconColor,
            "--n-icon-color-hover": iconColorHover,
            "--n-icon-color-pressed": iconColorPressed,
            "--n-icon-color-disabled": iconColorDisabled,
            "--n-suffix-text-color": suffixTextColor
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "input",
          vue.computed(() => {
            const { value: size } = mergedSizeRef;
            return size[0];
          }),
          cssVarsRef,
          props
        ) : void 0;
        return {
          ...exposedProps,
          wrapperElRef,
          inputElRef,
          inputMirrorElRef,
          inputEl2Ref,
          textareaElRef,
          textareaMirrorElRef,
          textareaScrollbarInstRef,
          rtlEnabled: rtlEnabledRef,
          uncontrolledValue: uncontrolledValueRef,
          mergedValue: mergedValueRef,
          passwordVisible: passwordVisibleRef,
          mergedPlaceholder: mergedPlaceholderRef,
          showPlaceholder1: showPlaceholder1Ref,
          showPlaceholder2: showPlaceholder2Ref,
          mergedFocus: mergedFocusRef,
          isComposing: isComposingRef,
          activated: activatedRef,
          showClearButton,
          mergedSize: mergedSizeRef,
          mergedDisabled: mergedDisabledRef,
          textDecorationStyle: textDecorationStyleRef,
          mergedClsPrefix: mergedClsPrefixRef,
          mergedBordered: mergedBorderedRef,
          mergedShowPasswordOn: mergedShowPasswordOnRef,
          placeholderStyle: placeholderStyleRef,
          mergedStatus: mergedStatusRef,
          textAreaScrollContainerWidth: textAreaScrollContainerWidthRef,
          handleTextAreaScroll,
          handleCompositionStart,
          handleCompositionEnd,
          handleInput,
          handleInputBlur,
          handleInputFocus,
          handleWrapperBlur,
          handleWrapperFocus,
          handleMouseEnter,
          handleMouseLeave,
          handleMouseDown,
          handleChange,
          handleClick,
          handleClear,
          handlePasswordToggleClick,
          handlePasswordToggleMousedown,
          handleWrapperKeydown,
          handleTextAreaMirrorResize,
          getTextareaScrollContainer: () => {
            return textareaElRef.value;
          },
          mergedTheme: themeRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedClsPrefix, mergedStatus, themeClass, type, onRender } = this;
        const $slots = this.$slots;
        onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          ref: "wrapperElRef",
          class: [
            `${mergedClsPrefix}-input`,
            themeClass,
            mergedStatus && `${mergedClsPrefix}-input--${mergedStatus}-status`,
            {
              [`${mergedClsPrefix}-input--rtl`]: this.rtlEnabled,
              [`${mergedClsPrefix}-input--disabled`]: this.mergedDisabled,
              [`${mergedClsPrefix}-input--textarea`]: type === "textarea",
              [`${mergedClsPrefix}-input--resizable`]: this.resizable && !this.autosize,
              [`${mergedClsPrefix}-input--autosize`]: this.autosize,
              [`${mergedClsPrefix}-input--round`]: this.round && !(type === "textarea"),
              [`${mergedClsPrefix}-input--pair`]: this.pair,
              [`${mergedClsPrefix}-input--focus`]: this.mergedFocus,
              [`${mergedClsPrefix}-input--stateful`]: this.stateful
            }
          ],
          style: this.cssVars,
          tabindex: !this.mergedDisabled && this.passivelyActivated && !this.activated ? 0 : void 0,
          onFocus: this.handleWrapperFocus,
          onBlur: this.handleWrapperBlur,
          onClick: this.handleClick,
          onMousedown: this.handleMouseDown,
          onMouseenter: this.handleMouseEnter,
          onMouseleave: this.handleMouseLeave,
          onCompositionstart: this.handleCompositionStart,
          onCompositionend: this.handleCompositionEnd,
          onKeyup: this.onKeyup,
          onKeydown: this.handleWrapperKeydown
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-input-wrapper`
        }, resolveWrappedSlot(
          $slots.prefix,
          (children) => children && /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-input__prefix`
          }, children)
        ), type === "textarea" ? /* @__PURE__ */ React.createElement(NScrollbar, {
          ref: "textareaScrollbarInstRef",
          class: `${mergedClsPrefix}-input__textarea`,
          container: this.getTextareaScrollContainer,
          triggerDisplayManually: true,
          useUnifiedContainer: true,
          internalHoistYRail: true
        }, {
          default: () => {
            const { textAreaScrollContainerWidth } = this;
            const scrollContainerWidthStyle = {
              width: this.autosize && textAreaScrollContainerWidth && `${textAreaScrollContainerWidth}px`
            };
            return /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement("textarea", {
              ...this.inputProps,
              ref: "textareaElRef",
              class: [
                `${mergedClsPrefix}-input__textarea-el`,
                this.inputProps?.class
              ],
              autofocus: this.autofocus,
              rows: Number(this.rows),
              placeholder: this.placeholder,
              value: this.mergedValue,
              disabled: this.mergedDisabled,
              maxlength: this.maxlength,
              minlength: this.minlength,
              readonly: this.readonly,
              tabindex: this.passivelyActivated && !this.activated ? -1 : void 0,
              style: [
                this.textDecorationStyle[0],
                this.inputProps?.style,
                scrollContainerWidthStyle
              ],
              onBlur: this.handleInputBlur,
              onFocus: (e) => this.handleInputFocus(e, 2),
              onInput: this.handleInput,
              onChange: this.handleChange,
              onScroll: this.handleTextAreaScroll
            }), this.showPlaceholder1 ? /* @__PURE__ */ React.createElement("div", {
              class: `${mergedClsPrefix}-input__placeholder`,
              style: [
                this.placeholderStyle,
                scrollContainerWidthStyle
              ],
              key: "placeholder"
            }, this.mergedPlaceholder[0]) : null, this.autosize ? /* @__PURE__ */ React.createElement(VResizeObserver, {
              onResize: this.handleTextAreaMirrorResize
            }, {
              default: () => /* @__PURE__ */ React.createElement("div", {
                ref: "textareaMirrorElRef",
                class: `${mergedClsPrefix}-input__textarea-mirror`,
                key: "mirror"
              })
            }) : null);
          }
        }) : /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-input__input`
        }, /* @__PURE__ */ React.createElement("input", {
          type: type === "password" && this.mergedShowPasswordOn && this.passwordVisible ? "text" : type,
          ...this.inputProps,
          ref: "inputElRef",
          class: [
            `${mergedClsPrefix}-input__input-el`,
            this.inputProps?.class
          ],
          style: [
            this.textDecorationStyle[0],
            this.inputProps?.style
          ],
          tabindex: this.passivelyActivated && !this.activated ? -1 : void 0,
          placeholder: this.mergedPlaceholder[0],
          disabled: this.mergedDisabled,
          maxlength: this.maxlength,
          minlength: this.minlength,
          value: Array.isArray(this.mergedValue) ? this.mergedValue[0] : this.mergedValue,
          readonly: this.readonly,
          autofocus: this.autofocus,
          size: this.attrSize,
          onBlur: this.handleInputBlur,
          onFocus: (e) => this.handleInputFocus(e, 0),
          onInput: (e) => this.handleInput(e, 0),
          onChange: (e) => this.handleChange(e, 0)
        }), this.showPlaceholder1 ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-input__placeholder`
        }, /* @__PURE__ */ React.createElement("span", null, this.mergedPlaceholder[0])) : null, this.autosize ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-input__input-mirror`,
          key: "mirror",
          ref: "inputMirrorElRef"
        }, "\xA0") : null), !this.pair && resolveWrappedSlot($slots.suffix, (children) => {
          return children || this.clearable || this.showCount || this.mergedShowPasswordOn || this.loading !== void 0 ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-input__suffix`
          }, [
            resolveWrappedSlot(
              $slots["clear-icon-placeholder"],
              (children2) => {
                return (this.clearable || children2) && /* @__PURE__ */ React.createElement(NBaseClear, {
                  clsPrefix: mergedClsPrefix,
                  show: this.showClearButton,
                  onClear: this.handleClear
                }, {
                  placeholder: () => children2,
                  icon: () => this.$slots["clear-icon"]?.()
                });
              }
            ),
            !this.internalLoadingBeforeSuffix ? children : null,
            this.loading !== void 0 ? /* @__PURE__ */ React.createElement(NBaseSuffix, {
              clsPrefix: mergedClsPrefix,
              loading: this.loading,
              showArrow: false,
              showClear: false,
              style: this.cssVars
            }) : null,
            this.internalLoadingBeforeSuffix ? children : null,
            this.showCount && this.type !== "textarea" ? /* @__PURE__ */ React.createElement(WordCount, null, {
              default: (props) => $slots.count?.(props)
            }) : null,
            this.mergedShowPasswordOn && this.type === "password" ? /* @__PURE__ */ React.createElement("div", {
              class: `${mergedClsPrefix}-input__eye`,
              onMousedown: this.handlePasswordToggleMousedown,
              onClick: this.handlePasswordToggleClick
            }, this.passwordVisible ? resolveSlot($slots["password-visible-icon"], () => [
              /* @__PURE__ */ React.createElement(NBaseIcon, {
                clsPrefix: mergedClsPrefix
              }, { default: () => /* @__PURE__ */ React.createElement(EyeIcon, null) })
            ]) : resolveSlot(
              $slots["password-invisible-icon"],
              () => [
                /* @__PURE__ */ React.createElement(NBaseIcon, {
                  clsPrefix: mergedClsPrefix
                }, { default: () => /* @__PURE__ */ React.createElement(EyeOffIcon, null) })
              ]
            )) : null
          ]) : null;
        })), this.pair ? /* @__PURE__ */ React.createElement("span", {
          class: `${mergedClsPrefix}-input__separator`
        }, resolveSlot($slots.separator, () => [this.separator])) : null, this.pair ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-input-wrapper`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-input__input`
        }, /* @__PURE__ */ React.createElement("input", {
          ref: "inputEl2Ref",
          type: this.type,
          class: `${mergedClsPrefix}-input__input-el`,
          tabindex: this.passivelyActivated && !this.activated ? -1 : void 0,
          placeholder: this.mergedPlaceholder[1],
          disabled: this.mergedDisabled,
          maxlength: this.maxlength,
          minlength: this.minlength,
          value: Array.isArray(this.mergedValue) ? this.mergedValue[1] : void 0,
          readonly: this.readonly,
          style: this.textDecorationStyle[1],
          onBlur: this.handleInputBlur,
          onFocus: (e) => this.handleInputFocus(e, 1),
          onInput: (e) => this.handleInput(e, 1),
          onChange: (e) => this.handleChange(e, 1)
        }), this.showPlaceholder2 ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-input__placeholder`
        }, /* @__PURE__ */ React.createElement("span", null, this.mergedPlaceholder[1])) : null), resolveWrappedSlot($slots.suffix, (children) => {
          return (this.clearable || children) && /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-input__suffix`
          }, [
            this.clearable && /* @__PURE__ */ React.createElement(NBaseClear, {
              clsPrefix: mergedClsPrefix,
              show: this.showClearButton,
              onClear: this.handleClear
            }, {
              icon: () => $slots["clear-icon"]?.(),
              placeholder: () => $slots["clear-icon-placeholder"]?.()
            }),
            children
          ]);
        })) : null, this.mergedBordered ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-input__border`
        }) : null, this.mergedBordered ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-input__state-border`
        }) : null, this.showCount && type === "textarea" ? /* @__PURE__ */ React.createElement(WordCount, null, {
          default: (props) => {
            const { renderCount } = this;
            if (renderCount) {
              return renderCount(props);
            }
            return $slots.count?.(props);
          }
        }) : null);
      }
    });

    var style$1i = cB("input-group", `
  display: inline-flex;
  width: 100%;
  flex-wrap: nowrap;
  vertical-align: bottom;
`, [c$1(">", [cB("input", [c$1("&:not(:last-child)", `
        border-top-right-radius: 0!important;
        border-bottom-right-radius: 0!important;
      `), c$1("&:not(:first-child)", `
        border-top-left-radius: 0!important;
        border-bottom-left-radius: 0!important;
        margin-left: -1px!important;
      `)]), cB("button", [c$1("&:not(:last-child)", `
        border-top-right-radius: 0!important;
        border-bottom-right-radius: 0!important;
      `, [cE("state-border, border", `
          border-top-right-radius: 0!important;
          border-bottom-right-radius: 0!important;
        `)]), c$1("&:not(:first-child)", `
        border-top-left-radius: 0!important;
        border-bottom-left-radius: 0!important;
      `, [cE("state-border, border", `
          border-top-left-radius: 0!important;
          border-bottom-left-radius: 0!important;
        `)])]), c$1("*", [c$1("&:not(:last-child)", `
        border-top-right-radius: 0!important;
        border-bottom-right-radius: 0!important;
      `, [c$1(">", [cB("input", `
            border-top-right-radius: 0!important;
            border-bottom-right-radius: 0!important;
          `), cB("base-selection", [cB("base-selection-label", `
              border-top-right-radius: 0!important;
              border-bottom-right-radius: 0!important;
            `), cB("base-selection-tags", `
              border-top-right-radius: 0!important;
              border-bottom-right-radius: 0!important;
            `), cE("box-shadow, border, state-border", `
              border-top-right-radius: 0!important;
              border-bottom-right-radius: 0!important;
            `)])])]), c$1("&:not(:first-child)", `
        margin-left: -1px!important;
        border-top-left-radius: 0!important;
        border-bottom-left-radius: 0!important;
      `, [c$1(">", [cB("input", `
            border-top-left-radius: 0!important;
            border-bottom-left-radius: 0!important;
          `), cB("base-selection", [cB("base-selection-label", `
              border-top-left-radius: 0!important;
              border-bottom-left-radius: 0!important;
            `), cB("base-selection-tags", `
              border-top-left-radius: 0!important;
              border-bottom-left-radius: 0!important;
            `), cE("box-shadow, border, state-border", `
              border-top-left-radius: 0!important;
              border-bottom-left-radius: 0!important;
            `)])])])])])]);

    const inputGroupProps = {};
    var NInputGroup = vue.defineComponent({
      name: "InputGroup",
      props: inputGroupProps,
      setup(props) {
        const { mergedClsPrefixRef } = useConfig(props);
        useStyle("-input-group", style$1i, mergedClsPrefixRef);
        return {
          mergedClsPrefix: mergedClsPrefixRef
        };
      },
      render() {
        const { mergedClsPrefix } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-input-group`
        }, this.$slots);
      }
    });

    var style$1h = cB("input-group-label", `
  position: relative;
  user-select: none;
  -webkit-user-select: none;
  box-sizing: border-box;
  padding: 0 12px;
  display: inline-block;
  border-radius: var(--n-border-radius);
  background-color: var(--n-group-label-color);
  color: var(--n-group-label-text-color);
  font-size: var(--n-font-size);
  line-height: var(--n-height);
  height: var(--n-height);
  flex-shrink: 0;
  white-space: nowrap;
  transition: 
    color .3s var(--n-bezier),
    background-color .3s var(--n-bezier),
    box-shadow .3s var(--n-bezier);
`, [cE("border", `
    position: absolute;
    left: 0;
    right: 0;
    top: 0;
    bottom: 0;
    border-radius: inherit;
    border: var(--n-group-label-border);
    transition: border-color .3s var(--n-bezier);
  `)]);

    const inputGroupLabelProps = {
      ...useTheme.props,
      size: {
        type: String,
        default: "medium"
      },
      bordered: {
        type: Boolean,
        default: void 0
      }
    };
    var InputGroupLabel = vue.defineComponent({
      name: "InputGroupLabel",
      props: inputGroupLabelProps,
      setup(props) {
        const { mergedBorderedRef, mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Input",
          "-input-group-label",
          style$1h,
          inputLight$1,
          props,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const { size } = props;
          const {
            common: { cubicBezierEaseInOut },
            self: {
              groupLabelColor,
              borderRadius,
              groupLabelTextColor,
              lineHeight,
              groupLabelBorder,
              [createKey("fontSize", size)]: fontSize,
              [createKey("height", size)]: height
            }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-group-label-color": groupLabelColor,
            "--n-group-label-border": groupLabelBorder,
            "--n-border-radius": borderRadius,
            "--n-group-label-text-color": groupLabelTextColor,
            "--n-font-size": fontSize,
            "--n-line-height": lineHeight,
            "--n-height": height
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "input-group-label",
          vue.computed(() => props.size[0]),
          cssVarsRef,
          props
        ) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          mergedBordered: mergedBorderedRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedClsPrefix } = this;
        this.onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          class: [`${mergedClsPrefix}-input-group-label`, this.themeClass],
          style: this.cssVars
        }, this.$slots.default?.(), this.mergedBordered ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-input-group-label__border`
        }) : null);
      }
    });

    function self$12(vars) {
      const {
        boxShadow2
      } = vars;
      return {
        menuBoxShadow: boxShadow2
      };
    }
    const autoCompleteLight = createTheme$1({
      name: "AutoComplete",
      common: commonLight,
      peers: {
        InternalSelectMenu: internalSelectMenuLight$1,
        Input: inputLight$1
      },
      self: self$12
    });
    var autoCompleteLight$1 = autoCompleteLight;

    const autoCompleteDark = {
      name: "AutoComplete",
      common: commonDark,
      peers: {
        InternalSelectMenu: internalSelectMenuDark$1,
        Input: inputDark$1
      },
      self: self$12
    };
    var autoCompleteDark$1 = autoCompleteDark;

    function mapAutoCompleteOptionsToSelectOptions(options) {
      return options.map(convertAutoCompleteOptionToSelectOption);
    }

    function convertAutoCompleteOptionToSelectOption(option) {
      if (typeof option === "string") {
        return {
          label: option,
          value: option
        };
      } else if (option.type === "group") {
        const groupOption = {
          type: "group",
          label: option.label ?? option.name,
          value: option.value ?? option.name,
          key: option.key || option.name,
          children: option.children.map(groupOption2 => convertAutoCompleteOptionToSelectOption(groupOption2))
        };
        return groupOption;
      } else {
        return option;
      }
    }

    var style$1g = c$1([cB("auto-complete", `
    z-index: auto;
    position: relative;
    display: inline-flex;
    width: 100%;
  `), cB("auto-complete-menu", `
    margin: 4px 0;
    box-shadow: var(--n-menu-box-shadow);
  `, [fadeInScaleUpTransition({
      originalTransition: "background-color .3s var(--n-bezier), box-shadow .3s var(--n-bezier)"
    })])]);

    const autoCompleteProps = {
      ...useTheme.props,
      to: useAdjustedTo.propTo,
      menuProps: Object,
      bordered: {
        type: Boolean,
        default: void 0
      },
      clearable: {
        type: Boolean,
        default: void 0
      },
      defaultValue: {
        type: String,
        default: null
      },
      loading: {
        type: Boolean,
        default: void 0
      },
      disabled: {
        type: Boolean,
        default: void 0
      },
      placeholder: String,
      placement: {
        type: String,
        default: "bottom-start"
      },
      value: String,
      blurAfterSelect: Boolean,
      clearAfterSelect: Boolean,
      getShow: Function,
      inputProps: Object,
      renderOption: Function,
      renderLabel: Function,
      size: String,
      options: {
        type: Array,
        default: () => []
      },
      zIndex: Number,
      status: String,
      "onUpdate:value": [Function, Array],
      onUpdateValue: [Function, Array],
      onSelect: [Function, Array],
      onBlur: [Function, Array],
      onFocus: [Function, Array],
      onInput: [Function, Array]
    };
    var AutoComplete = vue.defineComponent({
      name: "AutoComplete",
      props: autoCompleteProps,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.onInput !== void 0) {
              warnOnce(
                "auto-complete",
                "`on-input` is deprecated, please use `on-update:value` instead."
              );
            }
          });
        }
        const {
          mergedBorderedRef,
          namespaceRef,
          mergedClsPrefixRef,
          inlineThemeDisabled
        } = useConfig(props);
        const formItem = useFormItem(props);
        const { mergedSizeRef, mergedDisabledRef, mergedStatusRef } = formItem;
        const triggerElRef = vue.ref(null);
        const menuInstRef = vue.ref(null);
        const uncontrolledValueRef = vue.ref(props.defaultValue);
        const controlledValueRef = vue.toRef(props, "value");
        const mergedValueRef = useMergedState(
          controlledValueRef,
          uncontrolledValueRef
        );
        const canBeActivatedRef = vue.ref(false);
        const isComposingRef = vue.ref(false);
        const themeRef = useTheme(
          "AutoComplete",
          "-auto-complete",
          style$1g,
          autoCompleteLight$1,
          props,
          mergedClsPrefixRef
        );
        const selectOptionsRef = vue.computed(() => {
          return mapAutoCompleteOptionsToSelectOptions(props.options);
        });
        const mergedShowOptionsRef = vue.computed(() => {
          const { getShow } = props;
          if (getShow) {
            return getShow(mergedValueRef.value || "");
          }
          return !!mergedValueRef.value;
        });
        const activeRef = vue.computed(() => {
          return mergedShowOptionsRef.value && canBeActivatedRef.value && !!selectOptionsRef.value.length;
        });
        const treeMateRef = vue.computed(
          () => createTreeMate(
            selectOptionsRef.value,
            createTmOptions("value", "children")
          )
        );
        function doUpdateValue(value) {
          const { "onUpdate:value": _onUpdateValue, onUpdateValue, onInput } = props;
          const { nTriggerFormInput, nTriggerFormChange } = formItem;
          if (onUpdateValue)
            call(onUpdateValue, value);
          if (_onUpdateValue)
            call(_onUpdateValue, value);
          if (onInput)
            call(onInput, value);
          uncontrolledValueRef.value = value;
          nTriggerFormInput();
          nTriggerFormChange();
        }
        function doSelect(value) {
          const { onSelect } = props;
          const { nTriggerFormInput, nTriggerFormChange } = formItem;
          if (onSelect)
            call(onSelect, value);
          nTriggerFormInput();
          nTriggerFormChange();
        }
        function doBlur(e) {
          const { onBlur } = props;
          const { nTriggerFormBlur } = formItem;
          if (onBlur)
            call(onBlur, e);
          nTriggerFormBlur();
        }
        function doFocus(e) {
          const { onFocus } = props;
          const { nTriggerFormFocus } = formItem;
          if (onFocus)
            call(onFocus, e);
          nTriggerFormFocus();
        }
        function handleCompositionStart() {
          isComposingRef.value = true;
        }
        function handleCompositionEnd() {
          window.setTimeout(() => {
            isComposingRef.value = false;
          }, 0);
        }
        function handleKeyDown(e) {
          switch (e.key) {
            case "Enter":
              if (!isComposingRef.value) {
                const pendingOptionTmNode = menuInstRef.value?.getPendingTmNode();
                if (pendingOptionTmNode) {
                  select(pendingOptionTmNode.rawNode);
                  e.preventDefault();
                }
              }
              break;
            case "ArrowDown":
              menuInstRef.value?.next();
              break;
            case "ArrowUp":
              menuInstRef.value?.prev();
              break;
          }
        }
        function select(option) {
          if (option?.value !== void 0) {
            doSelect(option.value);
            if (props.clearAfterSelect) {
              doUpdateValue(null);
            } else if (option.label !== void 0) {
              doUpdateValue(option.label);
            }
            canBeActivatedRef.value = false;
            if (props.blurAfterSelect) {
              blur();
            }
          }
        }
        function handleClear() {
          doUpdateValue(null);
        }
        function handleFocus(e) {
          canBeActivatedRef.value = true;
          doFocus(e);
        }
        function handleBlur(e) {
          canBeActivatedRef.value = false;
          doBlur(e);
        }
        function handleInput(value) {
          canBeActivatedRef.value = true;
          doUpdateValue(value);
        }
        function handleToggle(option) {
          select(option.rawNode);
        }
        function handleClickOutsideMenu(e) {
          if (!triggerElRef.value?.contains(getPreciseEventTarget(e))) {
            canBeActivatedRef.value = false;
          }
        }
        function blur() {
          if (triggerElRef.value?.contains(document.activeElement)) {
            document.activeElement?.blur();
          }
        }
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self: { menuBoxShadow }
          } = themeRef.value;
          return {
            "--n-menu-box-shadow": menuBoxShadow,
            "--n-bezier": cubicBezierEaseInOut
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("auto-complete", void 0, cssVarsRef, props) : void 0;
        const inputInstRef = vue.ref(null);
        const exposedMethods = {
          focus: () => {
            inputInstRef.value?.focus();
          },
          blur: () => {
            inputInstRef.value?.blur();
          }
        };
        return {
          focus: exposedMethods.focus,
          blur: exposedMethods.blur,
          inputInstRef,
          uncontrolledValue: uncontrolledValueRef,
          mergedValue: mergedValueRef,
          isMounted: isMounted(),
          adjustedTo: useAdjustedTo(props),
          menuInstRef,
          triggerElRef,
          treeMate: treeMateRef,
          mergedSize: mergedSizeRef,
          mergedDisabled: mergedDisabledRef,
          active: activeRef,
          mergedStatus: mergedStatusRef,
          handleClear,
          handleFocus,
          handleBlur,
          handleInput,
          handleToggle,
          handleClickOutsideMenu,
          handleCompositionStart,
          handleCompositionEnd,
          handleKeyDown,
          mergedTheme: themeRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender,
          mergedBordered: mergedBorderedRef,
          namespace: namespaceRef,
          mergedClsPrefix: mergedClsPrefixRef
        };
      },
      render() {
        const { mergedClsPrefix } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-auto-complete`,
          ref: "triggerElRef",
          onKeydown: this.handleKeyDown,
          onCompositionstart: this.handleCompositionStart,
          onCompositionend: this.handleCompositionEnd
        }, /* @__PURE__ */ React.createElement(VBinder, null, {
          default: () => [
            /* @__PURE__ */ React.createElement(VTarget, null, {
              default: () => {
                const defaultSlot = this.$slots.default;
                if (defaultSlot) {
                  return getFirstSlotVNode(this.$slots, "default", {
                    handleInput: this.handleInput,
                    handleFocus: this.handleFocus,
                    handleBlur: this.handleBlur,
                    value: this.mergedValue
                  });
                }
                const { mergedTheme } = this;
                return /* @__PURE__ */ React.createElement(NInput, {
                  ref: "inputInstRef",
                  status: this.mergedStatus,
                  theme: mergedTheme.peers.Input,
                  themeOverrides: mergedTheme.peerOverrides.Input,
                  bordered: this.mergedBordered,
                  value: this.mergedValue,
                  placeholder: this.placeholder,
                  size: this.mergedSize,
                  disabled: this.mergedDisabled,
                  clearable: this.clearable,
                  loading: this.loading,
                  inputProps: this.inputProps,
                  onClear: this.handleClear,
                  onFocus: this.handleFocus,
                  onUpdateValue: this.handleInput,
                  onBlur: this.handleBlur
                }, {
                  suffix: () => this.$slots.suffix?.(),
                  prefix: () => this.$slots.prefix?.()
                });
              }
            }),
            /* @__PURE__ */ React.createElement(VFollower, {
              show: this.active,
              to: this.adjustedTo,
              containerClass: this.namespace,
              zIndex: this.zIndex,
              teleportDisabled: this.adjustedTo === useAdjustedTo.tdkey,
              placement: this.placement,
              width: "target"
            }, {
              default: () => /* @__PURE__ */ React.createElement(vue.Transition, {
                name: "fade-in-scale-up-transition",
                appear: this.isMounted
              }, {
                default: () => {
                  this.onRender?.();
                  if (!this.active)
                    return null;
                  const { menuProps } = this;
                  return vue.withDirectives(
                    /* @__PURE__ */ React.createElement(NInternalSelectMenu, {
                      ...menuProps,
                      clsPrefix: mergedClsPrefix,
                      ref: "menuInstRef",
                      theme: this.mergedTheme.peers.InternalSelectMenu,
                      themeOverrides: this.mergedTheme.peerOverrides.InternalSelectMenu,
                      "auto-pending": true,
                      class: [
                        `${mergedClsPrefix}-auto-complete-menu`,
                        this.themeClass,
                        menuProps?.class
                      ],
                      style: [
                        menuProps?.style,
                        this.cssVars
                      ],
                      treeMate: this.treeMate,
                      multiple: false,
                      renderLabel: this.renderLabel,
                      renderOption: this.renderOption,
                      size: "medium",
                      onToggle: this.handleToggle
                    }),
                    [
                      [
                        clickoutside$1,
                        this.handleClickOutsideMenu,
                        void 0,
                        { capture: true }
                      ]
                    ]
                  );
                }
              })
            })
          ]
        }));
      }
    });

    const isImageSupportNativeLazy = false;

    const resolveOptionsAndHash = function () {
      let options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      const {
        root = null
      } = options;
      return {
        hash: `${options.rootMargin || "0px 0px 0px 0px"}-${Array.isArray(options.threshold) ? options.threshold.join(",") : options.threshold ?? "0"}`,
        options: { ...options,
          root: (typeof root === "string" ? document.querySelector(root) : root) || document.documentElement
        }
      };
    };
    const observers = /* @__PURE__ */new WeakMap();
    const unobserveHandleMap = /* @__PURE__ */new WeakMap();
    const shouldStartLoadingRefMap = /* @__PURE__ */new WeakMap();
    const observeIntersection = (el, options, shouldStartLoadingRef) => {
      if (!el) return () => {};
      const resolvedOptionsAndHash = resolveOptionsAndHash(options);
      const {
        root
      } = resolvedOptionsAndHash.options;
      let rootObservers;

      const _rootObservers = observers.get(root);

      if (_rootObservers) {
        rootObservers = _rootObservers;
      } else {
        rootObservers = /* @__PURE__ */new Map();
        observers.set(root, rootObservers);
      }

      let observer;
      let observerAndObservedElements;

      if (rootObservers.has(resolvedOptionsAndHash.hash)) {
        observerAndObservedElements = rootObservers.get(resolvedOptionsAndHash.hash);

        if (!observerAndObservedElements[1].has(el)) {
          observer = observerAndObservedElements[0];
          observerAndObservedElements[1].add(el);
          observer.observe(el);
        }
      } else {
        observer = new IntersectionObserver(entries => {
          entries.forEach(entry => {
            if (entry.isIntersecting) {
              const _unobserve = unobserveHandleMap.get(entry.target);

              const _shouldStartLoadingRef = shouldStartLoadingRefMap.get(entry.target);

              if (_unobserve) _unobserve();

              if (_shouldStartLoadingRef) {
                _shouldStartLoadingRef.value = true;
              }
            }
          });
        }, resolvedOptionsAndHash.options);
        observer.observe(el);
        observerAndObservedElements = [observer, /* @__PURE__ */new Set([el])];
        rootObservers.set(resolvedOptionsAndHash.hash, observerAndObservedElements);
      }

      let unobservered = false;

      const unobserve = () => {
        if (unobservered) return;
        unobserveHandleMap.delete(el);
        shouldStartLoadingRefMap.delete(el);
        unobservered = true;

        if (observerAndObservedElements[1].has(el)) {
          observerAndObservedElements[0].unobserve(el);
          observerAndObservedElements[1].delete(el);
        }

        if (observerAndObservedElements[1].size <= 0) {
          rootObservers.delete(resolvedOptionsAndHash.hash);
        }

        if (!rootObservers.size) {
          observers.delete(root);
        }
      };

      unobserveHandleMap.set(el, unobserve);
      shouldStartLoadingRefMap.set(el, shouldStartLoadingRef);
      return unobserve;
    };

    const self$11 = vars => {
      const {
        borderRadius,
        avatarColor,
        cardColor,
        fontSize,
        heightTiny,
        heightSmall,
        heightMedium,
        heightLarge,
        heightHuge,
        modalColor,
        popoverColor
      } = vars;
      return {
        borderRadius,
        fontSize,
        border: `2px solid ${cardColor}`,
        heightTiny,
        heightSmall,
        heightMedium,
        heightLarge,
        heightHuge,
        color: composite(cardColor, avatarColor),
        colorModal: composite(modalColor, avatarColor),
        colorPopover: composite(popoverColor, avatarColor)
      };
    };
    const avatarLight = {
      name: "Avatar",
      common: commonLight,
      self: self$11
    };
    var avatarLight$1 = avatarLight;

    const avatarDark = {
      name: "Avatar",
      common: commonDark,
      self: self$11
    };
    var avatarDark$1 = avatarDark;

    const avatarGroupInjectionKey = createInjectionKey("n-avatar-group");

    var style$1f = cB("avatar", `
  width: var(--n-merged-size);
  height: var(--n-merged-size);
  color: #FFF;
  font-size: var(--n-font-size);
  display: inline-flex;
  position: relative;
  overflow: hidden;
  text-align: center;
  border: var(--n-border);
  border-radius: var(--n-border-radius);
  --n-merged-color: var(--n-color);
  background-color: var(--n-merged-color);
  transition:
    border-color .3s var(--n-bezier),
    background-color .3s var(--n-bezier),
    color .3s var(--n-bezier);
`, [insideModal(c$1("&", "--n-merged-color: var(--n-color-modal);")), insidePopover(c$1("&", "--n-merged-color: var(--n-color-popover);")), c$1("img", `
    width: 100%;
    height: 100%;
  `), cE("text", `
    white-space: nowrap;
    display: inline-block;
    position: absolute;
    left: 50%;
    top: 50%;
  `), cB("icon", `
    vertical-align: bottom;
    font-size: calc(var(--n-merged-size) - 6px);
  `), cE("text", "line-height: 1.25")]);

    const avatarProps = {
      ...useTheme.props,
      size: [String, Number],
      src: String,
      circle: {
        type: Boolean,
        default: void 0
      },
      objectFit: String,
      round: {
        type: Boolean,
        default: void 0
      },
      bordered: {
        type: Boolean,
        default: void 0
      },
      onError: Function,
      fallbackSrc: String,
      intersectionObserverOptions: Object,
      lazy: Boolean,
      color: String
    };
    var NAvatar = vue.defineComponent({
      name: "Avatar",
      props: avatarProps,
      setup(props) {
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const hasLoadErrorRef = vue.ref(false);
        let memoedTextHtml = null;
        const textRef = vue.ref(null);
        const selfRef = vue.ref(null);
        const fitTextTransform = () => {
          const { value: textEl } = textRef;
          if (textEl) {
            if (memoedTextHtml === null || memoedTextHtml !== textEl.innerHTML) {
              memoedTextHtml = textEl.innerHTML;
              const { value: selfEl } = selfRef;
              if (selfEl) {
                const { offsetWidth: elWidth, offsetHeight: elHeight } = selfEl;
                const { offsetWidth: textWidth, offsetHeight: textHeight } = textEl;
                const radix = 0.9;
                const ratio = Math.min(
                  elWidth / textWidth * radix,
                  elHeight / textHeight * radix,
                  1
                );
                textEl.style.transform = `translateX(-50%) translateY(-50%) scale(${ratio})`;
              }
            }
          }
        };
        const NAvatarGroup = vue.inject(avatarGroupInjectionKey, null);
        const mergedSizeRef = vue.computed(() => {
          const { size } = props;
          if (size)
            return size;
          const { size: avatarGroupSize } = NAvatarGroup || {};
          if (avatarGroupSize)
            return avatarGroupSize;
          return "medium";
        });
        const themeRef = useTheme(
          "Avatar",
          "-avatar",
          style$1f,
          avatarLight$1,
          props,
          mergedClsPrefixRef
        );
        const TagInjection = vue.inject(tagInjectionKey, null);
        const mergedRoundRef = vue.computed(() => {
          if (NAvatarGroup)
            return true;
          const { round, circle } = props;
          if (round !== void 0 || circle !== void 0)
            return round || circle;
          if (TagInjection) {
            return TagInjection.roundRef.value;
          }
          return false;
        });
        const mergedBorderedRef = vue.computed(() => {
          if (NAvatarGroup)
            return true;
          return props.bordered || false;
        });
        const handleError = (e) => {
          if (!shouldStartLoadingRef.value)
            return;
          hasLoadErrorRef.value = true;
          const { onError } = props;
          if (onError) {
            onError(e);
          }
        };
        vue.watch(
          () => props.src,
          () => hasLoadErrorRef.value = false
        );
        const cssVarsRef = vue.computed(() => {
          const size = mergedSizeRef.value;
          const round = mergedRoundRef.value;
          const bordered = mergedBorderedRef.value;
          const { color: propColor } = props;
          const {
            self: {
              borderRadius,
              fontSize,
              color,
              border,
              colorModal,
              colorPopover
            },
            common: { cubicBezierEaseInOut }
          } = themeRef.value;
          let height;
          if (typeof size === "number") {
            height = `${size}px`;
          } else {
            height = themeRef.value.self[createKey("height", size)];
          }
          return {
            "--n-font-size": fontSize,
            "--n-border": bordered ? border : "none",
            "--n-border-radius": round ? "50%" : borderRadius,
            "--n-color": propColor || color,
            "--n-color-modal": propColor || colorModal,
            "--n-color-popover": propColor || colorPopover,
            "--n-bezier": cubicBezierEaseInOut,
            "--n-merged-size": `var(--n-avatar-size-override, ${height})`
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "avatar",
          vue.computed(() => {
            const size = mergedSizeRef.value;
            const round = mergedRoundRef.value;
            const bordered = mergedBorderedRef.value;
            const { color } = props;
            let hash = "";
            if (size) {
              if (typeof size === "number") {
                hash += `a${size}`;
              } else {
                hash += size[0];
              }
            }
            if (round) {
              hash += "b";
            }
            if (bordered) {
              hash += "c";
            }
            if (color) {
              hash += color2Class(color);
            }
            return hash;
          }),
          cssVarsRef,
          props
        ) : void 0;
        const shouldStartLoadingRef = vue.ref(!props.lazy);
        vue.onMounted(() => {
          if (isImageSupportNativeLazy) {
            return;
          }
          let unobserve;
          const stopWatchHandle = vue.watchEffect(() => {
            unobserve?.();
            unobserve = void 0;
            if (props.lazy) {
              unobserve = observeIntersection(
                selfRef.value,
                props.intersectionObserverOptions,
                shouldStartLoadingRef
              );
            }
          });
          vue.onBeforeUnmount(() => {
            stopWatchHandle();
            unobserve?.();
          });
        });
        const loadedRef = vue.ref(!props.lazy);
        return {
          textRef,
          selfRef,
          mergedRoundRef,
          mergedClsPrefix: mergedClsPrefixRef,
          fitTextTransform,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender,
          hasLoadError: hasLoadErrorRef,
          handleError,
          shouldStartLoading: shouldStartLoadingRef,
          loaded: loadedRef,
          mergedOnLoad: (e) => {
            const { onLoad } = props;
            onLoad?.(e);
            loadedRef.value = true;
          }
        };
      },
      render() {
        const {
          $slots,
          src,
          mergedClsPrefix,
          lazy,
          onRender,
          mergedOnLoad,
          shouldStartLoading,
          loaded,
          hasLoadError
        } = this;
        onRender?.();
        let img;
        const placeholderNode = !loaded && !hasLoadError && this.$slots.placeholder?.();
        if (this.hasLoadError) {
          img = /* @__PURE__ */ React.createElement("img", {
            src: this.fallbackSrc,
            style: { objectFit: this.objectFit }
          });
        } else {
          img = resolveWrappedSlot($slots.default, (children) => {
            if (children) {
              return /* @__PURE__ */ React.createElement(VResizeObserver, {
                onResize: this.fitTextTransform
              }, {
                default: () => /* @__PURE__ */ React.createElement("span", {
                  ref: "textRef",
                  class: `${mergedClsPrefix}-avatar__text`
                }, children)
              });
            } else if (src) {
              return vue.h("img", {
                loading: "eager",
                src: shouldStartLoading || loaded ? src : void 0,
                onLoad: mergedOnLoad,
                "data-image-src": src,
                onError: this.handleError,
                style: [
                  { objectFit: this.objectFit },
                  placeholderNode ? {
                    height: "0",
                    width: "0",
                    visibility: "hidden",
                    position: "absolute"
                  } : ""
                ]
              });
            }
          });
        }
        return /* @__PURE__ */ React.createElement("span", {
          ref: "selfRef",
          class: [`${mergedClsPrefix}-avatar`, this.themeClass],
          style: this.cssVars
        }, img, lazy && placeholderNode);
      }
    });

    var style$1e = cB("avatar-group", `
  flex-wrap: nowrap;
  display: inline-flex;
  position: relative;
`, [cNotM("vertical", {
      flexDirection: "row"
    }, [cB("avatar", [c$1("&:not(:first-child)", `
         margin-left: -12px;
      `)])]), cM("vertical", {
      flexDirection: "column"
    }, [cB("avatar", [c$1("&:not(:first-child)", `
         margin-top: -12px;
      `)])])]);

    const avatarGroupDark = {
      name: "AvatarGroup",
      common: commonDark,
      peers: {
        Avatar: avatarDark$1
      }
    };
    var avatarGroupDark$1 = avatarGroupDark;

    const avatarGroupLight = createTheme$1({
      name: "AvatarGroup",
      common: commonLight,
      peers: {
        Avatar: avatarLight$1
      }
    });
    var avatarGroupLight$1 = avatarGroupLight;

    var rtlStyle$n = cB("avatar-group", [cM("rtl", `
    direction: rtl;
  `, [cNotM("vertical", `
      flex-direction: row;
    `, [cB("avatar", [c$1("&:not(:first-child)", `
          margin-right: -12px;
          margin-left: 0;
        `)])])])]);

    const avatarGroupRtl = {
      name: "AvatarGroup",
      style: rtlStyle$n
    };

    const avatarGroupProps = {
      ...useTheme.props,
      max: Number,
      maxStyle: [Object, String],
      options: {
        type: Array,
        default: () => []
      },
      vertical: Boolean,
      size: [String, Number]
    };
    var AvatarGroup = vue.defineComponent({
      name: "AvatarGroup",
      props: avatarGroupProps,
      setup(props) {
        const { mergedClsPrefixRef, mergedRtlRef } = useConfig(props);
        const mergedThemeRef = useTheme(
          "AvatarGroup",
          "-avatar-group",
          style$1e,
          avatarGroupLight$1,
          props,
          mergedClsPrefixRef
        );
        vue.provide(avatarGroupInjectionKey, props);
        const rtlEnabledRef = useRtl(
          "AvatarGroup",
          mergedRtlRef,
          mergedClsPrefixRef
        );
        const restOptionsRef = vue.computed(() => {
          const { max } = props;
          if (max === void 0)
            return void 0;
          const { options } = props;
          if (options.length > max)
            return options.slice(max - 1, options.length);
          return [];
        });
        const displayedOptionsRef = vue.computed(() => {
          const { options, max } = props;
          if (max === void 0)
            return options;
          if (options.length > max)
            return options.slice(0, max - 1);
          if (options.length === max)
            return options.slice(0, max);
          return options;
        });
        return {
          mergedTheme: mergedThemeRef,
          rtlEnabled: rtlEnabledRef,
          mergedClsPrefix: mergedClsPrefixRef,
          restOptions: restOptionsRef,
          displayedOptions: displayedOptionsRef
        };
      },
      render() {
        const {
          mergedClsPrefix,
          displayedOptions,
          restOptions,
          mergedTheme,
          $slots
        } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-avatar-group`,
            this.rtlEnabled && `${mergedClsPrefix}-avatar-group--rtl`,
            this.vertical && `${mergedClsPrefix}-avatar-group--vertical`
          ],
          role: "group"
        }, displayedOptions.map((option) => {
          return $slots.avatar ? $slots.avatar({ option }) : /* @__PURE__ */ React.createElement(NAvatar, {
            src: option.src,
            theme: mergedTheme.peers.Avatar,
            themeOverrides: mergedTheme.peerOverrides.Avatar
          });
        }), restOptions !== void 0 && restOptions.length > 0 && ($slots.rest ? $slots.rest({ options: restOptions, rest: restOptions.length }) : /* @__PURE__ */ React.createElement(NAvatar, {
          style: this.maxStyle,
          theme: mergedTheme.peers.Avatar,
          themeOverrides: mergedTheme.peerOverrides.Avatar
        }, {
          default: () => `+${restOptions.length}`
        })));
      }
    });

    var commonVariables$h = {
      width: "44px",
      height: "44px",
      borderRadius: "22px",
      iconSize: "26px"
    };

    const backTopDark = {
      name: "BackTop",
      common: commonDark,

      self(vars) {
        const {
          popoverColor,
          textColor2,
          primaryColorHover,
          primaryColorPressed
        } = vars;
        return { ...commonVariables$h,
          color: popoverColor,
          textColor: textColor2,
          iconColor: textColor2,
          iconColorHover: primaryColorHover,
          iconColorPressed: primaryColorPressed,
          boxShadow: "0 2px 8px 0px rgba(0, 0, 0, .12)",
          boxShadowHover: "0 2px 12px 0px rgba(0, 0, 0, .18)",
          boxShadowPressed: "0 2px 12px 0px rgba(0, 0, 0, .18)"
        };
      }

    };
    var backTopDark$1 = backTopDark;

    const self$10 = vars => {
      const {
        popoverColor,
        textColor2,
        primaryColorHover,
        primaryColorPressed
      } = vars;
      return { ...commonVariables$h,
        color: popoverColor,
        textColor: textColor2,
        iconColor: textColor2,
        iconColorHover: primaryColorHover,
        iconColorPressed: primaryColorPressed,
        boxShadow: "0 2px 8px 0px rgba(0, 0, 0, .12)",
        boxShadowHover: "0 2px 12px 0px rgba(0, 0, 0, .18)",
        boxShadowPressed: "0 2px 12px 0px rgba(0, 0, 0, .18)"
      };
    };

    const backTopLight = {
      name: "BackTop",
      common: commonLight,
      self: self$10
    };
    var backTopLight$1 = backTopLight;

    var BackTopIcon = /* @__PURE__ */ React.createElement("svg", {
      viewBox: "0 0 24 24",
      version: "1.1",
      xmlns: "http://www.w3.org/2000/svg",
      xlinkHref: "http://www.w3.org/1999/xlink"
    }, /* @__PURE__ */ React.createElement("g", {
      stroke: "none",
      "stroke-width": "1",
      "fill-rule": "evenodd"
    }, /* @__PURE__ */ React.createElement("g", {
      transform: "translate(-139.000000, -4423.000000)",
      "fill-rule": "nonzero"
    }, /* @__PURE__ */ React.createElement("g", {
      transform: "translate(120.000000, 4285.000000)"
    }, /* @__PURE__ */ React.createElement("g", {
      transform: "translate(7.000000, 126.000000)"
    }, /* @__PURE__ */ React.createElement("g", {
      transform: "translate(24.000000, 24.000000) scale(1, -1) translate(-24.000000, -24.000000) translate(12.000000, 12.000000)"
    }, /* @__PURE__ */ React.createElement("g", {
      transform: "translate(4.000000, 2.000000)"
    }, /* @__PURE__ */ React.createElement("path", {
      d: "M8,0 C8.51283584,0 8.93550716,0.38604019 8.99327227,0.883378875 L9,1 L9,10.584 L12.2928932,7.29289322 C12.6834175,6.90236893 13.3165825,6.90236893 13.7071068,7.29289322 C14.0675907,7.65337718 14.0953203,8.22060824 13.7902954,8.61289944 L13.7071068,8.70710678 L8.70710678,13.7071068 L8.62544899,13.7803112 L8.618,13.784 L8.59530661,13.8036654 L8.4840621,13.8753288 L8.37133602,13.9287745 L8.22929083,13.9735893 L8.14346259,13.9897165 L8.03324678,13.9994506 L7.9137692,13.9962979 L7.77070917,13.9735893 L7.6583843,13.9401293 L7.57677845,13.9063266 L7.47929125,13.8540045 L7.4048407,13.8036865 L7.38131006,13.7856883 C7.35030318,13.7612383 7.32077858,13.7349921 7.29289322,13.7071068 L2.29289322,8.70710678 L2.20970461,8.61289944 C1.90467972,8.22060824 1.93240926,7.65337718 2.29289322,7.29289322 C2.65337718,6.93240926 3.22060824,6.90467972 3.61289944,7.20970461 L3.70710678,7.29289322 L7,10.585 L7,1 L7.00672773,0.883378875 C7.06449284,0.38604019 7.48716416,0 8,0 Z"
    }), /* @__PURE__ */ React.createElement("path", {
      d: "M14.9333333,15.9994506 C15.5224371,15.9994506 16,16.4471659 16,16.9994506 C16,17.5122865 15.5882238,17.9349578 15.0577292,17.9927229 L14.9333333,17.9994506 L1.06666667,17.9994506 C0.477562934,17.9994506 0,17.5517354 0,16.9994506 C0,16.4866148 0.411776203,16.0639435 0.9422708,16.0061783 L1.06666667,15.9994506 L14.9333333,15.9994506 Z"
    }))))))));

    var style$1d = cB("back-top", `
  position: fixed;
  right: 40px;
  bottom: 40px;
  cursor: pointer;
  display: flex;
  align-items: center;
  justify-content: center;
  color: var(--n-text-color);
  transition:
    color .3s var(--n-bezier),
    box-shadow .3s var(--n-bezier),
    background-color .3s var(--n-bezier);
  border-radius: var(--n-border-radius);
  height: var(--n-height);
  min-width: var(--n-width);
  box-shadow: var(--n-box-shadow);
  background-color: var(--n-color);
`, [fadeInScaleUpTransition(), cM("transition-disabled", {
      transition: "none !important"
    }), cB("base-icon", `
    font-size: var(--n-icon-size);
    color: var(--n-icon-color);
    transition: color .3s var(--n-bezier);
  `), c$1("svg", {
      pointerEvents: "none"
    }), c$1("&:hover", {
      boxShadow: "var(--n-box-shadow-hover)"
    }, [cB("base-icon", {
      color: "var(--n-icon-color-hover)"
    })]), c$1("&:active", {
      boxShadow: "var(--n-box-shadow-pressed)"
    }, [cB("base-icon", {
      color: "var(--n-icon-color-pressed)"
    })])]);

    const backTopProps = {
      ...useTheme.props,
      show: {
        type: Boolean,
        default: void 0
      },
      right: {
        type: [Number, String],
        default: 40
      },
      bottom: {
        type: [Number, String],
        default: 40
      },
      to: {
        type: [String, Object],
        default: "body"
      },
      visibilityHeight: {
        type: Number,
        default: 180
      },
      listenTo: [String, Object, Function],
      "onUpdate:show": {
        type: Function,
        default: () => {
        }
      },
      target: Function,
      onShow: Function,
      onHide: Function
    };
    var BackTop = vue.defineComponent({
      name: "BackTop",
      inheritAttrs: false,
      props: backTopProps,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.target !== void 0) {
              warnOnce(
                "back-top",
                "`target` is deprecated, please use `listen-to` instead."
              );
            }
            if (props.onShow !== void 0) {
              warnOnce(
                "back-top",
                "`on-show` is deprecated, please use `on-update:show` instead."
              );
            }
            if (props.onHide !== void 0) {
              warnOnce(
                "back-top",
                "`on-hide` is deprecated, please use `on-update:show` instead."
              );
            }
          });
        }
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const scrollTopRef = vue.ref(null);
        const uncontrolledShowRef = vue.ref(false);
        vue.watchEffect(() => {
          const { value: scrollTop } = scrollTopRef;
          if (scrollTop === null) {
            uncontrolledShowRef.value = false;
            return;
          }
          uncontrolledShowRef.value = scrollTop >= props.visibilityHeight;
        });
        const DomInfoReadyRef = vue.ref(false);
        vue.watch(uncontrolledShowRef, (value) => {
          if (DomInfoReadyRef.value) {
            props["onUpdate:show"]?.(value);
          }
        });
        const controlledShowRef = vue.toRef(props, "show");
        const mergedShowRef = useMergedState(controlledShowRef, uncontrolledShowRef);
        const transitionDisabledRef = vue.ref(true);
        const placeholderRef = vue.ref(null);
        const styleRef = vue.computed(
          () => {
            return {
              right: `calc(${formatLength(props.right)} + ${lockHtmlScrollRightCompensationRef.value})`,
              bottom: formatLength(props.bottom)
            };
          }
        );
        let scrollElement;
        let scrollListenerRegistered;
        vue.watch(mergedShowRef, (value) => {
          if (DomInfoReadyRef.value) {
            if (value) {
              props.onShow?.();
            }
            props.onHide?.();
          }
        });
        const themeRef = useTheme(
          "BackTop",
          "-back-top",
          style$1d,
          backTopLight$1,
          props,
          mergedClsPrefixRef
        );
        function init() {
          if (scrollListenerRegistered)
            return;
          scrollListenerRegistered = true;
          const scrollEl = props.target?.() || unwrapElement(props.listenTo) || getScrollParent$1(placeholderRef.value);
          if (!scrollEl) {
            {
              warn$2(
                "back-top",
                "Container of back-top element is not found. This could be a bug of naive-ui."
              );
            }
            return;
          }
          scrollElement = scrollEl === document.documentElement ? document : scrollEl;
          const { to } = props;
          const target = typeof to === "string" ? document.querySelector(to) : to;
          if (!target) {
            warn$2("back-top", "Target is not found.");
          }
          scrollElement.addEventListener("scroll", handleScroll);
          handleScroll();
        }
        function handleClick() {
          (isDocument(scrollElement) ? document.documentElement : scrollElement).scrollTo({
            top: 0,
            behavior: "smooth"
          });
        }
        function handleScroll() {
          scrollTopRef.value = (isDocument(scrollElement) ? document.documentElement : scrollElement).scrollTop;
          if (!DomInfoReadyRef.value) {
            void vue.nextTick(() => {
              DomInfoReadyRef.value = true;
            });
          }
        }
        function handleAfterEnter() {
          transitionDisabledRef.value = false;
        }
        vue.onMounted(() => {
          init();
          transitionDisabledRef.value = mergedShowRef.value;
        });
        vue.onBeforeUnmount(() => {
          if (scrollElement) {
            scrollElement.removeEventListener("scroll", handleScroll);
          }
        });
        const cssVarsRef = vue.computed(() => {
          const {
            self: {
              color,
              boxShadow,
              boxShadowHover,
              boxShadowPressed,
              iconColor,
              iconColorHover,
              iconColorPressed,
              width,
              height,
              iconSize,
              borderRadius,
              textColor
            },
            common: { cubicBezierEaseInOut }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-border-radius": borderRadius,
            "--n-height": height,
            "--n-width": width,
            "--n-box-shadow": boxShadow,
            "--n-box-shadow-hover": boxShadowHover,
            "--n-box-shadow-pressed": boxShadowPressed,
            "--n-color": color,
            "--n-icon-size": iconSize,
            "--n-icon-color": iconColor,
            "--n-icon-color-hover": iconColorHover,
            "--n-icon-color-pressed": iconColorPressed,
            "--n-text-color": textColor
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("back-top", void 0, cssVarsRef, props) : void 0;
        return {
          placeholderRef,
          style: styleRef,
          mergedShow: mergedShowRef,
          isMounted: isMounted(),
          scrollElement: vue.ref(null),
          scrollTop: scrollTopRef,
          DomInfoReady: DomInfoReadyRef,
          transitionDisabled: transitionDisabledRef,
          mergedClsPrefix: mergedClsPrefixRef,
          handleAfterEnter,
          handleScroll,
          handleClick,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedClsPrefix } = this;
        return /* @__PURE__ */ React.createElement("div", {
          ref: "placeholderRef",
          class: `${mergedClsPrefix}-back-top-placeholder`,
          style: "display: none",
          "aria-hidden": true
        }, /* @__PURE__ */ React.createElement(LazyTeleport, {
          to: this.to,
          show: this.mergedShow
        }, {
          default: () => /* @__PURE__ */ React.createElement(vue.Transition, {
            name: "fade-in-scale-up-transition",
            appear: this.isMounted,
            onAfterEnter: this.handleAfterEnter
          }, {
            default: () => {
              this.onRender?.();
              return this.mergedShow ? vue.h(
                "div",
                vue.mergeProps(this.$attrs, {
                  class: [
                    `${mergedClsPrefix}-back-top`,
                    this.themeClass,
                    this.transitionDisabled && `${mergedClsPrefix}-back-top--transition-disabled`
                  ],
                  style: [this.style, this.cssVars],
                  onClick: this.handleClick
                }),
                resolveSlot(this.$slots.default, () => [
                  /* @__PURE__ */ React.createElement(NBaseIcon, {
                    clsPrefix: mergedClsPrefix
                  }, { default: () => BackTopIcon })
                ])
              ) : null;
            }
          })
        }));
      }
    });

    const badgeDark = {
      name: "Badge",
      common: commonDark,

      self(vars) {
        const {
          errorColorSuppl,
          infoColorSuppl,
          successColorSuppl,
          warningColorSuppl,
          fontFamily
        } = vars;
        return {
          color: errorColorSuppl,
          colorInfo: infoColorSuppl,
          colorSuccess: successColorSuppl,
          colorError: errorColorSuppl,
          colorWarning: warningColorSuppl,
          fontSize: "12px",
          fontFamily
        };
      }

    };
    var badgeDark$1 = badgeDark;

    const self$$ = vars => {
      const {
        errorColor,
        infoColor,
        successColor,
        warningColor,
        fontFamily
      } = vars;
      return {
        color: errorColor,
        colorInfo: infoColor,
        colorSuccess: successColor,
        colorError: errorColor,
        colorWarning: warningColor,
        fontSize: "12px",
        fontFamily
      };
    };

    const badgeLight = {
      name: "Badge",
      common: commonLight,
      self: self$$
    };
    var badgeLight$1 = badgeLight;

    var rtlStyle$m = cB("badge", [cM("rtl", `
    direction: rtl;
  `, [cB("badge-sup", `
      right: 100%;
      left: unset;
      transform: translateX(50%);
      direction: initial;
    `)])]);

    const badgeRtl = {
      name: "Badge",
      style: rtlStyle$m
    };

    var style$1c = c$1([c$1("@keyframes badge-wave-spread", {
      from: {
        boxShadow: "0 0 0.5px 0px var(--n-ripple-color)",
        opacity: 0.6
      },
      to: {
        boxShadow: "0 0 0.5px 4.5px var(--n-ripple-color)",
        opacity: 0
      }
    }), cB("badge", `
    display: inline-flex;
    position: relative;
    vertical-align: middle;
    color: var(--n-color);
    font-family: var(--n-font-family);
  `, [cM("as-is", [cB("badge-sup", {
      position: "static",
      transform: "translateX(0)"
    }, [fadeInScaleUpTransition({
      transformOrigin: "left bottom",
      originalTransform: "translateX(0)"
    })])]), cM("dot", [cB("badge-sup", `
        height: 8px;
        width: 8px;
        padding: 0;
        min-width: 8px;
        left: 100%;
        bottom: calc(100% - 4px);
      `, [c$1("::before", "border-radius: 4px;")])]), cB("badge-sup", `
      background: var(--n-color);
      transition:
        background-color .3s var(--n-bezier),
        color .3s var(--n-bezier);
      color: #FFF;
      position: absolute;
      height: 18px;
      line-height: 18px;
      border-radius: 9px;
      padding: 0 6px;
      text-align: center;
      font-size: var(--n-font-size);
      transform: translateX(-50%);
      left: 100%;
      bottom: calc(100% - 9px);
      font-variant-numeric: tabular-nums;
      z-index: 1;
      display: flex;
      align-items: center;
    `, [fadeInScaleUpTransition({
      transformOrigin: "left bottom",
      originalTransform: "translateX(-50%)"
    }), cB("base-wave", {
      zIndex: 1,
      animationDuration: "2s",
      animationIterationCount: "infinite",
      animationDelay: "1s",
      animationTimingFunction: "var(--n-ripple-bezier)",
      animationName: "badge-wave-spread"
    }), c$1("&::before", `
        opacity: 0;
        transform: scale(1);
        border-radius: 9px;
        content: "";
        position: absolute;
        left: 0;
        right: 0;
        top: 0;
        bottom: 0;
      `)])])]);

    const badgeProps = {
      ...useTheme.props,
      value: [String, Number],
      max: Number,
      dot: Boolean,
      type: {
        type: String,
        default: "default"
      },
      show: {
        type: Boolean,
        default: true
      },
      showZero: Boolean,
      processing: Boolean,
      color: String
    };
    var Badge = vue.defineComponent({
      name: "Badge",
      props: badgeProps,
      setup(props, { slots }) {
        const { mergedClsPrefixRef, inlineThemeDisabled, mergedRtlRef } = useConfig(props);
        const themeRef = useTheme(
          "Badge",
          "-badge",
          style$1c,
          badgeLight$1,
          props,
          mergedClsPrefixRef
        );
        const appearedRef = vue.ref(false);
        const handleAfterEnter = () => {
          appearedRef.value = true;
        };
        const handleAfterLeave = () => {
          appearedRef.value = false;
        };
        const showBadgeRef = vue.computed(() => {
          return props.show && (props.dot || props.value !== void 0 && !(!props.showZero && props.value <= 0) || !isSlotEmpty(slots.value));
        });
        vue.onMounted(() => {
          if (showBadgeRef.value)
            appearedRef.value = true;
        });
        const rtlEnabledRef = useRtl("Badge", mergedRtlRef, mergedClsPrefixRef);
        const cssVarsRef = vue.computed(() => {
          const { type, color: propColor } = props;
          const {
            common: { cubicBezierEaseInOut, cubicBezierEaseOut },
            self: { [createKey("color", type)]: color, fontFamily, fontSize }
          } = themeRef.value;
          return {
            "--n-font-size": fontSize,
            "--n-font-family": fontFamily,
            "--n-color": propColor || color,
            "--n-ripple-color": propColor || color,
            "--n-bezier": cubicBezierEaseInOut,
            "--n-ripple-bezier": cubicBezierEaseOut
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "badge",
          vue.computed(() => {
            let hash = "";
            const { type, color } = props;
            if (type) {
              hash += type[0];
            }
            if (color) {
              hash += color2Class(color);
            }
            return hash;
          }),
          cssVarsRef,
          props
        ) : void 0;
        return {
          rtlEnabled: rtlEnabledRef,
          mergedClsPrefix: mergedClsPrefixRef,
          appeared: appearedRef,
          showBadge: showBadgeRef,
          handleAfterEnter,
          handleAfterLeave,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedClsPrefix, onRender, themeClass, $slots } = this;
        onRender?.();
        const children = $slots.default?.();
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-badge`,
            this.rtlEnabled && `${mergedClsPrefix}-badge--rtl`,
            themeClass,
            {
              [`${mergedClsPrefix}-badge--dot`]: this.dot,
              [`${mergedClsPrefix}-badge--as-is`]: !children
            }
          ],
          style: this.cssVars
        }, children, /* @__PURE__ */ React.createElement(vue.Transition, {
          name: "fade-in-scale-up-transition",
          onAfterEnter: this.handleAfterEnter,
          onAfterLeave: this.handleAfterLeave
        }, {
          default: () => this.showBadge ? /* @__PURE__ */ React.createElement("sup", {
            class: `${mergedClsPrefix}-badge-sup`,
            title: getTitleAttribute(this.value)
          }, resolveSlot($slots.value, () => [
            !this.dot ? /* @__PURE__ */ React.createElement(NBaseSlotMachine, {
              clsPrefix: mergedClsPrefix,
              appeared: this.appeared,
              max: this.max,
              value: this.value
            }) : null
          ]), this.processing ? /* @__PURE__ */ React.createElement(NBaseWave, {
            clsPrefix: mergedClsPrefix
          }) : null) : null
        }));
      }
    });

    var commonVariables$g = {
      fontWeightActive: "400"
    };

    const self$_ = vars => {
      const {
        fontSize,
        textColor3,
        textColor2,
        borderRadius,
        buttonColor2Hover,
        buttonColor2Pressed
      } = vars;
      return { ...commonVariables$g,
        fontSize,
        itemLineHeight: "1.25",
        itemTextColor: textColor3,
        itemTextColorHover: textColor2,
        itemTextColorPressed: textColor2,
        itemTextColorActive: textColor2,
        itemBorderRadius: borderRadius,
        itemColorHover: buttonColor2Hover,
        itemColorPressed: buttonColor2Pressed,
        separatorColor: textColor3
      };
    };
    const breadcrumbLight = {
      name: "Breadcrumb",
      common: commonLight,
      self: self$_
    };
    var breadcrumbLight$1 = breadcrumbLight;

    const breadcrumbDark = {
      name: "Breadcrumb",
      common: commonDark,
      self: self$_
    };
    var breadcrumbDark$1 = breadcrumbDark;

    var style$1b = cB("breadcrumb", `
  white-space: nowrap;
  cursor: default;
  line-height: var(--n-item-line-height);
`, [c$1("ul", `
    list-style: none;
    padding: 0;
    margin: 0;
  `), c$1("a", `
    color: inherit;
    text-decoration: inherit;
  `), cB("breadcrumb-item", `
    font-size: var(--n-font-size);
    transition: color .3s var(--n-bezier);
    display: inline-flex;
    align-items: center;
  `, [cB("icon", `
      font-size: 18px;
      vertical-align: -.2em;
      transition: color .3s var(--n-bezier);
      color: var(--n-item-text-color);
    `), c$1("&:not(:last-child)", [cM("clickable", [cE("link", `
          cursor: pointer;
        `, [c$1("&:hover", `
            background-color: var(--n-item-color-hover);
          `), c$1("&:active", `
            background-color: var(--n-item-color-pressed);  
          `)])])]), cE("link", `
      padding: 4px;
      border-radius: var(--n-item-border-radius);
      transition:
        background-color .3s var(--n-bezier),
        color .3s var(--n-bezier);
      color: var(--n-item-text-color);
      position: relative;
    `, [c$1("&:hover", `
        color: var(--n-item-text-color-hover);
      `, [cB("icon", `
          color: var(--n-item-text-color-hover);
        `)]), c$1("&:active", `
        color: var(--n-item-text-color-pressed);
      `, [cB("icon", `
          color: var(--n-item-text-color-pressed);
        `)])]), cE("separator", `
      margin: 0 8px;
      color: var(--n-separator-color);
      transition: color .3s var(--n-bezier);
      user-select: none;
      -webkit-user-select: none;
    `), c$1("&:last-child", [cE("link", `
        font-weight: var(--n-font-weight-active);
        cursor: unset;
        color: var(--n-item-text-color-active);
      `, [cB("icon", `
          color: var(--n-item-text-color-active);
        `)]), cE("separator", `
        display: none;
      `)])])]);

    const breadcrumbInjectionKey = createInjectionKey("n-breadcrumb");
    const breadcrumbProps = {
      ...useTheme.props,
      separator: {
        type: String,
        default: "/"
      }
    };
    var Breadcrumb = vue.defineComponent({
      name: "Breadcrumb",
      props: breadcrumbProps,
      setup(props) {
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Breadcrumb",
          "-breadcrumb",
          style$1b,
          breadcrumbLight$1,
          props,
          mergedClsPrefixRef
        );
        vue.provide(breadcrumbInjectionKey, {
          separatorRef: vue.toRef(props, "separator"),
          mergedClsPrefixRef
        });
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self: {
              separatorColor,
              itemTextColor,
              itemTextColorHover,
              itemTextColorPressed,
              itemTextColorActive,
              fontSize,
              fontWeightActive,
              itemBorderRadius,
              itemColorHover,
              itemColorPressed,
              itemLineHeight
            }
          } = themeRef.value;
          return {
            "--n-font-size": fontSize,
            "--n-bezier": cubicBezierEaseInOut,
            "--n-item-text-color": itemTextColor,
            "--n-item-text-color-hover": itemTextColorHover,
            "--n-item-text-color-pressed": itemTextColorPressed,
            "--n-item-text-color-active": itemTextColorActive,
            "--n-separator-color": separatorColor,
            "--n-item-color-hover": itemColorHover,
            "--n-item-color-pressed": itemColorPressed,
            "--n-item-border-radius": itemBorderRadius,
            "--n-font-weight-active": fontWeightActive,
            "--n-item-line-height": itemLineHeight
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("breadcrumb", void 0, cssVarsRef, props) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        this.onRender?.();
        return /* @__PURE__ */ React.createElement("nav", {
          class: [`${this.mergedClsPrefix}-breadcrumb`, this.themeClass],
          style: this.cssVars,
          "aria-label": "Breadcrumb"
        }, /* @__PURE__ */ React.createElement("ul", null, this.$slots));
      }
    });

    const defaultWindow = isBrowser$2 ? window : null;
    const useBrowserLocation = function () {
      let customWindow = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultWindow;

      const getWindowLocation = () => {
        const {
          hash,
          host,
          hostname,
          href,
          origin,
          pathname,
          port,
          protocol,
          search
        } = (customWindow === null || customWindow === void 0 ? void 0 : customWindow.location) || {};
        return {
          hash,
          host,
          hostname,
          href,
          origin,
          pathname,
          port,
          protocol,
          search
        };
      };

      const updateLocation = () => {
        locationState.value = getWindowLocation();
      };

      const locationState = vue.ref(getWindowLocation());
      vue.onMounted(() => {
        if (customWindow) {
          customWindow.addEventListener("popstate", updateLocation);
          customWindow.addEventListener("hashchange", updateLocation);
        }
      });
      vue.onUnmounted(() => {
        if (customWindow) {
          customWindow.removeEventListener("popstate", updateLocation);
          customWindow.removeEventListener("hashchange", updateLocation);
        }
      });
      return locationState;
    };

    const breadcrumbItemProps = {
      separator: String,
      href: String,
      clickable: {
        type: Boolean,
        default: true
      },
      onClick: Function
    };
    var BreadcrumbItem = vue.defineComponent({
      name: "BreadcrumbItem",
      props: breadcrumbItemProps,
      setup(props, { slots }) {
        const NBreadcrumb = vue.inject(breadcrumbInjectionKey, null);
        if (!NBreadcrumb) {
          {
            warn$2(
              "breadcrumb",
              "`n-breadcrumb-item` must be placed inside `n-breadcrumb`."
            );
          }
          return () => null;
        }
        const { separatorRef, mergedClsPrefixRef } = NBreadcrumb;
        const browserLocationRef = useBrowserLocation();
        const htmlTagRef = vue.computed(() => props.href ? "a" : "span");
        const ariaCurrentRef = vue.computed(
          () => browserLocationRef.value.href === props.href ? "location" : null
        );
        return () => {
          const { value: mergedClsPrefix } = mergedClsPrefixRef;
          return /* @__PURE__ */ React.createElement("li", {
            class: [
              `${mergedClsPrefix}-breadcrumb-item`,
              props.clickable && `${mergedClsPrefix}-breadcrumb-item--clickable`
            ]
          }, vue.h(
            htmlTagRef.value,
            {
              class: `${mergedClsPrefix}-breadcrumb-item__link`,
              "aria-current": ariaCurrentRef.value,
              href: props.href,
              onClick: props.onClick
            },
            slots
          ), /* @__PURE__ */ React.createElement("span", {
            class: `${mergedClsPrefix}-breadcrumb-item__separator`,
            "aria-hidden": "true"
          }, resolveSlot(slots.separator, () => [
            props.separator ?? separatorRef.value
          ])));
        };
      }
    });

    function createHoverColor(rgb) {
      return composite(rgb, [255, 255, 255, 0.16]);
    }
    function createPressedColor(rgb) {
      return composite(rgb, [0, 0, 0, 0.12]);
    }

    const buttonGroupInjectionKey = createInjectionKey("n-button-group");

    var commonVariables$f = {
      paddingTiny: "0 6px",
      paddingSmall: "0 10px",
      paddingMedium: "0 14px",
      paddingLarge: "0 18px",
      paddingRoundTiny: "0 10px",
      paddingRoundSmall: "0 14px",
      paddingRoundMedium: "0 18px",
      paddingRoundLarge: "0 22px",
      iconMarginTiny: "6px",
      iconMarginSmall: "6px",
      iconMarginMedium: "6px",
      iconMarginLarge: "6px",
      iconSizeTiny: "14px",
      iconSizeSmall: "18px",
      iconSizeMedium: "18px",
      iconSizeLarge: "20px",
      rippleDuration: ".6s"
    };

    const self$Z = vars => {
      const {
        heightTiny,
        heightSmall,
        heightMedium,
        heightLarge,
        borderRadius,
        fontSizeTiny,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge,
        opacityDisabled,
        textColor2,
        textColor3,
        primaryColorHover,
        primaryColorPressed,
        borderColor,
        primaryColor,
        baseColor,
        infoColor,
        infoColorHover,
        infoColorPressed,
        successColor,
        successColorHover,
        successColorPressed,
        warningColor,
        warningColorHover,
        warningColorPressed,
        errorColor,
        errorColorHover,
        errorColorPressed,
        fontWeight,
        buttonColor2,
        buttonColor2Hover,
        buttonColor2Pressed,
        fontWeightStrong
      } = vars;
      return { ...commonVariables$f,
        heightTiny,
        heightSmall,
        heightMedium,
        heightLarge,
        borderRadiusTiny: borderRadius,
        borderRadiusSmall: borderRadius,
        borderRadiusMedium: borderRadius,
        borderRadiusLarge: borderRadius,
        fontSizeTiny,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge,
        opacityDisabled,
        colorOpacitySecondary: "0.16",
        colorOpacitySecondaryHover: "0.22",
        colorOpacitySecondaryPressed: "0.28",
        colorSecondary: buttonColor2,
        colorSecondaryHover: buttonColor2Hover,
        colorSecondaryPressed: buttonColor2Pressed,
        colorTertiary: buttonColor2,
        colorTertiaryHover: buttonColor2Hover,
        colorTertiaryPressed: buttonColor2Pressed,
        colorQuaternary: "#0000",
        colorQuaternaryHover: buttonColor2Hover,
        colorQuaternaryPressed: buttonColor2Pressed,
        color: "#0000",
        colorHover: "#0000",
        colorPressed: "#0000",
        colorFocus: "#0000",
        colorDisabled: "#0000",
        textColor: textColor2,
        textColorTertiary: textColor3,
        textColorHover: primaryColorHover,
        textColorPressed: primaryColorPressed,
        textColorFocus: primaryColorHover,
        textColorDisabled: textColor2,
        textColorText: textColor2,
        textColorTextHover: primaryColorHover,
        textColorTextPressed: primaryColorPressed,
        textColorTextFocus: primaryColorHover,
        textColorTextDisabled: textColor2,
        textColorGhost: textColor2,
        textColorGhostHover: primaryColorHover,
        textColorGhostPressed: primaryColorPressed,
        textColorGhostFocus: primaryColorHover,
        textColorGhostDisabled: textColor2,
        border: `1px solid ${borderColor}`,
        borderHover: `1px solid ${primaryColorHover}`,
        borderPressed: `1px solid ${primaryColorPressed}`,
        borderFocus: `1px solid ${primaryColorHover}`,
        borderDisabled: `1px solid ${borderColor}`,
        rippleColor: primaryColor,
        colorPrimary: primaryColor,
        colorHoverPrimary: primaryColorHover,
        colorPressedPrimary: primaryColorPressed,
        colorFocusPrimary: primaryColorHover,
        colorDisabledPrimary: primaryColor,
        textColorPrimary: baseColor,
        textColorHoverPrimary: baseColor,
        textColorPressedPrimary: baseColor,
        textColorFocusPrimary: baseColor,
        textColorDisabledPrimary: baseColor,
        textColorTextPrimary: primaryColor,
        textColorTextHoverPrimary: primaryColorHover,
        textColorTextPressedPrimary: primaryColorPressed,
        textColorTextFocusPrimary: primaryColorHover,
        textColorTextDisabledPrimary: textColor2,
        textColorGhostPrimary: primaryColor,
        textColorGhostHoverPrimary: primaryColorHover,
        textColorGhostPressedPrimary: primaryColorPressed,
        textColorGhostFocusPrimary: primaryColorHover,
        textColorGhostDisabledPrimary: primaryColor,
        borderPrimary: `1px solid ${primaryColor}`,
        borderHoverPrimary: `1px solid ${primaryColorHover}`,
        borderPressedPrimary: `1px solid ${primaryColorPressed}`,
        borderFocusPrimary: `1px solid ${primaryColorHover}`,
        borderDisabledPrimary: `1px solid ${primaryColor}`,
        rippleColorPrimary: primaryColor,
        colorInfo: infoColor,
        colorHoverInfo: infoColorHover,
        colorPressedInfo: infoColorPressed,
        colorFocusInfo: infoColorHover,
        colorDisabledInfo: infoColor,
        textColorInfo: baseColor,
        textColorHoverInfo: baseColor,
        textColorPressedInfo: baseColor,
        textColorFocusInfo: baseColor,
        textColorDisabledInfo: baseColor,
        textColorTextInfo: infoColor,
        textColorTextHoverInfo: infoColorHover,
        textColorTextPressedInfo: infoColorPressed,
        textColorTextFocusInfo: infoColorHover,
        textColorTextDisabledInfo: textColor2,
        textColorGhostInfo: infoColor,
        textColorGhostHoverInfo: infoColorHover,
        textColorGhostPressedInfo: infoColorPressed,
        textColorGhostFocusInfo: infoColorHover,
        textColorGhostDisabledInfo: infoColor,
        borderInfo: `1px solid ${infoColor}`,
        borderHoverInfo: `1px solid ${infoColorHover}`,
        borderPressedInfo: `1px solid ${infoColorPressed}`,
        borderFocusInfo: `1px solid ${infoColorHover}`,
        borderDisabledInfo: `1px solid ${infoColor}`,
        rippleColorInfo: infoColor,
        colorSuccess: successColor,
        colorHoverSuccess: successColorHover,
        colorPressedSuccess: successColorPressed,
        colorFocusSuccess: successColorHover,
        colorDisabledSuccess: successColor,
        textColorSuccess: baseColor,
        textColorHoverSuccess: baseColor,
        textColorPressedSuccess: baseColor,
        textColorFocusSuccess: baseColor,
        textColorDisabledSuccess: baseColor,
        textColorTextSuccess: successColor,
        textColorTextHoverSuccess: successColorHover,
        textColorTextPressedSuccess: successColorPressed,
        textColorTextFocusSuccess: successColorHover,
        textColorTextDisabledSuccess: textColor2,
        textColorGhostSuccess: successColor,
        textColorGhostHoverSuccess: successColorHover,
        textColorGhostPressedSuccess: successColorPressed,
        textColorGhostFocusSuccess: successColorHover,
        textColorGhostDisabledSuccess: successColor,
        borderSuccess: `1px solid ${successColor}`,
        borderHoverSuccess: `1px solid ${successColorHover}`,
        borderPressedSuccess: `1px solid ${successColorPressed}`,
        borderFocusSuccess: `1px solid ${successColorHover}`,
        borderDisabledSuccess: `1px solid ${successColor}`,
        rippleColorSuccess: successColor,
        colorWarning: warningColor,
        colorHoverWarning: warningColorHover,
        colorPressedWarning: warningColorPressed,
        colorFocusWarning: warningColorHover,
        colorDisabledWarning: warningColor,
        textColorWarning: baseColor,
        textColorHoverWarning: baseColor,
        textColorPressedWarning: baseColor,
        textColorFocusWarning: baseColor,
        textColorDisabledWarning: baseColor,
        textColorTextWarning: warningColor,
        textColorTextHoverWarning: warningColorHover,
        textColorTextPressedWarning: warningColorPressed,
        textColorTextFocusWarning: warningColorHover,
        textColorTextDisabledWarning: textColor2,
        textColorGhostWarning: warningColor,
        textColorGhostHoverWarning: warningColorHover,
        textColorGhostPressedWarning: warningColorPressed,
        textColorGhostFocusWarning: warningColorHover,
        textColorGhostDisabledWarning: warningColor,
        borderWarning: `1px solid ${warningColor}`,
        borderHoverWarning: `1px solid ${warningColorHover}`,
        borderPressedWarning: `1px solid ${warningColorPressed}`,
        borderFocusWarning: `1px solid ${warningColorHover}`,
        borderDisabledWarning: `1px solid ${warningColor}`,
        rippleColorWarning: warningColor,
        colorError: errorColor,
        colorHoverError: errorColorHover,
        colorPressedError: errorColorPressed,
        colorFocusError: errorColorHover,
        colorDisabledError: errorColor,
        textColorError: baseColor,
        textColorHoverError: baseColor,
        textColorPressedError: baseColor,
        textColorFocusError: baseColor,
        textColorDisabledError: baseColor,
        textColorTextError: errorColor,
        textColorTextHoverError: errorColorHover,
        textColorTextPressedError: errorColorPressed,
        textColorTextFocusError: errorColorHover,
        textColorTextDisabledError: textColor2,
        textColorGhostError: errorColor,
        textColorGhostHoverError: errorColorHover,
        textColorGhostPressedError: errorColorPressed,
        textColorGhostFocusError: errorColorHover,
        textColorGhostDisabledError: errorColor,
        borderError: `1px solid ${errorColor}`,
        borderHoverError: `1px solid ${errorColorHover}`,
        borderPressedError: `1px solid ${errorColorPressed}`,
        borderFocusError: `1px solid ${errorColorHover}`,
        borderDisabledError: `1px solid ${errorColor}`,
        rippleColorError: errorColor,
        waveOpacity: "0.6",
        fontWeight,
        fontWeightStrong
      };
    };
    const buttonLight = {
      name: "Button",
      common: commonLight,
      self: self$Z
    };
    var buttonLight$1 = buttonLight;

    const buttonDark = {
      name: "Button",
      common: commonDark,

      self(vars) {
        const commonSelf = self$Z(vars);
        commonSelf.waveOpacity = "0.8";
        commonSelf.colorOpacitySecondary = "0.16";
        commonSelf.colorOpacitySecondaryHover = "0.2";
        commonSelf.colorOpacitySecondaryPressed = "0.12";
        return commonSelf;
      }

    };
    var buttonDark$1 = buttonDark;

    var rtlStyle$l = cB("button", [cM("rtl", `
    direction: rtl;
  `, [cE("icon", {
      margin: "var(--n-icon-margin)",
      marginRight: 0
    }), cE("content", [c$1("~", [cE("icon", {
      margin: "var(--n-icon-margin)",
      marginLeft: 0
    })])])])]);

    const buttonRtl = {
      name: "Button",
      style: rtlStyle$l
    };

    var style$1a = c$1([cB("button", `
    margin: 0;
    font-weight: var(--n-font-weight);
    line-height: 1;
    font-family: inherit;
    padding: var(--n-padding);
    height: var(--n-height);
    font-size: var(--n-font-size);
    border-radius: var(--n-border-radius);
    color: var(--n-text-color);
    background-color: var(--n-color);
    width: var(--n-width);
    white-space: nowrap;
    outline: none;
    position: relative;
    z-index: auto;
    border: none;
    display: inline-flex;
    flex-wrap: nowrap;
    flex-shrink: 0;
    align-items: center;
    justify-content: center;
    user-select: none;
    -webkit-user-select: none;
    text-align: center;
    cursor: pointer;
    text-decoration: none;
    transition:
      color .3s var(--n-bezier),
      background-color .3s var(--n-bezier),
      opacity .3s var(--n-bezier),
      border-color .3s var(--n-bezier);
  `, [cM("color", [cE("border", {
      borderColor: "var(--n-border-color)"
    }), cM("disabled", [cE("border", {
      borderColor: "var(--n-border-color-disabled)"
    })]), cNotM("disabled", [c$1("&:focus", [cE("state-border", {
      borderColor: "var(--n-border-color-focus)"
    })]), c$1("&:hover", [cE("state-border", {
      borderColor: "var(--n-border-color-hover)"
    })]), c$1("&:active", [cE("state-border", {
      borderColor: "var(--n-border-color-pressed)"
    })]), cM("pressed", [cE("state-border", {
      borderColor: "var(--n-border-color-pressed)"
    })])])]), cM("disabled", {
      backgroundColor: "var(--n-color-disabled)",
      color: "var(--n-text-color-disabled)"
    }, [cE("border", {
      border: "var(--n-border-disabled)"
    })]), cNotM("disabled", [c$1("&:focus", {
      backgroundColor: "var(--n-color-focus)",
      color: "var(--n-text-color-focus)"
    }, [cE("state-border", {
      border: "var(--n-border-focus)"
    })]), c$1("&:hover", {
      backgroundColor: "var(--n-color-hover)",
      color: "var(--n-text-color-hover)"
    }, [cE("state-border", {
      border: "var(--n-border-hover)"
    })]), c$1("&:active", {
      backgroundColor: "var(--n-color-pressed)",
      color: "var(--n-text-color-pressed)"
    }, [cE("state-border", {
      border: "var(--n-border-pressed)"
    })]), cM("pressed", {
      backgroundColor: "var(--n-color-pressed)",
      color: "var(--n-text-color-pressed)"
    }, [cE("state-border", {
      border: "var(--n-border-pressed)"
    })])]), cM("loading", "cursor: wait;"), cB("base-wave", `
      pointer-events: none;
      top: 0;
      right: 0;
      bottom: 0;
      left: 0;
      animation-iteration-count: 1;
      animation-duration: var(--n-ripple-duration);
      animation-timing-function: var(--n-bezier-ease-out), var(--n-bezier-ease-out);
    `, [cM("active", {
      zIndex: 1,
      animationName: "button-wave-spread, button-wave-opacity"
    })]), isBrowser$2 && "MozBoxSizing" in document.createElement("div").style ? c$1("&::moz-focus-inner", {
      border: 0
    }) : null, cE("border, state-border", `
      position: absolute;
      left: 0;
      top: 0;
      right: 0;
      bottom: 0;
      border-radius: inherit;
      transition: border-color .3s var(--n-bezier);
      pointer-events: none;
    `), cE("border", {
      border: "var(--n-border)"
    }), cE("state-border", {
      border: "var(--n-border)",
      borderColor: "#0000",
      zIndex: 1
    }), cE("icon", `
      margin: var(--n-icon-margin);
      margin-left: 0;
      height: var(--n-icon-size);
      width: var(--n-icon-size);
      max-width: var(--n-icon-size);
      font-size: var(--n-icon-size);
      position: relative;
      flex-shrink: 0;
    `, [cB("icon-slot", `
        height: var(--n-icon-size);
        width: var(--n-icon-size);
        position: absolute;
        left: 0;
        top: 50%;
        transform: translateY(-50%);
        display: flex;
        align-items: center;
        justify-content: center;
      `, [iconSwitchTransition({
      top: "50%",
      originalTransform: "translateY(-50%)"
    })]), fadeInWidthExpandTransition()]), cE("content", `
      display: flex;
      align-items: center;
      flex-wrap: nowrap;
      min-width: 0;
    `, [c$1("~", [cE("icon", {
      margin: "var(--n-icon-margin)",
      marginRight: 0
    })])]), cM("block", `
      display: flex;
      width: 100%;
    `), cM("dashed", [cE("border, state-border", {
      borderStyle: "dashed !important"
    })]), cM("disabled", {
      cursor: "not-allowed",
      opacity: "var(--n-opacity-disabled)"
    })]), c$1("@keyframes button-wave-spread", {
      from: {
        boxShadow: "0 0 0.5px 0 var(--n-ripple-color)"
      },
      to: {
        boxShadow: "0 0 0.5px 4.5px var(--n-ripple-color)"
      }
    }), c$1("@keyframes button-wave-opacity", {
      from: {
        opacity: "var(--n-wave-opacity)"
      },
      to: {
        opacity: 0
      }
    })]);

    const buttonProps = {
      ...useTheme.props,
      color: String,
      textColor: String,
      text: Boolean,
      block: Boolean,
      loading: Boolean,
      disabled: Boolean,
      circle: Boolean,
      size: String,
      ghost: Boolean,
      round: Boolean,
      secondary: Boolean,
      tertiary: Boolean,
      quaternary: Boolean,
      strong: Boolean,
      focusable: {
        type: Boolean,
        default: true
      },
      keyboard: {
        type: Boolean,
        default: true
      },
      tag: {
        type: String,
        default: "button"
      },
      type: {
        type: String,
        default: "default"
      },
      dashed: Boolean,
      iconPlacement: {
        type: String,
        default: "left"
      },
      attrType: {
        type: String,
        default: "button"
      },
      bordered: {
        type: Boolean,
        default: true
      },
      onClick: [Function, Array],
      nativeFocusBehavior: {
        type: Boolean,
        default: !isSafari
      }
    };
    const Button = vue.defineComponent({
      name: "Button",
      props: buttonProps,
      setup(props) {
        {
          vue.watchEffect(() => {
            const { dashed, ghost, text, secondary, tertiary, quaternary } = props;
            if ((dashed || ghost || text) && (secondary || tertiary || quaternary)) {
              warnOnce(
                "button",
                "`dashed`, `ghost` and `text` props can't be used along with `secondary`, `tertiary` and `quaterary` props."
              );
            }
          });
        }
        const selfElRef = vue.ref(null);
        const waveElRef = vue.ref(null);
        const enterPressedRef = vue.ref(false);
        const showBorderRef = useMemo(() => {
          return !props.quaternary && !props.tertiary && !props.secondary && !props.text && (!props.color || props.ghost || props.dashed) && props.bordered;
        });
        const NButtonGroup = vue.inject(buttonGroupInjectionKey, {});
        const { mergedSizeRef } = useFormItem(
          {},
          {
            defaultSize: "medium",
            mergedSize: (NFormItem) => {
              const { size } = props;
              if (size)
                return size;
              const { size: buttonGroupSize } = NButtonGroup;
              if (buttonGroupSize)
                return buttonGroupSize;
              const { mergedSize: formItemSize } = NFormItem || {};
              if (formItemSize) {
                return formItemSize.value;
              }
              return "medium";
            }
          }
        );
        const mergedFocusableRef = vue.computed(() => {
          return props.focusable && !props.disabled;
        });
        const handleMousedown = (e) => {
          if (!mergedFocusableRef.value) {
            e.preventDefault();
          }
          if (props.nativeFocusBehavior) {
            return;
          }
          e.preventDefault();
          if (props.disabled) {
            return;
          }
          if (mergedFocusableRef.value) {
            selfElRef.value?.focus({ preventScroll: true });
          }
        };
        const handleClick = (e) => {
          if (!props.disabled && !props.loading) {
            const { onClick } = props;
            if (onClick)
              call(onClick, e);
            if (!props.text) {
              waveElRef.value?.play();
            }
          }
        };
        const handleKeyup = (e) => {
          switch (e.key) {
            case "Enter":
              if (!props.keyboard) {
                return;
              }
              enterPressedRef.value = false;
          }
        };
        const handleKeydown = (e) => {
          switch (e.key) {
            case "Enter":
              if (!props.keyboard || props.loading) {
                e.preventDefault();
                return;
              }
              enterPressedRef.value = true;
          }
        };
        const handleBlur = () => {
          enterPressedRef.value = false;
        };
        const { inlineThemeDisabled, mergedClsPrefixRef, mergedRtlRef } = useConfig(props);
        const themeRef = useTheme(
          "Button",
          "-button",
          style$1a,
          buttonLight$1,
          props,
          mergedClsPrefixRef
        );
        const rtlEnabledRef = useRtl("Button", mergedRtlRef, mergedClsPrefixRef);
        const cssVarsRef = vue.computed(() => {
          const theme = themeRef.value;
          const {
            common: { cubicBezierEaseInOut, cubicBezierEaseOut },
            self
          } = theme;
          const { rippleDuration, opacityDisabled, fontWeight, fontWeightStrong } = self;
          const size = mergedSizeRef.value;
          const {
            dashed,
            type,
            ghost,
            text,
            color,
            round,
            circle,
            textColor,
            secondary,
            tertiary,
            quaternary,
            strong
          } = props;
          const fontProps = {
            "font-weight": strong ? fontWeightStrong : fontWeight
          };
          let colorProps = {
            "--n-color": "initial",
            "--n-color-hover": "initial",
            "--n-color-pressed": "initial",
            "--n-color-focus": "initial",
            "--n-color-disabled": "initial",
            "--n-ripple-color": "initial",
            "--n-text-color": "initial",
            "--n-text-color-hover": "initial",
            "--n-text-color-pressed": "initial",
            "--n-text-color-focus": "initial",
            "--n-text-color-disabled": "initial"
          };
          const typeIsTertiary = type === "tertiary";
          const typeIsDefault = type === "default";
          const mergedType = typeIsTertiary ? "default" : type;
          if (text) {
            const propTextColor = textColor || color;
            const mergedTextColor = propTextColor || self[createKey("textColorText", mergedType)];
            colorProps = {
              "--n-color": "#0000",
              "--n-color-hover": "#0000",
              "--n-color-pressed": "#0000",
              "--n-color-focus": "#0000",
              "--n-color-disabled": "#0000",
              "--n-ripple-color": "#0000",
              "--n-text-color": mergedTextColor,
              "--n-text-color-hover": propTextColor ? createHoverColor(propTextColor) : self[createKey("textColorTextHover", mergedType)],
              "--n-text-color-pressed": propTextColor ? createPressedColor(propTextColor) : self[createKey("textColorTextPressed", mergedType)],
              "--n-text-color-focus": propTextColor ? createHoverColor(propTextColor) : self[createKey("textColorTextHover", mergedType)],
              "--n-text-color-disabled": propTextColor || self[createKey("textColorTextDisabled", mergedType)]
            };
          } else if (ghost || dashed) {
            const mergedTextColor = textColor || color;
            colorProps = {
              "--n-color": "#0000",
              "--n-color-hover": "#0000",
              "--n-color-pressed": "#0000",
              "--n-color-focus": "#0000",
              "--n-color-disabled": "#0000",
              "--n-ripple-color": color || self[createKey("rippleColor", mergedType)],
              "--n-text-color": mergedTextColor || self[createKey("textColorGhost", mergedType)],
              "--n-text-color-hover": mergedTextColor ? createHoverColor(mergedTextColor) : self[createKey("textColorGhostHover", mergedType)],
              "--n-text-color-pressed": mergedTextColor ? createPressedColor(mergedTextColor) : self[createKey("textColorGhostPressed", mergedType)],
              "--n-text-color-focus": mergedTextColor ? createHoverColor(mergedTextColor) : self[createKey("textColorGhostHover", mergedType)],
              "--n-text-color-disabled": mergedTextColor || self[createKey("textColorGhostDisabled", mergedType)]
            };
          } else if (secondary) {
            const typeTextColor = typeIsDefault ? self.textColor : typeIsTertiary ? self.textColorTertiary : self[createKey("color", mergedType)];
            const mergedTextColor = color || typeTextColor;
            const isColoredType = type !== "default" && type !== "tertiary";
            colorProps = {
              "--n-color": isColoredType ? changeColor(mergedTextColor, {
                alpha: Number(self.colorOpacitySecondary)
              }) : self.colorSecondary,
              "--n-color-hover": isColoredType ? changeColor(mergedTextColor, {
                alpha: Number(self.colorOpacitySecondaryHover)
              }) : self.colorSecondaryHover,
              "--n-color-pressed": isColoredType ? changeColor(mergedTextColor, {
                alpha: Number(self.colorOpacitySecondaryPressed)
              }) : self.colorSecondaryPressed,
              "--n-color-focus": isColoredType ? changeColor(mergedTextColor, {
                alpha: Number(self.colorOpacitySecondaryHover)
              }) : self.colorSecondaryHover,
              "--n-color-disabled": self.colorSecondary,
              "--n-ripple-color": "#0000",
              "--n-text-color": mergedTextColor,
              "--n-text-color-hover": mergedTextColor,
              "--n-text-color-pressed": mergedTextColor,
              "--n-text-color-focus": mergedTextColor,
              "--n-text-color-disabled": mergedTextColor
            };
          } else if (tertiary || quaternary) {
            const typeColor = typeIsDefault ? self.textColor : typeIsTertiary ? self.textColorTertiary : self[createKey("color", mergedType)];
            const mergedColor = color || typeColor;
            if (tertiary) {
              colorProps["--n-color"] = self.colorTertiary;
              colorProps["--n-color-hover"] = self.colorTertiaryHover;
              colorProps["--n-color-pressed"] = self.colorTertiaryPressed;
              colorProps["--n-color-focus"] = self.colorSecondaryHover;
              colorProps["--n-color-disabled"] = self.colorTertiary;
            } else {
              colorProps["--n-color"] = self.colorQuaternary;
              colorProps["--n-color-hover"] = self.colorQuaternaryHover;
              colorProps["--n-color-pressed"] = self.colorQuaternaryPressed;
              colorProps["--n-color-focus"] = self.colorQuaternaryHover;
              colorProps["--n-color-disabled"] = self.colorQuaternary;
            }
            colorProps["--n-ripple-color"] = "#0000";
            colorProps["--n-text-color"] = mergedColor;
            colorProps["--n-text-color-hover"] = mergedColor;
            colorProps["--n-text-color-pressed"] = mergedColor;
            colorProps["--n-text-color-focus"] = mergedColor;
            colorProps["--n-text-color-disabled"] = mergedColor;
          } else {
            colorProps = {
              "--n-color": color || self[createKey("color", mergedType)],
              "--n-color-hover": color ? createHoverColor(color) : self[createKey("colorHover", mergedType)],
              "--n-color-pressed": color ? createPressedColor(color) : self[createKey("colorPressed", mergedType)],
              "--n-color-focus": color ? createHoverColor(color) : self[createKey("colorFocus", mergedType)],
              "--n-color-disabled": color || self[createKey("colorDisabled", mergedType)],
              "--n-ripple-color": color || self[createKey("rippleColor", mergedType)],
              "--n-text-color": textColor || (color ? self.textColorPrimary : typeIsTertiary ? self.textColorTertiary : self[createKey("textColor", mergedType)]),
              "--n-text-color-hover": textColor || (color ? self.textColorHoverPrimary : self[createKey("textColorHover", mergedType)]),
              "--n-text-color-pressed": textColor || (color ? self.textColorPressedPrimary : self[createKey("textColorPressed", mergedType)]),
              "--n-text-color-focus": textColor || (color ? self.textColorFocusPrimary : self[createKey("textColorFocus", mergedType)]),
              "--n-text-color-disabled": textColor || (color ? self.textColorDisabledPrimary : self[createKey("textColorDisabled", mergedType)])
            };
          }
          let borderProps = {
            "--n-border": "initial",
            "--n-border-hover": "initial",
            "--n-border-pressed": "initial",
            "--n-border-focus": "initial",
            "--n-border-disabled": "initial"
          };
          if (text) {
            borderProps = {
              "--n-border": "none",
              "--n-border-hover": "none",
              "--n-border-pressed": "none",
              "--n-border-focus": "none",
              "--n-border-disabled": "none"
            };
          } else {
            borderProps = {
              "--n-border": self[createKey("border", mergedType)],
              "--n-border-hover": self[createKey("borderHover", mergedType)],
              "--n-border-pressed": self[createKey("borderPressed", mergedType)],
              "--n-border-focus": self[createKey("borderFocus", mergedType)],
              "--n-border-disabled": self[createKey("borderDisabled", mergedType)]
            };
          }
          const {
            [createKey("height", size)]: height,
            [createKey("fontSize", size)]: fontSize,
            [createKey("padding", size)]: padding,
            [createKey("paddingRound", size)]: paddingRound,
            [createKey("iconSize", size)]: iconSize,
            [createKey("borderRadius", size)]: borderRadius,
            [createKey("iconMargin", size)]: iconMargin,
            waveOpacity
          } = self;
          const sizeProps = {
            "--n-width": circle && !text ? height : "initial",
            "--n-height": text ? "initial" : height,
            "--n-font-size": fontSize,
            "--n-padding": circle ? "initial" : text ? "initial" : round ? paddingRound : padding,
            "--n-icon-size": iconSize,
            "--n-icon-margin": iconMargin,
            "--n-border-radius": text ? "initial" : circle || round ? height : borderRadius
          };
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-bezier-ease-out": cubicBezierEaseOut,
            "--n-ripple-duration": rippleDuration,
            "--n-opacity-disabled": opacityDisabled,
            "--n-wave-opacity": waveOpacity,
            ...fontProps,
            ...colorProps,
            ...borderProps,
            ...sizeProps
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "button",
          vue.computed(() => {
            let hash = "";
            const {
              dashed,
              type,
              ghost,
              text,
              color,
              round,
              circle,
              textColor,
              secondary,
              tertiary,
              quaternary,
              strong
            } = props;
            if (dashed)
              hash += "a";
            if (ghost)
              hash += "b";
            if (text)
              hash += "c";
            if (round)
              hash += "d";
            if (circle)
              hash += "e";
            if (secondary)
              hash += "f";
            if (tertiary)
              hash += "g";
            if (quaternary)
              hash += "h";
            if (strong)
              hash += "i";
            if (color)
              hash += "j" + color2Class(color);
            if (textColor)
              hash += "k" + color2Class(textColor);
            const { value: size } = mergedSizeRef;
            hash += "l" + size[0];
            hash += "m" + type[0];
            return hash;
          }),
          cssVarsRef,
          props
        ) : void 0;
        return {
          selfElRef,
          waveElRef,
          mergedClsPrefix: mergedClsPrefixRef,
          mergedFocusable: mergedFocusableRef,
          mergedSize: mergedSizeRef,
          showBorder: showBorderRef,
          enterPressed: enterPressedRef,
          rtlEnabled: rtlEnabledRef,
          handleMousedown,
          handleKeydown,
          handleBlur,
          handleKeyup,
          handleClick,
          customColorCssVars: vue.computed(() => {
            const { color } = props;
            if (!color)
              return null;
            const hoverColor = createHoverColor(color);
            return {
              "--n-border-color": color,
              "--n-border-color-hover": hoverColor,
              "--n-border-color-pressed": createPressedColor(color),
              "--n-border-color-focus": hoverColor,
              "--n-border-color-disabled": color
            };
          }),
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedClsPrefix, tag: Component, onRender } = this;
        onRender?.();
        const children = resolveWrappedSlot(
          this.$slots.default,
          (children2) => children2 && /* @__PURE__ */ React.createElement("span", {
            class: `${mergedClsPrefix}-button__content`
          }, children2)
        );
        return /* @__PURE__ */ React.createElement(Component, {
          ref: "selfElRef",
          class: [
            this.themeClass,
            `${mergedClsPrefix}-button`,
            `${mergedClsPrefix}-button--${this.type}-type`,
            `${mergedClsPrefix}-button--${this.mergedSize}-type`,
            this.rtlEnabled && `${mergedClsPrefix}-button--rtl`,
            this.disabled && `${mergedClsPrefix}-button--disabled`,
            this.block && `${mergedClsPrefix}-button--block`,
            this.enterPressed && `${mergedClsPrefix}-button--pressed`,
            !this.text && this.dashed && `${mergedClsPrefix}-button--dashed`,
            this.color && `${mergedClsPrefix}-button--color`,
            this.secondary && `${mergedClsPrefix}-button--secondary`,
            this.loading && `${mergedClsPrefix}-button--loading`,
            this.ghost && `${mergedClsPrefix}-button--ghost`
          ],
          tabindex: this.mergedFocusable ? 0 : -1,
          type: this.attrType,
          style: this.cssVars,
          disabled: this.disabled,
          onClick: this.handleClick,
          onBlur: this.handleBlur,
          onMousedown: this.handleMousedown,
          onKeyup: this.handleKeyup,
          onKeydown: this.handleKeydown
        }, this.iconPlacement === "right" && children, /* @__PURE__ */ React.createElement(NFadeInExpandTransition, {
          width: true
        }, {
          default: () => resolveWrappedSlot(
            this.$slots.icon,
            (children2) => (this.loading || children2) && /* @__PURE__ */ React.createElement("span", {
              class: `${mergedClsPrefix}-button__icon`,
              style: {
                margin: isSlotEmpty(this.$slots.default) ? "0" : ""
              }
            }, /* @__PURE__ */ React.createElement(NIconSwitchTransition, null, {
              default: () => this.loading ? /* @__PURE__ */ React.createElement(NBaseLoading, {
                clsPrefix: mergedClsPrefix,
                key: "loading",
                class: `${mergedClsPrefix}-icon-slot`,
                strokeWidth: 20
              }) : /* @__PURE__ */ React.createElement("div", {
                key: "icon",
                class: `${mergedClsPrefix}-icon-slot`,
                role: "none"
              }, children2)
            }))
          )
        }), this.iconPlacement === "left" && children, !this.text ? /* @__PURE__ */ React.createElement(NBaseWave, {
          ref: "waveElRef",
          clsPrefix: mergedClsPrefix
        }) : null, this.showBorder ? /* @__PURE__ */ React.createElement("div", {
          "aria-hidden": true,
          class: `${mergedClsPrefix}-button__border`,
          style: this.customColorCssVars
        }) : null, this.showBorder ? /* @__PURE__ */ React.createElement("div", {
          "aria-hidden": true,
          class: `${mergedClsPrefix}-button__state-border`,
          style: this.customColorCssVars
        }) : null);
      }
    });
    var NButton = Button;
    const XButton = Button;

    const zero = "0!important";
    const n1 = "-1px!important";

    function createLeftBorderStyle(type) {
      return cM(type + "-type", [c$1("& +", [cB("button", {}, [cM(type + "-type", [cE("border", {
        borderLeftWidth: zero
      }), cE("state-border", {
        left: n1
      })])])])]);
    }

    function createTopBorderStyle(type) {
      return cM(type + "-type", [c$1("& +", [cB("button", [cM(type + "-type", [cE("border", {
        borderTopWidth: zero
      }), cE("state-border", {
        top: n1
      })])])])]);
    }

    var style$19 = cB("button-group", `
  flex-wrap: nowrap;
  display: inline-flex;
  position: relative;
`, [cNotM("vertical", {
      flexDirection: "row"
    }, [cNotM("rtl", [cB("button", [c$1("&:first-child:not(:last-child)", `
          margin-right: ${zero};
          border-top-right-radius: ${zero};
          border-bottom-right-radius: ${zero};
        `), c$1("&:last-child:not(:first-child)", `
          margin-left: ${zero};
          border-top-left-radius: ${zero};
          border-bottom-left-radius: ${zero};
        `), c$1("&:not(:first-child):not(:last-child)", `
          margin-left: ${zero};
          margin-right: ${zero};
          border-radius: ${zero};
        `), createLeftBorderStyle("default"), cM("ghost", [createLeftBorderStyle("primary"), createLeftBorderStyle("info"), createLeftBorderStyle("success"), createLeftBorderStyle("warning"), createLeftBorderStyle("error")])])])]), cM("vertical", {
      flexDirection: "column"
    }, [cB("button", [c$1("&:first-child:not(:last-child)", `
        margin-bottom: ${zero};
        margin-left: ${zero};
        margin-right: ${zero};
        border-bottom-left-radius: ${zero};
        border-bottom-right-radius: ${zero};
      `), c$1("&:last-child:not(:first-child)", `
        margin-top: ${zero};
        margin-left: ${zero};
        margin-right: ${zero};
        border-top-left-radius: ${zero};
        border-top-right-radius: ${zero};
      `), c$1("&:not(:first-child):not(:last-child)", `
        margin: ${zero};
        border-radius: ${zero};
      `), createTopBorderStyle("default"), cM("ghost", [createTopBorderStyle("primary"), createTopBorderStyle("info"), createTopBorderStyle("success"), createTopBorderStyle("warning"), createTopBorderStyle("error")])])])]);

    const buttonGroupProps = {
      size: {
        type: String,
        default: void 0
      },
      vertical: Boolean
    };
    var NButtonGroup = vue.defineComponent({
      name: "ButtonGroup",
      props: buttonGroupProps,
      setup(props) {
        const { mergedClsPrefixRef, mergedRtlRef } = useConfig(props);
        useStyle("-button-group", style$19, mergedClsPrefixRef);
        vue.provide(buttonGroupInjectionKey, props);
        const rtlEnabledRef = useRtl(
          "ButtonGroup",
          mergedRtlRef,
          mergedClsPrefixRef
        );
        return {
          rtlEnabled: rtlEnabledRef,
          mergedClsPrefix: mergedClsPrefixRef
        };
      },
      render() {
        const { mergedClsPrefix } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-button-group`,
            this.rtlEnabled && `${mergedClsPrefix}-button-group--rtl`,
            this.vertical && `${mergedClsPrefix}-button-group--vertical`
          ],
          role: "group"
        }, this.$slots);
      }
    });

    const START_YEAR = 1901;
    const MONTH_ITEM_HEIGHT = 40;

    const matcherMap = {
      date: isSameDay,
      month: isSameMonth,
      year: isSameYear,
      quarter: isSameQuarter
    };

    function matchDate(sourceTime, patternTime, type) {
      const matcher = matcherMap[type];

      if (Array.isArray(sourceTime)) {
        return sourceTime.some(time => matcher(time, patternTime));
      } else {
        return matcher(sourceTime, patternTime);
      }
    }

    function dateItem(time, monthTs, valueTs, currentTs) {
      let inSpan = false;
      let startOfSpan = false;
      let endOfSpan = false;

      if (Array.isArray(valueTs)) {
        if (valueTs[0] < time && time < valueTs[1]) {
          inSpan = true;
        }

        if (matchDate(valueTs[0], time, "date")) startOfSpan = true;
        if (matchDate(valueTs[1], time, "date")) endOfSpan = true;
      }

      const selected = valueTs !== null && (Array.isArray(valueTs) ? matchDate(valueTs[0], time, "date") || matchDate(valueTs[1], time, "date") : matchDate(valueTs, time, "date"));
      return {
        type: "date",
        dateObject: {
          date: getDate(time),
          month: getMonth(time),
          year: getYear(time)
        },
        inCurrentMonth: isSameMonth(time, monthTs),
        isCurrentDate: matchDate(currentTs, time, "date"),
        inSpan,
        startOfSpan,
        endOfSpan,
        selected,
        ts: getTime(time)
      };
    }

    function monthItem(monthTs, valueTs, currentTs) {
      return {
        type: "month",
        dateObject: {
          month: getMonth(monthTs),
          year: getYear(monthTs)
        },
        isCurrent: isSameMonth(currentTs, monthTs),
        selected: valueTs !== null && matchDate(valueTs, monthTs, "month"),
        ts: getTime(monthTs)
      };
    }

    function yearItem(yearTs, valueTs, currentTs) {
      return {
        type: "year",
        dateObject: {
          year: getYear(yearTs)
        },
        isCurrent: isSameYear(currentTs, yearTs),
        selected: valueTs !== null && matchDate(valueTs, yearTs, "year"),
        ts: getTime(yearTs)
      };
    }

    function quarterItem(quarterTs, valueTs, currentTs) {
      return {
        type: "quarter",
        dateObject: {
          quarter: getQuarter(quarterTs),
          year: getYear(quarterTs)
        },
        isCurrent: isSameQuarter(currentTs, quarterTs),
        selected: valueTs !== null && matchDate(valueTs, quarterTs, "quarter"),
        ts: getTime(quarterTs)
      };
    }

    function dateArray(monthTs, valueTs, currentTs, startDay) {
      let strip = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : false;
      const displayMonth = getMonth(monthTs);
      let displayMonthIterator = getTime(startOfMonth(monthTs));
      let lastMonthIterator = getTime(addDays(displayMonthIterator, -1));
      const calendarDays = [];
      let protectLastMonthDateIsShownFlag = !strip;

      while (getDay(lastMonthIterator) !== startDay || protectLastMonthDateIsShownFlag) {
        calendarDays.unshift(dateItem(lastMonthIterator, monthTs, valueTs, currentTs));
        lastMonthIterator = getTime(addDays(lastMonthIterator, -1));
        protectLastMonthDateIsShownFlag = false;
      }

      while (getMonth(displayMonthIterator) === displayMonth) {
        calendarDays.push(dateItem(displayMonthIterator, monthTs, valueTs, currentTs));
        displayMonthIterator = getTime(addDays(displayMonthIterator, 1));
      }

      const endIndex = strip ? calendarDays.length <= 28 ? 28 : calendarDays.length <= 35 ? 35 : 42 : 42;

      while (calendarDays.length < endIndex) {
        calendarDays.push(dateItem(displayMonthIterator, monthTs, valueTs, currentTs));
        displayMonthIterator = getTime(addDays(displayMonthIterator, 1));
      }

      return calendarDays;
    }

    function monthArray(yearAnchorTs, valueTs, currentTs) {
      const calendarMonths = [];
      const yearStart = startOfYear(yearAnchorTs);

      for (let i = 0; i < 12; i++) {
        calendarMonths.push(monthItem(getTime(addMonths(yearStart, i)), valueTs, currentTs));
      }

      return calendarMonths;
    }

    function quarterArray(yearAnchorTs, valueTs, currentTs) {
      const calendarQuarters = [];
      const yearStart = startOfYear(yearAnchorTs);

      for (let i = 0; i < 4; i++) {
        calendarQuarters.push(quarterItem(getTime(addQuarters(yearStart, i)), valueTs, currentTs));
      }

      return calendarQuarters;
    }

    function yearArray(valueTs, currentTs) {
      const calendarYears = [];
      const time1900 = new Date(START_YEAR, 0, 1);

      for (let i = 0; i < 200; i++) {
        calendarYears.push(yearItem(getTime(addYears(time1900, i)), valueTs, currentTs));
      }

      return calendarYears;
    }

    function strictParse(string, pattern, backup, option) {
      const result = parse$1(string, pattern, backup, option);
      if (!isValid$1(result)) return result;else if (format$4(result, pattern, option) === string) return result;else return new Date(NaN);
    }

    function getDefaultTime(timeValue) {
      if (timeValue === void 0) {
        return void 0;
      }

      if (typeof timeValue === "number") {
        return timeValue;
      }

      const [hour, minute, second] = timeValue.split(":");
      return {
        hours: Number(hour),
        minutes: Number(minute),
        seconds: Number(second)
      };
    }

    function pluckValueFromRange(value, type) {
      return Array.isArray(value) ? value[type === "start" ? 0 : 1] : null;
    }

    var commonVariables$e = {
      titleFontSize: "22px"
    };

    const self$Y = vars => {
      const {
        borderRadius,
        fontSize,
        lineHeight,
        textColor2,
        textColor1,
        textColorDisabled,
        dividerColor,
        fontWeightStrong,
        primaryColor,
        baseColor,
        hoverColor,
        cardColor,
        modalColor,
        popoverColor
      } = vars;
      return { ...commonVariables$e,
        borderRadius,
        borderColor: composite(cardColor, dividerColor),
        borderColorModal: composite(modalColor, dividerColor),
        borderColorPopover: composite(popoverColor, dividerColor),
        textColor: textColor2,
        titleFontWeight: fontWeightStrong,
        titleTextColor: textColor1,
        dayTextColor: textColorDisabled,
        fontSize,
        lineHeight,
        dateColorCurrent: primaryColor,
        dateTextColorCurrent: baseColor,
        cellColorHover: composite(cardColor, hoverColor),
        cellColorHoverModal: composite(modalColor, hoverColor),
        cellColorHoverPopover: composite(popoverColor, hoverColor),
        cellColor: cardColor,
        cellColorModal: modalColor,
        cellColorPopover: popoverColor,
        barColor: primaryColor
      };
    };
    const calendarLight = createTheme$1({
      name: "Calendar",
      common: commonLight,
      peers: {
        Button: buttonLight$1
      },
      self: self$Y
    });
    var calendarLight$1 = calendarLight;

    const calendarDark = {
      name: "Calendar",
      common: commonDark,
      peers: {
        Button: buttonDark$1
      },
      self: self$Y
    };
    var calendarDark$1 = calendarDark;

    var style$18 = c$1([cB("calendar", `
    line-height: var(--n-line-height);
    font-size: var(--n-font-size);
    color: var(--n-text-color);
    height: 720px;
    display: flex;
    flex-direction: column;
  `, [cB("calendar-prev-btn", `
      cursor: pointer;
    `), cB("calendar-next-btn", `
      cursor: pointer;
    `), cB("calendar-header", `
      display: flex;
      align-items: center;
      line-height: 1;
      font-size: var(--n-title-font-size);
      padding: 0 0 18px 0;
      justify-content: space-between;
    `, [cE("title", `
        color: var(--n-title-text-color);
        font-weight: var(--n-title-font-weight);
        transition: color .3s var(--n-bezier);
      `), cE("extra", `
        display: flex;
        align-items: center;
      `)]), cB("calendar-dates", `
      display: grid;
      grid-template-columns: repeat(7, minmax(0, 1fr));
      grid-auto-rows: 1fr;
      border-radius: var(--n-border-radius);
      flex: 1;
      border-top: 1px solid;
      border-left: 1px solid;
      border-color: var(--n-border-color);
      transition: border-color .3s var(--n-bezier);
    `), cB("calendar-cell", `
      box-sizing: border-box;
      padding: 10px;
      border-right: 1px solid;
      border-bottom: 1px solid;
      border-color: var(--n-border-color);
      cursor: pointer;
      position: relative;
      transition:
        color .3s var(--n-bezier),
        border-color .3s var(--n-bezier),
        background-color .3s var(--n-bezier);
    `, [c$1("&:nth-child(7)", `
        border-top-right-radius: var(--n-border-radius);
      `), c$1("&:nth-last-child(7)", `
        border-bottom-left-radius: var(--n-border-radius);
      `), c$1("&:last-child", `
        border-bottom-right-radius: var(--n-border-radius);
      `), c$1("&:hover", `
        background-color: var(--n-cell-color-hover);
      `), cE("bar", `
        position: absolute;
        left: 0;
        right: 0;
        bottom: -1px;
        height: 3px;
        background-color: #0000;
        transition: background-color .3s var(--n-bezier);
      `), cM("selected", [cE("bar", `
          background-color: var(--n-bar-color);
        `)]), cB("calendar-date", `
        transition:
          color .3s var(--n-bezier),
          border-color .3s var(--n-bezier),
          background-color .3s var(--n-bezier);
        color: var(--n-text-color);
      `, [cE("date", `
          color: var(--n-text-color);
        `)]), cM("disabled, other-month", `
        color: var(--n-day-text-color);
      `, [cB("calendar-date", [cE("date", `
            color: var(--n-day-text-color);
          `)])]), cM("disabled", `
        cursor: not-allowed;
      `), cM("current", [cB("calendar-date", [cE("date", `
            color: var(--n-date-text-color-current);
            background-color: var(--n-date-color-current);
          `)])]), cB("calendar-date", `
        position: relative;
        line-height: 1;
        display: flex;
        align-items: center;
        height: 1em;
        justify-content: space-between;
        padding-bottom: .75em;
      `, [cE("date", `
          border-radius: 50%;
          display: flex;
          align-items: center;
          justify-content: center;
          margin-left: -0.4em;
          width: 1.8em;
          height: 1.8em;
          transition:
            color .3s var(--n-bezier),
            background-color .3s var(--n-bezier);
        `), cE("day", `
          color: var(--n-day-text-color);
          transition: color .3s var(--n-bezier);
        `)])])]), insideModal(cB("calendar", [cB("calendar-dates", `
      border-color: var(--n-border-color-modal);
    `), cB("calendar-cell", `
      border-color: var(--n-border-color-modal);
    `, [c$1("&:hover", `
        background-color: var(--n-cell-color-hover-modal);
      `)])])), insidePopover(cB("calendar", [cB("calendar-dates", `
      border-color: var(--n-border-color-popover);
    `), cB("calendar-cell", `
      border-color: var(--n-border-color-popover);
    `, [c$1("&:hover", `
        background-color: var(--n-cell-color-hover-popover);
      `)])]))]);

    const calendarProps = {
      ...useTheme.props,
      isDateDisabled: Function,
      value: Number,
      defaultValue: {
        type: Number,
        default: null
      },
      onPanelChange: Function,
      "onUpdate:value": [Function, Array],
      onUpdateValue: [Function, Array]
    };
    var Calendar = vue.defineComponent({
      name: "Calendar",
      props: calendarProps,
      setup(props) {
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Calendar",
          "-calendar",
          style$18,
          calendarLight$1,
          props,
          mergedClsPrefixRef
        );
        const { localeRef, dateLocaleRef } = useLocale("DatePicker");
        const now = Date.now();
        const monthTsRef = vue.ref(startOfMonth(now).valueOf());
        const uncontrolledValueRef = vue.ref(props.defaultValue || null);
        const mergedValueRef = useMergedState(
          vue.toRef(props, "value"),
          uncontrolledValueRef
        );
        function doUpdateValue(value, time) {
          const { onUpdateValue, "onUpdate:value": _onUpdateValue } = props;
          if (onUpdateValue) {
            call(onUpdateValue, value, time);
          }
          if (_onUpdateValue) {
            call(_onUpdateValue, value, time);
          }
          uncontrolledValueRef.value = value;
        }
        function handlePrevClick() {
          const monthTs = addMonths(monthTsRef.value, -1).valueOf();
          monthTsRef.value = monthTs;
          props.onPanelChange?.({
            year: getYear(monthTs),
            month: getMonth(monthTs) + 1
          });
        }
        function handleNextClick() {
          const monthTs = addMonths(monthTsRef.value, 1).valueOf();
          monthTsRef.value = monthTs;
          props.onPanelChange?.({
            year: getYear(monthTs),
            month: getMonth(monthTs) + 1
          });
        }
        function handleTodayClick() {
          const { value: monthTs } = monthTsRef;
          const oldYear = getYear(monthTs);
          const oldMonth = getMonth(monthTs);
          const newMonthTs = startOfMonth(now).valueOf();
          monthTsRef.value = newMonthTs;
          const newYear = getYear(newMonthTs);
          const newMonth = getMonth(newMonthTs);
          if (oldYear !== newYear || oldMonth !== newMonth) {
            props.onPanelChange?.({
              year: newYear,
              month: newMonth + 1
            });
          }
        }
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self: {
              borderColor,
              borderColorModal,
              borderColorPopover,
              borderRadius,
              titleFontSize,
              textColor,
              titleFontWeight,
              titleTextColor,
              dayTextColor,
              fontSize,
              lineHeight,
              dateColorCurrent,
              dateTextColorCurrent,
              cellColorHover,
              cellColor,
              cellColorModal,
              barColor,
              cellColorPopover,
              cellColorHoverModal,
              cellColorHoverPopover
            }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-border-color": borderColor,
            "--n-border-color-modal": borderColorModal,
            "--n-border-color-popover": borderColorPopover,
            "--n-border-radius": borderRadius,
            "--n-text-color": textColor,
            "--n-title-font-weight": titleFontWeight,
            "--n-title-font-size": titleFontSize,
            "--n-title-text-color": titleTextColor,
            "--n-day-text-color": dayTextColor,
            "--n-font-size": fontSize,
            "--n-line-height": lineHeight,
            "--n-date-color-current": dateColorCurrent,
            "--n-date-text-color-current": dateTextColorCurrent,
            "--n-cell-color": cellColor,
            "--n-cell-color-modal": cellColorModal,
            "--n-cell-color-popover": cellColorPopover,
            "--n-cell-color-hover": cellColorHover,
            "--n-cell-color-hover-modal": cellColorHoverModal,
            "--n-cell-color-hover-popover": cellColorHoverPopover,
            "--n-bar-color": barColor
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("calendar", void 0, cssVarsRef, props) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          locale: localeRef,
          dateLocale: dateLocaleRef,
          now,
          mergedValue: mergedValueRef,
          monthTs: monthTsRef,
          dateItems: vue.computed(() => {
            return dateArray(
              monthTsRef.value,
              mergedValueRef.value,
              now,
              localeRef.value.firstDayOfWeek,
              true
            );
          }),
          doUpdateValue,
          handleTodayClick,
          handlePrevClick,
          handleNextClick,
          mergedTheme: themeRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const {
          isDateDisabled,
          mergedClsPrefix,
          monthTs,
          cssVars,
          mergedValue,
          mergedTheme,
          $slots,
          locale: { monthBeforeYear, today },
          dateLocale: { locale },
          handleTodayClick,
          handlePrevClick,
          handleNextClick,
          onRender
        } = this;
        onRender?.();
        const normalizedValue = mergedValue && startOfDay(mergedValue).valueOf();
        const year = getYear(monthTs);
        const calendarMonth = getMonth(monthTs) + 1;
        return /* @__PURE__ */ React.createElement("div", {
          class: [`${mergedClsPrefix}-calendar`, this.themeClass],
          style: cssVars
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-calendar-header`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-calendar-header__title`
        }, resolveSlotWithProps(
          $slots.header,
          { year, month: calendarMonth },
          () => {
            const localeMonth = format$4(monthTs, "MMMM", { locale });
            return [
              monthBeforeYear ? `${localeMonth} ${year}` : `${year} ${localeMonth}`
            ];
          }
        )), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-calendar-header__extra`
        }, /* @__PURE__ */ React.createElement(NButtonGroup, null, {
          default: () => /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(NButton, {
            size: "small",
            onClick: handlePrevClick,
            theme: mergedTheme.peers.Button,
            themeOverrides: mergedTheme.peerOverrides.Button
          }, {
            icon: () => /* @__PURE__ */ React.createElement(NBaseIcon, {
              clsPrefix: mergedClsPrefix,
              class: `${mergedClsPrefix}-calendar-prev-btn`
            }, { default: () => /* @__PURE__ */ React.createElement(ChevronLeftIcon, null) })
          }), /* @__PURE__ */ React.createElement(NButton, {
            size: "small",
            onClick: handleTodayClick,
            theme: mergedTheme.peers.Button,
            themeOverrides: mergedTheme.peerOverrides.Button
          }, { default: () => today }), /* @__PURE__ */ React.createElement(NButton, {
            size: "small",
            onClick: handleNextClick,
            theme: mergedTheme.peers.Button,
            themeOverrides: mergedTheme.peerOverrides.Button
          }, {
            icon: () => /* @__PURE__ */ React.createElement(NBaseIcon, {
              clsPrefix: mergedClsPrefix,
              class: `${mergedClsPrefix}-calendar-next-btn`
            }, { default: () => /* @__PURE__ */ React.createElement(ChevronRightIcon, null) })
          }))
        }))), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-calendar-dates`
        }, this.dateItems.map(
          ({ dateObject, ts, inCurrentMonth, isCurrentDate }, index) => {
            const { year: year2, month, date } = dateObject;
            const fullDate = format$4(ts, "yyyy-MM-dd");
            const notInCurrentMonth = !inCurrentMonth;
            const disabled = isDateDisabled?.(ts) === true;
            const selected = normalizedValue === startOfDay(ts).valueOf();
            return /* @__PURE__ */ React.createElement("div", {
              key: `${calendarMonth}-${index}`,
              class: [
                `${mergedClsPrefix}-calendar-cell`,
                disabled && `${mergedClsPrefix}-calendar-cell--disabled`,
                notInCurrentMonth && `${mergedClsPrefix}-calendar-cell--other-month`,
                disabled && `${mergedClsPrefix}-calendar-cell--not-allowed`,
                isCurrentDate && `${mergedClsPrefix}-calendar-cell--current`,
                selected && `${mergedClsPrefix}-calendar-cell--selected`
              ],
              onClick: () => {
                if (disabled)
                  return;
                const monthTs2 = startOfMonth(ts).valueOf();
                this.monthTs = monthTs2;
                if (notInCurrentMonth) {
                  this.onPanelChange?.({
                    year: getYear(monthTs2),
                    month: getMonth(monthTs2) + 1
                  });
                }
                this.doUpdateValue(ts, {
                  year: year2,
                  month: month + 1,
                  date
                });
              }
            }, /* @__PURE__ */ React.createElement("div", {
              class: `${mergedClsPrefix}-calendar-date`
            }, /* @__PURE__ */ React.createElement("div", {
              class: `${mergedClsPrefix}-calendar-date__date`,
              title: fullDate
            }, date), index < 7 && /* @__PURE__ */ React.createElement("div", {
              class: `${mergedClsPrefix}-calendar-date__day`,
              title: fullDate
            }, format$4(ts, "EEE", {
              locale
            }))), $slots.default?.({
              year: year2,
              month: month + 1,
              date
            }), /* @__PURE__ */ React.createElement("div", {
              class: `${mergedClsPrefix}-calendar-cell__bar`
            }));
          }
        )));
      }
    });

    const self$X = vars => {
      const {
        fontSize,
        boxShadow2,
        popoverColor,
        textColor2,
        borderRadius,
        borderColor,
        heightSmall,
        heightMedium,
        heightLarge,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge,
        dividerColor
      } = vars;
      return {
        panelFontSize: fontSize,
        boxShadow: boxShadow2,
        color: popoverColor,
        textColor: textColor2,
        borderRadius,
        border: `1px solid ${borderColor}`,
        heightSmall,
        heightMedium,
        heightLarge,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge,
        dividerColor
      };
    };
    const colorPickerLight = createTheme$1({
      name: "ColorPicker",
      common: commonLight,
      peers: {
        Input: inputLight$1,
        Button: buttonLight$1
      },
      self: self$X
    });
    var colorPickerLight$1 = colorPickerLight;

    const colorPickerDark = {
      name: "ColorPicker",
      common: commonDark,
      peers: {
        Input: inputDark$1,
        Button: buttonDark$1
      },
      self: self$X
    };
    var colorPickerDark$1 = colorPickerDark;

    function deriveDefaultValue(modes, showAlpha) {
      const mode = modes[0];

      switch (mode) {
        case "hex":
          return showAlpha ? "#000000FF" : "#000000";

        case "rgb":
          return showAlpha ? "rgba(0, 0, 0, 1)" : "rgb(0, 0, 0)";

        case "hsl":
          return showAlpha ? "hsla(0, 0%, 0%, 1)" : "hsl(0, 0%, 0%)";

        case "hsv":
          return showAlpha ? "hsva(0, 0%, 0%, 1)" : "hsv(0, 0%, 0%)";
      }

      warn$2("color-picker", "props.modes is invalid.");
      return "#000000";
    }
    function getModeFromValue(color) {
      if (color === null) return null;
      if (/^ *#/.test(color)) return "hex";
      if (color.includes("rgb")) return "rgb";
      if (color.includes("hsl")) return "hsl";
      if (color.includes("hsv")) return "hsv";
      return null;
    }
    function normalizeHue(hue) {
      hue = Math.round(hue);
      return hue >= 360 ? 359 : hue < 0 ? 0 : hue;
    }
    function normalizeAlpha(alpha) {
      alpha = Math.round(alpha * 100) / 100;
      return alpha > 1 ? 1 : alpha < 0 ? 0 : alpha;
    }
    const convert = {
      rgb: {
        hex(value) {
          return toHexaString(rgba(value));
        },

        hsl(value) {
          const [r, g, b, a] = rgba(value);
          return toHslaString([...rgb2hsl(r, g, b), a]);
        },

        hsv(value) {
          const [r, g, b, a] = rgba(value);
          return toHsvaString([...rgb2hsv(r, g, b), a]);
        }

      },
      hex: {
        rgb(value) {
          return toRgbaString(rgba(value));
        },

        hsl(value) {
          const [r, g, b, a] = rgba(value);
          return toHslaString([...rgb2hsl(r, g, b), a]);
        },

        hsv(value) {
          const [r, g, b, a] = rgba(value);
          return toHsvaString([...rgb2hsv(r, g, b), a]);
        }

      },
      hsl: {
        hex(value) {
          const [h, s, l, a] = hsla(value);
          return toHexaString([...hsl2rgb(h, s, l), a]);
        },

        rgb(value) {
          const [h, s, l, a] = hsla(value);
          return toRgbaString([...hsl2rgb(h, s, l), a]);
        },

        hsv(value) {
          const [h, s, l, a] = hsla(value);
          return toHsvaString([...hsl2hsv(h, s, l), a]);
        }

      },
      hsv: {
        hex(value) {
          const [h, s, v, a] = hsva(value);
          return toHexaString([...hsv2rgb(h, s, v), a]);
        },

        rgb(value) {
          const [h, s, v, a] = hsva(value);
          return toRgbaString([...hsv2rgb(h, s, v), a]);
        },

        hsl(value) {
          const [h, s, v, a] = hsva(value);
          return toHslaString([...hsv2hsl(h, s, v), a]);
        }

      }
    };
    function convertColor(value, mode, originalMode) {
      originalMode = originalMode || getModeFromValue(value);
      if (!originalMode) return null;
      if (originalMode === mode) return value;
      const conversions = convert[originalMode];
      return conversions[mode](value);
    }

    const HANDLE_SIZE$2 = "12px";
    const HANDLE_SIZE_NUM$1 = 12;
    const RADIUS$2 = "6px";
    const RADIUS_NUM = 6;
    const GRADIENT = "linear-gradient(90deg,red,#ff0 16.66%,#0f0 33.33%,#0ff 50%,#00f 66.66%,#f0f 83.33%,red)";
    var HueSlider = vue.defineComponent({
      name: "HueSlider",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        hue: {
          type: Number,
          required: true
        },
        onUpdateHue: {
          type: Function,
          required: true
        },
        onComplete: Function
      },
      setup(props) {
        const railRef = vue.ref(null);
        function handleMouseDown(e) {
          if (!railRef.value)
            return;
          on("mousemove", document, handleMouseMove);
          on("mouseup", document, handleMouseUp);
          handleMouseMove(e);
        }
        function handleMouseMove(e) {
          const { value: railEl } = railRef;
          if (!railEl)
            return;
          const { width, left } = railEl.getBoundingClientRect();
          const newHue = normalizeHue(
            (e.clientX - left - RADIUS_NUM) / (width - HANDLE_SIZE_NUM$1) * 360
          );
          props.onUpdateHue(newHue);
        }
        function handleMouseUp() {
          off("mousemove", document, handleMouseMove);
          off("mouseup", document, handleMouseUp);
          props.onComplete?.();
        }
        return {
          railRef,
          handleMouseDown
        };
      },
      render() {
        const { clsPrefix } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-color-picker-slider`,
          style: {
            height: HANDLE_SIZE$2,
            borderRadius: RADIUS$2
          }
        }, /* @__PURE__ */ React.createElement("div", {
          ref: "railRef",
          style: {
            boxShadow: "inset 0 0 2px 0 rgba(0, 0, 0, .24)",
            boxSizing: "border-box",
            backgroundImage: GRADIENT,
            height: HANDLE_SIZE$2,
            borderRadius: RADIUS$2,
            position: "relative"
          },
          onMousedown: this.handleMouseDown
        }, /* @__PURE__ */ React.createElement("div", {
          style: {
            position: "absolute",
            left: RADIUS$2,
            right: RADIUS$2,
            top: 0,
            bottom: 0
          }
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-color-picker-handle`,
          style: {
            left: `calc((${this.hue}%) / 359 * 100 - ${RADIUS$2})`,
            borderRadius: RADIUS$2,
            width: HANDLE_SIZE$2,
            height: HANDLE_SIZE$2
          }
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-color-picker-handle__fill`,
          style: {
            backgroundColor: `hsl(${this.hue}, 100%, 50%)`,
            borderRadius: RADIUS$2,
            width: HANDLE_SIZE$2,
            height: HANDLE_SIZE$2
          }
        })))));
      }
    });

    const HANDLE_SIZE$1 = "12px";
    const HANDLE_SIZE_NUM = 12;
    const RADIUS$1 = "6px";
    var AlphaSlider = vue.defineComponent({
      name: "AlphaSlider",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        rgba: {
          type: Array,
          default: null
        },
        alpha: {
          type: Number,
          default: 0
        },
        onUpdateAlpha: {
          type: Function,
          required: true
        },
        onComplete: Function
      },
      setup(props) {
        const railRef = vue.ref(null);
        function handleMouseDown(e) {
          if (!railRef.value || !props.rgba)
            return;
          on("mousemove", document, handleMouseMove);
          on("mouseup", document, handleMouseUp);
          handleMouseMove(e);
        }
        function handleMouseMove(e) {
          const { value: railEl } = railRef;
          if (!railEl)
            return;
          const { width, left } = railEl.getBoundingClientRect();
          const newAlpha = (e.clientX - left) / (width - HANDLE_SIZE_NUM);
          props.onUpdateAlpha(normalizeAlpha(newAlpha));
        }
        function handleMouseUp() {
          off("mousemove", document, handleMouseMove);
          off("mouseup", document, handleMouseUp);
          props.onComplete?.();
        }
        return {
          railRef,
          railBackgroundImage: vue.computed(() => {
            const { rgba } = props;
            if (!rgba)
              return "";
            return `linear-gradient(to right, rgba(${rgba[0]}, ${rgba[1]}, ${rgba[2]}, 0) 0%, rgba(${rgba[0]}, ${rgba[1]}, ${rgba[2]}, 1) 100%)`;
          }),
          handleMouseDown
        };
      },
      render() {
        const { clsPrefix } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-color-picker-slider`,
          ref: "railRef",
          style: {
            height: HANDLE_SIZE$1,
            borderRadius: RADIUS$1
          },
          onMousedown: this.handleMouseDown
        }, /* @__PURE__ */ React.createElement("div", {
          style: {
            borderRadius: RADIUS$1,
            position: "absolute",
            left: 0,
            right: 0,
            top: 0,
            bottom: 0,
            overflow: "hidden"
          }
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-color-picker-checkboard`
        }), /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-color-picker-slider__image`,
          style: {
            backgroundImage: this.railBackgroundImage
          }
        })), this.rgba && /* @__PURE__ */ React.createElement("div", {
          style: {
            position: "absolute",
            left: RADIUS$1,
            right: RADIUS$1,
            top: 0,
            bottom: 0
          }
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-color-picker-handle`,
          style: {
            left: `calc(${this.alpha * 100}% - ${RADIUS$1})`,
            borderRadius: RADIUS$1,
            width: HANDLE_SIZE$1,
            height: HANDLE_SIZE$1
          }
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-color-picker-handle__fill`,
          style: {
            backgroundColor: toRgbaString(this.rgba),
            borderRadius: RADIUS$1,
            width: HANDLE_SIZE$1,
            height: HANDLE_SIZE$1
          }
        }))));
      }
    });

    const HANDLE_SIZE = "12px";
    const RADIUS = "6px";
    var Pallete = vue.defineComponent({
      name: "Pallete",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        rgba: {
          type: Array,
          default: null
        },
        displayedHue: {
          type: Number,
          required: true
        },
        displayedSv: {
          type: Array,
          required: true
        },
        onUpdateSV: {
          type: Function,
          required: true
        },
        onComplete: Function
      },
      setup(props) {
        const palleteRef = vue.ref(null);
        function handleMouseDown(e) {
          if (!palleteRef.value)
            return;
          on("mousemove", document, handleMouseMove);
          on("mouseup", document, handleMouseUp);
          handleMouseMove(e);
        }
        function handleMouseMove(e) {
          const { value: palleteEl } = palleteRef;
          if (!palleteEl)
            return;
          const { width, height, left, bottom } = palleteEl.getBoundingClientRect();
          const newV = (bottom - e.clientY) / height;
          const newS = (e.clientX - left) / width;
          const normalizedNewS = 100 * (newS > 1 ? 1 : newS < 0 ? 0 : newS);
          const normalizedNewV = 100 * (newV > 1 ? 1 : newV < 0 ? 0 : newV);
          props.onUpdateSV(normalizedNewS, normalizedNewV);
        }
        function handleMouseUp() {
          off("mousemove", document, handleMouseMove);
          off("mouseup", document, handleMouseUp);
          props.onComplete?.();
        }
        return {
          palleteRef,
          handleColor: vue.computed(() => {
            const { rgba } = props;
            if (!rgba)
              return "";
            return `rgb(${rgba[0]}, ${rgba[1]}, ${rgba[2]})`;
          }),
          handleMouseDown
        };
      },
      render() {
        const { clsPrefix } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-color-picker-pallete`,
          onMousedown: this.handleMouseDown,
          ref: "palleteRef"
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-color-picker-pallete__layer`,
          style: {
            backgroundImage: `linear-gradient(90deg, white, hsl(${this.displayedHue}, 100%, 50%))`
          }
        }), /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-color-picker-pallete__layer ${clsPrefix}-color-picker-pallete__layer--shadowed`,
          style: {
            backgroundImage: "linear-gradient(180deg, rgba(0, 0, 0, 0%), rgba(0, 0, 0, 100%))"
          }
        }), this.rgba && /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-color-picker-handle`,
          style: {
            width: HANDLE_SIZE,
            height: HANDLE_SIZE,
            borderRadius: RADIUS,
            left: `calc(${this.displayedSv[0]}% - ${RADIUS})`,
            bottom: `calc(${this.displayedSv[1]}% - ${RADIUS})`
          }
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-color-picker-handle__fill`,
          style: {
            backgroundColor: this.handleColor,
            borderRadius: RADIUS,
            width: HANDLE_SIZE,
            height: HANDLE_SIZE
          }
        })));
      }
    });

    const colorPickerInjectionKey = createInjectionKey("n-color-picker");

    function normalizeRgbUnit(value) {
      if (/^\d{1,3}\.?\d*$/.test(value.trim())) {
        return Math.max(0, Math.min(parseInt(value), 255));
      }
      return false;
    }
    function normalizeHueUnit(value) {
      if (/^\d{1,3}\.?\d*$/.test(value.trim())) {
        return Math.max(0, Math.min(parseInt(value), 360));
      }
      return false;
    }
    function normalizeSlvUnit(value) {
      if (/^\d{1,3}\.?\d*$/.test(value.trim())) {
        return Math.max(0, Math.min(parseInt(value), 100));
      }
      return false;
    }
    function normalizeHexaUnit(value) {
      const trimmedValue = value.trim();
      if (/^#[0-9a-fA-F]+$/.test(trimmedValue)) {
        return [4, 5, 7, 9].includes(trimmedValue.length);
      }
      return false;
    }
    function normalizeAlphaUnit(value) {
      if (/^\d{1,3}\.?\d*%$/.test(value.trim())) {
        return Math.max(0, Math.min(parseInt(value) / 100, 100));
      }
      return false;
    }
    const inputThemeOverrides = {
      paddingSmall: "0 4px"
    };
    var ColorInputUnit = vue.defineComponent({
      name: "ColorInputUnit",
      props: {
        label: {
          type: String,
          required: true
        },
        value: {
          type: [Number, String],
          default: null
        },
        showAlpha: Boolean,
        onUpdateValue: {
          type: Function,
          required: true
        }
      },
      setup(props) {
        const inputValueRef = vue.ref("");
        const { themeRef } = vue.inject(colorPickerInjectionKey, null);
        vue.watchEffect(() => {
          inputValueRef.value = getInputString();
        });
        function getInputString() {
          const { value } = props;
          if (value === null)
            return "";
          const { label } = props;
          if (label === "HEX") {
            return value;
          }
          if (label === "A") {
            return `${Math.floor(value * 100)}%`;
          }
          return String(Math.floor(value));
        }
        function handleInputUpdateValue(value) {
          inputValueRef.value = value;
        }
        function handleInputChange(value) {
          let unit;
          let valid;
          switch (props.label) {
            case "HEX":
              valid = normalizeHexaUnit(value);
              if (valid) {
                props.onUpdateValue(value);
              }
              inputValueRef.value = getInputString();
              break;
            case "H":
              unit = normalizeHueUnit(value);
              if (unit === false) {
                inputValueRef.value = getInputString();
              } else {
                props.onUpdateValue(unit);
              }
              break;
            case "S":
            case "L":
            case "V":
              unit = normalizeSlvUnit(value);
              if (unit === false) {
                inputValueRef.value = getInputString();
              } else {
                props.onUpdateValue(unit);
              }
              break;
            case "A":
              unit = normalizeAlphaUnit(value);
              if (unit === false) {
                inputValueRef.value = getInputString();
              } else {
                props.onUpdateValue(unit);
              }
              break;
            case "R":
            case "G":
            case "B":
              unit = normalizeRgbUnit(value);
              if (unit === false) {
                inputValueRef.value = getInputString();
              } else {
                props.onUpdateValue(unit);
              }
              break;
          }
        }
        return {
          mergedTheme: themeRef,
          inputValue: inputValueRef,
          handleInputChange,
          handleInputUpdateValue
        };
      },
      render() {
        const { mergedTheme } = this;
        return /* @__PURE__ */ React.createElement(NInput, {
          size: "small",
          placeholder: this.label,
          theme: mergedTheme.peers.Input,
          themeOverrides: mergedTheme.peerOverrides.Input,
          builtinThemeOverrides: inputThemeOverrides,
          value: this.inputValue,
          onUpdateValue: this.handleInputUpdateValue,
          onChange: this.handleInputChange,
          style: this.label === "A" ? "flex-grow: 1.25;" : ""
        });
      }
    });

    var ColorInput = vue.defineComponent({
      name: "ColorInput",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        mode: {
          type: String,
          required: true
        },
        modes: {
          type: Array,
          required: true
        },
        showAlpha: {
          type: Boolean,
          required: true
        },
        value: {
          type: String,
          default: null
        },
        valueArr: {
          type: Array,
          default: null
        },
        onUpdateValue: {
          type: Function,
          required: true
        },
        onUpdateMode: {
          type: Function,
          required: true
        }
      },
      setup(props) {
        return {
          handleUnitUpdateValue(index, value) {
            const { showAlpha } = props;
            if (props.mode === "hex") {
              props.onUpdateValue(
                (showAlpha ? toHexaString : toHexString)(value)
              );
              return;
            }
            let nextValueArr;
            if (props.valueArr === null) {
              nextValueArr = [0, 0, 0, 0];
            } else {
              nextValueArr = Array.from(props.valueArr);
            }
            switch (props.mode) {
              case "hsv":
                nextValueArr[index] = value;
                props.onUpdateValue(
                  (showAlpha ? toHsvaString : toHsvString)(nextValueArr)
                );
                break;
              case "rgb":
                nextValueArr[index] = value;
                props.onUpdateValue(
                  (showAlpha ? toRgbaString : toRgbString)(nextValueArr)
                );
                break;
              case "hsl":
                nextValueArr[index] = value;
                props.onUpdateValue(
                  (showAlpha ? toHslaString : toHslString)(nextValueArr)
                );
                break;
            }
          }
        };
      },
      render() {
        const { clsPrefix, modes } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-color-picker-input`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-color-picker-input__mode`,
          onClick: this.onUpdateMode,
          style: {
            cursor: modes.length === 1 ? "" : "pointer"
          }
        }, this.mode.toUpperCase() + (this.showAlpha ? "A" : "")), /* @__PURE__ */ React.createElement(NInputGroup, null, {
          default: () => {
            const { mode, valueArr, showAlpha } = this;
            if (mode === "hex") {
              let hexValue = null;
              try {
                hexValue = valueArr === null ? null : (showAlpha ? toHexaString : toHexString)(
                  valueArr
                );
              } catch {
              }
              return /* @__PURE__ */ React.createElement(ColorInputUnit, {
                label: "HEX",
                showAlpha,
                value: hexValue,
                onUpdateValue: (unitValue) => {
                  this.handleUnitUpdateValue(0, unitValue);
                }
              });
            }
            return (mode + (showAlpha ? "a" : "")).split("").map((v, i) => /* @__PURE__ */ React.createElement(ColorInputUnit, {
              label: v.toUpperCase(),
              value: valueArr === null ? null : valueArr[i],
              onUpdateValue: (unitValue) => {
                this.handleUnitUpdateValue(i, unitValue);
              }
            }));
          }
        }));
      }
    });

    var ColorPickerTrigger = vue.defineComponent({
      name: "ColorPickerTrigger",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        value: {
          type: String,
          default: null
        },
        hsla: {
          type: Array,
          default: null
        },
        disabled: Boolean,
        onClick: Function
      },
      setup(props) {
        const { colorPickerSlots, renderLabelRef } = vue.inject(
          colorPickerInjectionKey,
          null
        );
        return () => {
          const { hsla, value, clsPrefix, onClick, disabled } = props;
          const renderLabel = colorPickerSlots.label || renderLabelRef.value;
          return /* @__PURE__ */ React.createElement("div", {
            class: [
              `${clsPrefix}-color-picker-trigger`,
              disabled && `${clsPrefix}-color-picker-trigger--disabled`
            ],
            onClick: disabled ? void 0 : onClick
          }, /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-color-picker-trigger__fill`
          }, /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-color-picker-checkboard`
          }), /* @__PURE__ */ React.createElement("div", {
            style: {
              position: "absolute",
              left: 0,
              right: 0,
              top: 0,
              bottom: 0,
              backgroundColor: hsla ? toHslaString(hsla) : ""
            }
          }), value && hsla ? /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-color-picker-trigger__value`,
            style: {
              color: hsla[2] > 50 || hsla[3] < 0.5 ? "black" : "white"
            }
          }, renderLabel ? renderLabel(value) : value) : null));
        };
      }
    });

    function normalizeColor(color, mode) {
      if (mode === "hsv") {
        const [h2, s, v, a] = hsva(color);
        return toRgbaString([...hsv2rgb(h2, s, v), a]);
      }
      return color;
    }
    function getHexFromName(color) {
      const ctx = document.createElement("canvas").getContext("2d");
      ctx.fillStyle = color;
      return ctx.fillStyle;
    }
    var ColorPickerSwatches = vue.defineComponent({
      name: "ColorPickerSwatches",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        mode: {
          type: String,
          required: true
        },
        swatches: {
          type: Array,
          required: true
        },
        onUpdateColor: {
          type: Function,
          required: true
        }
      },
      setup(props) {
        const parsedSwatchesRef = vue.computed(
          () => props.swatches.map((value) => {
            const mode = getModeFromValue(value);
            return {
              value,
              mode,
              legalValue: normalizeColor(value, mode)
            };
          })
        );
        function normalizeOutput(parsed) {
          const { mode: modeProp } = props;
          let { value, mode: swatchColorMode } = parsed;
          if (!swatchColorMode) {
            swatchColorMode = "hex";
            if (/^[a-zA-Z]+$/.test(value)) {
              value = getHexFromName(value);
            } else {
              warn$2("color-picker", `color ${value} in swatches is invalid.`);
              value = "#000000";
            }
          }
          if (swatchColorMode === modeProp)
            return value;
          return convertColor(value, modeProp, swatchColorMode);
        }
        function handleSwatchSelect(parsed) {
          props.onUpdateColor(normalizeOutput(parsed));
        }
        function handleSwatchKeyDown(e, parsed) {
          if (e.key === "Enter")
            handleSwatchSelect(parsed);
        }
        return {
          parsedSwatchesRef,
          handleSwatchSelect,
          handleSwatchKeyDown
        };
      },
      render() {
        const { clsPrefix } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-color-picker-swatches`
        }, this.parsedSwatchesRef.map((swatch) => /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-color-picker-swatch`,
          tabindex: 0,
          onClick: () => this.handleSwatchSelect(swatch),
          onKeydown: (e) => this.handleSwatchKeyDown(e, swatch)
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-color-picker-swatch__fill`,
          style: { background: swatch.legalValue }
        }))));
      }
    });

    var ColorPreview = vue.defineComponent({
      name: "ColorPreview",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        mode: {
          type: String,
          required: true
        },
        color: {
          type: String,
          default: null,
          validator: (value) => {
            const mode = getModeFromValue(value);
            return Boolean(!value || mode && mode !== "hsv");
          }
        },
        onUpdateColor: {
          type: Function,
          required: true
        }
      },
      setup(props) {
        function handleChange(e) {
          const value = e.target.value;
          props.onUpdateColor?.(
            convertColor(value.toUpperCase(), props.mode, "hex")
          );
          e.stopPropagation();
        }
        return {
          handleChange
        };
      },
      render() {
        const { clsPrefix } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-color-picker-preview__preview`
        }, /* @__PURE__ */ React.createElement("span", {
          class: `${clsPrefix}-color-picker-preview__fill`,
          style: {
            background: this.color || "#000000"
          }
        }), /* @__PURE__ */ React.createElement("input", {
          class: `${clsPrefix}-color-picker-preview__input`,
          type: "color",
          value: this.color,
          onChange: this.handleChange
        }));
      }
    });

    var style$17 = c$1([cB("color-picker", `
    display: inline-block;
    box-sizing: border-box;
    height: var(--n-height);
    font-size: var(--n-font-size);
    width: 100%;
    position: relative;
  `), cB("color-picker-panel", `
    margin: 4px 0;
    width: 240px;
    font-size: var(--n-panel-font-size);
    color: var(--n-text-color);
    background-color: var(--n-color);
    transition:
      box-shadow .3s var(--n-bezier),
      color .3s var(--n-bezier),
      background-color .3s var(--n-bezier);
    border-radius: var(--n-border-radius);
    box-shadow: var(--n-box-shadow);
  `, [fadeInScaleUpTransition(), cB("input", `
      text-align: center;
    `)]), cB("color-picker-checkboard", `
    background: white; 
    position: absolute;
    left: 0;
    right: 0;
    top: 0;
    bottom: 0;
  `, [c$1("&::after", `
      background-image: linear-gradient(45deg, #DDD 25%, #0000 25%), linear-gradient(-45deg, #DDD 25%, #0000 25%), linear-gradient(45deg, #0000 75%, #DDD 75%), linear-gradient(-45deg, #0000 75%, #DDD 75%);
      background-size: 12px 12px;
      background-position: 0 0, 0 6px, 6px -6px, -6px 0px;
      background-repeat: repeat;
      content: "";
      position: absolute;
      left: 0;
      right: 0;
      top: 0;
      bottom: 0;
    `)]), cB("color-picker-slider", `
    margin-bottom: 8px;
    position: relative;
    box-sizing: border-box;
  `, [cE("image", `
      position: absolute;
      left: 0;
      right: 0;
      top: 0;
      bottom: 0;
    `), c$1("&::after", `
      content: "";
      position: absolute;
      border-radius: inherit;
      left: 0;
      right: 0;
      top: 0;
      bottom: 0;
      box-shadow: inset 0 0 2px 0 rgba(0, 0, 0, .24);
      pointer-events: none;
    `)]), cB("color-picker-handle", `
    z-index: 1;
    box-shadow: 0 0 2px 0 rgba(0, 0, 0, .45);
    position: absolute;
    background-color: white;
    overflow: hidden;
  `, [cE("fill", `
      box-sizing: border-box;
      border: 2px solid white;
    `)]), cB("color-picker-pallete", `
    height: 180px;
    position: relative;
    margin-bottom: 8px;
    cursor: crosshair;
  `, [cE("layer", `
      position: absolute;
      left: 0;
      right: 0;
      top: 0;
      bottom: 0;
    `, [cM("shadowed", `
        box-shadow: inset 0 0 2px 0 rgba(0, 0, 0, .24);
      `)])]), cB("color-picker-preview", `
    display: flex;
  `, [cE("sliders", `
      flex: 1 0 auto;
    `), cE("preview", `
      position: relative;
      height: 30px;
      width: 30px;
      margin: 0 0 8px 6px;
      border-radius: 50%;
      box-shadow: rgba(0, 0, 0, .15) 0px 0px 0px 1px inset;
      overflow: hidden;
    `), cE("fill", `
      display: block;
      width: 30px;
      height: 30px;
    `), cE("input", `
      position: absolute;
      top: 0;
      left: 0;
      width: 30px;
      height: 30px;
      opacity: 0;
      z-index: 1;
    `)]), cB("color-picker-input", `
    display: flex;
    align-items: center;
  `, [cB("input", `
      flex-grow: 1;
      flex-basis: 0;
    `), cE("mode", `
      width: 72px;
      text-align: center;
    `)]), cB("color-picker-control", `
    padding: 12px;
  `), cB("color-picker-action", `
    display: flex;
    margin-top: -4px;
    border-top: 1px solid var(--n-divider-color);
    padding: 8px 12px;
    justify-content: flex-end;
  `, [cB("button", "margin-left: 8px;")]), cB("color-picker-trigger", `
    border: var(--n-border);
    height: 100%;
    box-sizing: border-box;
    border-radius: var(--n-border-radius);
    transition: border-color .3s var(--n-bezier);
    cursor: pointer;
  `, [cE("value", `
      white-space: nowrap;
      position: relative;
    `), cE("fill", `
      border-radius: var(--n-border-radius);
      position: absolute;
      display: flex;
      align-items: center;
      justify-content: center;
      left: 4px;
      right: 4px;
      top: 4px;
      bottom: 4px;
    `), cM("disabled", "cursor: not-allowed"), cB("color-picker-checkboard", `
      border-radius: var(--n-border-radius);
    `, [c$1("&::after", `
        --n-block-size: calc((var(--n-height) - 8px) / 3);
        background-size: calc(var(--n-block-size) * 2) calc(var(--n-block-size) * 2);
        background-position: 0 0, 0 var(--n-block-size), var(--n-block-size) calc(-1 * var(--n-block-size)), calc(-1 * var(--n-block-size)) 0px;  
      `)])]), cB("color-picker-swatches", `
    display: grid;
    grid-gap: 8px;
    flex-wrap: wrap;
    position: relative;
    grid-template-columns: repeat(auto-fill, 18px);
    margin-top: 10px;
  `, [cB("color-picker-swatch", `
      width: 18px;
      height: 18px;
      background-image: linear-gradient(45deg, #DDD 25%, #0000 25%), linear-gradient(-45deg, #DDD 25%, #0000 25%), linear-gradient(45deg, #0000 75%, #DDD 75%), linear-gradient(-45deg, #0000 75%, #DDD 75%);
      background-size: 8px 8px;
      background-position: 0px 0, 0px 4px, 4px -4px, -4px 0px;
      background-repeat: repeat;
    `, [cE("fill", `
        position: relative;
        width: 100%;
        height: 100%;
        border-radius: 3px;
        box-shadow: rgba(0, 0, 0, .15) 0px 0px 0px 1px inset;
        cursor: pointer;
      `), c$1("&:focus", `
        outline: none;
      `, [cE("fill", [c$1("&::after", `
            position: absolute;
            top: 0;
            right: 0;
            bottom: 0;
            left: 0;
            background: inherit;
            filter: blur(2px);
            content: "";
          `)])])])])]);

    const colorPickerProps = {
      ...useTheme.props,
      value: String,
      show: {
        type: Boolean,
        default: void 0
      },
      defaultShow: Boolean,
      defaultValue: String,
      modes: {
        type: Array,
        default: () => ["rgb", "hex", "hsl"]
      },
      placement: {
        type: String,
        default: "bottom-start"
      },
      to: useAdjustedTo.propTo,
      showAlpha: {
        type: Boolean,
        default: true
      },
      showPreview: Boolean,
      swatches: Array,
      disabled: {
        type: Boolean,
        default: void 0
      },
      actions: {
        type: Array,
        default: null
      },
      internalActions: Array,
      size: String,
      renderLabel: Function,
      onComplete: Function,
      onConfirm: Function,
      "onUpdate:show": [Function, Array],
      onUpdateShow: [Function, Array],
      "onUpdate:value": [Function, Array],
      onUpdateValue: [Function, Array]
    };
    var NColorPicker = vue.defineComponent({
      name: "ColorPicker",
      props: colorPickerProps,
      setup(props, { slots }) {
        const selfRef = vue.ref(null);
        let upcomingValue = null;
        const formItem = useFormItem(props);
        const { mergedSizeRef, mergedDisabledRef } = formItem;
        const { localeRef } = useLocale("global");
        const { mergedClsPrefixRef, namespaceRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "ColorPicker",
          "-color-picker",
          style$17,
          colorPickerLight$1,
          props,
          mergedClsPrefixRef
        );
        vue.provide(colorPickerInjectionKey, {
          themeRef,
          renderLabelRef: vue.toRef(props, "renderLabel"),
          colorPickerSlots: slots
        });
        const uncontrolledShowRef = vue.ref(props.defaultShow);
        const mergedShowRef = useMergedState(
          vue.toRef(props, "show"),
          uncontrolledShowRef
        );
        function doUpdateShow(value) {
          const { onUpdateShow, "onUpdate:show": _onUpdateShow } = props;
          if (onUpdateShow)
            call(onUpdateShow, value);
          if (_onUpdateShow)
            call(_onUpdateShow, value);
          uncontrolledShowRef.value = value;
        }
        const { defaultValue } = props;
        const uncontrolledValueRef = vue.ref(
          defaultValue === void 0 ? deriveDefaultValue(props.modes, props.showAlpha) : defaultValue
        );
        const mergedValueRef = useMergedState(
          vue.toRef(props, "value"),
          uncontrolledValueRef
        );
        const undoStackRef = vue.ref([mergedValueRef.value]);
        const valueIndexRef = vue.ref(0);
        const valueModeRef = vue.computed(() => getModeFromValue(mergedValueRef.value));
        const { modes } = props;
        const displayedModeRef = vue.ref(
          getModeFromValue(mergedValueRef.value) || modes[0] || "rgb"
        );
        function handleUpdateDisplayedMode() {
          const { modes: modes2 } = props;
          const { value: displayedMode } = displayedModeRef;
          const currentModeIndex = modes2.findIndex((mode) => mode === displayedMode);
          if (~currentModeIndex) {
            displayedModeRef.value = modes2[(currentModeIndex + 1) % modes2.length];
          } else {
            displayedModeRef.value = "rgb";
          }
        }
        let _h, s, l, v, r, g, b, a;
        const hsvaRef = vue.computed(() => {
          const { value: mergedValue } = mergedValueRef;
          if (!mergedValue)
            return null;
          switch (valueModeRef.value) {
            case "hsv":
              return hsva(mergedValue);
            case "hsl":
              [_h, s, l, a] = hsla(mergedValue);
              return [...hsl2hsv(_h, s, l), a];
            case "rgb":
            case "hex":
              [r, g, b, a] = rgba(mergedValue);
              return [...rgb2hsv(r, g, b), a];
          }
        });
        const rgbaRef = vue.computed(() => {
          const { value: mergedValue } = mergedValueRef;
          if (!mergedValue)
            return null;
          switch (valueModeRef.value) {
            case "rgb":
            case "hex":
              return rgba(mergedValue);
            case "hsv":
              [_h, s, v, a] = hsva(mergedValue);
              return [...hsv2rgb(_h, s, v), a];
            case "hsl":
              [_h, s, l, a] = hsla(mergedValue);
              return [...hsl2rgb(_h, s, l), a];
          }
        });
        const hslaRef = vue.computed(() => {
          const { value: mergedValue } = mergedValueRef;
          if (!mergedValue)
            return null;
          switch (valueModeRef.value) {
            case "hsl":
              return hsla(mergedValue);
            case "hsv":
              [_h, s, v, a] = hsva(mergedValue);
              return [...hsv2hsl(_h, s, v), a];
            case "rgb":
            case "hex":
              [r, g, b, a] = rgba(mergedValue);
              return [...rgb2hsl(r, g, b), a];
          }
        });
        const mergedValueArrRef = vue.computed(() => {
          switch (displayedModeRef.value) {
            case "rgb":
            case "hex":
              return rgbaRef.value;
            case "hsv":
              return hsvaRef.value;
            case "hsl":
              return hslaRef.value;
          }
        });
        const displayedHueRef = vue.ref(0);
        const displayedAlphaRef = vue.ref(1);
        const displayedSvRef = vue.ref([0, 0]);
        function handleUpdateSv(s2, v2) {
          const { value: hsvaArr } = hsvaRef;
          const hue = displayedHueRef.value;
          const alpha = hsvaArr ? hsvaArr[3] : 1;
          displayedSvRef.value = [s2, v2];
          const { showAlpha } = props;
          switch (displayedModeRef.value) {
            case "hsv":
              doUpdateValue(
                (showAlpha ? toHsvaString : toHsvString)([hue, s2, v2, alpha]),
                "cursor"
              );
              break;
            case "hsl":
              doUpdateValue(
                (showAlpha ? toHslaString : toHslString)([
                  ...hsv2hsl(hue, s2, v2),
                  alpha
                ]),
                "cursor"
              );
              break;
            case "rgb":
              doUpdateValue(
                (showAlpha ? toRgbaString : toRgbString)([
                  ...hsv2rgb(hue, s2, v2),
                  alpha
                ]),
                "cursor"
              );
              break;
            case "hex":
              doUpdateValue(
                (showAlpha ? toHexaString : toHexString)([
                  ...hsv2rgb(hue, s2, v2),
                  alpha
                ]),
                "cursor"
              );
              break;
          }
        }
        function handleUpdateHue(hue) {
          displayedHueRef.value = hue;
          const { value: hsvaArr } = hsvaRef;
          if (!hsvaArr) {
            return;
          }
          const [, s2, v2, a2] = hsvaArr;
          const { showAlpha } = props;
          switch (displayedModeRef.value) {
            case "hsv":
              doUpdateValue(
                (showAlpha ? toHsvaString : toHsvString)([hue, s2, v2, a2]),
                "cursor"
              );
              break;
            case "rgb":
              doUpdateValue(
                (showAlpha ? toRgbaString : toRgbString)([
                  ...hsv2rgb(hue, s2, v2),
                  a2
                ]),
                "cursor"
              );
              break;
            case "hex":
              doUpdateValue(
                (showAlpha ? toHexaString : toHexString)([
                  ...hsv2rgb(hue, s2, v2),
                  a2
                ]),
                "cursor"
              );
              break;
            case "hsl":
              doUpdateValue(
                (showAlpha ? toHslaString : toHslString)([
                  ...hsv2hsl(hue, s2, v2),
                  a2
                ]),
                "cursor"
              );
              break;
          }
        }
        function handleUpdateAlpha(alpha) {
          switch (displayedModeRef.value) {
            case "hsv":
              [_h, s, v] = hsvaRef.value;
              doUpdateValue(toHsvaString([_h, s, v, alpha]), "cursor");
              break;
            case "rgb":
              [r, g, b] = rgbaRef.value;
              doUpdateValue(toRgbaString([r, g, b, alpha]), "cursor");
              break;
            case "hex":
              [r, g, b] = rgbaRef.value;
              doUpdateValue(toHexaString([r, g, b, alpha]), "cursor");
              break;
            case "hsl":
              [_h, s, l] = hslaRef.value;
              doUpdateValue(toHslaString([_h, s, l, alpha]), "cursor");
              break;
          }
          displayedAlphaRef.value = alpha;
        }
        function doUpdateValue(value, updateSource) {
          if (updateSource === "cursor") {
            upcomingValue = value;
          } else {
            upcomingValue = null;
          }
          const { nTriggerFormChange, nTriggerFormInput } = formItem;
          const { onUpdateValue, "onUpdate:value": _onUpdateValue } = props;
          if (onUpdateValue)
            call(onUpdateValue, value);
          if (_onUpdateValue)
            call(_onUpdateValue, value);
          nTriggerFormChange();
          nTriggerFormInput();
          uncontrolledValueRef.value = value;
        }
        function handleInputUpdateValue(value) {
          doUpdateValue(value, "input");
          void vue.nextTick(handleComplete);
        }
        function handleComplete(pushStack = true) {
          const { value } = mergedValueRef;
          if (value) {
            const { nTriggerFormChange, nTriggerFormInput } = formItem;
            const { onComplete } = props;
            if (onComplete) {
              onComplete(value);
            }
            const { value: undoStack } = undoStackRef;
            const { value: valueIndex } = valueIndexRef;
            if (pushStack) {
              undoStack.splice(valueIndex + 1, undoStack.length, value);
              valueIndexRef.value = valueIndex + 1;
            }
            nTriggerFormChange();
            nTriggerFormInput();
          }
        }
        function undo() {
          const { value: valueIndex } = valueIndexRef;
          if (valueIndex - 1 < 0)
            return;
          doUpdateValue(undoStackRef.value[valueIndex - 1], "input");
          handleComplete(false);
          valueIndexRef.value = valueIndex - 1;
        }
        function redo() {
          const { value: valueIndex } = valueIndexRef;
          if (valueIndex < 0 || valueIndex + 1 >= undoStackRef.value.length)
            return;
          doUpdateValue(undoStackRef.value[valueIndex + 1], "input");
          handleComplete(false);
          valueIndexRef.value = valueIndex + 1;
        }
        function handleConfirm() {
          const { value } = mergedValueRef;
          const { onConfirm } = props;
          if (onConfirm) {
            onConfirm(value);
          }
          doUpdateShow(false);
        }
        const undoableRef = vue.computed(() => valueIndexRef.value >= 1);
        const redoableRef = vue.computed(() => {
          const { value: undoStack } = undoStackRef;
          return undoStack.length > 1 && valueIndexRef.value < undoStack.length - 1;
        });
        vue.watch(mergedShowRef, (value) => {
          if (!value) {
            undoStackRef.value = [mergedValueRef.value];
            valueIndexRef.value = 0;
          }
        });
        vue.watchEffect(() => {
          if (upcomingValue && upcomingValue === mergedValueRef.value) ; else {
            const { value } = hsvaRef;
            if (value) {
              displayedHueRef.value = value[0];
              displayedAlphaRef.value = value[3];
              displayedSvRef.value = [value[1], value[2]];
            }
          }
          upcomingValue = null;
        });
        const cssVarsRef = vue.computed(() => {
          const { value: mergedSize } = mergedSizeRef;
          const {
            common: { cubicBezierEaseInOut },
            self: {
              textColor,
              color,
              panelFontSize,
              boxShadow,
              border,
              borderRadius,
              dividerColor,
              [createKey("height", mergedSize)]: height,
              [createKey("fontSize", mergedSize)]: fontSize
            }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-text-color": textColor,
            "--n-color": color,
            "--n-panel-font-size": panelFontSize,
            "--n-font-size": fontSize,
            "--n-box-shadow": boxShadow,
            "--n-border": border,
            "--n-border-radius": borderRadius,
            "--n-height": height,
            "--n-divider-color": dividerColor
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "color-picker",
          vue.computed(() => {
            return mergedSizeRef.value[0];
          }),
          cssVarsRef,
          props
        ) : void 0;
        function renderPanel() {
          const { value: rgba2 } = rgbaRef;
          const { value: displayedHue } = displayedHueRef;
          const { internalActions, modes: modes2, actions } = props;
          const { value: mergedTheme } = themeRef;
          const { value: mergedClsPrefix } = mergedClsPrefixRef;
          return /* @__PURE__ */ React.createElement("div", {
            class: [
              `${mergedClsPrefix}-color-picker-panel`,
              themeClassHandle?.themeClass.value
            ],
            onDragstart: (e) => {
              e.preventDefault();
            },
            style: inlineThemeDisabled ? void 0 : cssVarsRef.value
          }, /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-color-picker-control`
          }, /* @__PURE__ */ React.createElement(Pallete, {
            clsPrefix: mergedClsPrefix,
            rgba: rgba2,
            displayedHue,
            displayedSv: displayedSvRef.value,
            onUpdateSV: handleUpdateSv,
            onComplete: handleComplete
          }), /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-color-picker-preview`
          }, /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-color-picker-preview__sliders`
          }, /* @__PURE__ */ React.createElement(HueSlider, {
            clsPrefix: mergedClsPrefix,
            hue: displayedHue,
            onUpdateHue: handleUpdateHue,
            onComplete: handleComplete
          }), props.showAlpha ? /* @__PURE__ */ React.createElement(AlphaSlider, {
            clsPrefix: mergedClsPrefix,
            rgba: rgba2,
            alpha: displayedAlphaRef.value,
            onUpdateAlpha: handleUpdateAlpha,
            onComplete: handleComplete
          }) : null), props.showPreview ? /* @__PURE__ */ React.createElement(ColorPreview, {
            clsPrefix: mergedClsPrefix,
            mode: displayedModeRef.value,
            color: rgbaRef.value && toHexString(rgbaRef.value),
            onUpdateColor: (color) => doUpdateValue(color, "input")
          }) : null), /* @__PURE__ */ React.createElement(ColorInput, {
            clsPrefix: mergedClsPrefix,
            showAlpha: props.showAlpha,
            mode: displayedModeRef.value,
            modes: modes2,
            onUpdateMode: handleUpdateDisplayedMode,
            value: mergedValueRef.value,
            valueArr: mergedValueArrRef.value,
            onUpdateValue: handleInputUpdateValue
          }), props.swatches?.length && /* @__PURE__ */ React.createElement(ColorPickerSwatches, {
            clsPrefix: mergedClsPrefix,
            mode: displayedModeRef.value,
            swatches: props.swatches,
            onUpdateColor: (color) => doUpdateValue(color, "input")
          })), actions?.length ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-color-picker-action`
          }, actions.includes("confirm") && /* @__PURE__ */ React.createElement(NButton, {
            size: "small",
            onClick: handleConfirm,
            theme: mergedTheme.peers.Button,
            themeOverrides: mergedTheme.peerOverrides.Button
          }, { default: () => localeRef.value.confirm })) : null, slots.action ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-color-picker-action`
          }, { default: slots.action }) : internalActions ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-color-picker-action`
          }, internalActions.includes("undo") && /* @__PURE__ */ React.createElement(NButton, {
            size: "small",
            onClick: undo,
            disabled: !undoableRef.value,
            theme: mergedTheme.peers.Button,
            themeOverrides: mergedTheme.peerOverrides.Button
          }, { default: () => localeRef.value.undo }), internalActions.includes("redo") && /* @__PURE__ */ React.createElement(NButton, {
            size: "small",
            onClick: redo,
            disabled: !redoableRef.value,
            theme: mergedTheme.peers.Button,
            themeOverrides: mergedTheme.peerOverrides.Button
          }, { default: () => localeRef.value.redo })) : null);
        }
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          namespace: namespaceRef,
          selfRef,
          hsla: hslaRef,
          rgba: rgbaRef,
          mergedShow: mergedShowRef,
          mergedDisabled: mergedDisabledRef,
          isMounted: isMounted(),
          adjustedTo: useAdjustedTo(props),
          mergedValue: mergedValueRef,
          handleTriggerClick() {
            doUpdateShow(true);
          },
          handleClickOutside(e) {
            if (selfRef.value?.contains(getPreciseEventTarget(e))) {
              return;
            }
            doUpdateShow(false);
          },
          renderPanel,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { $slots, mergedClsPrefix, onRender } = this;
        onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          class: [this.themeClass, `${mergedClsPrefix}-color-picker`],
          ref: "selfRef",
          style: this.cssVars
        }, /* @__PURE__ */ React.createElement(VBinder, null, {
          default: () => [
            /* @__PURE__ */ React.createElement(VTarget, null, {
              default: () => /* @__PURE__ */ React.createElement(ColorPickerTrigger, {
                clsPrefix: mergedClsPrefix,
                value: this.mergedValue,
                hsla: this.hsla,
                disabled: this.mergedDisabled,
                onClick: this.handleTriggerClick
              }, {
                label: $slots.label
              })
            }),
            /* @__PURE__ */ React.createElement(VFollower, {
              placement: this.placement,
              show: this.mergedShow,
              containerClass: this.namespace,
              teleportDisabled: this.adjustedTo === useAdjustedTo.tdkey,
              to: this.adjustedTo
            }, {
              default: () => /* @__PURE__ */ React.createElement(vue.Transition, {
                name: "fade-in-scale-up-transition",
                appear: this.isMounted
              }, {
                default: () => this.mergedShow ? vue.withDirectives(this.renderPanel(), [
                  [
                    clickoutside$1,
                    this.handleClickOutside,
                    void 0,
                    { capture: true }
                  ]
                ]) : null
              })
            })
          ]
        }));
      }
    });

    var commonVariables$d = {
      paddingSmall: "12px 16px 12px",
      paddingMedium: "19px 24px 20px",
      paddingLarge: "23px 32px 24px",
      paddingHuge: "27px 40px 28px",
      titleFontSizeSmall: "16px",
      titleFontSizeMedium: "18px",
      titleFontSizeLarge: "18px",
      titleFontSizeHuge: "18px",
      closeIconSize: "18px",
      closeSize: "22px"
    };

    const self$W = vars => {
      const {
        primaryColor,
        borderRadius,
        lineHeight,
        fontSize,
        cardColor,
        textColor2,
        textColor1,
        dividerColor,
        fontWeightStrong,
        closeIconColor,
        closeIconColorHover,
        closeIconColorPressed,
        closeColorHover,
        closeColorPressed,
        modalColor,
        boxShadow1,
        popoverColor,
        actionColor
      } = vars;
      return { ...commonVariables$d,
        lineHeight,
        color: cardColor,
        colorModal: modalColor,
        colorPopover: popoverColor,
        colorTarget: primaryColor,
        colorEmbedded: actionColor,
        colorEmbeddedModal: actionColor,
        colorEmbeddedPopover: actionColor,
        textColor: textColor2,
        titleTextColor: textColor1,
        borderColor: dividerColor,
        actionColor,
        titleFontWeight: fontWeightStrong,
        closeColorHover,
        closeColorPressed,
        closeBorderRadius: borderRadius,
        closeIconColor,
        closeIconColorHover,
        closeIconColorPressed,
        fontSizeSmall: fontSize,
        fontSizeMedium: fontSize,
        fontSizeLarge: fontSize,
        fontSizeHuge: fontSize,
        boxShadow: boxShadow1,
        borderRadius
      };
    };
    const cardLight = {
      name: "Card",
      common: commonLight,
      self: self$W
    };
    var cardLight$1 = cardLight;

    const cardDark = {
      name: "Card",
      common: commonDark,

      self(vars) {
        const commonSelf = self$W(vars);
        const {
          cardColor,
          modalColor,
          popoverColor
        } = vars;
        commonSelf.colorEmbedded = cardColor;
        commonSelf.colorEmbeddedModal = modalColor;
        commonSelf.colorEmbeddedPopover = popoverColor;
        return commonSelf;
      }

    };
    var cardDark$1 = cardDark;

    var rtlStyle$k = cB("card", [cM("rtl", `
    direction: rtl;
  `), c$1(">", [cB("card-header", [c$1(">", [cE("close", `
          margin: 0 8px 0 0;
        `)])])])]);

    const cardRtl = {
      name: "Card",
      style: rtlStyle$k
    };

    var style$16 = c$1([cB("card", `
    font-size: var(--n-font-size);
    line-height: var(--n-line-height);
    display: flex;
    flex-direction: column;
    width: 100%;
    box-sizing: border-box;
    position: relative;
    border-radius: var(--n-border-radius);
    background-color: var(--n-color);
    color: var(--n-text-color);
    word-break: break-word;
    transition: 
      color .3s var(--n-bezier),
      background-color .3s var(--n-bezier),
      box-shadow .3s var(--n-bezier),
      border-color .3s var(--n-bezier);
  `, [asModal({
      background: "var(--n-color-modal)"
    }), cM("hoverable", [c$1("&:hover", "box-shadow: var(--n-box-shadow);")]), cM("content-segmented", [c$1(">", [cE("content", {
      paddingTop: "var(--n-padding-bottom)"
    })])]), cM("content-soft-segmented", [c$1(">", [cE("content", `
          margin: 0 var(--n-padding-left);
          padding: var(--n-padding-bottom) 0;
        `)])]), cM("footer-segmented", [c$1(">", [cE("footer", {
      paddingTop: "var(--n-padding-bottom)"
    })])]), cM("footer-soft-segmented", [c$1(">", [cE("footer", `
          padding: var(--n-padding-bottom) 0;
          margin: 0 var(--n-padding-left);
        `)])]), c$1(">", [cB("card-header", `
        box-sizing: border-box;
        display: flex;
        align-items: center;
        font-size: var(--n-title-font-size);
        padding:
          var(--n-padding-top)
          var(--n-padding-left)
          var(--n-padding-bottom)
          var(--n-padding-left);
      `, [cE("main", `
          font-weight: var(--n-title-font-weight);
          transition: color .3s var(--n-bezier);
          flex: 1;
          color: var(--n-title-text-color);
        `), cE("extra", `
          display: flex;
          align-items: center;
          font-size: var(--n-font-size);
          font-weight: 400;
          transition: color .3s var(--n-bezier);
          color: var(--n-text-color);
        `), cE("close", `
          margin: 0 0 0 8px;
          transition:
            background-color .3s var(--n-bezier),
            color .3s var(--n-bezier);
        `)]), cE("action", `
        box-sizing: border-box;
        transition:
          background-color .3s var(--n-bezier),
          border-color .3s var(--n-bezier);
        background-clip: padding-box;
        background-color: var(--n-action-color);
      `), cE("content", "flex: 1;"), cE("content, footer", `
        box-sizing: border-box;
        padding: 0 var(--n-padding-left) var(--n-padding-bottom) var(--n-padding-left);
        font-size: var(--n-font-size);
      `, [c$1("&:first-child", {
      paddingTop: "var(--n-padding-bottom)"
    })]), cE("action", `
        background-color: var(--n-action-color);
        padding: var(--n-padding-bottom) var(--n-padding-left);
        border-bottom-left-radius: var(--n-border-radius);
        border-bottom-right-radius: var(--n-border-radius);
      `)]), cB("card-cover", `
      overflow: hidden;
      width: 100%;
      border-radius: var(--n-border-radius) var(--n-border-radius) 0 0;
    `, [c$1("img", `
        display: block;
        width: 100%;
      `)]), cM("bordered", `
      border: 1px solid var(--n-border-color);
    `, [c$1("&:target", "border-color: var(--n-color-target);")]), cM("action-segmented", [c$1(">", [cE("action", [c$1("&:not(:first-child)", {
      borderTop: "1px solid var(--n-border-color)"
    })])])]), cM("content-segmented, content-soft-segmented", [c$1(">", [cE("content", {
      transition: "border-color 0.3s var(--n-bezier)"
    }, [c$1("&:not(:first-child)", {
      borderTop: "1px solid var(--n-border-color)"
    })])])]), cM("footer-segmented, footer-soft-segmented", [c$1(">", [cE("footer", {
      transition: "border-color 0.3s var(--n-bezier)"
    }, [c$1("&:not(:first-child)", {
      borderTop: "1px solid var(--n-border-color)"
    })])])]), cM("embedded", `
      background-color: var(--n-color-embedded);
    `)]), insideModal(cB("card", `
    background: var(--n-color-modal);
  `, [cM("embedded", `
      background-color: var(--n-color-embedded-modal);
    `)])), insidePopover(cB("card", `
    background: var(--n-color-popover);
  `, [cM("embedded", `
      background-color: var(--n-color-embedded-popover);
    `)]))]);

    const cardBaseProps = {
      title: String,
      contentStyle: [Object, String],
      headerStyle: [Object, String],
      headerExtraStyle: [Object, String],
      footerStyle: [Object, String],
      embedded: Boolean,
      segmented: {
        type: [Boolean, Object],
        default: false
      },
      size: {
        type: String,
        default: "medium"
      },
      bordered: {
        type: Boolean,
        default: true
      },
      closable: {
        type: Boolean,
        default: false
      },
      hoverable: Boolean,
      role: String,
      onClose: [Function, Array]
    };
    const cardBasePropKeys = keysOf(cardBaseProps);
    const cardProps = {
      ...useTheme.props,
      ...cardBaseProps
    };
    var NCard = vue.defineComponent({
      name: "Card",
      props: cardProps,
      setup(props) {
        const handleCloseClick = () => {
          const { onClose } = props;
          if (onClose)
            call(onClose);
        };
        const { inlineThemeDisabled, mergedClsPrefixRef, mergedRtlRef } = useConfig(props);
        const themeRef = useTheme(
          "Card",
          "-card",
          style$16,
          cardLight$1,
          props,
          mergedClsPrefixRef
        );
        const rtlEnabledRef = useRtl("Card", mergedRtlRef, mergedClsPrefixRef);
        const cssVarsRef = vue.computed(() => {
          const { size } = props;
          const {
            self: {
              color,
              colorModal,
              colorTarget,
              textColor,
              titleTextColor,
              titleFontWeight,
              borderColor,
              actionColor,
              borderRadius,
              lineHeight,
              closeIconColor,
              closeIconColorHover,
              closeIconColorPressed,
              closeColorHover,
              closeColorPressed,
              closeBorderRadius,
              closeIconSize,
              closeSize,
              boxShadow,
              colorPopover,
              colorEmbedded,
              colorEmbeddedModal,
              colorEmbeddedPopover,
              [createKey("padding", size)]: padding,
              [createKey("fontSize", size)]: fontSize,
              [createKey("titleFontSize", size)]: titleFontSize
            },
            common: { cubicBezierEaseInOut }
          } = themeRef.value;
          const {
            top: paddingTop,
            left: paddingLeft,
            bottom: paddingBottom
          } = getMargin(padding);
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-border-radius": borderRadius,
            "--n-color": color,
            "--n-color-modal": colorModal,
            "--n-color-popover": colorPopover,
            "--n-color-embedded": colorEmbedded,
            "--n-color-embedded-modal": colorEmbeddedModal,
            "--n-color-embedded-popover": colorEmbeddedPopover,
            "--n-color-target": colorTarget,
            "--n-text-color": textColor,
            "--n-line-height": lineHeight,
            "--n-action-color": actionColor,
            "--n-title-text-color": titleTextColor,
            "--n-title-font-weight": titleFontWeight,
            "--n-close-icon-color": closeIconColor,
            "--n-close-icon-color-hover": closeIconColorHover,
            "--n-close-icon-color-pressed": closeIconColorPressed,
            "--n-close-color-hover": closeColorHover,
            "--n-close-color-pressed": closeColorPressed,
            "--n-border-color": borderColor,
            "--n-box-shadow": boxShadow,
            "--n-padding-top": paddingTop,
            "--n-padding-bottom": paddingBottom,
            "--n-padding-left": paddingLeft,
            "--n-font-size": fontSize,
            "--n-title-font-size": titleFontSize,
            "--n-close-size": closeSize,
            "--n-close-icon-size": closeIconSize,
            "--n-close-border-radius": closeBorderRadius
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "card",
          vue.computed(() => {
            return props.size[0];
          }),
          cssVarsRef,
          props
        ) : void 0;
        return {
          rtlEnabled: rtlEnabledRef,
          mergedClsPrefix: mergedClsPrefixRef,
          mergedTheme: themeRef,
          handleCloseClick,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const {
          segmented,
          bordered,
          hoverable,
          mergedClsPrefix,
          rtlEnabled,
          onRender,
          embedded,
          $slots
        } = this;
        onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-card`,
            this.themeClass,
            embedded && `${mergedClsPrefix}-card--embedded`,
            {
              [`${mergedClsPrefix}-card--rtl`]: rtlEnabled,
              [`${mergedClsPrefix}-card--content${typeof segmented !== "boolean" && segmented.content === "soft" ? "-soft" : ""}-segmented`]: segmented === true || segmented !== false && segmented.content,
              [`${mergedClsPrefix}-card--footer${typeof segmented !== "boolean" && segmented.footer === "soft" ? "-soft" : ""}-segmented`]: segmented === true || segmented !== false && segmented.footer,
              [`${mergedClsPrefix}-card--action-segmented`]: segmented === true || segmented !== false && segmented.action,
              [`${mergedClsPrefix}-card--bordered`]: bordered,
              [`${mergedClsPrefix}-card--hoverable`]: hoverable
            }
          ],
          style: this.cssVars,
          role: this.role
        }, resolveWrappedSlot(
          $slots.cover,
          (children) => children && /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-card-cover`,
            role: "none"
          }, children)
        ), resolveWrappedSlot($slots.header, (children) => {
          return children || this.title || this.closable ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-card-header`,
            style: this.headerStyle
          }, /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-card-header__main`,
            role: "heading"
          }, children || this.title), resolveWrappedSlot(
            $slots["header-extra"],
            (children2) => children2 && /* @__PURE__ */ React.createElement("div", {
              class: `${mergedClsPrefix}-card-header__extra`,
              style: this.headerExtraStyle
            }, children2)
          ), this.closable ? /* @__PURE__ */ React.createElement(NBaseClose, {
            clsPrefix: mergedClsPrefix,
            class: `${mergedClsPrefix}-card-header__close`,
            onClick: this.handleCloseClick,
            absolute: true
          }) : null) : null;
        }), resolveWrappedSlot(
          $slots.default,
          (children) => children && /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-card__content`,
            style: this.contentStyle,
            role: "none"
          }, children)
        ), resolveWrappedSlot(
          $slots.footer,
          (children) => children && [
            /* @__PURE__ */ React.createElement("div", {
              class: `${mergedClsPrefix}-card__footer`,
              style: this.footerStyle,
              role: "none"
            }, children)
          ]
        ), resolveWrappedSlot(
          $slots.action,
          (children) => children && /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-card__action`,
            role: "none"
          }, children)
        ));
      }
    });

    const self$V = vars => {
      return {
        dotSize: "8px",
        dotColor: "rgba(255, 255, 255, .3)",
        dotColorActive: "rgba(255, 255, 255, 1)",
        dotColorFocus: "rgba(255, 255, 255, .5)",
        dotLineWidth: "16px",
        dotLineWidthActive: "24px",
        arrowColor: "#eee"
      };
    };
    const carouselLight = {
      name: "Carousel",
      common: commonLight,
      self: self$V
    };
    var carouselLight$1 = carouselLight;

    const carouselDark = {
      name: "Carousel",
      common: commonDark,
      self: self$V
    };
    var carouselDark$1 = carouselDark;

    function addDuplicateSlides(slides) {
      const {
        length
      } = slides;

      if (length > 1) {
        slides.push(duplicateSlide(slides[0], 0, "append"));
        slides.unshift(duplicateSlide(slides[length - 1], length - 1, "prepend"));
        return slides;
      }

      return slides;
    }

    function duplicateSlide(child, index, position) {
      return vue.cloneVNode(child, {
        key: `carousel-item-duplicate-${index}-${position}`
      });
    }

    function getDisplayIndex(current, length, duplicatedable) {
      return !duplicatedable ? current : current === 0 ? length - 3 : current === length - 1 ? 0 : current - 1;
    }
    function getRealIndex(current, duplicatedable) {
      return !duplicatedable ? current : current + 1;
    }
    function getPrevIndex(current, length, duplicatedable) {
      if (current < 0) return null;
      return current === 0 ? duplicatedable ? length - 1 : null : current - 1;
    }
    function getNextIndex(current, length, duplicatedable) {
      if (current > length - 1) return null;
      return current === length - 1 ? duplicatedable ? 0 : null : current + 1;
    }
    function getDisplayTotalView(total, duplicatedable) {
      return duplicatedable && total > 3 ? total - 2 : total;
    }

    function isTouchEvent$1(e) {
      return window.TouchEvent && e instanceof window.TouchEvent;
    }

    function calculateSize(element, innerOnly) {
      let {
        width,
        height
      } = element.getBoundingClientRect();

      if (innerOnly) {
        const style = getComputedStyle(element);
        width = width - parseFloat(style.getPropertyValue("padding-left")) - parseFloat(style.getPropertyValue("padding-right"));
        height = height - parseFloat(style.getPropertyValue("padding-top")) - parseFloat(style.getPropertyValue("padding-bottom"));
      }

      return {
        width,
        height
      };
    }
    function clampValue(value, min, max) {
      return value < min ? min : value > max ? max : value;
    }
    function resolveSpeed(value) {
      if (value === void 0) return 0;
      if (typeof value === "number") return value;
      const timeRE = /^((\d+)?\.?\d+?)(ms|s)?$/;
      const match = value.match(timeRE);

      if (match) {
        const [, number,, unit = "ms"] = match;
        return Number(number) * (unit === "ms" ? 1 : 1e3);
      }

      return 0;
    }

    const carouselMethodsInjectionKey = createInjectionKey("n-carousel-methods");
    const provideCarouselContext = contextValue => vue.provide(carouselMethodsInjectionKey, contextValue);
    const useCarouselContext = function () {
      let location = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "unknown";
      let component = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : "component";
      const CarouselContext = vue.inject(carouselMethodsInjectionKey);

      if (!CarouselContext) {
        throwError(location, `\`${component}\` must be placed inside \`n-carousel\`.`);
      }

      return CarouselContext;
    };

    const carouselDotsProps = {
      total: {
        type: Number,
        default: 0
      },
      currentIndex: {
        type: Number,
        default: 0
      },
      dotType: {
        type: String,
        default: "dot"
      },
      trigger: {
        type: String,
        default: "click"
      },
      keyboard: Boolean
    };
    var NCarouselDots = vue.defineComponent({
      name: "CarouselDots",
      props: carouselDotsProps,
      setup(props) {
        const { mergedClsPrefixRef } = useConfig(props);
        const dotElsRef = vue.ref([]);
        const NCarousel = useCarouselContext();
        function handleKeydown(e, current) {
          switch (e.key) {
            case "Enter":
            case " ":
              e.preventDefault();
              NCarousel.to(current);
              return;
          }
          if (props.keyboard) {
            handleKeyboard(e);
          }
        }
        function handleMouseenter(current) {
          if (props.trigger === "hover") {
            NCarousel.to(current);
          }
        }
        function handleClick(current) {
          if (props.trigger === "click") {
            NCarousel.to(current);
          }
        }
        function handleKeyboard(e) {
          if (e.shiftKey || e.altKey || e.ctrlKey || e.metaKey) {
            return;
          }
          const nodeName = document.activeElement?.nodeName.toLowerCase();
          if (nodeName === "input" || nodeName === "textarea") {
            return;
          }
          const { code: keycode } = e;
          const isVerticalNext = keycode === "PageUp" || keycode === "ArrowUp";
          const isVerticalPrev = keycode === "PageDown" || keycode === "ArrowDown";
          const isHorizontalNext = keycode === "PageUp" || keycode === "ArrowRight";
          const isHorizontalPrev = keycode === "PageDown" || keycode === "ArrowLeft";
          const vertical = NCarousel.isVertical();
          const wantToNext = vertical ? isVerticalNext : isHorizontalNext;
          const wantToPrev = vertical ? isVerticalPrev : isHorizontalPrev;
          if (!wantToNext && !wantToPrev) {
            return;
          }
          e.preventDefault();
          if (wantToNext && !NCarousel.isNextDisabled()) {
            NCarousel.next();
            focusDot(NCarousel.currentIndexRef.value);
          } else if (wantToPrev && !NCarousel.isPrevDisabled()) {
            NCarousel.prev();
            focusDot(NCarousel.currentIndexRef.value);
          }
        }
        function focusDot(index) {
          dotElsRef.value[index]?.focus();
        }
        vue.onBeforeUpdate(() => dotElsRef.value.length = 0);
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          dotEls: dotElsRef,
          handleKeydown,
          handleMouseenter,
          handleClick
        };
      },
      render() {
        const { mergedClsPrefix, dotEls } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-carousel__dots`,
            `${mergedClsPrefix}-carousel__dots--${this.dotType}`
          ],
          role: "tablist"
        }, indexMap(this.total, (i) => {
          const selected = i === this.currentIndex;
          return /* @__PURE__ */ React.createElement("div", {
            "aria-selected": selected,
            ref: (el) => dotEls.push(el),
            role: "button",
            tabindex: "0",
            class: [
              `${mergedClsPrefix}-carousel__dot`,
              selected && `${mergedClsPrefix}-carousel__dot--active`
            ],
            key: i,
            onClick: () => this.handleClick(i),
            onMouseenter: () => this.handleMouseenter(i),
            onKeydown: (e) => this.handleKeydown(e, i)
          });
        }));
      }
    });

    const backwardIcon = /* @__PURE__ */ React.createElement("svg", {
      xmlns: "http://www.w3.org/2000/svg",
      viewBox: "0 0 16 16"
    }, /* @__PURE__ */ React.createElement("g", {
      fill: "none"
    }, /* @__PURE__ */ React.createElement("path", {
      d: "M10.26 3.2a.75.75 0 0 1 .04 1.06L6.773 8l3.527 3.74a.75.75 0 1 1-1.1 1.02l-4-4.25a.75.75 0 0 1 0-1.02l4-4.25a.75.75 0 0 1 1.06-.04z",
      fill: "currentColor"
    })));
    const forwardIcon = /* @__PURE__ */ React.createElement("svg", {
      xmlns: "http://www.w3.org/2000/svg",
      viewBox: "0 0 16 16"
    }, /* @__PURE__ */ React.createElement("g", {
      fill: "none"
    }, /* @__PURE__ */ React.createElement("path", {
      d: "M5.74 3.2a.75.75 0 0 0-.04 1.06L9.227 8L5.7 11.74a.75.75 0 1 0 1.1 1.02l4-4.25a.75.75 0 0 0 0-1.02l-4-4.25a.75.75 0 0 0-1.06-.04z",
      fill: "currentColor"
    })));
    var NCarouselArrow = vue.defineComponent({
      name: "CarouselArrow",
      setup(props) {
        const { mergedClsPrefixRef } = useConfig(props);
        const { isVertical, isPrevDisabled, isNextDisabled, prev, next } = useCarouselContext();
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          isVertical,
          isPrevDisabled,
          isNextDisabled,
          prev,
          next
        };
      },
      render() {
        const { mergedClsPrefix } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-carousel__arrow-group`
        }, /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-carousel__arrow`,
            this.isPrevDisabled() && `${mergedClsPrefix}-carousel__arrow--disabled`
          ],
          role: "button",
          onClick: this.prev
        }, backwardIcon), /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-carousel__arrow`,
            this.isNextDisabled() && `${mergedClsPrefix}-carousel__arrow--disabled`
          ],
          role: "button",
          onClick: this.next
        }, forwardIcon));
      }
    });

    const CarouselItemName = "CarouselItem";
    const isCarouselItem = (child) => child.type?.name === CarouselItemName;
    var NCarouselItem = vue.defineComponent({
      name: CarouselItemName,
      setup(props) {
        const { mergedClsPrefixRef } = useConfig(props);
        const NCarousel = useCarouselContext(
          lodash.exports.camelCase(CarouselItemName),
          `n-${lodash.exports.camelCase(CarouselItemName)}`
        );
        const selfElRef = vue.ref();
        const indexRef = vue.computed(() => {
          const { value: selfEl } = selfElRef;
          return selfEl ? NCarousel.getSlideIndex(selfEl) : -1;
        });
        const isPrevRef = vue.computed(() => NCarousel.isPrev(indexRef.value));
        const isNextRef = vue.computed(() => NCarousel.isNext(indexRef.value));
        const isActiveRef = vue.computed(() => NCarousel.isActive(indexRef.value));
        const styleRef = vue.computed(() => NCarousel.getSlideStyle(indexRef.value));
        vue.onMounted(() => NCarousel.addSlide(selfElRef.value));
        vue.onBeforeUnmount(() => {
          NCarousel.removeSlide(selfElRef.value);
        });
        function handleClick(event) {
          const { value: index } = indexRef;
          if (index !== void 0) {
            NCarousel?.onCarouselItemClick(index, event);
          }
        }
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          selfElRef,
          isPrev: isPrevRef,
          isNext: isNextRef,
          isActive: isActiveRef,
          index: indexRef,
          style: styleRef,
          handleClick
        };
      },
      render() {
        const {
          $slots: slots,
          mergedClsPrefix,
          isPrev,
          isNext,
          isActive,
          index,
          style
        } = this;
        const className = [
          `${mergedClsPrefix}-carousel__slide`,
          {
            [`${mergedClsPrefix}-carousel__slide--current`]: isActive,
            [`${mergedClsPrefix}-carousel__slide--prev`]: isPrev,
            [`${mergedClsPrefix}-carousel__slide--next`]: isNext
          }
        ];
        return /* @__PURE__ */ React.createElement("div", {
          ref: "selfElRef",
          class: className,
          role: "option",
          tabindex: "-1",
          "data-index": index,
          "aria-hidden": !isActive,
          style,
          onClickCapture: this.handleClick
        }, slots.default?.({
          isPrev,
          isNext,
          isActive,
          index
        }));
      }
    });

    var style$15 = cB("carousel", `
  position: relative;
  width: 100%;
  height: 100%;
  touch-action: pan-y;
  overflow: hidden;
`, [cE("slides", `
    display: flex;
    width: 100%;
    height: 100%;
    transition-timing-function: var(--n-bezier);
    transition-property: transform;
  `, [cE("slide", `
      flex-shrink: 0;
      position: relative;
      width: 100%;
      height: 100%;
      outline: none;
      overflow: hidden;
    `, [c$1("> img", `
        display: block;
      `)])]), cE("dots", `
    position: absolute;
    display: flex;
    flex-wrap: nowrap;
  `, [cM("dot", [cE("dot", `
        height: var(--n-dot-size);
        width: var(--n-dot-size);
        background-color: var(--n-dot-color);
        border-radius: 50%;
        cursor: pointer;
        transition:
          box-shadow .3s var(--n-bezier),
          background-color .3s var(--n-bezier);
        outline: none;
      `, [c$1("&:focus", `
          background-color: var(--n-dot-color-focus);
        `), cM("active", `
          background-color: var(--n-dot-color-active);
        `)])]), cM("line", [cE("dot", `
        border-radius: 9999px;
        width: var(--n-dot-line-width);
        height: 4px;
        background-color: var(--n-dot-color);
        cursor: pointer;
        transition:
          width .3s var(--n-bezier),
          box-shadow .3s var(--n-bezier),
          background-color .3s var(--n-bezier);
        outline: none;
      `, [c$1("&:focus", `
          background-color: var(--n-dot-color-focus);
        `), cM("active", `
          width: var(--n-dot-line-width-active);
          background-color: var(--n-dot-color-active);
        `)])])]), cE("arrow", `
    transition: background-color .3s var(--n-bezier);
    cursor: pointer;
    height: 28px;
    width: 28px;
    display: flex;
    align-items: center;
    justify-content: center;
    background-color: rgba(255, 255, 255, .2);
    color: var(--n-arrow-color);
    border-radius: 8px;
    user-select: none;
    -webkit-user-select: none;
    font-size: 18px;
  `, [c$1("svg", `
      height: 1em;
      width: 1em;
    `), c$1("&:hover", `
      background-color: rgba(255, 255, 255, .3);
    `)]), cM("vertical", `
    touch-action: pan-x;
  `, [cE("slides", `
      flex-direction: column;
    `), cM("fade", [cE("slide", `
        top: 50%;
        left: unset;
        transform: translateY(-50%);
      `)]), cM("card", [cE("slide", `
        top: 50%;
        left: unset;
        transform: translateY(-50%) translateZ(-400px);
      `, [cM("current", `
          transform: translateY(-50%) translateZ(0);
        `), cM("prev", `
          transform: translateY(-100%) translateZ(-200px);
        `), cM("next", `
          transform: translateY(0%) translateZ(-200px);
        `)])])]), cM("usercontrol", [cE("slides", [c$1(">", [c$1("div", `
          position: absolute;
          top: 50%;
          left: 50%;
          width: 100%;
          height: 100%;
          transform: translate(-50%, -50%);
        `)])])]), cM("left", [cE("dots", `
      transform: translateY(-50%);
      top: 50%;
      left: 12px;
      flex-direction: column;
    `, [cM("line", [cE("dot", `
          width: 4px;
          height: var(--n-dot-line-width);
          margin: 4px 0;
          transition:
            height .3s var(--n-bezier),
            box-shadow .3s var(--n-bezier),
            background-color .3s var(--n-bezier);
          outline: none;
        `, [cM("active", `
            height: var(--n-dot-line-width-active);
          `)])])]), cE("dot", `
      margin: 4px 0;
    `)]), cE("arrow-group", `
    position: absolute;
    display: flex;
    flex-wrap: nowrap;
  `), cM("vertical", [cE("arrow", `
      transform: rotate(90deg);
    `)]), cM("show-arrow", [cM("bottom", [cE("dots", `
        transform: translateX(0);
        bottom: 18px;
        left: 18px;
      `)]), cM("top", [cE("dots", `
        transform: translateX(0);
        top: 18px;
        left: 18px;
      `)]), cM("left", [cE("dots", `
        transform: translateX(0);
        top: 18px;
        left: 18px;
      `)]), cM("right", [cE("dots", `
        transform: translateX(0);
        top: 18px;
        right: 18px;
      `)])]), cM("left", [cE("arrow-group", `
      bottom: 12px;
      left: 12px;
      flex-direction: column;
    `, [c$1("> *:first-child", `
        margin-bottom: 12px;
      `)])]), cM("right", [cE("dots", `
      transform: translateY(-50%);
      top: 50%;
      right: 12px;
      flex-direction: column;
    `, [cM("line", [cE("dot", `
          width: 4px;
          height: var(--n-dot-line-width);
          margin: 4px 0;
          transition:
            height .3s var(--n-bezier),
            box-shadow .3s var(--n-bezier),
            background-color .3s var(--n-bezier);
          outline: none;
        `, [cM("active", `
            height: var(--n-dot-line-width-active);
          `)])])]), cE("dot", `
      margin: 4px 0;
    `), cE("arrow-group", `
      bottom: 12px;
      right: 12px;
      flex-direction: column;
    `, [c$1("> *:first-child", `
        margin-bottom: 12px;
      `)])]), cM("top", [cE("dots", `
      transform: translateX(-50%);
      top: 12px;
      left: 50%;
    `, [cM("line", [cE("dot", `
          margin: 0 4px;
        `)])]), cE("dot", `
      margin: 0 4px;
    `), cE("arrow-group", `
      top: 12px;
      right: 12px;
    `, [c$1("> *:first-child", `
        margin-right: 12px;
      `)])]), cM("bottom", [cE("dots", `
      transform: translateX(-50%);
      bottom: 12px;
      left: 50%;
    `, [cM("line", [cE("dot", `
          margin: 0 4px;
        `)])]), cE("dot", `
      margin: 0 4px;
    `), cE("arrow-group", `
      bottom: 12px;
      right: 12px;
    `, [c$1("> *:first-child", `
        margin-right: 12px;
      `)])]), cM("fade", [cE("slide", `
      position: absolute;
      opacity: 0;
      transition-property: opacity;
      pointer-events: none;
    `, [cM("current", `
        opacity: 1;
        pointer-events: auto;
      `)])]), cM("card", [cE("slides", `
      perspective: 1000px;
    `), cE("slide", `
      position: absolute;
      left: 50%;
      opacity: 0;
      transform: translateX(-50%) translateZ(-400px);
      transition-property: opacity, transform;
    `, [cM("current", `
        opacity: 1;
        transform: translateX(-50%) translateZ(0);
        z-index: 1;
      `), cM("prev", `
        opacity: 0.4;
        transform: translateX(-100%) translateZ(-200px);
      `), cM("next", `
        opacity: 0.4;
        transform: translateX(0%) translateZ(-200px);
      `)])])]);

    const transitionProperties = [
      "transitionDuration",
      "transitionTimingFunction"
    ];
    const carouselProps = {
      ...useTheme.props,
      defaultIndex: {
        type: Number,
        default: 0
      },
      currentIndex: Number,
      showArrow: Boolean,
      dotType: {
        type: String,
        default: "dot"
      },
      dotPlacement: {
        type: String,
        default: "bottom"
      },
      slidesPerView: {
        type: [Number, String],
        default: 1
      },
      spaceBetween: {
        type: Number,
        default: 0
      },
      centeredSlides: Boolean,
      direction: {
        type: String,
        default: "horizontal"
      },
      autoplay: Boolean,
      interval: {
        type: Number,
        default: 5e3
      },
      loop: {
        type: Boolean,
        default: true
      },
      effect: {
        type: String,
        default: "slide"
      },
      showDots: {
        type: Boolean,
        default: true
      },
      trigger: {
        type: String,
        default: "click"
      },
      transitionStyle: {
        type: Object,
        default: () => ({
          transitionDuration: "300ms"
        })
      },
      transitionProps: Object,
      draggable: Boolean,
      prevSlideStyle: [Object, String],
      nextSlideStyle: [Object, String],
      touchable: {
        type: Boolean,
        default: true
      },
      mousewheel: Boolean,
      keyboard: Boolean,
      "onUpdate:currentIndex": Function,
      onUpdateCurrentIndex: Function
    };
    let globalDragging = false;
    var Carousel = vue.defineComponent({
      name: "Carousel",
      props: carouselProps,
      setup(props) {
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const selfElRef = vue.ref(null);
        const slidesElRef = vue.ref(null);
        const slideElsRef = vue.ref([]);
        const slideVNodesRef = { value: [] };
        const verticalRef = vue.computed(() => props.direction === "vertical");
        const sizeAxisRef = vue.computed(() => verticalRef.value ? "height" : "width");
        const spaceAxisRef = vue.computed(
          () => verticalRef.value ? "bottom" : "right"
        );
        const sequenceLayoutRef = vue.computed(() => props.effect === "slide");
        const duplicatedableRef = vue.computed(
          () => props.loop && props.slidesPerView === 1 && sequenceLayoutRef.value
        );
        const userWantsControlRef = vue.computed(() => props.effect === "custom");
        const displaySlidesPerViewRef = vue.computed(
          () => !sequenceLayoutRef.value || props.centeredSlides ? 1 : props.slidesPerView
        );
        const realSlidesPerViewRef = vue.computed(
          () => userWantsControlRef.value ? 1 : props.slidesPerView
        );
        const autoSlideSizeRef = vue.computed(
          () => displaySlidesPerViewRef.value === "auto" || props.slidesPerView === "auto" && props.centeredSlides
        );
        const perViewSizeRef = vue.ref({ width: 0, height: 0 });
        const slideSizesRef = vue.computed(() => {
          const { value: slidesEls } = slideElsRef;
          if (!slidesEls.length)
            return [];
          const { value: autoSlideSize } = autoSlideSizeRef;
          if (autoSlideSize) {
            return slidesEls.map((slide) => calculateSize(slide));
          }
          const { value: slidesPerView } = realSlidesPerViewRef;
          const { value: perViewSize } = perViewSizeRef;
          const { value: axis } = sizeAxisRef;
          let axisSize = perViewSize[axis];
          if (slidesPerView !== "auto") {
            const { spaceBetween } = props;
            const remaining = axisSize - (slidesPerView - 1) * spaceBetween;
            const percentage = 1 / Math.max(1, slidesPerView);
            axisSize = remaining * percentage;
          }
          const slideSize = { ...perViewSize, [axis]: axisSize };
          return slidesEls.map(() => slideSize);
        });
        const slideTranlatesRef = vue.computed(() => {
          const { value: slideSizes } = slideSizesRef;
          if (!slideSizes.length)
            return [];
          const { centeredSlides, spaceBetween } = props;
          const { value: axis } = sizeAxisRef;
          const { [axis]: perViewSize } = perViewSizeRef.value;
          let previousTranslate2 = 0;
          return slideSizes.map(({ [axis]: slideSize }) => {
            let translate = previousTranslate2;
            if (centeredSlides) {
              translate += (slideSize - perViewSize) / 2;
            }
            previousTranslate2 += slideSize + spaceBetween;
            return translate;
          });
        });
        const isMountedRef = vue.ref(false);
        const transitionStyleRef = vue.computed(() => {
          const { transitionStyle } = props;
          return transitionStyle ? keep(transitionStyle, transitionProperties) : {};
        });
        const speedRef = vue.computed(
          () => userWantsControlRef.value ? 0 : resolveSpeed(transitionStyleRef.value.transitionDuration)
        );
        const slideStylesRef = vue.computed(() => {
          const { value: slidesEls } = slideElsRef;
          if (!slidesEls.length)
            return [];
          const useComputedSize = !(autoSlideSizeRef.value || realSlidesPerViewRef.value === 1);
          const getSlideSize = (index) => {
            if (useComputedSize) {
              const { value: axis } = sizeAxisRef;
              return {
                [axis]: `${slideSizesRef.value[index][axis]}px`
              };
            }
          };
          if (userWantsControlRef.value) {
            return slidesEls.map((_, i) => getSlideSize(i));
          }
          const { effect, spaceBetween } = props;
          const { value: spaceAxis } = spaceAxisRef;
          return slidesEls.reduce((styles, _, i) => {
            const style2 = {
              ...getSlideSize(i),
              [`margin-${spaceAxis}`]: `${spaceBetween}px`
            };
            styles.push(style2);
            if (isMountedRef.value && (effect === "fade" || effect === "card")) {
              Object.assign(style2, transitionStyleRef.value);
            }
            return styles;
          }, []);
        });
        const totalViewRef = vue.computed(() => {
          const { value: slidesPerView } = displaySlidesPerViewRef;
          const { length: totalSlides } = slideElsRef.value;
          if (slidesPerView !== "auto") {
            return Math.max(totalSlides - slidesPerView, 0) + 1;
          } else {
            const { value: slideSizes } = slideSizesRef;
            const { length } = slideSizes;
            if (!length)
              return totalSlides;
            const { value: translates } = slideTranlatesRef;
            const { value: axis } = sizeAxisRef;
            const perViewSize = perViewSizeRef.value[axis];
            let lastViewSize = slideSizes[slideSizes.length - 1][axis];
            let i = length;
            while (i > 1 && lastViewSize < perViewSize) {
              i--;
              lastViewSize += translates[i] - translates[i - 1];
            }
            return clampValue(i + 1, 1, length);
          }
        });
        const displayTotalViewRef = vue.computed(
          () => getDisplayTotalView(totalViewRef.value, duplicatedableRef.value)
        );
        const defaultRealIndex = getRealIndex(
          props.defaultIndex,
          duplicatedableRef.value
        );
        const uncontrolledDisplayIndexRef = vue.ref(
          getDisplayIndex(
            defaultRealIndex,
            totalViewRef.value,
            duplicatedableRef.value
          )
        );
        const mergedDisplayIndexRef = useMergedState(
          vue.toRef(props, "currentIndex"),
          uncontrolledDisplayIndexRef
        );
        const realIndexRef = vue.computed(
          () => getRealIndex(mergedDisplayIndexRef.value, duplicatedableRef.value)
        );
        function toRealIndex(index) {
          index = clampValue(index, 0, totalViewRef.value - 1);
          const displayIndex = getDisplayIndex(
            index,
            totalViewRef.value,
            duplicatedableRef.value
          );
          const { value: lastDisplayIndex } = mergedDisplayIndexRef;
          if (displayIndex !== mergedDisplayIndexRef.value) {
            uncontrolledDisplayIndexRef.value = displayIndex;
            props["onUpdate:currentIndex"]?.(displayIndex, lastDisplayIndex);
            props.onUpdateCurrentIndex?.(displayIndex, lastDisplayIndex);
          }
        }
        function getRealPrevIndex(index = realIndexRef.value) {
          return getPrevIndex(index, totalViewRef.value, props.loop);
        }
        function getRealNextIndex(index = realIndexRef.value) {
          return getNextIndex(index, totalViewRef.value, props.loop);
        }
        function isRealPrev(slideOrIndex) {
          const index = getSlideIndex(slideOrIndex);
          return index !== null && getRealPrevIndex() === index;
        }
        function isRealNext(slideOrIndex) {
          const index = getSlideIndex(slideOrIndex);
          return index !== null && getRealNextIndex() === index;
        }
        function isRealActive(slideOrIndex) {
          return realIndexRef.value === getSlideIndex(slideOrIndex);
        }
        function isDisplayActive(index) {
          return mergedDisplayIndexRef.value === index;
        }
        function isPrevDisabled() {
          return getRealPrevIndex() === null;
        }
        function isNextDisabled() {
          return getRealNextIndex() === null;
        }
        function to(index) {
          const realIndex = clampValue(
            getRealIndex(index, duplicatedableRef.value),
            0,
            totalViewRef.value
          );
          if (index !== mergedDisplayIndexRef.value || realIndex !== realIndexRef.value) {
            toRealIndex(realIndex);
          }
        }
        function prev() {
          const prevIndex = getRealPrevIndex();
          if (prevIndex !== null)
            toRealIndex(prevIndex);
        }
        function next() {
          const nextIndex = getRealNextIndex();
          if (nextIndex !== null)
            toRealIndex(nextIndex);
        }
        function prevIfSlideTransitionEnd() {
          if (!inTransition || !duplicatedableRef.value)
            prev();
        }
        function nextIfSlideTransitionEnd() {
          if (!inTransition || !duplicatedableRef.value)
            next();
        }
        let inTransition = false;
        let previousTranslate = 0;
        const translateStyleRef = vue.ref({});
        function updateTranslate(translate, speed = 0) {
          translateStyleRef.value = Object.assign({}, transitionStyleRef.value, {
            transform: verticalRef.value ? `translateY(${-translate}px)` : `translateX(${-translate}px)`,
            transitionDuration: `${speed}ms`
          });
        }
        function fixTranslate(speed = 0) {
          if (sequenceLayoutRef.value) {
            translateTo(realIndexRef.value, speed);
          } else if (previousTranslate !== 0) {
            if (!inTransition && speed > 0) {
              inTransition = true;
            }
            updateTranslate(previousTranslate = 0, speed);
          }
        }
        function translateTo(index, speed) {
          const translate = getTranslate(index);
          if (translate !== previousTranslate && speed > 0) {
            inTransition = true;
          }
          previousTranslate = getTranslate(realIndexRef.value);
          updateTranslate(translate, speed);
        }
        function getTranslate(index) {
          let translate;
          if (index >= totalViewRef.value - 1) {
            translate = getLastViewTranslate();
          } else {
            translate = slideTranlatesRef.value[index] || 0;
          }
          return translate;
        }
        function getLastViewTranslate() {
          if (displaySlidesPerViewRef.value === "auto") {
            const { value: axis } = sizeAxisRef;
            const { [axis]: perViewSize } = perViewSizeRef.value;
            const { value: translates } = slideTranlatesRef;
            const lastTranslate = translates[translates.length - 1];
            let overallSize;
            if (lastTranslate === void 0) {
              overallSize = perViewSize;
            } else {
              const { value: slideSizes } = slideSizesRef;
              overallSize = lastTranslate + slideSizes[slideSizes.length - 1][axis];
            }
            return overallSize - perViewSize;
          } else {
            const { value: translates } = slideTranlatesRef;
            return translates[totalViewRef.value - 1] || 0;
          }
        }
        const carouselContext = {
          currentIndexRef: mergedDisplayIndexRef,
          to,
          prev: prevIfSlideTransitionEnd,
          next: nextIfSlideTransitionEnd,
          isVertical: () => verticalRef.value,
          isHorizontal: () => !verticalRef.value,
          isPrev: isRealPrev,
          isNext: isRealNext,
          isActive: isRealActive,
          isPrevDisabled,
          isNextDisabled,
          getSlideIndex,
          getSlideStyle,
          addSlide,
          removeSlide,
          onCarouselItemClick
        };
        provideCarouselContext(carouselContext);
        function addSlide(slide) {
          if (!slide)
            return;
          slideElsRef.value.push(slide);
        }
        function removeSlide(slide) {
          if (!slide)
            return;
          const index = getSlideIndex(slide);
          if (index !== -1) {
            slideElsRef.value.splice(index, 1);
          }
        }
        function getSlideIndex(slideOrIndex) {
          return typeof slideOrIndex === "number" ? slideOrIndex : slideOrIndex ? slideElsRef.value.indexOf(slideOrIndex) : -1;
        }
        function getSlideStyle(slide) {
          const index = getSlideIndex(slide);
          if (index !== -1) {
            const styles = [slideStylesRef.value[index]];
            const isPrev = carouselContext.isPrev(index);
            const isNext = carouselContext.isNext(index);
            if (isPrev) {
              styles.push(props.prevSlideStyle || "");
            }
            if (isNext) {
              styles.push(props.nextSlideStyle || "");
            }
            return vue.normalizeStyle(styles);
          }
        }
        function onCarouselItemClick(index, event) {
          let allowClick = !inTransition && !dragging && !isEffectiveDrag;
          if (props.effect === "card" && allowClick && !isRealActive(index)) {
            to(index);
            allowClick = false;
          }
          if (!allowClick) {
            event.preventDefault();
            event.stopPropagation();
          }
        }
        let autoplayTimer = null;
        function stopAutoplay() {
          if (autoplayTimer) {
            clearInterval(autoplayTimer);
            autoplayTimer = null;
          }
        }
        function resetAutoplay() {
          stopAutoplay();
          const disabled = !props.autoplay || displayTotalViewRef.value < 2;
          if (!disabled) {
            autoplayTimer = window.setInterval(next, props.interval);
          }
        }
        let dragStartX = 0;
        let dragStartY = 0;
        let dragOffset = 0;
        let dragStartTime = 0;
        let dragging = false;
        let isEffectiveDrag = false;
        function handleTouchstart(event) {
          if (globalDragging)
            return;
          if (!slidesElRef.value?.contains(
            getPreciseEventTarget(event)
          )) {
            return;
          }
          globalDragging = true;
          dragging = true;
          isEffectiveDrag = false;
          dragStartTime = Date.now();
          stopAutoplay();
          if (event.type !== "touchstart" && !event.target.isContentEditable) {
            event.preventDefault();
          }
          const touchEvent = isTouchEvent$1(event) ? event.touches[0] : event;
          if (verticalRef.value) {
            dragStartY = touchEvent.clientY;
          } else {
            dragStartX = touchEvent.clientX;
          }
          if (props.touchable) {
            on("touchmove", document, handleTouchmove, { passive: true });
            on("touchend", document, handleTouchend);
            on("touchcancel", document, handleTouchend);
          }
          if (props.draggable) {
            on("mousemove", document, handleTouchmove);
            on("mouseup", document, handleTouchend);
          }
        }
        function handleTouchmove(event) {
          const { value: vertical } = verticalRef;
          const { value: axis } = sizeAxisRef;
          const touchEvent = isTouchEvent$1(event) ? event.touches[0] : event;
          const offset = vertical ? touchEvent.clientY - dragStartY : touchEvent.clientX - dragStartX;
          const perViewSize = perViewSizeRef.value[axis];
          dragOffset = clampValue(offset, -perViewSize, perViewSize);
          if (event.cancelable) {
            event.preventDefault();
          }
          if (sequenceLayoutRef.value) {
            updateTranslate(previousTranslate - dragOffset, 0);
          }
        }
        function handleTouchend() {
          const { value: realIndex } = realIndexRef;
          let currentIndex = realIndex;
          if (!inTransition && dragOffset !== 0 && sequenceLayoutRef.value) {
            const currentTranslate = previousTranslate - dragOffset;
            const translates = [
              ...slideTranlatesRef.value.slice(0, totalViewRef.value - 1),
              getLastViewTranslate()
            ];
            let prevOffset = null;
            for (let i = 0; i < translates.length; i++) {
              const offset = Math.abs(translates[i] - currentTranslate);
              if (prevOffset !== null && prevOffset < offset) {
                break;
              }
              prevOffset = offset;
              currentIndex = i;
            }
          }
          if (currentIndex === realIndex) {
            const timeElapsed = Date.now() - dragStartTime;
            const { value: axis } = sizeAxisRef;
            const perViewSize = perViewSizeRef.value[axis];
            if (dragOffset > perViewSize / 2 || dragOffset / timeElapsed > 0.4) {
              currentIndex = getRealPrevIndex(realIndex);
            } else if (dragOffset < -perViewSize / 2 || dragOffset / timeElapsed < -0.4) {
              currentIndex = getRealNextIndex(realIndex);
            }
          }
          if (currentIndex !== null && currentIndex !== realIndex) {
            isEffectiveDrag = true;
            toRealIndex(currentIndex);
            void vue.nextTick(() => {
              if (!duplicatedableRef.value || uncontrolledDisplayIndexRef.value !== mergedDisplayIndexRef.value) {
                fixTranslate(speedRef.value);
              }
            });
          } else {
            fixTranslate(speedRef.value);
          }
          resetDragStatus();
          resetAutoplay();
        }
        function resetDragStatus() {
          if (dragging) {
            globalDragging = false;
          }
          dragging = false;
          dragStartX = 0;
          dragStartY = 0;
          dragOffset = 0;
          dragStartTime = 0;
          off("touchmove", document, handleTouchmove);
          off("touchend", document, handleTouchend);
          off("touchcancel", document, handleTouchend);
          off("mousemove", document, handleTouchmove);
          off("mouseup", document, handleTouchend);
        }
        function handleTransitionEnd() {
          if (sequenceLayoutRef.value && inTransition) {
            const { value: realIndex } = realIndexRef;
            translateTo(realIndex, 0);
          } else {
            resetAutoplay();
          }
          if (sequenceLayoutRef.value) {
            translateStyleRef.value.transitionDuration = "0ms";
          }
          inTransition = false;
        }
        function handleMousewheel(event) {
          event.preventDefault();
          if (inTransition)
            return;
          let { deltaX, deltaY } = event;
          if (event.shiftKey && !deltaX) {
            deltaX = deltaY;
          }
          const prevMultiplier = -1;
          const nextMultiplier = 1;
          const m = (deltaX || deltaY) > 0 ? nextMultiplier : prevMultiplier;
          let rx = 0;
          let ry = 0;
          if (verticalRef.value) {
            ry = m;
          } else {
            rx = m;
          }
          const responseStep = 10;
          if (ry * deltaY >= responseStep || rx * deltaX >= responseStep) {
            if (m === nextMultiplier && !isNextDisabled()) {
              next();
            } else if (m === prevMultiplier && !isPrevDisabled()) {
              prev();
            }
          }
        }
        function handleResize() {
          perViewSizeRef.value = calculateSize(selfElRef.value, true);
          resetAutoplay();
        }
        function handleSlideResize() {
          if (autoSlideSizeRef.value) {
            slideSizesRef.effect.scheduler?.();
            slideSizesRef.effect.run();
          }
        }
        function handleMouseenter() {
          if (props.autoplay) {
            stopAutoplay();
          }
        }
        function handleMouseleave() {
          if (props.autoplay) {
            resetAutoplay();
          }
        }
        vue.onMounted(() => {
          vue.watchEffect(resetAutoplay);
          requestAnimationFrame(() => isMountedRef.value = true);
        });
        vue.onBeforeUnmount(() => {
          resetDragStatus();
          stopAutoplay();
        });
        vue.onUpdated(() => {
          const { value: slidesEls } = slideElsRef;
          const { value: slideVNodes } = slideVNodesRef;
          const indexMap = /* @__PURE__ */ new Map();
          const getDisplayIndex2 = (el) => indexMap.has(el) ? indexMap.get(el) : -1;
          let isChanged = false;
          for (let i = 0; i < slidesEls.length; i++) {
            const index = slideVNodes.findIndex((v) => v.el === slidesEls[i]);
            if (index !== i) {
              isChanged = true;
            }
            indexMap.set(slidesEls[i], index);
          }
          if (isChanged) {
            slidesEls.sort((a, b) => getDisplayIndex2(a) - getDisplayIndex2(b));
          }
        });
        vue.watch(
          realIndexRef,
          (realIndex, lastRealIndex) => {
            if (realIndex === lastRealIndex)
              return;
            resetAutoplay();
            if (sequenceLayoutRef.value) {
              if (duplicatedableRef.value && displayTotalViewRef.value > 2) {
                const { value: length } = totalViewRef;
                if (realIndex === length - 2 && lastRealIndex === 1) {
                  realIndex = 0;
                } else if (realIndex === 1 && lastRealIndex === length - 2) {
                  realIndex = length - 1;
                }
              }
              translateTo(realIndex, speedRef.value);
            } else {
              fixTranslate();
            }
          },
          { immediate: true }
        );
        vue.watch(
          [duplicatedableRef, displaySlidesPerViewRef],
          () => void vue.nextTick(() => toRealIndex(realIndexRef.value))
        );
        vue.watch(slideTranlatesRef, () => sequenceLayoutRef.value && fixTranslate(), {
          deep: true
        });
        vue.watch(sequenceLayoutRef, (value) => {
          if (!value) {
            inTransition = false;
            updateTranslate(previousTranslate = 0);
          } else {
            fixTranslate();
          }
        });
        const slidesControlListenersRef = vue.computed(() => {
          return {
            onTouchstartPassive: props.touchable ? handleTouchstart : void 0,
            onMousedown: props.draggable ? handleTouchstart : void 0,
            onWheel: props.mousewheel ? handleMousewheel : void 0
          };
        });
        const arrowSlotPropsRef = vue.computed(() => ({
          ...keep(carouselContext, [
            "to",
            "prev",
            "next",
            "isPrevDisabled",
            "isNextDisabled"
          ]),
          total: displayTotalViewRef.value,
          currentIndex: mergedDisplayIndexRef.value
        }));
        const dotSlotPropsRef = vue.computed(() => ({
          total: displayTotalViewRef.value,
          currentIndex: mergedDisplayIndexRef.value,
          to: carouselContext.to
        }));
        const caroulseExposedMethod = {
          getCurrentIndex: () => mergedDisplayIndexRef.value,
          to,
          prev,
          next
        };
        const themeRef = useTheme(
          "Carousel",
          "-carousel",
          style$15,
          carouselLight$1,
          props,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self: {
              dotSize,
              dotColor,
              dotColorActive,
              dotColorFocus,
              dotLineWidth,
              dotLineWidthActive,
              arrowColor
            }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-dot-color": dotColor,
            "--n-dot-color-focus": dotColorFocus,
            "--n-dot-color-active": dotColorActive,
            "--n-dot-size": dotSize,
            "--n-dot-line-width": dotLineWidth,
            "--n-dot-line-width-active": dotLineWidthActive,
            "--n-arrow-color": arrowColor
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("carousel", void 0, cssVarsRef, props) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          selfElRef,
          slidesElRef,
          slideVNodes: slideVNodesRef,
          duplicatedable: duplicatedableRef,
          userWantsControl: userWantsControlRef,
          autoSlideSize: autoSlideSizeRef,
          displayIndex: mergedDisplayIndexRef,
          realIndex: realIndexRef,
          slideStyles: slideStylesRef,
          translateStyle: translateStyleRef,
          slidesControlListeners: slidesControlListenersRef,
          handleTransitionEnd,
          handleResize,
          handleSlideResize,
          handleMouseenter,
          handleMouseleave,
          isActive: isDisplayActive,
          arrowSlotProps: arrowSlotPropsRef,
          dotSlotProps: dotSlotPropsRef,
          ...caroulseExposedMethod,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const {
          mergedClsPrefix,
          showArrow,
          userWantsControl,
          slideStyles,
          dotType,
          dotPlacement,
          slidesControlListeners,
          transitionProps = {},
          arrowSlotProps,
          dotSlotProps,
          $slots: { default: defaultSlot, dots: dotsSlot, arrow: arrowSlot }
        } = this;
        const children = defaultSlot && flatten$3(defaultSlot()) || [];
        let slides = filterCarouselItem(children);
        if (!slides.length) {
          slides = children.map((ch) => /* @__PURE__ */ React.createElement(NCarouselItem, null, {
            default: () => vue.cloneVNode(ch)
          }));
        }
        if (this.duplicatedable) {
          slides = addDuplicateSlides(slides);
        }
        this.slideVNodes.value = slides;
        if (this.autoSlideSize) {
          slides = slides.map((slide) => /* @__PURE__ */ React.createElement(VResizeObserver, {
            onResize: this.handleSlideResize
          }, {
            default: () => slide
          }));
        }
        this.onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          ref: "selfElRef",
          class: [
            this.themeClass,
            `${mergedClsPrefix}-carousel`,
            this.direction === "vertical" && `${mergedClsPrefix}-carousel--vertical`,
            this.showArrow && `${mergedClsPrefix}-carousel--show-arrow`,
            `${mergedClsPrefix}-carousel--${dotPlacement}`,
            `${mergedClsPrefix}-carousel--${this.direction}`,
            `${mergedClsPrefix}-carousel--${this.effect}`,
            userWantsControl && `${mergedClsPrefix}-carousel--usercontrol`
          ],
          style: this.cssVars,
          ...slidesControlListeners,
          onMouseenter: this.handleMouseenter,
          onMouseleave: this.handleMouseleave
        }, /* @__PURE__ */ React.createElement(VResizeObserver, {
          onResize: this.handleResize
        }, {
          default: () => /* @__PURE__ */ React.createElement("div", {
            ref: "slidesElRef",
            class: `${mergedClsPrefix}-carousel__slides`,
            role: "listbox",
            style: this.translateStyle,
            onTransitionend: this.handleTransitionEnd
          }, userWantsControl ? slides.map((slide, i) => /* @__PURE__ */ React.createElement("div", {
            style: slideStyles[i],
            key: i
          }, vue.withDirectives(
            /* @__PURE__ */ React.createElement(vue.Transition, {
              ...transitionProps
            }, {
              default: () => slide
            }),
            [[vue.vShow, this.isActive(i)]]
          ))) : slides)
        }), this.showDots && dotSlotProps.total > 1 && resolveSlotWithProps(dotsSlot, dotSlotProps, () => [
          /* @__PURE__ */ React.createElement(NCarouselDots, {
            key: dotType + dotPlacement,
            total: dotSlotProps.total,
            currentIndex: dotSlotProps.currentIndex,
            dotType,
            trigger: this.trigger,
            keyboard: this.keyboard
          })
        ]), showArrow && resolveSlotWithProps(arrowSlot, arrowSlotProps, () => [
          /* @__PURE__ */ React.createElement(NCarouselArrow, null)
        ]));
      }
    });
    function filterCarouselItem(vnodes) {
      return vnodes.reduce((carouselItems, vnode) => {
        if (isCarouselItem(vnode)) {
          carouselItems.push(vnode);
        }
        return carouselItems;
      }, []);
    }

    var commonVariables$c = {
      sizeSmall: "14px",
      sizeMedium: "16px",
      sizeLarge: "18px",
      labelPadding: "0 8px"
    };

    const self$U = vars => {
      const {
        baseColor,
        inputColorDisabled,
        cardColor,
        modalColor,
        popoverColor,
        textColorDisabled,
        borderColor,
        primaryColor,
        textColor2,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge,
        borderRadiusSmall,
        lineHeight
      } = vars;
      return { ...commonVariables$c,
        labelLineHeight: lineHeight,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge,
        borderRadius: borderRadiusSmall,
        color: baseColor,
        colorChecked: primaryColor,
        colorDisabled: inputColorDisabled,
        colorDisabledChecked: inputColorDisabled,
        colorTableHeader: cardColor,
        colorTableHeaderModal: modalColor,
        colorTableHeaderPopover: popoverColor,
        checkMarkColor: baseColor,
        checkMarkColorDisabled: textColorDisabled,
        checkMarkColorDisabledChecked: textColorDisabled,
        border: `1px solid ${borderColor}`,
        borderDisabled: `1px solid ${borderColor}`,
        borderDisabledChecked: `1px solid ${borderColor}`,
        borderChecked: `1px solid ${primaryColor}`,
        borderFocus: `1px solid ${primaryColor}`,
        boxShadowFocus: `0 0 0 2px ${changeColor(primaryColor, {
      alpha: 0.3
    })}`,
        textColor: textColor2,
        textColorDisabled
      };
    };
    const checkboxLight = {
      name: "Checkbox",
      common: commonLight,
      self: self$U
    };
    var checkboxLight$1 = checkboxLight;

    const checkboxDark = {
      name: "Checkbox",
      common: commonDark,

      self(vars) {
        const {
          cardColor
        } = vars;
        const commonSelf = self$U(vars);
        commonSelf.color = "#0000";
        commonSelf.checkMarkColor = cardColor;
        return commonSelf;
      }

    };
    var checkboxDark$1 = checkboxDark;

    var rtlStyle$j = cB("checkbox", [cM("rtl", `
    direction: rtl;
  `)]);

    const checkboxRtl = {
      name: "Checkbox",
      style: rtlStyle$j
    };

    const self$T = vars => {
      const {
        borderRadius,
        boxShadow2,
        popoverColor,
        textColor2,
        textColor3,
        primaryColor,
        textColorDisabled,
        dividerColor,
        hoverColor,
        fontSizeMedium,
        heightMedium
      } = vars;
      return {
        menuBorderRadius: borderRadius,
        menuColor: popoverColor,
        menuBoxShadow: boxShadow2,
        menuDividerColor: dividerColor,
        menuHeight: "calc(var(--n-option-height) * 6.6)",
        optionArrowColor: textColor3,
        optionHeight: heightMedium,
        optionFontSize: fontSizeMedium,
        optionColorHover: hoverColor,
        optionTextColor: textColor2,
        optionTextColorActive: primaryColor,
        optionTextColorDisabled: textColorDisabled,
        optionCheckMarkColor: primaryColor,
        loadingColor: primaryColor,
        columnWidth: "180px"
      };
    };
    const cascaderLight = createTheme$1({
      name: "Cascader",
      common: commonLight,
      peers: {
        InternalSelectMenu: internalSelectMenuLight$1,
        InternalSelection: internalSelectionLight$1,
        Scrollbar: scrollbarLight$1,
        Checkbox: checkboxLight$1,
        Empty: emptyLight$1
      },
      self: self$T
    });
    var cascaderLight$1 = cascaderLight;

    const cascaderDark = {
      name: "Cascader",
      common: commonDark,
      peers: {
        InternalSelectMenu: internalSelectMenuDark$1,
        InternalSelection: internalSelectionDark$1,
        Scrollbar: scrollbarDark$1,
        Checkbox: checkboxDark$1,
        Empty: emptyLight$1
      },
      self: self$T
    };
    var cascaderDark$1 = cascaderDark;

    function getRawNodePath(tmNodes) {
      if (!tmNodes) return null;
      return tmNodes.map(tmNode => tmNode.rawNode);
    }

    function createSelectOptions(tmNodes, checkStrategyIsChild, labelField, separator) {
      const selectOptions = [];
      const path = [];

      function traverse(_tmNodes) {
        for (const tmNode of _tmNodes) {
          if (tmNode.disabled) continue;
          const {
            rawNode
          } = tmNode;
          path.push(rawNode);

          if (tmNode.isLeaf || !checkStrategyIsChild) {
            selectOptions.push({
              label: getPathLabel(tmNode, separator, labelField),
              value: tmNode.key,
              rawNode: tmNode.rawNode,
              path: Array.from(path)
            });
          }

          if (!tmNode.isLeaf && tmNode.children) {
            traverse(tmNode.children);
          }

          path.pop();
        }
      }

      traverse(tmNodes);
      return selectOptions;
    }

    function getPathLabel(node, separator, labelField) {
      const path = [];

      while (node) {
        path.push(node.rawNode[labelField]);
        node = node.parent;
      }

      return path.reverse().join(separator);
    }

    var CheckMark = /* @__PURE__ */ React.createElement("svg", {
      viewBox: "0 0 64 64",
      class: "check-icon"
    }, /* @__PURE__ */ React.createElement("path", {
      d: "M50.42,16.76L22.34,39.45l-8.1-11.46c-1.12-1.58-3.3-1.96-4.88-0.84c-1.58,1.12-1.95,3.3-0.84,4.88l10.26,14.51  c0.56,0.79,1.42,1.31,2.38,1.45c0.16,0.02,0.32,0.03,0.48,0.03c0.8,0,1.57-0.27,2.2-0.78l30.99-25.03c1.5-1.21,1.74-3.42,0.52-4.92  C54.13,15.78,51.93,15.55,50.42,16.76z"
    }));

    var LineMark = /* @__PURE__ */ React.createElement("svg", {
      viewBox: "0 0 100 100",
      class: "line-icon"
    }, /* @__PURE__ */ React.createElement("path", {
      d: "M80.2,55.5H21.4c-2.8,0-5.1-2.5-5.1-5.5l0,0c0-3,2.3-5.5,5.1-5.5h58.7c2.8,0,5.1,2.5,5.1,5.5l0,0C85.2,53.1,82.9,55.5,80.2,55.5z"
    }));

    const checkboxGroupInjectionKey = createInjectionKey("n-checkbox-group");
    const checkboxGroupProps = {
      min: Number,
      max: Number,
      size: String,
      value: Array,
      defaultValue: {
        type: Array,
        default: null
      },
      disabled: {
        type: Boolean,
        default: void 0
      },
      "onUpdate:value": [Function, Array],
      onUpdateValue: [Function, Array],
      onChange: [Function, Array]
    };
    var NCheckboxGroup = vue.defineComponent({
      name: "CheckboxGroup",
      props: checkboxGroupProps,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.onChange !== void 0) {
              warnOnce(
                "checkbox-group",
                "`on-change` is deprecated, please use `on-update:value` instead."
              );
            }
          });
        }
        const { mergedClsPrefixRef } = useConfig(props);
        const formItem = useFormItem(props);
        const { mergedSizeRef, mergedDisabledRef } = formItem;
        const uncontrolledValueRef = vue.ref(props.defaultValue);
        const controlledValueRef = vue.computed(() => props.value);
        const mergedValueRef = useMergedState(
          controlledValueRef,
          uncontrolledValueRef
        );
        const checkedCount = vue.computed(() => {
          return mergedValueRef.value?.length || 0;
        });
        const valueSetRef = vue.computed(() => {
          if (Array.isArray(mergedValueRef.value)) {
            return new Set(mergedValueRef.value);
          }
          return /* @__PURE__ */ new Set();
        });
        function toggleCheckbox(checked, checkboxValue) {
          const { nTriggerFormInput, nTriggerFormChange } = formItem;
          const {
            onChange,
            "onUpdate:value": _onUpdateValue,
            onUpdateValue
          } = props;
          if (Array.isArray(mergedValueRef.value)) {
            const groupValue = Array.from(mergedValueRef.value);
            const index = groupValue.findIndex((value) => value === checkboxValue);
            if (checked) {
              if (!~index) {
                groupValue.push(checkboxValue);
                if (onUpdateValue) {
                  call(onUpdateValue, groupValue, {
                    actionType: "check",
                    value: checkboxValue
                  });
                }
                if (_onUpdateValue) {
                  call(_onUpdateValue, groupValue, {
                    actionType: "check",
                    value: checkboxValue
                  });
                }
                nTriggerFormInput();
                nTriggerFormChange();
                uncontrolledValueRef.value = groupValue;
                if (onChange)
                  call(onChange, groupValue);
              }
            } else {
              if (~index) {
                groupValue.splice(index, 1);
                if (onUpdateValue) {
                  call(onUpdateValue, groupValue, {
                    actionType: "uncheck",
                    value: checkboxValue
                  });
                }
                if (_onUpdateValue) {
                  call(_onUpdateValue, groupValue, {
                    actionType: "uncheck",
                    value: checkboxValue
                  });
                }
                if (onChange)
                  call(onChange, groupValue);
                uncontrolledValueRef.value = groupValue;
                nTriggerFormInput();
                nTriggerFormChange();
              }
            }
          } else {
            if (checked) {
              if (onUpdateValue) {
                call(onUpdateValue, [checkboxValue], {
                  actionType: "check",
                  value: checkboxValue
                });
              }
              if (_onUpdateValue) {
                call(_onUpdateValue, [checkboxValue], {
                  actionType: "check",
                  value: checkboxValue
                });
              }
              if (onChange)
                call(onChange, [checkboxValue]);
              uncontrolledValueRef.value = [checkboxValue];
              nTriggerFormInput();
              nTriggerFormChange();
            } else {
              if (onUpdateValue) {
                call(onUpdateValue, [], {
                  actionType: "uncheck",
                  value: checkboxValue
                });
              }
              if (_onUpdateValue) {
                call(_onUpdateValue, [], {
                  actionType: "uncheck",
                  value: checkboxValue
                });
              }
              if (onChange)
                call(onChange, []);
              uncontrolledValueRef.value = [];
              nTriggerFormInput();
              nTriggerFormChange();
            }
          }
        }
        vue.provide(checkboxGroupInjectionKey, {
          checkedCountRef: checkedCount,
          maxRef: vue.toRef(props, "max"),
          minRef: vue.toRef(props, "min"),
          valueSetRef,
          disabledRef: mergedDisabledRef,
          mergedSizeRef,
          toggleCheckbox
        });
        return {
          mergedClsPrefix: mergedClsPrefixRef
        };
      },
      render() {
        return /* @__PURE__ */ React.createElement("div", {
          class: `${this.mergedClsPrefix}-checkbox-group`,
          role: "group"
        }, this.$slots);
      }
    });

    var style$14 = c$1([cB("checkbox", `
    line-height: var(--n-label-line-height);
    font-size: var(--n-font-size);
    outline: none;
    cursor: pointer;
    display: inline-flex;
    flex-wrap: nowrap;
    align-items: flex-start;
    word-break: break-word;
    --n-merged-color-table: var(--n-color-table);
  `, [c$1("&:hover", [cB("checkbox-box", [cE("border", {
      border: "var(--n-border-checked)"
    })])]), c$1("&:focus:not(:active)", [cB("checkbox-box", [cE("border", `
          border: var(--n-border-focus);
          box-shadow: var(--n-box-shadow-focus);
        `)])]), cM("inside-table", [cB("checkbox-box", `
        background-color: var(--n-merged-color-table);
      `)]), cM("checked", [cB("checkbox-box", `
        background-color: var(--n-color-checked);
      `, [cB("checkbox-icon", [c$1(".check-icon", `
            opacity: 1;
            transform: scale(1);
          `)])])]), cM("indeterminate", [cB("checkbox-box", [cB("checkbox-icon", [c$1(".check-icon", `
            opacity: 0;
            transform: scale(.5);
          `), c$1(".line-icon", `
            opacity: 1;
            transform: scale(1);
          `)])])]), cM("checked, indeterminate", [c$1("&:focus:not(:active)", [cB("checkbox-box", [cE("border", `
            border: var(--n-border-checked);
            box-shadow: var(--n-box-shadow-focus);
          `)])]), cB("checkbox-box", `
        background-color: var(--n-color-checked);
        border-left: 0;
        border-top: 0;
      `, [cE("border", {
      border: "var(--n-border-checked)"
    })])]), cM("disabled", {
      cursor: "not-allowed"
    }, [cM("checked", [cB("checkbox-box", `
          background-color: var(--n-color-disabled-checked);
        `, [cE("border", {
      border: "var(--n-border-disabled-checked)"
    }), cB("checkbox-icon", [c$1(".check-icon, .line-icon", {
      fill: "var(--n-check-mark-color-disabled-checked)"
    })])])]), cB("checkbox-box", `
        background-color: var(--n-color-disabled);
      `, [cE("border", {
      border: "var(--n-border-disabled)"
    }), cB("checkbox-icon", [c$1(".check-icon, .line-icon", {
      fill: "var(--n-check-mark-color-disabled)"
    })])]), cE("label", {
      color: "var(--n-text-color-disabled)"
    })]), cB("checkbox-box-wrapper", `
      position: relative;
      width: var(--n-size);
      flex-shrink: 0;
      flex-grow: 0;
      user-select: none;
      -webkit-user-select: none;
    `), cB("checkbox-box", `
      position: absolute;
      left: 0;
      top: 50%;
      transform: translateY(-50%);
      height: var(--n-size);
      width: var(--n-size);
      display: inline-block;
      box-sizing: border-box;
      border-radius: var(--n-border-radius);
      background-color: var(--n-color);
      transition: background-color 0.3s var(--n-bezier);
    `, [cE("border", `
        transition:
          border-color .3s var(--n-bezier),
          box-shadow .3s var(--n-bezier);
        border-radius: inherit;
        position: absolute;
        left: 0;
        right: 0;
        top: 0;
        bottom: 0;
        border: var(--n-border);
      `), cB("checkbox-icon", `
        display: flex;
        align-items: center;
        justify-content: center;
        position: absolute;
        left: 1px;
        right: 1px;
        top: 1px;
        bottom: 1px;
      `, [c$1(".check-icon, .line-icon", `
          width: 100%;
          fill: var(--n-check-mark-color);
          opacity: 0;
          transform: scale(0.5);
          transform-origin: center;
          transition:
            fill 0.3s var(--n-bezier),
            transform 0.3s var(--n-bezier),
            opacity 0.3s var(--n-bezier),
            border-color 0.3s var(--n-bezier);
        `), iconSwitchTransition({
      left: "1px",
      top: "1px"
    })])]), cE("label", `
      color: var(--n-text-color);
      transition: color .3s var(--n-bezier);
      user-select: none;
      -webkit-user-select: none;
      padding: var(--n-label-padding);
    `, [c$1("&:empty", {
      display: "none"
    })])]), insideModal(cB("checkbox", `
      --n-merged-color-table: var(--n-color-table-modal);
    `)), insidePopover(cB("checkbox", `
      --n-merged-color-table: var(--n-color-table-popover);
    `))]);

    const checkboxProps = {
      ...useTheme.props,
      size: String,
      checked: {
        type: [Boolean, String, Number],
        default: void 0
      },
      defaultChecked: {
        type: [Boolean, String, Number],
        default: false
      },
      value: [String, Number],
      disabled: {
        type: Boolean,
        default: void 0
      },
      indeterminate: Boolean,
      label: String,
      focusable: {
        type: Boolean,
        default: true
      },
      checkedValue: {
        type: [Boolean, String, Number],
        default: true
      },
      uncheckedValue: {
        type: [Boolean, String, Number],
        default: false
      },
      "onUpdate:checked": [Function, Array],
      onUpdateChecked: [Function, Array],
      privateInsideTable: Boolean,
      onChange: [Function, Array]
    };
    var NCheckbox = vue.defineComponent({
      name: "Checkbox",
      props: checkboxProps,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.onChange) {
              warnOnce(
                "checkbox",
                "`on-change` is deprecated, please use `on-update:checked` instead."
              );
            }
          });
        }
        const selfRef = vue.ref(null);
        const { mergedClsPrefixRef, inlineThemeDisabled, mergedRtlRef } = useConfig(props);
        const formItem = useFormItem(props, {
          mergedSize(NFormItem) {
            const { size } = props;
            if (size !== void 0)
              return size;
            if (NCheckboxGroup) {
              const { value: mergedSize } = NCheckboxGroup.mergedSizeRef;
              if (mergedSize !== void 0) {
                return mergedSize;
              }
            }
            if (NFormItem) {
              const { mergedSize } = NFormItem;
              if (mergedSize !== void 0)
                return mergedSize.value;
            }
            return "medium";
          },
          mergedDisabled(NFormItem) {
            const { disabled } = props;
            if (disabled !== void 0)
              return disabled;
            if (NCheckboxGroup) {
              if (NCheckboxGroup.disabledRef.value)
                return true;
              const {
                maxRef: { value: max },
                checkedCountRef
              } = NCheckboxGroup;
              if (max !== void 0 && checkedCountRef.value >= max && !renderedCheckedRef.value) {
                return true;
              }
              const {
                minRef: { value: min }
              } = NCheckboxGroup;
              if (min !== void 0 && checkedCountRef.value <= min && renderedCheckedRef.value) {
                return true;
              }
            }
            if (NFormItem) {
              return NFormItem.disabled.value;
            }
            return false;
          }
        });
        const { mergedDisabledRef, mergedSizeRef } = formItem;
        const NCheckboxGroup = vue.inject(checkboxGroupInjectionKey, null);
        const uncontrolledCheckedRef = vue.ref(props.defaultChecked);
        const controlledCheckedRef = vue.toRef(props, "checked");
        const mergedCheckedRef = useMergedState(
          controlledCheckedRef,
          uncontrolledCheckedRef
        );
        const renderedCheckedRef = useMemo(() => {
          if (NCheckboxGroup) {
            const groupValueSet = NCheckboxGroup.valueSetRef.value;
            if (groupValueSet && props.value !== void 0) {
              return groupValueSet.has(props.value);
            }
            return false;
          } else {
            return mergedCheckedRef.value === props.checkedValue;
          }
        });
        const themeRef = useTheme(
          "Checkbox",
          "-checkbox",
          style$14,
          checkboxLight$1,
          props,
          mergedClsPrefixRef
        );
        function toggle(e) {
          if (NCheckboxGroup && props.value !== void 0) {
            NCheckboxGroup.toggleCheckbox(!renderedCheckedRef.value, props.value);
          } else {
            const {
              onChange,
              "onUpdate:checked": _onUpdateCheck,
              onUpdateChecked
            } = props;
            const { nTriggerFormInput, nTriggerFormChange } = formItem;
            const nextChecked = renderedCheckedRef.value ? props.uncheckedValue : props.checkedValue;
            if (_onUpdateCheck) {
              call(_onUpdateCheck, nextChecked, e);
            }
            if (onUpdateChecked) {
              call(onUpdateChecked, nextChecked, e);
            }
            if (onChange)
              call(onChange, nextChecked, e);
            nTriggerFormInput();
            nTriggerFormChange();
            uncontrolledCheckedRef.value = nextChecked;
          }
        }
        function handleClick(e) {
          if (!mergedDisabledRef.value) {
            toggle(e);
          }
        }
        function handleKeyUp(e) {
          if (mergedDisabledRef.value)
            return;
          switch (e.key) {
            case " ":
            case "Enter":
              toggle(e);
          }
        }
        function handleKeyDown(e) {
          switch (e.key) {
            case " ":
              e.preventDefault();
          }
        }
        const exposedMethods = {
          focus: () => {
            selfRef.value?.focus();
          },
          blur: () => {
            selfRef.value?.blur();
          }
        };
        const rtlEnabledRef = useRtl("Checkbox", mergedRtlRef, mergedClsPrefixRef);
        const cssVarsRef = vue.computed(() => {
          const { value: mergedSize } = mergedSizeRef;
          const {
            common: { cubicBezierEaseInOut },
            self: {
              borderRadius,
              color,
              colorChecked,
              colorDisabled,
              colorTableHeader,
              colorTableHeaderModal,
              colorTableHeaderPopover,
              checkMarkColor,
              checkMarkColorDisabled,
              border,
              borderFocus,
              borderDisabled,
              borderChecked,
              boxShadowFocus,
              textColor,
              textColorDisabled,
              checkMarkColorDisabledChecked,
              colorDisabledChecked,
              borderDisabledChecked,
              labelPadding,
              labelLineHeight,
              [createKey("fontSize", mergedSize)]: fontSize,
              [createKey("size", mergedSize)]: size
            }
          } = themeRef.value;
          return {
            "--n-label-line-height": labelLineHeight,
            "--n-size": size,
            "--n-bezier": cubicBezierEaseInOut,
            "--n-border-radius": borderRadius,
            "--n-border": border,
            "--n-border-checked": borderChecked,
            "--n-border-focus": borderFocus,
            "--n-border-disabled": borderDisabled,
            "--n-border-disabled-checked": borderDisabledChecked,
            "--n-box-shadow-focus": boxShadowFocus,
            "--n-color": color,
            "--n-color-checked": colorChecked,
            "--n-color-table": colorTableHeader,
            "--n-color-table-modal": colorTableHeaderModal,
            "--n-color-table-popover": colorTableHeaderPopover,
            "--n-color-disabled": colorDisabled,
            "--n-color-disabled-checked": colorDisabledChecked,
            "--n-text-color": textColor,
            "--n-text-color-disabled": textColorDisabled,
            "--n-check-mark-color": checkMarkColor,
            "--n-check-mark-color-disabled": checkMarkColorDisabled,
            "--n-check-mark-color-disabled-checked": checkMarkColorDisabledChecked,
            "--n-font-size": fontSize,
            "--n-label-padding": labelPadding
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "checkbox",
          vue.computed(() => mergedSizeRef.value[0]),
          cssVarsRef,
          props
        ) : void 0;
        return Object.assign(formItem, exposedMethods, {
          rtlEnabled: rtlEnabledRef,
          selfRef,
          mergedClsPrefix: mergedClsPrefixRef,
          mergedDisabled: mergedDisabledRef,
          renderedChecked: renderedCheckedRef,
          mergedTheme: themeRef,
          labelId: createId(),
          handleClick,
          handleKeyUp,
          handleKeyDown,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        });
      },
      render() {
        const {
          $slots,
          renderedChecked,
          mergedDisabled,
          indeterminate,
          privateInsideTable,
          cssVars,
          labelId,
          label,
          mergedClsPrefix,
          focusable,
          handleKeyUp,
          handleKeyDown,
          handleClick
        } = this;
        this.onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          ref: "selfRef",
          class: [
            `${mergedClsPrefix}-checkbox`,
            this.themeClass,
            this.rtlEnabled && `${mergedClsPrefix}-checkbox--rtl`,
            renderedChecked && `${mergedClsPrefix}-checkbox--checked`,
            mergedDisabled && `${mergedClsPrefix}-checkbox--disabled`,
            indeterminate && `${mergedClsPrefix}-checkbox--indeterminate`,
            privateInsideTable && `${mergedClsPrefix}-checkbox--inside-table`
          ],
          tabindex: mergedDisabled || !focusable ? void 0 : 0,
          role: "checkbox",
          "aria-checked": indeterminate ? "mixed" : renderedChecked,
          "aria-labelledby": labelId,
          style: cssVars,
          onKeyup: handleKeyUp,
          onKeydown: handleKeyDown,
          onClick: handleClick,
          onMousedown: () => {
            on(
              "selectstart",
              window,
              (e) => {
                e.preventDefault();
              },
              {
                once: true
              }
            );
          }
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-checkbox-box-wrapper`
        }, "\xA0", /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-checkbox-box`
        }, /* @__PURE__ */ React.createElement(NIconSwitchTransition, null, {
          default: () => this.indeterminate ? /* @__PURE__ */ React.createElement("div", {
            key: "indeterminate",
            class: `${mergedClsPrefix}-checkbox-icon`
          }, LineMark) : /* @__PURE__ */ React.createElement("div", {
            key: "check",
            class: `${mergedClsPrefix}-checkbox-icon`
          }, CheckMark)
        }), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-checkbox-box__border`
        }))), label !== null || $slots.default ? /* @__PURE__ */ React.createElement("span", {
          class: `${mergedClsPrefix}-checkbox__label`,
          id: labelId
        }, $slots.default ? $slots.default() : label) : null);
      }
    });

    const cascaderInjectionKey = createInjectionKey("n-cascader");

    var NCascaderOption = vue.defineComponent({
      name: "NCascaderOption",
      props: {
        tmNode: {
          type: Object,
          required: true
        }
      },
      setup(props) {
        const {
          expandTriggerRef,
          remoteRef,
          multipleRef,
          mergedValueRef,
          checkedKeysRef,
          indeterminateKeysRef,
          hoverKeyPathRef,
          keyboardKeyRef,
          loadingKeySetRef,
          cascadeRef,
          mergedCheckStrategyRef,
          onLoadRef,
          mergedClsPrefixRef,
          mergedThemeRef,
          labelFieldRef,
          updateHoverKey,
          updateKeyboardKey,
          addLoadingKey,
          deleteLoadingKey,
          closeMenu,
          doCheck,
          doUncheck,
          renderLabelRef
        } = vue.inject(cascaderInjectionKey);
        const valueRef = vue.computed(() => props.tmNode.key);
        const useHoverTriggerRef = vue.computed(() => {
          const { value: expandTrigger } = expandTriggerRef;
          const { value: remote } = remoteRef;
          return !remote && expandTrigger === "hover";
        });
        const mergedHandleMouseEnterRef = vue.computed(() => {
          if (useHoverTriggerRef.value) {
            return handleMouseEnter;
          }
          return void 0;
        });
        const mergedHandleMouseMoveRef = vue.computed(() => {
          if (useHoverTriggerRef.value) {
            return handleMouseMove;
          }
          return void 0;
        });
        const checkedRef = useMemo(() => {
          const { value: multiple } = multipleRef;
          if (!multiple)
            return mergedValueRef.value === valueRef.value;
          return checkedKeysRef.value.includes(valueRef.value);
        });
        const indeterminateRef = useMemo(() => {
          if (!multipleRef.value)
            return false;
          return indeterminateKeysRef.value.includes(valueRef.value);
        });
        const hoverPendingRef = useMemo(() => {
          return hoverKeyPathRef.value.includes(valueRef.value);
        });
        const keyboardPendingRef = useMemo(() => {
          const { value: keyboardKey } = keyboardKeyRef;
          if (keyboardKey === null)
            return false;
          return keyboardKey === valueRef.value;
        });
        const isLoadingRef = useMemo(() => {
          if (remoteRef.value) {
            return loadingKeySetRef.value.has(valueRef.value);
          }
          return false;
        });
        const showCheckboxRef = vue.computed(() => {
          if (multipleRef.value && cascadeRef.value)
            return true;
          if (mergedCheckStrategyRef.value !== "child")
            return true;
        });
        const isLeafRef = vue.computed(() => props.tmNode.isLeaf);
        const disabledRef = vue.computed(() => props.tmNode.disabled);
        const labelRef = vue.computed(
          () => props.tmNode.rawNode[labelFieldRef.value]
        );
        const isShallowLoadedRef = vue.computed(() => {
          return props.tmNode.shallowLoaded;
        });
        function handleClick(e) {
          if (disabledRef.value)
            return;
          const { value: remote } = remoteRef;
          const { value: loadingKeySet } = loadingKeySetRef;
          const { value: onLoad } = onLoadRef;
          const { value } = valueRef;
          const { value: isLeaf } = isLeafRef;
          const { value: isShallowLoaded } = isShallowLoadedRef;
          if (!happensIn(e, "checkbox")) {
            if (remote && !isShallowLoaded && !loadingKeySet.has(value) && onLoad) {
              addLoadingKey(value);
              onLoad(props.tmNode.rawNode).then(() => {
                deleteLoadingKey(value);
              }).catch(() => {
                deleteLoadingKey(value);
              });
            }
            updateHoverKey(value);
            updateKeyboardKey(value);
          }
          if (isLeaf) {
            toggleCheckbox();
          }
        }
        function handleMouseEnter() {
          if (!useHoverTriggerRef.value || disabledRef.value)
            return;
          const { value } = valueRef;
          updateHoverKey(value);
          updateKeyboardKey(value);
        }
        function handleMouseMove() {
          if (!useHoverTriggerRef.value)
            return;
          handleMouseEnter();
        }
        function handleCheckboxUpdateValue() {
          const { value: isLeaf } = isLeafRef;
          if (!isLeaf)
            toggleCheckbox();
        }
        function toggleCheckbox() {
          const { value: multiple } = multipleRef;
          const { value } = valueRef;
          if (multiple) {
            if (indeterminateRef.value || checkedRef.value) {
              doUncheck(value);
            } else {
              doCheck(value);
            }
          } else {
            doCheck(value);
            closeMenu(true);
          }
        }
        return {
          checkStrategy: mergedCheckStrategyRef,
          multiple: multipleRef,
          cascade: cascadeRef,
          checked: checkedRef,
          indeterminate: indeterminateRef,
          hoverPending: hoverPendingRef,
          keyboardPending: keyboardPendingRef,
          isLoading: isLoadingRef,
          showCheckbox: showCheckboxRef,
          isLeaf: isLeafRef,
          disabled: disabledRef,
          label: labelRef,
          mergedClsPrefix: mergedClsPrefixRef,
          mergedTheme: mergedThemeRef,
          handleClick,
          handleCheckboxUpdateValue,
          mergedHandleMouseEnter: mergedHandleMouseEnterRef,
          mergedHandleMouseMove: mergedHandleMouseMoveRef,
          renderLabel: renderLabelRef
        };
      },
      render() {
        const { mergedClsPrefix, renderLabel } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-cascader-option`,
            {
              [`${mergedClsPrefix}-cascader-option--pending`]: this.keyboardPending || this.hoverPending,
              [`${mergedClsPrefix}-cascader-option--disabled`]: this.disabled,
              [`${mergedClsPrefix}-cascader-option--show-prefix`]: this.showCheckbox
            }
          ],
          onMouseenter: this.mergedHandleMouseEnter,
          onMousemove: this.mergedHandleMouseMove,
          onClick: this.handleClick
        }, this.showCheckbox ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-cascader-option__prefix`
        }, /* @__PURE__ */ React.createElement(NCheckbox, {
          focusable: false,
          "data-checkbox": true,
          disabled: this.disabled,
          checked: this.checked,
          indeterminate: this.indeterminate,
          theme: this.mergedTheme.peers.Checkbox,
          themeOverrides: this.mergedTheme.peerOverrides.Checkbox,
          onUpdateChecked: this.handleCheckboxUpdateValue
        })) : null, /* @__PURE__ */ React.createElement("span", {
          class: `${mergedClsPrefix}-cascader-option__label`
        }, renderLabel ? renderLabel(this.tmNode.rawNode, this.checked) : this.label), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-cascader-option__suffix`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-cascader-option-icon-placeholder`
        }, !this.isLeaf ? /* @__PURE__ */ React.createElement(NBaseLoading, {
          clsPrefix: mergedClsPrefix,
          scale: 0.85,
          strokeWidth: 24,
          show: this.isLoading,
          class: `${mergedClsPrefix}-cascader-option-icon`
        }, {
          default: () => /* @__PURE__ */ React.createElement(NBaseIcon, {
            clsPrefix: mergedClsPrefix,
            key: "arrow",
            class: `${mergedClsPrefix}-cascader-option-icon ${mergedClsPrefix}-cascader-option-icon--arrow`
          }, {
            default: () => /* @__PURE__ */ React.createElement(ChevronRightIcon, null)
          })
        }) : this.checkStrategy === "child" && !(this.multiple && this.cascade) ? /* @__PURE__ */ React.createElement(vue.Transition, {
          name: "fade-in-scale-up-transition"
        }, {
          default: () => this.checked ? /* @__PURE__ */ React.createElement(NBaseIcon, {
            clsPrefix: mergedClsPrefix,
            class: `${mergedClsPrefix}-cascader-option-icon ${mergedClsPrefix}-cascader-option-icon--checkmark`
          }, { default: () => /* @__PURE__ */ React.createElement(FinishedIcon, null) }) : null
        }) : null)));
      }
    });

    var NCascaderSubmenu = vue.defineComponent({
      name: "CascaderSubmenu",
      props: {
        depth: {
          type: Number,
          required: true
        },
        tmNodes: {
          type: Array,
          required: true
        }
      },
      setup() {
        const {
          virtualScrollRef,
          mergedClsPrefixRef,
          mergedThemeRef,
          optionHeightRef
        } = vue.inject(cascaderInjectionKey);
        const scrollbarInstRef = vue.ref(null);
        const vlInstRef = vue.ref(null);
        const inst = {
          scroll(index, elSize) {
            if (virtualScrollRef.value) {
              vlInstRef.value?.scrollTo({
                index
              });
            } else {
              scrollbarInstRef.value?.scrollTo({
                index,
                elSize
              });
            }
          }
        };
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          mergedTheme: mergedThemeRef,
          scrollbarInstRef,
          vlInstRef,
          virtualScroll: virtualScrollRef,
          itemSize: vue.computed(() => depx(optionHeightRef.value)),
          handleVlScroll: () => {
            scrollbarInstRef.value?.sync();
          },
          getVlContainer: () => {
            return vlInstRef.value?.listElRef;
          },
          getVlContent: () => {
            return vlInstRef.value?.itemsElRef;
          },
          ...inst
        };
      },
      render() {
        const { mergedClsPrefix, mergedTheme, virtualScroll } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            virtualScroll && `${mergedClsPrefix}-cascader-submenu--virtual`,
            `${mergedClsPrefix}-cascader-submenu`
          ]
        }, /* @__PURE__ */ React.createElement(NScrollbar, {
          ref: "scrollbarInstRef",
          theme: mergedTheme.peers.Scrollbar,
          themeOverrides: mergedTheme.peerOverrides.Scrollbar,
          container: virtualScroll ? this.getVlContainer : void 0,
          content: virtualScroll ? this.getVlContent : void 0
        }, {
          default: () => virtualScroll ? /* @__PURE__ */ React.createElement(VVirtualList, {
            items: this.tmNodes,
            itemSize: this.itemSize,
            onScroll: this.handleVlScroll,
            showScrollbar: false,
            ref: "vlInstRef"
          }, {
            default: ({ item: tmNode }) => /* @__PURE__ */ React.createElement(NCascaderOption, {
              key: tmNode.key,
              tmNode
            })
          }) : this.tmNodes.map((tmNode) => /* @__PURE__ */ React.createElement(NCascaderOption, {
            key: tmNode.key,
            tmNode
          }))
        }));
      }
    });

    var CascaderMenu = vue.defineComponent({
      name: "NCascaderMenu",
      props: {
        value: [String, Number, Array],
        placement: {
          type: String,
          default: "bottom-start"
        },
        show: Boolean,
        menuModel: {
          type: Array,
          required: true
        },
        loading: Boolean,
        onFocus: {
          type: Function,
          required: true
        },
        onBlur: {
          type: Function,
          required: true
        },
        onKeydown: {
          type: Function,
          required: true
        },
        onMousedown: {
          type: Function,
          required: true
        },
        onTabout: {
          type: Function,
          required: true
        }
      },
      setup(props) {
        const {
          localeRef,
          isMountedRef,
          mergedClsPrefixRef,
          syncCascaderMenuPosition,
          handleCascaderMenuClickOutside,
          mergedThemeRef
        } = vue.inject(cascaderInjectionKey);
        const submenuInstRefs = [];
        const maskInstRef = vue.ref(null);
        const selfElRef = vue.ref(null);
        function handleResize() {
          syncCascaderMenuPosition();
        }
        useOnResize(selfElRef, handleResize);
        function showErrorMessage(label) {
          const {
            value: { loadingRequiredMessage }
          } = localeRef;
          maskInstRef.value?.showOnce(loadingRequiredMessage(label));
        }
        function handleClickOutside(e) {
          handleCascaderMenuClickOutside(e);
        }
        function handleFocusin(e) {
          const { value: selfEl } = selfElRef;
          if (!selfEl)
            return;
          if (!selfEl.contains(e.relatedTarget)) {
            props.onFocus(e);
          }
        }
        function handleFocusout(e) {
          const { value: selfEl } = selfElRef;
          if (!selfEl)
            return;
          if (!selfEl.contains(e.relatedTarget)) {
            props.onBlur(e);
          }
        }
        const exposedRef = {
          scroll(depth, index, elSize) {
            const submenuInst = submenuInstRefs[depth];
            if (submenuInst) {
              submenuInst.scroll(index, elSize);
            }
          },
          showErrorMessage
        };
        return {
          isMounted: isMountedRef,
          mergedClsPrefix: mergedClsPrefixRef,
          selfElRef,
          submenuInstRefs,
          maskInstRef,
          mergedTheme: mergedThemeRef,
          handleFocusin,
          handleFocusout,
          handleClickOutside,
          ...exposedRef
        };
      },
      render() {
        const { submenuInstRefs, mergedClsPrefix, mergedTheme } = this;
        return /* @__PURE__ */ React.createElement(vue.Transition, {
          name: "fade-in-scale-up-transition",
          appear: this.isMounted
        }, {
          default: () => {
            if (!this.show)
              return null;
            return vue.withDirectives(
              /* @__PURE__ */ React.createElement("div", {
                tabindex: "0",
                ref: "selfElRef",
                class: `${mergedClsPrefix}-cascader-menu`,
                onMousedown: this.onMousedown,
                onFocusin: this.handleFocusin,
                onFocusout: this.handleFocusout,
                onKeydown: this.onKeydown
              }, this.menuModel[0].length ? /* @__PURE__ */ React.createElement("div", {
                class: `${mergedClsPrefix}-cascader-submenu-wrapper`
              }, this.menuModel.map((submenuOptions, index) => /* @__PURE__ */ React.createElement(NCascaderSubmenu, {
                ref: (instance) => {
                  if (instance) {
                    submenuInstRefs[index] = instance;
                  }
                },
                key: index,
                tmNodes: submenuOptions,
                depth: index + 1
              })), /* @__PURE__ */ React.createElement(NBaseMenuMask, {
                clsPrefix: mergedClsPrefix,
                ref: "maskInstRef"
              })) : /* @__PURE__ */ React.createElement("div", {
                class: `${mergedClsPrefix}-cascader-menu__empty`
              }, resolveSlot(this.$slots.empty, () => [
                /* @__PURE__ */ React.createElement(NEmpty, {
                  theme: mergedTheme.peers.Empty,
                  themeOverrides: mergedTheme.peerOverrides.Empty
                })
              ])), resolveWrappedSlot(
                this.$slots.action,
                (children) => children && /* @__PURE__ */ React.createElement("div", {
                  class: `${mergedClsPrefix}-cascader-menu-action`,
                  "data-action": true
                }, children)
              ), /* @__PURE__ */ React.createElement(FocusDetector, {
                onFocus: this.onTabout
              })),
              [
                [
                  clickoutside$1,
                  this.handleClickOutside,
                  void 0,
                  { capture: true }
                ]
              ]
            );
          }
        });
      }
    });

    var CascaderSelectMenu = vue.defineComponent({
      name: "NCascaderSelectMenu",
      props: {
        value: {
          type: [String, Number, Array],
          default: null
        },
        show: Boolean,
        pattern: {
          type: String,
          default: ""
        },
        multiple: Boolean,
        tmNodes: {
          type: Array,
          default: () => []
        },
        filter: Function,
        labelField: {
          type: String,
          required: true
        },
        separator: {
          type: String,
          required: true
        }
      },
      setup(props) {
        const {
          isMountedRef,
          mergedValueRef,
          mergedClsPrefixRef,
          mergedThemeRef,
          mergedCheckStrategyRef,
          syncSelectMenuPosition,
          closeMenu,
          handleSelectMenuClickOutside,
          doUncheck: cascaderDoUncheck,
          doCheck: cascaderDoCheck,
          clearPattern
        } = vue.inject(cascaderInjectionKey);
        const menuInstRef = vue.ref(null);
        const selectOptionsRef = vue.computed(() => {
          return createSelectOptions(
            props.tmNodes,
            mergedCheckStrategyRef.value === "child",
            props.labelField,
            props.separator
          );
        });
        const mergedFilterRef = vue.computed(() => {
          const { filter } = props;
          if (filter)
            return filter;
          const { labelField } = props;
          return (pattern, _, path) => path.some(
            (option) => option[labelField] && ~option[labelField].indexOf(pattern)
          );
        });
        const filteredSelectOptionsRef = vue.computed(() => {
          const { pattern } = props;
          const { value: mergedFilter } = mergedFilterRef;
          return (pattern ? selectOptionsRef.value.filter((option) => {
            return mergedFilter(pattern, option.rawNode, option.path);
          }) : selectOptionsRef.value).map((option) => ({
            value: option.value,
            label: option.label
          }));
        });
        const selectTreeMateRef = vue.computed(() => {
          return createTreeMate(filteredSelectOptionsRef.value, createTmOptions("value", "children"));
        });
        function handleResize() {
          syncSelectMenuPosition();
        }
        function handleToggle(tmNode) {
          doCheck(tmNode);
        }
        function doCheck(tmNode) {
          if (props.multiple) {
            const { value: mergedValue } = mergedValueRef;
            if (Array.isArray(mergedValue)) {
              if (!mergedValue.includes(tmNode.key)) {
                cascaderDoCheck(tmNode.key);
              } else {
                cascaderDoUncheck(tmNode.key);
              }
            } else if (mergedValue === null) {
              cascaderDoCheck(tmNode.key);
            }
            clearPattern();
          } else {
            cascaderDoCheck(tmNode.key);
            closeMenu(true);
          }
        }
        function prev() {
          menuInstRef.value?.prev();
        }
        function next() {
          menuInstRef.value?.next();
        }
        function enter() {
          if (menuInstRef) {
            const pendingOptionTmNode = menuInstRef.value?.getPendingTmNode();
            if (pendingOptionTmNode) {
              doCheck(pendingOptionTmNode);
            }
            return true;
          }
          return false;
        }
        function handleClickOutside(e) {
          handleSelectMenuClickOutside(e);
        }
        const exposedRef = {
          prev,
          next,
          enter
        };
        return {
          isMounted: isMountedRef,
          mergedTheme: mergedThemeRef,
          mergedClsPrefix: mergedClsPrefixRef,
          menuInstRef,
          selectTreeMate: selectTreeMateRef,
          handleResize,
          handleToggle,
          handleClickOutside,
          ...exposedRef
        };
      },
      render() {
        const { mergedClsPrefix, isMounted, mergedTheme } = this;
        return /* @__PURE__ */ React.createElement(vue.Transition, {
          name: "fade-in-scale-up-transition",
          appear: isMounted
        }, {
          default: () => this.show ? vue.withDirectives(
            /* @__PURE__ */ React.createElement(NInternalSelectMenu, {
              ref: "menuInstRef",
              onResize: this.handleResize,
              clsPrefix: mergedClsPrefix,
              class: `${mergedClsPrefix}-cascader-menu`,
              autoPending: true,
              themeOverrides: mergedTheme.peerOverrides.InternalSelectMenu,
              theme: mergedTheme.peers.InternalSelectMenu,
              treeMate: this.selectTreeMate,
              multiple: this.multiple,
              value: this.value,
              onToggle: this.handleToggle
            }),
            [
              [
                clickoutside$1,
                this.handleClickOutside,
                void 0,
                { capture: true }
              ]
            ]
          ) : null
        });
      }
    });

    var style$13 = c$1([cB("cascader-menu", `
    outline: none;
    position: relative;
    margin: 4px 0;
    display: flex;
    flex-flow: column nowrap;
    border-radius: var(--n-menu-border-radius);
    overflow: hidden;
    box-shadow: var(--n-menu-box-shadow);
    color: var(--n-option-text-color);
    background-color: var(--n-menu-color);
  `, [fadeInScaleUpTransition({
      transformOrigin: "inherit",
      duration: "0.2s"
    }), cE("empty", `
      display: flex;
      padding: 12px 32px;
      flex: 1;
      justify-content: center;
    `), cB("scrollbar", {
      width: "100%"
    }), cB("base-menu-mask", {
      backgroundColor: "var(--n-menu-mask-color)"
    }), cB("base-loading", {
      color: "var(--n-loading-color)"
    }), cB("cascader-submenu-wrapper", `
      position: relative;
      display: flex;
      flex-wrap: nowrap;
    `), cB("cascader-submenu", `
      height: var(--n-menu-height);
      min-width: var(--n-column-width);
      position: relative;
    `, [cM("virtual", `
        width: var(--n-column-width);
      `), cB("scrollbar-content", {
      position: "relative"
    }), c$1("&:first-child", `
        border-top-left-radius: var(--n-menu-border-radius);
        border-bottom-left-radius: var(--n-menu-border-radius);
      `), c$1("&:last-child", `
        border-top-right-radius: var(--n-menu-border-radius);
        border-bottom-right-radius: var(--n-menu-border-radius);
      `), c$1("&:not(:first-child)", `
        border-left: 1px solid var(--n-menu-divider-color);
      `)]), cB("cascader-menu-action", `
      box-sizing: border-box;
      padding: 8px;
      border-top: 1px solid var(--n-menu-divider-color);
    `), cB("cascader-option", `
      height: var(--n-option-height);
      line-height: var(--n-option-height);
      font-size: var(--n-option-font-size);
      padding: 0 0 0 18px;
      box-sizing: border-box;
      min-width: 182px;
      background-color: #0000;
      display: flex;
      align-items: center;
      white-space: nowrap;
      position: relative;
      cursor: pointer;
      transition:
        background-color .2s var(--n-bezier),
        color 0.2s var(--n-bezier);
    `, [cM("show-prefix", {
      paddingLeft: 0
    }), cE("label", `
        flex: 1 0 0;
        overflow: hidden;
        text-overflow: ellipsis;
      `), cE("prefix", {
      width: "32px",
      display: "flex",
      alignItems: "center",
      justifyContent: "center"
    }), cE("suffix", {
      width: "32px",
      display: "flex",
      alignItems: "center",
      justifyContent: "center"
    }), cB("cascader-option-icon-placeholder", {
      lineHeight: 0,
      position: "relative",
      width: "16px",
      height: "16px",
      fontSize: "16px"
    }, [cB("cascader-option-icon", [cM("checkmark", {
      color: "var(--n-option-check-mark-color)"
    }, [fadeInScaleUpTransition({
      originalTransition: "background-color .3s var(--n-bezier), box-shadow .3s var(--n-bezier)"
    })]), cM("arrow", {
      color: "var(--n-option-arrow-color)"
    })])]), cM("selected", {
      color: "var(--n-option-text-color-active)"
    }), cM("active", {
      color: "var(--n-option-text-color-active)",
      backgroundColor: "var(--n-option-color-hover)"
    }), cM("pending", {
      backgroundColor: "var(--n-option-color-hover)"
    }), c$1("&:hover", {
      backgroundColor: "var(--n-option-color-hover)"
    }), cM("disabled", `
        color: var(--n-option-text-color-disabled);
        background-color: #0000;
        cursor: not-allowed;
      `, [cB("cascader-option-icon", [cM("arrow", {
      color: "var(--n-option-text-color-disabled)"
    })])])])]), cB("cascader", `
    z-index: auto;
    position: relative;
    width: 100%;
  `)]);

    const cascaderProps = {
      ...useTheme.props,
      allowCheckingNotLoaded: Boolean,
      to: useAdjustedTo.propTo,
      bordered: {
        type: Boolean,
        default: void 0
      },
      options: {
        type: Array,
        default: () => []
      },
      value: [String, Number, Array],
      defaultValue: {
        type: [String, Number, Array],
        default: null
      },
      placeholder: String,
      multiple: Boolean,
      size: String,
      filterable: Boolean,
      disabled: {
        type: Boolean,
        default: void 0
      },
      disabledField: {
        type: String,
        default: "disabled"
      },
      expandTrigger: {
        type: String,
        default: "click"
      },
      clearable: Boolean,
      clearFilterAfterSelect: {
        type: Boolean,
        default: true
      },
      remote: Boolean,
      onLoad: Function,
      separator: {
        type: String,
        default: " / "
      },
      filter: Function,
      placement: {
        type: String,
        default: "bottom-start"
      },
      cascade: {
        type: Boolean,
        default: true
      },
      leafOnly: Boolean,
      showPath: {
        type: Boolean,
        default: true
      },
      show: {
        type: Boolean,
        default: void 0
      },
      maxTagCount: [String, Number],
      menuProps: Object,
      filterMenuProps: Object,
      virtualScroll: {
        type: Boolean,
        default: true
      },
      checkStrategy: {
        type: String,
        default: "all"
      },
      valueField: {
        type: String,
        default: "value"
      },
      labelField: {
        type: String,
        default: "label"
      },
      childrenField: {
        type: String,
        default: "children"
      },
      renderLabel: Function,
      status: String,
      "onUpdate:value": [Function, Array],
      onUpdateValue: [Function, Array],
      "onUpdate:show": [Function, Array],
      onUpdateShow: [Function, Array],
      onBlur: Function,
      onFocus: Function,
      onChange: [Function, Array]
    };
    var Cascader = vue.defineComponent({
      name: "Cascader",
      props: cascaderProps,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.leafOnly) {
              warnOnce(
                "cascader",
                '`leaf-only` is deprecated, please use `check-strategy="child"` instead'
              );
            }
            if (props.onChange !== void 0) {
              warnOnce(
                "cascader",
                "`on-change` is deprecated, please use `on-update:value` instead."
              );
            }
          });
        }
        const {
          mergedBorderedRef,
          mergedClsPrefixRef,
          namespaceRef,
          inlineThemeDisabled
        } = useConfig(props);
        const themeRef = useTheme(
          "Cascader",
          "-cascader",
          style$13,
          cascaderLight$1,
          props,
          mergedClsPrefixRef
        );
        const { localeRef } = useLocale("Cascader");
        const uncontrolledValueRef = vue.ref(props.defaultValue);
        const controlledValueRef = vue.computed(() => props.value);
        const mergedValueRef = useMergedState(
          controlledValueRef,
          uncontrolledValueRef
        );
        const mergedCheckStrategyRef = vue.computed(() => {
          return props.leafOnly ? "child" : props.checkStrategy;
        });
        const patternRef = vue.ref("");
        const formItem = useFormItem(props);
        const { mergedSizeRef, mergedDisabledRef, mergedStatusRef } = formItem;
        const cascaderMenuInstRef = vue.ref(null);
        const selectMenuInstRef = vue.ref(null);
        const triggerInstRef = vue.ref(null);
        const keyboardKeyRef = vue.ref(null);
        const hoverKeyRef = vue.ref(null);
        const loadingKeySetRef = vue.ref(/* @__PURE__ */ new Set());
        const selectMenuFollowerRef = vue.ref(null);
        const cascaderMenuFollowerRef = vue.ref(null);
        const adjustedToRef = useAdjustedTo(props);
        const focusedRef = vue.ref(false);
        const addLoadingKey = (key) => {
          loadingKeySetRef.value.add(key);
        };
        const deleteLoadingKey = (key) => {
          loadingKeySetRef.value.delete(key);
        };
        const treeMateRef = vue.computed(() => {
          const { valueField, childrenField, disabledField } = props;
          return createTreeMate(props.options, {
            getDisabled(node) {
              return node[disabledField];
            },
            getKey(node) {
              return node[valueField];
            },
            getChildren(node) {
              return node[childrenField];
            }
          });
        });
        const mergedKeysRef = vue.computed(() => {
          const { cascade, multiple } = props;
          if (multiple && Array.isArray(mergedValueRef.value)) {
            return treeMateRef.value.getCheckedKeys(mergedValueRef.value, {
              cascade,
              allowNotLoaded: props.allowCheckingNotLoaded
            });
          } else {
            return {
              checkedKeys: [],
              indeterminateKeys: []
            };
          }
        });
        const checkedKeysRef = vue.computed(() => mergedKeysRef.value.checkedKeys);
        const indeterminateKeysRef = vue.computed(
          () => mergedKeysRef.value.indeterminateKeys
        );
        const menuModelRef = vue.computed(() => {
          const { treeNodePath, treeNode } = treeMateRef.value.getPath(
            hoverKeyRef.value
          );
          let ret;
          if (treeNode === null) {
            ret = [treeMateRef.value.treeNodes];
          } else {
            ret = treeNodePath.map((treeNode2) => treeNode2.siblings);
            if (!treeNode.isLeaf && !loadingKeySetRef.value.has(treeNode.key) && treeNode.children) {
              ret.push(treeNode.children);
            }
          }
          return ret;
        });
        const hoverKeyPathRef = vue.computed(() => {
          const { keyPath } = treeMateRef.value.getPath(hoverKeyRef.value);
          return keyPath;
        });
        const optionHeightRef = vue.computed(() => {
          return themeRef.value.self.optionHeight;
        });
        if (vue.isReactive(props.options)) {
          vue.watch(props.options, (value, oldValue) => {
            if (!(value === oldValue)) {
              hoverKeyRef.value = null;
              keyboardKeyRef.value = null;
            }
          });
        }
        function doUpdateShow(value) {
          const { onUpdateShow, "onUpdate:show": _onUpdateShow } = props;
          if (onUpdateShow) {
            call(onUpdateShow, value);
          }
          if (_onUpdateShow) {
            call(_onUpdateShow, value);
          }
          uncontrolledShowRef.value = value;
        }
        function doUpdateValue(value, option, optionPath) {
          const {
            onUpdateValue,
            "onUpdate:value": _onUpdateValue,
            onChange
          } = props;
          const { nTriggerFormInput, nTriggerFormChange } = formItem;
          if (onUpdateValue) {
            call(onUpdateValue, value, option, optionPath);
          }
          if (_onUpdateValue) {
            call(_onUpdateValue, value, option, optionPath);
          }
          if (onChange) {
            call(onChange, value, option, optionPath);
          }
          uncontrolledValueRef.value = value;
          nTriggerFormInput();
          nTriggerFormChange();
        }
        function updateKeyboardKey(key) {
          keyboardKeyRef.value = key;
        }
        function updateHoverKey(key) {
          hoverKeyRef.value = key;
        }
        function doCheck(key) {
          const { cascade, multiple, filterable } = props;
          const {
            value: { check, getNode, getPath }
          } = treeMateRef;
          if (multiple) {
            try {
              const { checkedKeys } = check(key, mergedKeysRef.value.checkedKeys, {
                cascade,
                checkStrategy: mergedCheckStrategyRef.value,
                allowNotLoaded: props.allowCheckingNotLoaded
              });
              doUpdateValue(
                checkedKeys,
                checkedKeys.map(
                  (checkedKey) => getNode(checkedKey)?.rawNode || null
                ),
                checkedKeys.map(
                  (checkedKey) => getRawNodePath(getPath(checkedKey)?.treeNodePath)
                )
              );
              if (filterable)
                focusSelectionInput();
              keyboardKeyRef.value = key;
              hoverKeyRef.value = key;
            } catch (err) {
              if (err instanceof SubtreeNotLoadedError) {
                if (cascaderMenuInstRef.value) {
                  const tmNode = getNode(key);
                  if (tmNode !== null) {
                    cascaderMenuInstRef.value.showErrorMessage(
                      tmNode.rawNode[props.labelField]
                    );
                  }
                }
              } else {
                throw err;
              }
            }
          } else {
            if (mergedCheckStrategyRef.value === "child") {
              const tmNode = getNode(key);
              if (tmNode?.isLeaf) {
                doUpdateValue(
                  key,
                  tmNode.rawNode,
                  getRawNodePath(getPath(key).treeNodePath)
                );
              } else {
                return false;
              }
            } else {
              const tmNode = getNode(key);
              doUpdateValue(
                key,
                tmNode?.rawNode || null,
                getRawNodePath(getPath(key)?.treeNodePath)
              );
            }
          }
          return true;
        }
        function doUncheck(key) {
          const { cascade, multiple } = props;
          if (multiple) {
            const {
              value: { uncheck, getNode, getPath }
            } = treeMateRef;
            const { checkedKeys } = uncheck(key, mergedKeysRef.value.checkedKeys, {
              cascade,
              checkStrategy: mergedCheckStrategyRef.value,
              allowNotLoaded: props.allowCheckingNotLoaded
            });
            doUpdateValue(
              checkedKeys,
              checkedKeys.map((checkedKey) => getNode(checkedKey)?.rawNode || null),
              checkedKeys.map(
                (checkedKey) => getRawNodePath(getPath(checkedKey)?.treeNodePath)
              )
            );
            keyboardKeyRef.value = key;
            hoverKeyRef.value = key;
          }
        }
        const selectedOptionsRef = vue.computed(() => {
          if (props.multiple) {
            const { showPath, separator, labelField, cascade } = props;
            const { getCheckedKeys, getNode } = treeMateRef.value;
            const value = getCheckedKeys(checkedKeysRef.value, {
              cascade,
              checkStrategy: mergedCheckStrategyRef.value,
              allowNotLoaded: props.allowCheckingNotLoaded
            }).checkedKeys;
            return value.map((key) => {
              const node = getNode(key);
              if (node === null) {
                return {
                  label: String(key),
                  value: key
                };
              } else {
                return {
                  label: showPath ? getPathLabel(node, separator, labelField) : node.rawNode[labelField],
                  value: node.key
                };
              }
            });
          } else
            return [];
        });
        const selectedOptionRef = vue.computed(() => {
          const { multiple, showPath, separator, labelField } = props;
          const { value } = mergedValueRef;
          if (!multiple && !Array.isArray(value)) {
            const { getNode } = treeMateRef.value;
            if (value === null) {
              return null;
            }
            const node = getNode(value);
            if (node === null) {
              return {
                label: String(value),
                value
              };
            } else {
              return {
                label: showPath ? getPathLabel(node, separator, labelField) : node.rawNode[labelField],
                value: node.key
              };
            }
          } else
            return null;
        });
        const uncontrolledShowRef = vue.ref(false);
        const controlledShowRef = vue.toRef(props, "show");
        const mergedShowRef = useMergedState(controlledShowRef, uncontrolledShowRef);
        const localizedPlaceholderRef = vue.computed(() => {
          const { placeholder } = props;
          if (placeholder !== void 0)
            return placeholder;
          return localeRef.value.placeholder;
        });
        const showSelectMenuRef = vue.computed(() => {
          return !!(props.filterable && patternRef.value);
        });
        vue.watch(
          mergedShowRef,
          (show) => {
            if (!show)
              return;
            if (props.multiple)
              return;
            const { value } = mergedValueRef;
            if (!Array.isArray(value) && value !== null) {
              keyboardKeyRef.value = value;
              hoverKeyRef.value = value;
              void vue.nextTick(() => {
                if (!mergedShowRef.value)
                  return;
                const { value: hoverKey } = hoverKeyRef;
                if (mergedValueRef.value !== null) {
                  const node = treeMateRef.value.getNode(hoverKey);
                  if (node) {
                    cascaderMenuInstRef.value?.scroll(
                      node.level,
                      node.index,
                      depx(optionHeightRef.value)
                    );
                  }
                }
              });
            } else {
              keyboardKeyRef.value = null;
              hoverKeyRef.value = null;
            }
          },
          {
            immediate: true
          }
        );
        function doBlur(e) {
          const { onBlur } = props;
          const { nTriggerFormBlur } = formItem;
          if (onBlur)
            call(onBlur, e);
          nTriggerFormBlur();
        }
        function doFocus(e) {
          const { onFocus } = props;
          const { nTriggerFormFocus } = formItem;
          if (onFocus)
            call(onFocus, e);
          nTriggerFormFocus();
        }
        function focusSelectionInput() {
          triggerInstRef.value?.focusInput();
        }
        function focusSelection() {
          triggerInstRef.value?.focus();
        }
        function openMenu() {
          if (!mergedDisabledRef.value) {
            patternRef.value = "";
            doUpdateShow(true);
            if (props.filterable) {
              focusSelectionInput();
            }
          }
        }
        function closeMenu(returnFocus = false) {
          if (returnFocus) {
            focusSelection();
          }
          doUpdateShow(false);
          patternRef.value = "";
        }
        function handleCascaderMenuClickOutside(e) {
          if (showSelectMenuRef.value)
            return;
          if (mergedShowRef.value) {
            if (!triggerInstRef.value?.$el.contains(
              getPreciseEventTarget(e)
            )) {
              closeMenu();
            }
          }
        }
        function handleSelectMenuClickOutside(e) {
          if (!showSelectMenuRef.value)
            return;
          handleCascaderMenuClickOutside(e);
        }
        function clearPattern() {
          if (props.clearFilterAfterSelect)
            patternRef.value = "";
        }
        function move(direction) {
          const { value: keyboardKey } = keyboardKeyRef;
          const { value: treeMate } = treeMateRef;
          switch (direction) {
            case "prev":
              if (keyboardKey !== null) {
                const node = treeMate.getPrev(keyboardKey, { loop: true });
                if (node !== null) {
                  updateKeyboardKey(node.key);
                  cascaderMenuInstRef.value?.scroll(
                    node.level,
                    node.index,
                    depx(optionHeightRef.value)
                  );
                }
              }
              break;
            case "next":
              if (keyboardKey === null) {
                const node = treeMate.getFirstAvailableNode();
                if (node !== null) {
                  updateKeyboardKey(node.key);
                  cascaderMenuInstRef.value?.scroll(
                    node.level,
                    node.index,
                    depx(optionHeightRef.value)
                  );
                }
              } else {
                const node = treeMate.getNext(keyboardKey, { loop: true });
                if (node !== null) {
                  updateKeyboardKey(node.key);
                  cascaderMenuInstRef.value?.scroll(
                    node.level,
                    node.index,
                    depx(optionHeightRef.value)
                  );
                }
              }
              break;
            case "child":
              if (keyboardKey !== null) {
                const currentNode = treeMate.getNode(keyboardKey);
                if (currentNode !== null) {
                  if (currentNode.shallowLoaded) {
                    const node = treeMate.getChild(keyboardKey);
                    if (node !== null) {
                      updateHoverKey(keyboardKey);
                      updateKeyboardKey(node.key);
                    }
                  } else {
                    const { value: loadingKeySet } = loadingKeySetRef;
                    if (!loadingKeySet.has(keyboardKey)) {
                      addLoadingKey(keyboardKey);
                      updateHoverKey(keyboardKey);
                      const { onLoad } = props;
                      if (onLoad) {
                        onLoad(currentNode.rawNode).then(() => {
                          deleteLoadingKey(keyboardKey);
                        }).catch(() => {
                          deleteLoadingKey(keyboardKey);
                        });
                      }
                    }
                  }
                }
              }
              break;
            case "parent":
              if (keyboardKey !== null) {
                const node = treeMate.getParent(keyboardKey);
                if (node !== null) {
                  updateKeyboardKey(node.key);
                  const parentNode = node.getParent();
                  if (parentNode === null) {
                    updateHoverKey(null);
                  } else {
                    updateHoverKey(parentNode.key);
                  }
                }
              }
              break;
          }
        }
        function handleKeydown(e) {
          switch (e.key) {
            case " ":
            case "ArrowDown":
            case "ArrowUp":
              if (props.filterable && mergedShowRef.value) {
                break;
              }
              e.preventDefault();
              break;
          }
          if (happensIn(e, "action"))
            return;
          switch (e.key) {
            case " ":
              if (props.filterable)
                return;
            case "Enter":
              if (!mergedShowRef.value) {
                openMenu();
              } else {
                const { value: showSelectMenu } = showSelectMenuRef;
                const { value: keyboardKey } = keyboardKeyRef;
                if (!showSelectMenu) {
                  if (keyboardKey !== null) {
                    if (checkedKeysRef.value.includes(keyboardKey) || indeterminateKeysRef.value.includes(keyboardKey)) {
                      doUncheck(keyboardKey);
                    } else {
                      const checkIsValid = doCheck(keyboardKey);
                      if (!props.multiple && checkIsValid) {
                        closeMenu(true);
                      }
                    }
                  }
                } else {
                  if (selectMenuInstRef.value) {
                    const hasCorrespondingOption = selectMenuInstRef.value.enter();
                    if (hasCorrespondingOption)
                      clearPattern();
                  }
                }
              }
              break;
            case "ArrowUp":
              e.preventDefault();
              if (mergedShowRef.value) {
                if (showSelectMenuRef.value) {
                  selectMenuInstRef.value?.prev();
                } else {
                  move("prev");
                }
              }
              break;
            case "ArrowDown":
              e.preventDefault();
              if (mergedShowRef.value) {
                if (showSelectMenuRef.value) {
                  selectMenuInstRef.value?.next();
                } else {
                  move("next");
                }
              } else {
                openMenu();
              }
              break;
            case "ArrowLeft":
              e.preventDefault();
              if (mergedShowRef.value && !showSelectMenuRef.value) {
                move("parent");
              }
              break;
            case "ArrowRight":
              e.preventDefault();
              if (mergedShowRef.value && !showSelectMenuRef.value) {
                move("child");
              }
              break;
            case "Escape":
              if (mergedShowRef.value) {
                markEventEffectPerformed(e);
                closeMenu(true);
              }
          }
        }
        function handleMenuKeydown(e) {
          handleKeydown(e);
        }
        function handleClear(e) {
          e.stopPropagation();
          if (props.multiple) {
            doUpdateValue([], [], []);
          } else {
            doUpdateValue(null, null, null);
          }
        }
        function handleTriggerFocus(e) {
          if (!cascaderMenuInstRef.value?.$el.contains(e.relatedTarget)) {
            focusedRef.value = true;
            doFocus(e);
          }
        }
        function handleTriggerBlur(e) {
          if (!cascaderMenuInstRef.value?.$el.contains(e.relatedTarget)) {
            focusedRef.value = false;
            doBlur(e);
            closeMenu();
          }
        }
        function handleMenuFocus(e) {
          if (!triggerInstRef.value?.$el.contains(e.relatedTarget)) {
            focusedRef.value = true;
            doFocus(e);
          }
        }
        function handleMenuBlur(e) {
          if (!triggerInstRef.value?.$el.contains(e.relatedTarget)) {
            focusedRef.value = false;
            doBlur(e);
          }
        }
        function handleMenuMousedown(e) {
          if (!happensIn(e, "action")) {
            if (props.multiple && props.filter) {
              e.preventDefault();
              focusSelectionInput();
            }
          }
        }
        function handleMenuTabout() {
          closeMenu(true);
        }
        function handleTriggerClick() {
          if (props.filterable) {
            openMenu();
          } else {
            if (mergedShowRef.value) {
              closeMenu(true);
            } else {
              openMenu();
            }
          }
        }
        function handlePatternInput(e) {
          patternRef.value = e.target.value;
        }
        function handleDeleteOption(option) {
          const { multiple } = props;
          const { value: mergedValue } = mergedValueRef;
          if (multiple && Array.isArray(mergedValue) && option.value !== void 0) {
            doUncheck(option.value);
          } else {
            doUpdateValue(null, null, null);
          }
        }
        function syncSelectMenuPosition() {
          selectMenuFollowerRef.value?.syncPosition();
        }
        function syncCascaderMenuPosition() {
          cascaderMenuFollowerRef.value?.syncPosition();
        }
        function handleTriggerResize() {
          if (mergedShowRef.value) {
            if (showSelectMenuRef.value) {
              syncSelectMenuPosition();
            } else {
              syncCascaderMenuPosition();
            }
          }
        }
        vue.provide(cascaderInjectionKey, {
          mergedClsPrefixRef,
          mergedThemeRef: themeRef,
          mergedValueRef,
          checkedKeysRef,
          indeterminateKeysRef,
          hoverKeyPathRef,
          mergedCheckStrategyRef,
          cascadeRef: vue.toRef(props, "cascade"),
          multipleRef: vue.toRef(props, "multiple"),
          keyboardKeyRef,
          hoverKeyRef,
          remoteRef: vue.toRef(props, "remote"),
          loadingKeySetRef,
          expandTriggerRef: vue.toRef(props, "expandTrigger"),
          isMountedRef: isMounted(),
          onLoadRef: vue.toRef(props, "onLoad"),
          virtualScrollRef: vue.toRef(props, "virtualScroll"),
          optionHeightRef,
          localeRef,
          labelFieldRef: vue.toRef(props, "labelField"),
          renderLabelRef: vue.toRef(props, "renderLabel"),
          syncCascaderMenuPosition,
          syncSelectMenuPosition,
          updateKeyboardKey,
          updateHoverKey,
          addLoadingKey,
          deleteLoadingKey,
          doCheck,
          doUncheck,
          closeMenu,
          handleSelectMenuClickOutside,
          handleCascaderMenuClickOutside,
          clearPattern
        });
        const exposedMethods = {
          focus: () => {
            triggerInstRef.value?.focus();
          },
          blur: () => {
            triggerInstRef.value?.blur();
          }
        };
        const cssVarsRef = vue.computed(() => {
          const {
            self: {
              optionArrowColor,
              optionTextColor,
              optionTextColorActive,
              optionTextColorDisabled,
              optionCheckMarkColor,
              menuColor,
              menuBoxShadow,
              menuDividerColor,
              menuBorderRadius,
              menuHeight,
              optionColorHover,
              optionHeight,
              optionFontSize,
              loadingColor,
              columnWidth
            },
            common: { cubicBezierEaseInOut }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-menu-border-radius": menuBorderRadius,
            "--n-menu-box-shadow": menuBoxShadow,
            "--n-menu-height": menuHeight,
            "--n-column-width": columnWidth,
            "--n-menu-color": menuColor,
            "--n-menu-divider-color": menuDividerColor,
            "--n-option-height": optionHeight,
            "--n-option-font-size": optionFontSize,
            "--n-option-text-color": optionTextColor,
            "--n-option-text-color-disabled": optionTextColorDisabled,
            "--n-option-text-color-active": optionTextColorActive,
            "--n-option-color-hover": optionColorHover,
            "--n-option-check-mark-color": optionCheckMarkColor,
            "--n-option-arrow-color": optionArrowColor,
            "--n-menu-mask-color": changeColor(menuColor, { alpha: 0.75 }),
            "--n-loading-color": loadingColor
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("cascader", void 0, cssVarsRef, props) : void 0;
        return {
          ...exposedMethods,
          handleTriggerResize,
          mergedStatus: mergedStatusRef,
          selectMenuFollowerRef,
          cascaderMenuFollowerRef,
          triggerInstRef,
          selectMenuInstRef,
          cascaderMenuInstRef,
          mergedBordered: mergedBorderedRef,
          mergedClsPrefix: mergedClsPrefixRef,
          namespace: namespaceRef,
          mergedValue: mergedValueRef,
          mergedShow: mergedShowRef,
          showSelectMenu: showSelectMenuRef,
          pattern: patternRef,
          treeMate: treeMateRef,
          mergedSize: mergedSizeRef,
          mergedDisabled: mergedDisabledRef,
          localizedPlaceholder: localizedPlaceholderRef,
          selectedOption: selectedOptionRef,
          selectedOptions: selectedOptionsRef,
          adjustedTo: adjustedToRef,
          menuModel: menuModelRef,
          handleMenuTabout,
          handleMenuFocus,
          handleMenuBlur,
          handleMenuKeydown,
          handleMenuMousedown,
          handleTriggerFocus,
          handleTriggerBlur,
          handleTriggerClick,
          handleClear,
          handleDeleteOption,
          handlePatternInput,
          handleKeydown,
          focused: focusedRef,
          optionHeight: optionHeightRef,
          mergedTheme: themeRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedClsPrefix } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-cascader`
        }, /* @__PURE__ */ React.createElement(VBinder, null, {
          default: () => [
            /* @__PURE__ */ React.createElement(VTarget, null, {
              default: () => /* @__PURE__ */ React.createElement(NInternalSelection, {
                onResize: this.handleTriggerResize,
                ref: "triggerInstRef",
                status: this.mergedStatus,
                clsPrefix: mergedClsPrefix,
                maxTagCount: this.maxTagCount,
                bordered: this.mergedBordered,
                size: this.mergedSize,
                theme: this.mergedTheme.peers.InternalSelection,
                themeOverrides: this.mergedTheme.peerOverrides.InternalSelection,
                active: this.mergedShow,
                pattern: this.pattern,
                placeholder: this.localizedPlaceholder,
                selectedOption: this.selectedOption,
                selectedOptions: this.selectedOptions,
                multiple: this.multiple,
                filterable: this.filterable,
                clearable: this.clearable,
                disabled: this.mergedDisabled,
                focused: this.focused,
                onFocus: this.handleTriggerFocus,
                onBlur: this.handleTriggerBlur,
                onClick: this.handleTriggerClick,
                onClear: this.handleClear,
                onDeleteOption: this.handleDeleteOption,
                onPatternInput: this.handlePatternInput,
                onKeydown: this.handleKeydown
              }, {
                arrow: () => this.$slots.arrow?.()
              })
            }),
            /* @__PURE__ */ React.createElement(VFollower, {
              key: "cascaderMenu",
              ref: "cascaderMenuFollowerRef",
              show: this.mergedShow && !this.showSelectMenu,
              containerClass: this.namespace,
              placement: this.placement,
              width: !this.options.length ? "target" : void 0,
              teleportDisabled: this.adjustedTo === useAdjustedTo.tdkey,
              to: this.adjustedTo
            }, {
              default: () => {
                this.onRender?.();
                const { menuProps } = this;
                return /* @__PURE__ */ React.createElement(CascaderMenu, {
                  ...menuProps,
                  ref: "cascaderMenuInstRef",
                  class: [this.themeClass, menuProps?.class],
                  value: this.mergedValue,
                  show: this.mergedShow && !this.showSelectMenu,
                  menuModel: this.menuModel,
                  style: [
                    this.cssVars,
                    menuProps?.style
                  ],
                  onFocus: this.handleMenuFocus,
                  onBlur: this.handleMenuBlur,
                  onKeydown: this.handleMenuKeydown,
                  onMousedown: this.handleMenuMousedown,
                  onTabout: this.handleMenuTabout
                }, {
                  action: () => this.$slots.action?.(),
                  empty: () => this.$slots.empty?.()
                });
              }
            }),
            /* @__PURE__ */ React.createElement(VFollower, {
              key: "selectMenu",
              ref: "selectMenuFollowerRef",
              show: this.mergedShow && this.showSelectMenu,
              containerClass: this.namespace,
              width: "target",
              placement: this.placement,
              to: this.adjustedTo,
              teleportDisabled: this.adjustedTo === useAdjustedTo.tdkey
            }, {
              default: () => {
                this.onRender?.();
                const { filterMenuProps } = this;
                return /* @__PURE__ */ React.createElement(CascaderSelectMenu, {
                  ...filterMenuProps,
                  ref: "selectMenuInstRef",
                  class: [this.themeClass, filterMenuProps?.class],
                  value: this.mergedValue,
                  show: this.mergedShow && this.showSelectMenu,
                  pattern: this.pattern,
                  multiple: this.multiple,
                  tmNodes: this.treeMate.treeNodes,
                  filter: this.filter,
                  labelField: this.labelField,
                  separator: this.separator,
                  style: [
                    this.cssVars,
                    filterMenuProps?.style
                  ]
                });
              }
            })
          ]
        }));
      }
    });

    const codeDark = {
      name: "Code",
      common: commonDark,

      self(vars) {
        const {
          textColor2,
          fontSize,
          fontWeightStrong,
          textColor3
        } = vars;
        return {
          textColor: textColor2,
          fontSize,
          fontWeightStrong,
          "mono-3": "#5c6370",
          "hue-1": "#56b6c2",
          "hue-2": "#61aeee",
          "hue-3": "#c678dd",
          "hue-4": "#98c379",
          "hue-5": "#e06c75",
          "hue-5-2": "#be5046",
          "hue-6": "#d19a66",
          "hue-6-2": "#e6c07b",
          lineNumberTextColor: textColor3
        };
      }

    };
    var codeDark$1 = codeDark;

    const self$S = vars => {
      const {
        textColor2,
        fontSize,
        fontWeightStrong,
        textColor3
      } = vars;
      return {
        textColor: textColor2,
        fontSize,
        fontWeightStrong,
        "mono-3": "#a0a1a7",
        "hue-1": "#0184bb",
        "hue-2": "#4078f2",
        "hue-3": "#a626a4",
        "hue-4": "#50a14f",
        "hue-5": "#e45649",
        "hue-5-2": "#c91243",
        "hue-6": "#986801",
        "hue-6-2": "#c18401",
        lineNumberTextColor: textColor3
      };
    };

    const codeLight = {
      name: "Code",
      common: commonLight,
      self: self$S
    };
    var codeLight$1 = codeLight;

    var style$12 = c$1([cB("code", `
    font-size: var(--n-font-size);
    font-family: var(--n-font-family);
  `, [cM("show-line-numbers", `
      display: flex;
    `), cE("line-numbers", `
      user-select: none;
      padding-right: 12px;
      text-align: right;
      transition: color .3s var(--n-bezier);
      color: var(--n-line-number-text-color);
    `), cM("word-wrap", [c$1("pre", `
        white-space: pre-wrap;
        word-break: break-all;
      `)]), c$1("pre", `
      margin: 0;
      line-height: inherit;
      font-size: inherit;
      font-family: inherit;
    `), c$1("[class^=hljs]", `
      color: var(--n-text-color);
      transition: 
        color .3s var(--n-bezier),
        background-color .3s var(--n-bezier);
    `)]), _ref => {
      let {
        props
      } = _ref;
      const codeClass = `${props.bPrefix}code`;
      return [`${codeClass} .hljs-comment,
      ${codeClass} .hljs-quote {
        color: var(--n-mono-3);
        font-style: italic;
      }`, `${codeClass} .hljs-doctag,
      ${codeClass} .hljs-keyword,
      ${codeClass} .hljs-formula {
        color: var(--n-hue-3);
      }`, `${codeClass} .hljs-section,
      ${codeClass} .hljs-name,
      ${codeClass} .hljs-selector-tag,
      ${codeClass} .hljs-deletion,
      ${codeClass} .hljs-subst {
        color: var(--n-hue-5);
      }`, `${codeClass} .hljs-literal {
        color: var(--n-hue-1);
      }`, `${codeClass} .hljs-string,
      ${codeClass} .hljs-regexp,
      ${codeClass} .hljs-addition,
      ${codeClass} .hljs-attribute,
      ${codeClass} .hljs-meta-string {
        color: var(--n-hue-4);
      }`, `${codeClass} .hljs-built_in,
      ${codeClass} .hljs-class .hljs-title {
        color: var(--n-hue-6-2);
      }`, `${codeClass} .hljs-attr,
      ${codeClass} .hljs-variable,
      ${codeClass} .hljs-template-variable,
      ${codeClass} .hljs-type,
      ${codeClass} .hljs-selector-class,
      ${codeClass} .hljs-selector-attr,
      ${codeClass} .hljs-selector-pseudo,
      ${codeClass} .hljs-number {
        color: var(--n-hue-6);
      }`, `${codeClass} .hljs-symbol,
      ${codeClass} .hljs-bullet,
      ${codeClass} .hljs-link,
      ${codeClass} .hljs-meta,
      ${codeClass} .hljs-selector-id,
      ${codeClass} .hljs-title {
        color: var(--n-hue-2);
      }`, `${codeClass} .hljs-emphasis {
        font-style: italic;
      }`, `${codeClass} .hljs-strong {
        font-weight: var(--n-font-weight-strong);
      }`, `${codeClass} .hljs-link {
        text-decoration: underline;
      }`];
    }]);

    const codeProps = {
      ...useTheme.props,
      language: String,
      code: {
        type: String,
        default: ""
      },
      trim: {
        type: Boolean,
        default: true
      },
      hljs: Object,
      uri: Boolean,
      inline: Boolean,
      wordWrap: Boolean,
      showLineNumbers: Boolean,
      internalFontSize: Number,
      internalNoHighlight: Boolean
    };
    var NCode = vue.defineComponent({
      name: "Code",
      props: codeProps,
      setup(props, { slots }) {
        const { internalNoHighlight } = props;
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig();
        const codeRef = vue.ref(null);
        const hljsRef = internalNoHighlight ? { value: void 0 } : useHljs(props);
        const createCodeHtml = (language, code, trim) => {
          const { value: hljs } = hljsRef;
          if (!hljs) {
            return null;
          }
          if (!(language && hljs.getLanguage(language))) {
            return null;
          }
          return hljs.highlight(trim ? code.trim() : code, {
            language
          }).value;
        };
        const mergedShowLineNumbersRef = vue.computed(() => {
          if (props.inline || props.wordWrap)
            return false;
          return props.showLineNumbers;
        });
        const setCode = () => {
          if (slots.default)
            return;
          const { value: codeEl } = codeRef;
          if (!codeEl)
            return;
          const { language } = props;
          const code = props.uri ? window.decodeURIComponent(props.code) : props.code;
          if (language) {
            const html = createCodeHtml(language, code, props.trim);
            if (html !== null) {
              if (props.inline) {
                codeEl.innerHTML = html;
              } else {
                const prevPreEl = codeEl.querySelector(".__code__");
                if (prevPreEl)
                  codeEl.removeChild(prevPreEl);
                const preEl = document.createElement("pre");
                preEl.className = "__code__";
                preEl.innerHTML = html;
                codeEl.appendChild(preEl);
              }
              return;
            }
          }
          if (props.inline) {
            codeEl.textContent = code;
            return;
          }
          const maybePreEl = codeEl.querySelector(".__code__");
          if (maybePreEl) {
            maybePreEl.textContent = code;
          } else {
            const wrap = document.createElement("pre");
            wrap.className = "__code__";
            wrap.textContent = code;
            codeEl.innerHTML = "";
            codeEl.appendChild(wrap);
          }
        };
        vue.onMounted(setCode);
        vue.watch(vue.toRef(props, "language"), setCode);
        vue.watch(vue.toRef(props, "code"), setCode);
        if (!internalNoHighlight)
          vue.watch(hljsRef, setCode);
        const themeRef = useTheme(
          "Code",
          "-code",
          style$12,
          codeLight$1,
          props,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut, fontFamilyMono },
            self: {
              textColor,
              fontSize,
              fontWeightStrong,
              lineNumberTextColor,
              "mono-3": $1,
              "hue-1": $2,
              "hue-2": $3,
              "hue-3": $4,
              "hue-4": $5,
              "hue-5": $6,
              "hue-5-2": $7,
              "hue-6": $8,
              "hue-6-2": $9
            }
          } = themeRef.value;
          const { internalFontSize } = props;
          return {
            "--n-font-size": internalFontSize ? `${internalFontSize}px` : fontSize,
            "--n-font-family": fontFamilyMono,
            "--n-font-weight-strong": fontWeightStrong,
            "--n-bezier": cubicBezierEaseInOut,
            "--n-text-color": textColor,
            "--n-mono-3": $1,
            "--n-hue-1": $2,
            "--n-hue-2": $3,
            "--n-hue-3": $4,
            "--n-hue-4": $5,
            "--n-hue-5": $6,
            "--n-hue-5-2": $7,
            "--n-hue-6": $8,
            "--n-hue-6-2": $9,
            "--n-line-number-text-color": lineNumberTextColor
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "code",
          vue.computed(() => {
            return `${props.internalFontSize || "a"}`;
          }),
          cssVarsRef,
          props
        ) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          codeRef,
          mergedShowLineNumbers: mergedShowLineNumbersRef,
          lineNumbers: vue.computed(() => {
            let number = 1;
            const numbers = [];
            let lastIsLineWrap = false;
            for (const char of props.code) {
              if (char === "\n") {
                lastIsLineWrap = true;
                numbers.push(number++);
              } else {
                lastIsLineWrap = false;
              }
            }
            if (!lastIsLineWrap) {
              numbers.push(number++);
            }
            return numbers.join("\n");
          }),
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedClsPrefix, wordWrap, mergedShowLineNumbers, onRender } = this;
        onRender?.();
        return /* @__PURE__ */ React.createElement("code", {
          class: [
            `${mergedClsPrefix}-code`,
            this.themeClass,
            wordWrap && `${mergedClsPrefix}-code--word-wrap`,
            mergedShowLineNumbers && `${mergedClsPrefix}-code--show-line-numbers`
          ],
          style: this.cssVars,
          ref: "codeRef"
        }, mergedShowLineNumbers ? /* @__PURE__ */ React.createElement("pre", {
          class: `${mergedClsPrefix}-code__line-numbers`
        }, this.lineNumbers) : null, this.$slots.default?.());
      }
    });

    const self$R = vars => {
      const {
        fontWeight,
        textColor1,
        textColor2,
        textColorDisabled,
        dividerColor,
        fontSize
      } = vars;
      return {
        titleFontSize: fontSize,
        titleFontWeight: fontWeight,
        dividerColor,
        titleTextColor: textColor1,
        titleTextColorDisabled: textColorDisabled,
        fontSize,
        textColor: textColor2,
        arrowColor: textColor2,
        arrowColorDisabled: textColorDisabled
      };
    };
    const collapseLight = {
      name: "Collapse",
      common: commonLight,
      self: self$R
    };
    var collapseLight$1 = collapseLight;

    const collapseDark = {
      name: "Collapse",
      common: commonDark,
      self: self$R
    };
    var collapseDark$1 = collapseDark;

    var rtlStyle$i = cB("collapse", [cM("rtl", `
    direction: rtl;
  `, [cB("collapse-item", [cB("collapse-item", {
      marginRight: "32px",
      marginLeft: 0
    }), cM("left-arrow-placement", [cE("header", [cB("collapse-item-arrow", {
      marginRight: 0,
      marginLeft: "4px"
    })])]), cM("right-arrow-placement", [cE("header", [cB("collapse-item-arrow", {
      marginLeft: 0,
      marginRight: "4px"
    })])]), cM("active", [cE("header", [cM("active", [cB("collapse-item-arrow", {
      transform: "rotate(-90deg)"
    })])])])])])]);

    const collapseRtl = {
      name: "Collapse",
      style: rtlStyle$i
    };

    var style$11 = cB("collapse", "width: 100%;", [cB("collapse-item", `
    font-size: var(--n-font-size);
    color: var(--n-text-color);
    transition:
      color .3s var(--n-bezier),
      border-color .3s var(--n-bezier);
    margin: 16px 0 0 0;
  `, [cM("disabled", [cE("header", "cursor: not-allowed;", [cE("header-main", `
          color: var(--n-title-text-color-disabled);
        `), cB("collapse-item-arrow", `
          color: var(--n-arrow-color-disabled);
        `)])]), cB("collapse-item", "margin-left: 32px;"), c$1("&:first-child", "margin-top: 0;"), c$1("&:first-child >", [cE("header", "padding-top: 0;")]), cM("left-arrow-placement", [cE("header", [cB("collapse-item-arrow", "margin-right: 4px;")])]), cM("right-arrow-placement", [cE("header", [cB("collapse-item-arrow", "margin-left: 4px;")])]), cE("content-wrapper", [cE("content-inner", "padding-top: 16px;"), fadeInHeightExpandTransition({
      duration: "0.15s"
    })]), cM("active", [cE("header", [cM("active", [cB("collapse-item-arrow", "transform: rotate(90deg);")])])]), c$1("&:not(:first-child)", "border-top: 1px solid var(--n-divider-color);"), cE("header", `
      font-size: var(--n-title-font-size);
      display: flex;
      flex-wrap: nowrap;
      align-items: center;
      transition: color .3s var(--n-bezier);
      position: relative;
      padding: 16px 0 0 0;
      color: var(--n-title-text-color);
      cursor: pointer;
    `, [cE("header-main", `
        display: flex;
        flex-wrap: nowrap;
        align-items: center;
        font-weight: var(--n-title-font-weight);
        transition: color .3s var(--n-bezier);
        flex: 1;
        color: var(--n-title-text-color);
      `), cE("header-extra", `
        display: flex;
        align-items: center;
        transition: color .3s var(--n-bezier);
        color: var(--n-text-color);
      `), cB("collapse-item-arrow", `
        display: flex;
        transition:
          transform .15s var(--n-bezier),
          color .3s var(--n-bezier);
        font-size: 18px;
        color: var(--n-arrow-color);
      `)])])]);

    const collapseProps = {
      ...useTheme.props,
      defaultExpandedNames: {
        type: [Array, String],
        default: null
      },
      expandedNames: [Array, String],
      arrowPlacement: {
        type: String,
        default: "left"
      },
      accordion: {
        type: Boolean,
        default: false
      },
      displayDirective: {
        type: String,
        default: "if"
      },
      onItemHeaderClick: [Function, Array],
      "onUpdate:expandedNames": [Function, Array],
      onUpdateExpandedNames: [Function, Array],
      onExpandedNamesChange: {
        type: [Function, Array],
        validator: () => {
          {
            warn$2(
              "collapse",
              "`on-expanded-names-change` is deprecated, please use `on-update:expanded-names` instead."
            );
          }
          return true;
        },
        default: void 0
      }
    };
    const collapseInjectionKey = createInjectionKey("n-collapse");
    var NCollapse = vue.defineComponent({
      name: "Collapse",
      props: collapseProps,
      setup(props, { slots }) {
        const { mergedClsPrefixRef, inlineThemeDisabled, mergedRtlRef } = useConfig(props);
        const uncontrolledExpandedNamesRef = vue.ref(props.defaultExpandedNames);
        const controlledExpandedNamesRef = vue.computed(() => props.expandedNames);
        const mergedExpandedNamesRef = useMergedState(
          controlledExpandedNamesRef,
          uncontrolledExpandedNamesRef
        );
        const themeRef = useTheme(
          "Collapse",
          "-collapse",
          style$11,
          collapseLight$1,
          props,
          mergedClsPrefixRef
        );
        function doUpdateExpandedNames(names) {
          const {
            "onUpdate:expandedNames": _onUpdateExpandedNames,
            onUpdateExpandedNames,
            onExpandedNamesChange
          } = props;
          if (onUpdateExpandedNames) {
            call(onUpdateExpandedNames, names);
          }
          if (_onUpdateExpandedNames) {
            call(_onUpdateExpandedNames, names);
          }
          if (onExpandedNamesChange) {
            call(onExpandedNamesChange, names);
          }
          uncontrolledExpandedNamesRef.value = names;
        }
        function doItemHeaderClick(info) {
          const { onItemHeaderClick } = props;
          if (onItemHeaderClick) {
            call(onItemHeaderClick, info);
          }
        }
        function toggleItem(collapse, name, event) {
          const { accordion } = props;
          const { value: expandedNames } = mergedExpandedNamesRef;
          if (accordion) {
            if (collapse) {
              doUpdateExpandedNames([name]);
              doItemHeaderClick({ name, expanded: true, event });
            } else {
              doUpdateExpandedNames([]);
              doItemHeaderClick({ name, expanded: false, event });
            }
          } else {
            if (!Array.isArray(expandedNames)) {
              doUpdateExpandedNames([name]);
              doItemHeaderClick({ name, expanded: true, event });
            } else {
              const activeNames = expandedNames.slice();
              const index = activeNames.findIndex(
                (activeName) => name === activeName
              );
              if (~index) {
                activeNames.splice(index, 1);
                doUpdateExpandedNames(activeNames);
                doItemHeaderClick({ name, expanded: false, event });
              } else {
                activeNames.push(name);
                doUpdateExpandedNames(activeNames);
                doItemHeaderClick({ name, expanded: true, event });
              }
            }
          }
        }
        vue.provide(collapseInjectionKey, {
          props,
          mergedClsPrefixRef,
          expandedNamesRef: mergedExpandedNamesRef,
          slots,
          toggleItem
        });
        const rtlEnabledRef = useRtl("Collapse", mergedRtlRef, mergedClsPrefixRef);
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self: {
              titleFontWeight,
              dividerColor,
              titleTextColor,
              titleTextColorDisabled,
              textColor,
              arrowColor,
              fontSize,
              titleFontSize,
              arrowColorDisabled
            }
          } = themeRef.value;
          return {
            "--n-font-size": fontSize,
            "--n-bezier": cubicBezierEaseInOut,
            "--n-text-color": textColor,
            "--n-divider-color": dividerColor,
            "--n-title-font-size": titleFontSize,
            "--n-title-text-color": titleTextColor,
            "--n-title-text-color-disabled": titleTextColorDisabled,
            "--n-title-font-weight": titleFontWeight,
            "--n-arrow-color": arrowColor,
            "--n-arrow-color-disabled": arrowColorDisabled
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("collapse", void 0, cssVarsRef, props) : void 0;
        return {
          rtlEnabled: rtlEnabledRef,
          mergedTheme: themeRef,
          mergedClsPrefix: mergedClsPrefixRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        this.onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${this.mergedClsPrefix}-collapse`,
            this.rtlEnabled && `${this.mergedClsPrefix}-collapse--rtl`,
            this.themeClass
          ],
          style: this.cssVars
        }, this.$slots);
      }
    });

    var NCollapseItemContent = vue.defineComponent({
      name: "CollapseItemContent",
      props: {
        displayDirective: {
          type: String,
          required: true
        },
        show: Boolean,
        clsPrefix: {
          type: String,
          required: true
        }
      },
      setup(props) {
        const onceTrueRef = useFalseUntilTruthy(vue.toRef(props, "show"));
        return {
          onceTrue: onceTrueRef
        };
      },
      render() {
        return /* @__PURE__ */ React.createElement(NFadeInExpandTransition, null, {
          default: () => {
            const { show, displayDirective, onceTrue, clsPrefix } = this;
            const useVShow = displayDirective === "show" && onceTrue;
            const contentNode = /* @__PURE__ */ React.createElement("div", {
              class: `${clsPrefix}-collapse-item__content-wrapper`
            }, /* @__PURE__ */ React.createElement("div", {
              class: `${clsPrefix}-collapse-item__content-inner`
            }, this.$slots));
            return useVShow ? vue.withDirectives(contentNode, [[vue.vShow, show]]) : show ? contentNode : null;
          }
        });
      }
    });

    const collapseItemProps = {
      title: String,
      name: [String, Number],
      disabled: Boolean,
      displayDirective: String
    };
    var NCollapseItem = vue.defineComponent({
      name: "CollapseItem",
      props: collapseItemProps,
      setup(props) {
        const { mergedRtlRef } = useConfig(props);
        const randomName = createId();
        const mergedNameRef = useMemo(() => {
          return props.name ?? randomName;
        });
        const NCollapse = vue.inject(collapseInjectionKey);
        if (!NCollapse) {
          throwError(
            "collapse-item",
            "`n-collapse-item` must be placed inside `n-collapse`."
          );
        }
        const {
          expandedNamesRef,
          props: collapseProps,
          mergedClsPrefixRef,
          slots: collapseSlots
        } = NCollapse;
        const collapsedRef = vue.computed(() => {
          const { value: expandedNames } = expandedNamesRef;
          if (Array.isArray(expandedNames)) {
            const { value: name } = mergedNameRef;
            return !~expandedNames.findIndex(
              (expandedName) => expandedName === name
            );
          } else if (expandedNames) {
            const { value: name } = mergedNameRef;
            return name !== expandedNames;
          }
          return true;
        });
        const rtlEnabledRef = useRtl("Collapse", mergedRtlRef, mergedClsPrefixRef);
        return {
          rtlEnabled: rtlEnabledRef,
          collapseSlots,
          randomName,
          mergedClsPrefix: mergedClsPrefixRef,
          collapsed: collapsedRef,
          mergedDisplayDirective: vue.computed(() => {
            const { displayDirective } = props;
            if (displayDirective) {
              return displayDirective;
            } else {
              return collapseProps.displayDirective;
            }
          }),
          arrowPlacement: vue.computed(() => {
            return collapseProps.arrowPlacement;
          }),
          handleClick(e) {
            if (NCollapse && !props.disabled) {
              NCollapse.toggleItem(collapsedRef.value, mergedNameRef.value, e);
            }
          }
        };
      },
      render() {
        const {
          collapseSlots,
          $slots,
          arrowPlacement,
          collapsed,
          mergedDisplayDirective,
          mergedClsPrefix,
          disabled
        } = this;
        const headerNode = $slots.header ? $slots.header() : this.title;
        const headerExtraSlot = $slots["header-extra"] || collapseSlots["header-extra"];
        const arrowSlot = $slots.arrow || collapseSlots.arrow;
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-collapse-item`,
            `${mergedClsPrefix}-collapse-item--${arrowPlacement}-arrow-placement`,
            disabled && `${mergedClsPrefix}-collapse-item--disabled`,
            !collapsed && `${mergedClsPrefix}-collapse-item--active`
          ]
        }, /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-collapse-item__header`,
            !collapsed && `${mergedClsPrefix}-collapse-item__header--active`
          ]
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-collapse-item__header-main`,
          onClick: this.handleClick
        }, arrowPlacement === "right" && headerNode, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-collapse-item-arrow`,
          key: this.rtlEnabled ? 0 : 1
        }, arrowSlot ? arrowSlot({ collapsed }) : /* @__PURE__ */ React.createElement(NBaseIcon, {
          clsPrefix: mergedClsPrefix
        }, {
          default: collapseSlots.expandIcon ?? (() => this.rtlEnabled ? /* @__PURE__ */ React.createElement(ChevronLeftIcon, null) : /* @__PURE__ */ React.createElement(ChevronRightIcon, null))
        })), arrowPlacement === "left" && headerNode), headerExtraSlot && /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-collapse-item__header-extra`,
          onClick: this.handleClick
        }, { default: headerExtraSlot })), /* @__PURE__ */ React.createElement(NCollapseItemContent, {
          clsPrefix: mergedClsPrefix,
          displayDirective: mergedDisplayDirective,
          show: !collapsed
        }, $slots));
      }
    });

    var style$10 = cB("collapse-transition", {
      width: "100%"
    }, [fadeInHeightExpandTransition()]);

    const self$Q = vars => {
      const {
        cubicBezierEaseInOut
      } = vars;
      return {
        bezier: cubicBezierEaseInOut
      };
    };
    const collapseTransitionLight = {
      name: "CollapseTransition",
      common: commonLight,
      self: self$Q
    };
    var collapseTransitionLight$1 = collapseTransitionLight;

    const collapseTransitionDark = {
      name: "CollapseTransition",
      common: commonDark,
      self: self$Q
    };
    var collapseTransitionDark$1 = collapseTransitionDark;

    var rtlStyle$h = cB("collapse-transition", [cM("rtl", `
    direction: rtl;
    text-align: right;
  `)]);

    const collapseTransitionRtl = {
      name: "CollapseTransition",
      style: rtlStyle$h
    };

    const collapseTransitionProps = {
      ...useTheme.props,
      show: {
        type: Boolean,
        default: true
      },
      appear: Boolean,
      collapsed: {
        type: Boolean,
        default: void 0
      }
    };
    var CollapseTransition = vue.defineComponent({
      name: "CollapseTransition",
      props: collapseTransitionProps,
      inheritAttrs: false,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.collapsed !== void 0) {
              warnOnce(
                "collapse-transition",
                "`collapsed` is deprecated, please use `show` instead"
              );
            }
          });
        }
        const { mergedClsPrefixRef, inlineThemeDisabled, mergedRtlRef } = useConfig(props);
        const mergedThemeRef = useTheme(
          "CollapseTransition",
          "-collapse-transition",
          style$10,
          collapseTransitionLight$1,
          props,
          mergedClsPrefixRef
        );
        const rtlEnabledRef = useRtl(
          "CollapseTransition",
          mergedRtlRef,
          mergedClsPrefixRef
        );
        const mergedShowRef = vue.computed(() => {
          if (props.collapsed !== void 0) {
            return props.collapsed;
          }
          return props.show;
        });
        const cssVarsRef = vue.computed(() => {
          const {
            self: { bezier }
          } = mergedThemeRef.value;
          return {
            "--n-bezier": bezier
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("collapse-transition", void 0, cssVarsRef, props) : void 0;
        return {
          rtlEnabled: rtlEnabledRef,
          mergedShow: mergedShowRef,
          mergedClsPrefix: mergedClsPrefixRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        return /* @__PURE__ */ React.createElement(NFadeInExpandTransition, {
          appear: this.appear
        }, {
          default: () => {
            if (!this.mergedShow)
              return;
            this.onRender?.();
            return vue.h(
              "div",
              vue.mergeProps(
                {
                  class: [
                    `${this.mergedClsPrefix}-collapse-transition`,
                    this.rtlEnabled && `${this.mergedClsPrefix}-collapse-transition--rtl`,
                    this.themeClass
                  ],
                  style: this.cssVars
                },
                this.$attrs
              ),
              this.$slots
            );
          }
        });
      }
    });

    const configProviderProps = {
      abstract: Boolean,
      bordered: {
        type: Boolean,
        default: void 0
      },
      clsPrefix: String,
      locale: Object,
      dateLocale: Object,
      namespace: String,
      rtl: Array,
      tag: {
        type: String,
        default: "div"
      },
      hljs: Object,
      theme: Object,
      themeOverrides: Object,
      componentOptions: Object,
      icons: Object,
      breakpoints: Object,
      preflightStyleDisabled: Boolean,
      inlineThemeDisabled: {
        type: Boolean,
        default: void 0
      },
      as: {
        type: String,
        validator: () => {
          warn$2("config-provider", "`as` is deprecated, please use `tag` instead.");
          return true;
        },
        default: void 0
      }
    };
    var NConfigProvider = vue.defineComponent({
      name: "ConfigProvider",
      alias: ["App"],
      props: configProviderProps,

      setup(props) {
        const NConfigProvider = vue.inject(configProviderInjectionKey, null);
        const mergedThemeRef = vue.computed(() => {
          const {
            theme
          } = props;
          if (theme === null) return void 0;
          const inheritedTheme = NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.mergedThemeRef.value;
          return theme === void 0 ? inheritedTheme : inheritedTheme === void 0 ? theme : Object.assign({}, inheritedTheme, theme);
        });
        const mergedThemeOverridesRef = vue.computed(() => {
          const {
            themeOverrides
          } = props;
          if (themeOverrides === null) return void 0;

          if (themeOverrides === void 0) {
            return NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.mergedThemeOverridesRef.value;
          } else {
            const inheritedThemeOverrides = NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.mergedThemeOverridesRef.value;

            if (inheritedThemeOverrides === void 0) {
              return themeOverrides;
            } else {
              return lodash.exports.merge({}, inheritedThemeOverrides, themeOverrides);
            }
          }
        });
        const mergedNamespaceRef = useMemo(() => {
          const {
            namespace
          } = props;
          return namespace === void 0 ? NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.mergedNamespaceRef.value : namespace;
        });
        const mergedBorderedRef = useMemo(() => {
          const {
            bordered
          } = props;
          return bordered === void 0 ? NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.mergedBorderedRef.value : bordered;
        });
        const mergedIconsRef = vue.computed(() => {
          const {
            icons
          } = props;
          return icons === void 0 ? NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.mergedIconsRef.value : icons;
        });
        const mergedComponentPropsRef = vue.computed(() => {
          const {
            componentOptions
          } = props;
          if (componentOptions !== void 0) return componentOptions;
          return NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.mergedComponentPropsRef.value;
        });
        const mergedClsPrefixRef = vue.computed(() => {
          const {
            clsPrefix
          } = props;
          if (clsPrefix !== void 0) return clsPrefix;
          return NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.mergedClsPrefixRef.value;
        });
        const mergedRtlRef = vue.computed(() => {
          const {
            rtl
          } = props;

          if (rtl === void 0) {
            return NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.mergedRtlRef.value;
          }

          const rtlEnabledState = {};

          for (const rtlInfo of rtl) {
            var _rtlInfo$peers;

            rtlEnabledState[rtlInfo.name] = vue.markRaw(rtlInfo);
            (_rtlInfo$peers = rtlInfo.peers) === null || _rtlInfo$peers === void 0 ? void 0 : _rtlInfo$peers.forEach(peerRtlInfo => {
              if (!(peerRtlInfo.name in rtlEnabledState)) {
                rtlEnabledState[peerRtlInfo.name] = vue.markRaw(peerRtlInfo);
              }
            });
          }

          return rtlEnabledState;
        });
        const mergedBreakpointsRef = vue.computed(() => {
          return props.breakpoints || (NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.mergedBreakpointsRef.value);
        });
        const inlineThemeDisabled = props.inlineThemeDisabled || (NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.inlineThemeDisabled);
        const preflightStyleDisabled = props.preflightStyleDisabled || (NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.preflightStyleDisabled);
        const mergedThemeHashRef = vue.computed(() => {
          const {
            value: theme
          } = mergedThemeRef;
          const {
            value: mergedThemeOverrides
          } = mergedThemeOverridesRef;
          const hasThemeOverrides = mergedThemeOverrides && Object.keys(mergedThemeOverrides).length !== 0;
          const themeName = theme === null || theme === void 0 ? void 0 : theme.name;

          if (themeName) {
            if (hasThemeOverrides) {
              return `${themeName}-${murmur2(JSON.stringify(mergedThemeOverridesRef.value))}`;
            }

            return themeName;
          } else {
            if (hasThemeOverrides) {
              return murmur2(JSON.stringify(mergedThemeOverridesRef.value));
            }

            return "";
          }
        });
        vue.provide(configProviderInjectionKey, {
          mergedThemeHashRef,
          mergedBreakpointsRef,
          mergedRtlRef,
          mergedIconsRef,
          mergedComponentPropsRef,
          mergedBorderedRef,
          mergedNamespaceRef,
          mergedClsPrefixRef,
          mergedLocaleRef: vue.computed(() => {
            const {
              locale
            } = props;
            if (locale === null) return void 0;
            return locale === void 0 ? NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.mergedLocaleRef.value : locale;
          }),
          mergedDateLocaleRef: vue.computed(() => {
            const {
              dateLocale
            } = props;
            if (dateLocale === null) return void 0;
            return dateLocale === void 0 ? NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.mergedDateLocaleRef.value : dateLocale;
          }),
          mergedHljsRef: vue.computed(() => {
            const {
              hljs
            } = props;
            return hljs === void 0 ? NConfigProvider === null || NConfigProvider === void 0 ? void 0 : NConfigProvider.mergedHljsRef.value : hljs;
          }),
          mergedThemeRef,
          mergedThemeOverridesRef,
          inlineThemeDisabled: inlineThemeDisabled || false,
          preflightStyleDisabled: preflightStyleDisabled || false
        });
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          mergedBordered: mergedBorderedRef,
          mergedNamespace: mergedNamespaceRef,
          mergedTheme: mergedThemeRef,
          mergedThemeOverrides: mergedThemeOverridesRef
        };
      },

      render() {
        var _this$$slots$default, _this$$slots, _this$$slots$default2, _this$$slots2;

        return !this.abstract ? vue.h(this.as || this.tag, {
          class: `${this.mergedClsPrefix || defaultClsPrefix}-config-provider`
        }, (_this$$slots$default = (_this$$slots = this.$slots).default) === null || _this$$slots$default === void 0 ? void 0 : _this$$slots$default.call(_this$$slots)) : (_this$$slots$default2 = (_this$$slots2 = this.$slots).default) === null || _this$$slots$default2 === void 0 ? void 0 : _this$$slots$default2.call(_this$$slots2);
      }

    });

    const countdownProps = {
      duration: {
        type: Number,
        default: 0
      },
      active: {
        type: Boolean,
        default: true
      },
      precision: {
        type: Number,
        default: 0
      },
      render: Function,
      onFinish: Function
    };
    var Countdown = vue.defineComponent({
      name: "Countdown",
      props: countdownProps,
      setup(props) {
        let timerId = null;
        let elapsed = 0;
        let finished = false;
        const distanceRef = vue.ref(0);
        vue.watchEffect(() => {
          distanceRef.value = props.duration;
        });
        let pnow = -1;
        function getDistance(time) {
          return props.duration - elapsed + pnow - time;
        }
        function getTimeInfo(distance) {
          const hours = Math.floor(distance / 36e5);
          const minutes = Math.floor(distance % 36e5 / 6e4);
          const seconds = Math.floor(distance % 6e4 / 1e3);
          const milliseconds = Math.floor(distance % 1e3);
          return {
            hours,
            minutes,
            seconds,
            milliseconds
          };
        }
        function getDisplayValue(info) {
          const { hours, minutes, seconds, milliseconds } = info;
          const { precision } = props;
          switch (precision) {
            case 0:
              return `${String(hours).padStart(2, "0")}:${String(minutes).padStart(
            2,
            "0"
          )}:${String(seconds).padStart(2, "0")}`;
            default:
              return `${String(hours).padStart(2, "0")}:${String(minutes).padStart(
            2,
            "0"
          )}:${String(seconds).padStart(2, "0")}.${String(
            Math.floor(
              milliseconds / (precision === 1 ? 100 : precision === 2 ? 10 : 1)
            )
          ).padStart(precision, "0")}`;
          }
        }
        const frame = () => {
          const { precision } = props;
          const distance = getDistance(performance.now());
          if (distance <= 0) {
            distanceRef.value = 0;
            stopTimer();
            if (!finished) {
              finished = true;
              props.onFinish?.();
            }
            return;
          }
          let leftTime;
          switch (precision) {
            case 3:
            case 2:
              leftTime = distance % 34;
              break;
            case 1:
              leftTime = distance % 100;
              break;
            default:
              leftTime = distance % 1e3;
          }
          distanceRef.value = distance;
          timerId = window.setTimeout(() => {
            frame();
          }, leftTime);
        };
        const stopTimer = () => {
          if (timerId !== null) {
            window.clearTimeout(timerId);
            timerId = null;
          }
        };
        vue.onMounted(() => {
          vue.watchEffect(() => {
            if (props.active) {
              pnow = performance.now();
              frame();
            } else {
              const now = performance.now();
              if (pnow !== -1) {
                elapsed += now - pnow;
              }
              stopTimer();
            }
          });
        });
        vue.onBeforeUnmount(() => {
          stopTimer();
        });
        function reset() {
          distanceRef.value = props.duration;
          elapsed = 0;
          pnow = performance.now();
          if (props.active && finished) {
            frame();
          }
          finished = false;
        }
        const countdownExposedMethod = {
          reset
        };
        return Object.assign(countdownExposedMethod, {
          distance: distanceRef,
          getTimeInfo,
          getDisplayValue
        });
      },
      render() {
        const { render, precision, distance, getTimeInfo, getDisplayValue } = this;
        let timeInfo;
        switch (precision) {
          case 0:
            timeInfo = getTimeInfo(distance + 999);
            timeInfo.milliseconds = 0;
            break;
          case 1:
            timeInfo = getTimeInfo(distance + 99);
            timeInfo.milliseconds = Math.floor(timeInfo.milliseconds / 100) * 100;
            break;
          case 2:
            timeInfo = getTimeInfo(distance + 9);
            timeInfo.milliseconds = Math.floor(timeInfo.milliseconds / 10) * 10;
            break;
          case 3:
            timeInfo = getTimeInfo(distance);
        }
        if (render) {
          return render(timeInfo);
        } else {
          return getDisplayValue(timeInfo);
        }
      }
    });

    const easeOut = t => 1 - Math.pow(1 - t, 5);

    function tween(props) {
      const {
        from,
        to,
        duration,
        onUpdate,
        onFinish
      } = props;

      const tick = () => {
        const current = performance.now();
        const elapsedTime = Math.min(current - startTime, duration);
        const currentValue = from + (to - from) * easeOut(elapsedTime / duration);

        if (elapsedTime === duration) {
          onFinish();
          return;
        }

        onUpdate(currentValue);
        requestAnimationFrame(tick);
      };

      const startTime = performance.now();
      tick();
    }

    const numberAnimationProps = {
      to: {
        type: Number,
        default: 0
      },
      precision: {
        type: Number,
        default: 0
      },
      showSeparator: Boolean,
      locale: String,
      from: { type: Number, default: 0 },
      active: {
        type: Boolean,
        default: true
      },
      duration: {
        type: Number,
        default: 2e3
      },
      onFinish: Function
    };
    var NumberAnimation = vue.defineComponent({
      name: "NumberAnimation",
      props: numberAnimationProps,
      setup(props) {
        const { localeRef } = useLocale("name");
        const { duration } = props;
        const displayedValueRef = vue.ref(props.from);
        const mergedLocaleRef = vue.computed(() => {
          const { locale } = props;
          if (locale !== void 0)
            return locale;
          return localeRef.value;
        });
        let animating = false;
        const onUpdate = (currentValue) => {
          displayedValueRef.value = currentValue;
        };
        const onFinish = () => {
          displayedValueRef.value = props.to;
          animating = false;
          props.onFinish?.();
        };
        const animate = (from = props.from, to = props.to) => {
          animating = true;
          displayedValueRef.value = props.from;
          if (from !== to) {
            tween({
              from,
              to,
              duration,
              onUpdate,
              onFinish
            });
          }
        };
        const formattedValueRef = vue.computed(() => {
          const formatted = lodash.exports.round(
            displayedValueRef.value,
            props.precision
          ).toFixed(props.precision);
          const splitValue = formatted.split(".");
          const numberFormatter = new Intl.NumberFormat(mergedLocaleRef.value);
          const decimalSeparator = numberFormatter.formatToParts(0.5).find((part) => part.type === "decimal")?.value;
          const integer = props.showSeparator ? numberFormatter.format(Number(splitValue[0])) : splitValue[0];
          const decimal = splitValue[1];
          return {
            integer,
            decimal,
            decimalSeparator
          };
        });
        function play() {
          if (animating)
            return;
          animate();
        }
        vue.onMounted(() => {
          vue.watchEffect(() => {
            if (props.active)
              animate();
          });
        });
        const exposedMethods = { play };
        return {
          formattedValue: formattedValueRef,
          ...exposedMethods
        };
      },
      render() {
        const {
          formattedValue: { integer, decimal, decimalSeparator }
        } = this;
        return [integer, decimal ? decimalSeparator : null, decimal];
      }
    });

    const popselect = {
      name: "Popselect",
      common: commonDark,
      peers: {
        Popover: popoverDark$1,
        InternalSelectMenu: internalSelectMenuDark$1
      }
    };
    var popselectDark = popselect;

    function self$P(vars) {
      const {
        boxShadow2
      } = vars;
      return {
        menuBoxShadow: boxShadow2
      };
    }
    const popselectLight = createTheme$1({
      name: "Popselect",
      common: commonLight,
      peers: {
        Popover: popoverLight$1,
        InternalSelectMenu: internalSelectMenuLight$1
      },
      self: self$P
    });
    var popselectLight$1 = popselectLight;

    const popselectInjectionKey = createInjectionKey("n-popselect");

    var style$$ = cB("popselect-menu", `
  box-shadow: var(--n-menu-box-shadow);
`);

    const panelProps$1 = {
      multiple: Boolean,
      value: {
        type: [String, Number, Array],
        default: null
      },
      cancelable: Boolean,
      options: {
        type: Array,
        default: () => []
      },
      size: {
        type: String,
        default: "medium"
      },
      scrollable: Boolean,
      "onUpdate:value": [Function, Array],
      onUpdateValue: [Function, Array],
      onMouseenter: Function,
      onMouseleave: Function,
      renderLabel: Function,
      internalShowCheckmark: {
        type: Boolean,
        default: void 0
      },
      nodeProps: Function,
      virtualScroll: Boolean,
      onChange: [Function, Array]
    };
    const panelPropKeys$1 = keysOf(panelProps$1);
    var NPopselectPanel = vue.defineComponent({
      name: "PopselectPanel",
      props: panelProps$1,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.onChange !== void 0) {
              warn$2(
                "popselect",
                "`on-change` is deprecated, please use `on-update:value` instead."
              );
            }
          });
        }
        const NPopselect = vue.inject(popselectInjectionKey);
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Popselect",
          "-pop-select",
          style$$,
          popselectLight$1,
          NPopselect.props,
          mergedClsPrefixRef
        );
        const treeMateRef = vue.computed(() => {
          return createTreeMate(props.options, createTmOptions("value", "children"));
        });
        function doUpdateValue(value, option) {
          const {
            onUpdateValue,
            "onUpdate:value": _onUpdateValue,
            onChange
          } = props;
          if (onUpdateValue)
            call(onUpdateValue, value, option);
          if (_onUpdateValue) {
            call(_onUpdateValue, value, option);
          }
          if (onChange)
            call(onChange, value, option);
        }
        function handleToggle(tmNode) {
          toggle(tmNode.key);
        }
        function handleMenuMousedown(e) {
          if (!happensIn(e, "action"))
            e.preventDefault();
        }
        function toggle(value) {
          const {
            value: { getNode }
          } = treeMateRef;
          if (props.multiple) {
            if (Array.isArray(props.value)) {
              const newValue = [];
              const newOptions = [];
              let shouldAddValue = true;
              props.value.forEach((v) => {
                if (v === value) {
                  shouldAddValue = false;
                  return;
                }
                const tmNode = getNode(v);
                if (tmNode) {
                  newValue.push(tmNode.key);
                  newOptions.push(tmNode.rawNode);
                }
              });
              if (shouldAddValue) {
                newValue.push(value);
                newOptions.push(getNode(value).rawNode);
              }
              doUpdateValue(newValue, newOptions);
            } else {
              const tmNode = getNode(value);
              if (tmNode) {
                doUpdateValue([value], [tmNode.rawNode]);
              }
            }
          } else {
            if (props.value === value && props.cancelable) {
              doUpdateValue(null, null);
            } else {
              const tmNode = getNode(value);
              if (tmNode) {
                doUpdateValue(value, tmNode.rawNode);
              }
              const { "onUpdate:show": _onUpdateShow, onUpdateShow } = NPopselect.props;
              if (_onUpdateShow)
                call(_onUpdateShow, false);
              if (onUpdateShow)
                call(onUpdateShow, false);
              NPopselect.setShow(false);
            }
          }
          void vue.nextTick(() => {
            NPopselect.syncPosition();
          });
        }
        vue.watch(vue.toRef(props, "options"), () => {
          void vue.nextTick(() => {
            NPopselect.syncPosition();
          });
        });
        const cssVarsRef = vue.computed(() => {
          const {
            self: { menuBoxShadow }
          } = themeRef.value;
          return {
            "--n-menu-box-shadow": menuBoxShadow
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("select", void 0, cssVarsRef, NPopselect.props) : void 0;
        return {
          mergedTheme: NPopselect.mergedThemeRef,
          mergedClsPrefix: mergedClsPrefixRef,
          treeMate: treeMateRef,
          handleToggle,
          handleMenuMousedown,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        this.onRender?.();
        return /* @__PURE__ */ React.createElement(NInternalSelectMenu, {
          clsPrefix: this.mergedClsPrefix,
          focusable: true,
          nodeProps: this.nodeProps,
          class: [`${this.mergedClsPrefix}-popselect-menu`, this.themeClass],
          style: this.cssVars,
          theme: this.mergedTheme.peers.InternalSelectMenu,
          themeOverrides: this.mergedTheme.peerOverrides.InternalSelectMenu,
          multiple: this.multiple,
          treeMate: this.treeMate,
          size: this.size,
          value: this.value,
          virtualScroll: this.virtualScroll,
          scrollable: this.scrollable,
          renderLabel: this.renderLabel,
          onToggle: this.handleToggle,
          onMouseenter: this.onMouseenter,
          onMouseleave: this.onMouseenter,
          onMousedown: this.handleMenuMousedown,
          showCheckmark: this.internalShowCheckmark
        }, {
          action: () => this.$slots.action?.() || [],
          empty: () => this.$slots.empty?.() || []
        });
      }
    });

    const popselectProps = {
      ...useTheme.props,
      ...omit(popoverBaseProps, ["showArrow", "arrow"]),
      placement: {
        ...popoverBaseProps.placement,
        default: "bottom"
      },
      trigger: {
        type: String,
        default: "hover"
      },
      ...panelProps$1
    };
    var NPopselect = vue.defineComponent({
      name: "Popselect",
      props: popselectProps,
      inheritAttrs: false,
      __popover__: true,
      setup(props) {
        const themeRef = useTheme(
          "Popselect",
          "-popselect",
          void 0,
          popselectLight$1,
          props
        );
        const popoverInstRef = vue.ref(null);
        function syncPosition() {
          popoverInstRef.value?.syncPosition();
        }
        function setShow(value) {
          popoverInstRef.value?.setShow(value);
        }
        vue.provide(popselectInjectionKey, {
          props,
          mergedThemeRef: themeRef,
          syncPosition,
          setShow
        });
        const exposedMethods = {
          syncPosition,
          setShow
        };
        return {
          ...exposedMethods,
          popoverInstRef,
          mergedTheme: themeRef
        };
      },
      render() {
        const { mergedTheme } = this;
        const popoverProps = {
          theme: mergedTheme.peers.Popover,
          themeOverrides: mergedTheme.peerOverrides.Popover,
          builtinThemeOverrides: {
            padding: "0"
          },
          ref: "popoverInstRef",
          internalRenderBody: (className, ref2, style, onMouseenter, onMouseleave) => {
            const { $attrs } = this;
            return /* @__PURE__ */ React.createElement(NPopselectPanel, {
              ...$attrs,
              class: [$attrs.class, className],
              style: [$attrs.style, style],
              ...keep(this.$props, panelPropKeys$1),
              ref: createRefSetter(ref2),
              onMouseenter: mergeEventHandlers([
                onMouseenter,
                $attrs.onMouseenter
              ]),
              onMouseleave: mergeEventHandlers([
                onMouseleave,
                $attrs.onMouseleave
              ])
            }, {
              action: () => this.$slots.action?.(),
              empty: () => this.$slots.empty?.()
            });
          }
        };
        return /* @__PURE__ */ React.createElement(NPopover, {
          ...omit(this.$props, panelPropKeys$1),
          ...popoverProps,
          internalDeactivateImmediately: true
        }, {
          trigger: () => this.$slots.default?.()
        });
      }
    });

    function self$O(vars) {
      const {
        boxShadow2
      } = vars;
      return {
        menuBoxShadow: boxShadow2
      };
    }
    const selectLight = createTheme$1({
      name: "Select",
      common: commonLight,
      peers: {
        InternalSelection: internalSelectionLight$1,
        InternalSelectMenu: internalSelectMenuLight$1
      },
      self: self$O
    });
    var selectLight$1 = selectLight;

    const selectDark = {
      name: "Select",
      common: commonDark,
      peers: {
        InternalSelection: internalSelectionDark$1,
        InternalSelectMenu: internalSelectMenuDark$1
      },
      self: self$O
    };
    var selectDark$1 = selectDark;

    var style$_ = c$1([cB("select", `
    z-index: auto;
    outline: none;
    width: 100%;
    position: relative;
  `), cB("select-menu", `
    margin: 4px 0;
    box-shadow: var(--n-menu-box-shadow);
  `, [fadeInScaleUpTransition({
      originalTransition: "background-color .3s var(--n-bezier), box-shadow .3s var(--n-bezier)"
    })])]);

    const selectProps = {
      ...useTheme.props,
      to: useAdjustedTo.propTo,
      bordered: {
        type: Boolean,
        default: void 0
      },
      clearable: Boolean,
      clearFilterAfterSelect: {
        type: Boolean,
        default: true
      },
      options: {
        type: Array,
        default: () => []
      },
      defaultValue: {
        type: [String, Number, Array],
        default: null
      },
      value: [String, Number, Array],
      placeholder: String,
      menuProps: Object,
      multiple: Boolean,
      size: String,
      filterable: Boolean,
      disabled: {
        type: Boolean,
        default: void 0
      },
      remote: Boolean,
      loading: Boolean,
      filter: Function,
      placement: {
        type: String,
        default: "bottom-start"
      },
      widthMode: {
        type: String,
        default: "trigger"
      },
      tag: Boolean,
      onCreate: Function,
      fallbackOption: {
        type: [Function, Boolean],
        default: void 0
      },
      show: {
        type: Boolean,
        default: void 0
      },
      showArrow: {
        type: Boolean,
        default: true
      },
      maxTagCount: [Number, String],
      consistentMenuWidth: {
        type: Boolean,
        default: true
      },
      virtualScroll: {
        type: Boolean,
        default: true
      },
      labelField: {
        type: String,
        default: "label"
      },
      valueField: {
        type: String,
        default: "value"
      },
      childrenField: {
        type: String,
        default: "children"
      },
      renderLabel: Function,
      renderOption: Function,
      renderTag: Function,
      "onUpdate:value": [Function, Array],
      inputProps: Object,
      nodeProps: Function,
      onUpdateValue: [Function, Array],
      onBlur: [Function, Array],
      onClear: [Function, Array],
      onFocus: [Function, Array],
      onScroll: [Function, Array],
      onSearch: [Function, Array],
      onUpdateShow: [Function, Array],
      "onUpdate:show": [Function, Array],
      displayDirective: {
        type: String,
        default: "show"
      },
      resetMenuOnOptionsChange: {
        type: Boolean,
        default: true
      },
      status: String,
      internalShowCheckmark: {
        type: Boolean,
        default: true
      },
      onChange: [Function, Array],
      items: Array
    };
    var NSelect = vue.defineComponent({
      name: "Select",
      props: selectProps,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.items !== void 0) {
              warnOnce(
                "select",
                "`items` is deprecated, please use `options` instead."
              );
            }
            if (props.onChange !== void 0) {
              warnOnce(
                "select",
                "`on-change` is deprecated, please use `on-update:value` instead."
              );
            }
          });
        }
        const {
          mergedClsPrefixRef,
          mergedBorderedRef,
          namespaceRef,
          inlineThemeDisabled
        } = useConfig(props);
        const themeRef = useTheme(
          "Select",
          "-select",
          style$_,
          selectLight$1,
          props,
          mergedClsPrefixRef
        );
        const uncontrolledValueRef = vue.ref(props.defaultValue);
        const controlledValueRef = vue.toRef(props, "value");
        const mergedValueRef = useMergedState(
          controlledValueRef,
          uncontrolledValueRef
        );
        const focusedRef = vue.ref(false);
        const patternRef = vue.ref("");
        const treeMateRef = vue.computed(() => {
          const { valueField, childrenField } = props;
          const options = createTmOptions(valueField, childrenField);
          return createTreeMate(filteredOptionsRef.value, options);
        });
        const valOptMapRef = vue.computed(
          () => createValOptMap(
            localOptionsRef.value,
            props.valueField,
            props.childrenField
          )
        );
        const uncontrolledShowRef = vue.ref(false);
        const mergedShowRef = useMergedState(
          vue.toRef(props, "show"),
          uncontrolledShowRef
        );
        const triggerRef = vue.ref(null);
        const followerRef = vue.ref(null);
        const menuRef = vue.ref(null);
        const { localeRef } = useLocale("Select");
        const localizedPlaceholderRef = vue.computed(() => {
          return props.placeholder ?? localeRef.value.placeholder;
        });
        const compitableOptionsRef = useCompitable(props, ["items", "options"]);
        const emptyArray = [];
        const createdOptionsRef = vue.ref([]);
        const beingCreatedOptionsRef = vue.ref([]);
        const memoValOptMapRef = vue.ref(/* @__PURE__ */ new Map());
        const wrappedFallbackOptionRef = vue.computed(() => {
          const { fallbackOption } = props;
          if (fallbackOption === void 0) {
            const { labelField, valueField } = props;
            return (value) => ({
              [labelField]: String(value),
              [valueField]: value
            });
          }
          if (fallbackOption === false)
            return false;
          return (value) => {
            return Object.assign(
              fallbackOption(value),
              {
                value
              }
            );
          };
        });
        const localOptionsRef = vue.computed(() => {
          return beingCreatedOptionsRef.value.concat(
            createdOptionsRef.value
          ).concat(compitableOptionsRef.value);
        });
        const resolvedFilterRef = vue.computed(() => {
          const { filter } = props;
          if (filter)
            return filter;
          const { labelField, valueField } = props;
          return (pattern, option) => {
            if (!option)
              return false;
            const label = option[labelField];
            if (typeof label === "string") {
              return patternMatched(pattern, label);
            }
            const value = option[valueField];
            if (typeof value === "string") {
              return patternMatched(pattern, value);
            }
            if (typeof value === "number") {
              return patternMatched(pattern, String(value));
            }
            return false;
          };
        });
        const filteredOptionsRef = vue.computed(() => {
          if (props.remote) {
            return compitableOptionsRef.value;
          } else {
            const { value: localOptions } = localOptionsRef;
            const { value: pattern } = patternRef;
            if (!pattern.length || !props.filterable) {
              return localOptions;
            } else {
              return filterOptions(
                localOptions,
                resolvedFilterRef.value,
                pattern,
                props.childrenField
              );
            }
          }
        });
        function getMergedOptions(values) {
          const remote = props.remote;
          const { value: memoValOptMap } = memoValOptMapRef;
          const { value: valOptMap } = valOptMapRef;
          const { value: wrappedFallbackOption } = wrappedFallbackOptionRef;
          const options = [];
          values.forEach((value) => {
            if (valOptMap.has(value)) {
              options.push(valOptMap.get(value));
            } else if (remote && memoValOptMap.has(value)) {
              options.push(memoValOptMap.get(value));
            } else if (wrappedFallbackOption) {
              const option = wrappedFallbackOption(value);
              if (option) {
                options.push(option);
              }
            }
          });
          return options;
        }
        const selectedOptionsRef = vue.computed(() => {
          if (props.multiple) {
            const { value: values } = mergedValueRef;
            if (!Array.isArray(values))
              return [];
            return getMergedOptions(values);
          }
          return null;
        });
        const selectedOptionRef = vue.computed(() => {
          const { value: mergedValue } = mergedValueRef;
          if (!props.multiple && !Array.isArray(mergedValue)) {
            if (mergedValue === null)
              return null;
            return getMergedOptions([mergedValue])[0] || null;
          }
          return null;
        });
        const formItem = useFormItem(props);
        const { mergedSizeRef, mergedDisabledRef, mergedStatusRef } = formItem;
        function doUpdateValue(value, option) {
          const {
            onChange,
            "onUpdate:value": _onUpdateValue,
            onUpdateValue
          } = props;
          const { nTriggerFormChange, nTriggerFormInput } = formItem;
          if (onChange)
            call(onChange, value, option);
          if (onUpdateValue)
            call(onUpdateValue, value, option);
          if (_onUpdateValue) {
            call(_onUpdateValue, value, option);
          }
          uncontrolledValueRef.value = value;
          nTriggerFormChange();
          nTriggerFormInput();
        }
        function doBlur(e) {
          const { onBlur } = props;
          const { nTriggerFormBlur } = formItem;
          if (onBlur)
            call(onBlur, e);
          nTriggerFormBlur();
        }
        function doClear() {
          const { onClear } = props;
          if (onClear)
            call(onClear);
        }
        function doFocus(e) {
          const { onFocus } = props;
          const { nTriggerFormFocus } = formItem;
          if (onFocus)
            call(onFocus, e);
          nTriggerFormFocus();
        }
        function doSearch(value) {
          const { onSearch } = props;
          if (onSearch)
            call(onSearch, value);
        }
        function doScroll(e) {
          const { onScroll } = props;
          if (onScroll)
            call(onScroll, e);
        }
        function updateMemorizedOptions() {
          const { remote, multiple } = props;
          if (remote) {
            const { value: memoValOptMap } = memoValOptMapRef;
            if (multiple) {
              const { valueField } = props;
              selectedOptionsRef.value?.forEach((option) => {
                memoValOptMap.set(
                  option[valueField],
                  option
                );
              });
            } else {
              const option = selectedOptionRef.value;
              if (option) {
                memoValOptMap.set(
                  option[props.valueField],
                  option
                );
              }
            }
          }
        }
        function doUpdateShow(value) {
          const { onUpdateShow, "onUpdate:show": _onUpdateShow } = props;
          if (onUpdateShow)
            call(onUpdateShow, value);
          if (_onUpdateShow)
            call(_onUpdateShow, value);
          uncontrolledShowRef.value = value;
        }
        function openMenu() {
          if (!mergedDisabledRef.value) {
            doUpdateShow(true);
            uncontrolledShowRef.value = true;
            if (props.filterable) {
              focusSelectionInput();
            }
          }
        }
        function closeMenu() {
          doUpdateShow(false);
        }
        function handleMenuAfterLeave() {
          patternRef.value = "";
          beingCreatedOptionsRef.value = emptyArray;
        }
        const activeWithoutMenuOpenRef = vue.ref(false);
        function onTriggerInputFocus() {
          if (props.filterable) {
            activeWithoutMenuOpenRef.value = true;
          }
        }
        function onTriggerInputBlur() {
          if (props.filterable) {
            activeWithoutMenuOpenRef.value = false;
            if (!mergedShowRef.value) {
              handleMenuAfterLeave();
            }
          }
        }
        function handleTriggerClick() {
          if (mergedDisabledRef.value)
            return;
          if (!mergedShowRef.value) {
            openMenu();
          } else {
            if (!props.filterable) {
              closeMenu();
            } else {
              focusSelectionInput();
            }
          }
        }
        function handleTriggerBlur(e) {
          if (menuRef.value?.selfRef?.contains(e.relatedTarget)) {
            return;
          }
          focusedRef.value = false;
          doBlur(e);
          closeMenu();
        }
        function handleTriggerFocus(e) {
          doFocus(e);
          focusedRef.value = true;
        }
        function handleMenuFocus(e) {
          focusedRef.value = true;
        }
        function handleMenuBlur(e) {
          if (triggerRef.value?.$el.contains(e.relatedTarget))
            return;
          focusedRef.value = false;
          doBlur(e);
          closeMenu();
        }
        function handleMenuTabOut() {
          triggerRef.value?.focus();
          closeMenu();
        }
        function handleMenuClickOutside(e) {
          if (mergedShowRef.value) {
            if (!triggerRef.value?.$el.contains(
              getPreciseEventTarget(e)
            )) {
              closeMenu();
            }
          }
        }
        function createClearedMultipleSelectValue(value) {
          if (!Array.isArray(value))
            return [];
          if (wrappedFallbackOptionRef.value) {
            return Array.from(value);
          } else {
            const { remote } = props;
            const { value: valOptMap } = valOptMapRef;
            if (remote) {
              const { value: memoValOptMap } = memoValOptMapRef;
              return value.filter((v) => valOptMap.has(v) || memoValOptMap.has(v));
            } else {
              return value.filter((v) => valOptMap.has(v));
            }
          }
        }
        function handleToggleByTmNode(tmNode) {
          handleToggleByOption(tmNode.rawNode);
        }
        function handleToggleByOption(option) {
          if (mergedDisabledRef.value)
            return;
          const { tag, remote, clearFilterAfterSelect, valueField } = props;
          if (tag && !remote) {
            const { value: beingCreatedOptions } = beingCreatedOptionsRef;
            const beingCreatedOption = beingCreatedOptions[0] || null;
            if (beingCreatedOption) {
              const createdOptions = createdOptionsRef.value;
              if (!createdOptions.length) {
                createdOptionsRef.value = [beingCreatedOption];
              } else {
                createdOptions.push(beingCreatedOption);
              }
              beingCreatedOptionsRef.value = emptyArray;
            }
          }
          if (remote) {
            memoValOptMapRef.value.set(
              option[valueField],
              option
            );
          }
          if (props.multiple) {
            const changedValue = createClearedMultipleSelectValue(
              mergedValueRef.value
            );
            const index = changedValue.findIndex(
              (value) => value === option[valueField]
            );
            if (~index) {
              changedValue.splice(index, 1);
              if (tag && !remote) {
                const createdOptionIndex = getCreatedOptionIndex(
                  option[valueField]
                );
                if (~createdOptionIndex) {
                  createdOptionsRef.value.splice(createdOptionIndex, 1);
                  if (clearFilterAfterSelect)
                    patternRef.value = "";
                }
              }
            } else {
              changedValue.push(
                option[valueField]
              );
              if (clearFilterAfterSelect)
                patternRef.value = "";
            }
            doUpdateValue(changedValue, getMergedOptions(changedValue));
          } else {
            if (tag && !remote) {
              const createdOptionIndex = getCreatedOptionIndex(
                option[valueField]
              );
              if (~createdOptionIndex) {
                createdOptionsRef.value = [
                  createdOptionsRef.value[createdOptionIndex]
                ];
              } else {
                createdOptionsRef.value = emptyArray;
              }
            }
            focusSelection();
            closeMenu();
            doUpdateValue(
              option[valueField],
              option
            );
          }
        }
        function getCreatedOptionIndex(optionValue) {
          const createdOptions = createdOptionsRef.value;
          return createdOptions.findIndex(
            (createdOption) => createdOption[props.valueField] === optionValue
          );
        }
        function handlePatternInput(e) {
          if (!mergedShowRef.value) {
            openMenu();
          }
          const { value } = e.target;
          patternRef.value = value;
          const { tag, remote } = props;
          doSearch(value);
          if (tag && !remote) {
            if (!value) {
              beingCreatedOptionsRef.value = emptyArray;
              return;
            }
            const { onCreate } = props;
            const optionBeingCreated = onCreate ? onCreate(value) : { [props.labelField]: value, [props.valueField]: value };
            const { valueField } = props;
            if (compitableOptionsRef.value.some(
              (option) => option[valueField] === optionBeingCreated[valueField]
            ) || createdOptionsRef.value.some(
              (option) => option[valueField] === optionBeingCreated[valueField]
            )) {
              beingCreatedOptionsRef.value = emptyArray;
            } else {
              beingCreatedOptionsRef.value = [optionBeingCreated];
            }
          }
        }
        function handleClear(e) {
          e.stopPropagation();
          const { multiple } = props;
          if (!multiple && props.filterable) {
            closeMenu();
          }
          doClear();
          if (multiple) {
            doUpdateValue([], []);
          } else {
            doUpdateValue(null, null);
          }
        }
        function handleMenuMousedown(e) {
          if (!happensIn(e, "action") && !happensIn(e, "empty"))
            e.preventDefault();
        }
        function handleMenuScroll(e) {
          doScroll(e);
        }
        function handleKeydown(e) {
          switch (e.key) {
            case " ":
              if (props.filterable)
                break;
              else {
                e.preventDefault();
              }
            case "Enter":
              if (!triggerRef.value?.isCompositing) {
                if (mergedShowRef.value) {
                  const pendingTmNode = menuRef.value?.getPendingTmNode();
                  if (pendingTmNode) {
                    handleToggleByTmNode(pendingTmNode);
                  } else if (!props.filterable) {
                    closeMenu();
                    focusSelection();
                  }
                } else {
                  openMenu();
                  if (props.tag && activeWithoutMenuOpenRef.value) {
                    const beingCreatedOption = beingCreatedOptionsRef.value[0];
                    if (beingCreatedOption) {
                      const optionValue = beingCreatedOption[props.valueField];
                      const { value: mergedValue } = mergedValueRef;
                      if (props.multiple) {
                        if (Array.isArray(mergedValue) && mergedValue.some((value) => value === optionValue)) ; else {
                          handleToggleByOption(beingCreatedOption);
                        }
                      } else {
                        handleToggleByOption(beingCreatedOption);
                      }
                    }
                  }
                }
              }
              e.preventDefault();
              break;
            case "ArrowUp":
              e.preventDefault();
              if (props.loading)
                return;
              if (mergedShowRef.value) {
                menuRef.value?.prev();
              }
              break;
            case "ArrowDown":
              e.preventDefault();
              if (props.loading)
                return;
              if (mergedShowRef.value) {
                menuRef.value?.next();
              } else {
                openMenu();
              }
              break;
            case "Escape":
              if (mergedShowRef.value) {
                markEventEffectPerformed(e);
                closeMenu();
              }
              triggerRef.value?.focus();
              break;
          }
        }
        function focusSelection() {
          triggerRef.value?.focus();
        }
        function focusSelectionInput() {
          triggerRef.value?.focusInput();
        }
        function handleTriggerOrMenuResize() {
          if (!mergedShowRef.value)
            return;
          followerRef.value?.syncPosition();
        }
        updateMemorizedOptions();
        vue.watch(vue.toRef(props, "options"), updateMemorizedOptions);
        const exposedMethods = {
          focus: () => {
            triggerRef.value?.focus();
          },
          blur: () => {
            triggerRef.value?.blur();
          }
        };
        const cssVarsRef = vue.computed(() => {
          const {
            self: { menuBoxShadow }
          } = themeRef.value;
          return {
            "--n-menu-box-shadow": menuBoxShadow
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("select", void 0, cssVarsRef, props) : void 0;
        return {
          ...exposedMethods,
          mergedStatus: mergedStatusRef,
          mergedClsPrefix: mergedClsPrefixRef,
          mergedBordered: mergedBorderedRef,
          namespace: namespaceRef,
          treeMate: treeMateRef,
          isMounted: isMounted(),
          triggerRef,
          menuRef,
          pattern: patternRef,
          uncontrolledShow: uncontrolledShowRef,
          mergedShow: mergedShowRef,
          adjustedTo: useAdjustedTo(props),
          uncontrolledValue: uncontrolledValueRef,
          mergedValue: mergedValueRef,
          followerRef,
          localizedPlaceholder: localizedPlaceholderRef,
          selectedOption: selectedOptionRef,
          selectedOptions: selectedOptionsRef,
          mergedSize: mergedSizeRef,
          mergedDisabled: mergedDisabledRef,
          focused: focusedRef,
          activeWithoutMenuOpen: activeWithoutMenuOpenRef,
          inlineThemeDisabled,
          onTriggerInputFocus,
          onTriggerInputBlur,
          handleTriggerOrMenuResize,
          handleMenuFocus,
          handleMenuBlur,
          handleMenuTabOut,
          handleTriggerClick,
          handleToggle: handleToggleByTmNode,
          handleDeleteOption: handleToggleByOption,
          handlePatternInput,
          handleClear,
          handleTriggerBlur,
          handleTriggerFocus,
          handleKeydown,
          handleMenuAfterLeave,
          handleMenuClickOutside,
          handleMenuScroll,
          handleMenuKeydown: handleKeydown,
          handleMenuMousedown,
          mergedTheme: themeRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        return /* @__PURE__ */ React.createElement("div", {
          class: `${this.mergedClsPrefix}-select`
        }, /* @__PURE__ */ React.createElement(VBinder, null, {
          default: () => [
            /* @__PURE__ */ React.createElement(VTarget, null, {
              default: () => /* @__PURE__ */ React.createElement(NInternalSelection, {
                ref: "triggerRef",
                inlineThemeDisabled: this.inlineThemeDisabled,
                status: this.mergedStatus,
                inputProps: this.inputProps,
                clsPrefix: this.mergedClsPrefix,
                showArrow: this.showArrow,
                maxTagCount: this.maxTagCount,
                bordered: this.mergedBordered,
                active: this.activeWithoutMenuOpen || this.mergedShow,
                pattern: this.pattern,
                placeholder: this.localizedPlaceholder,
                selectedOption: this.selectedOption,
                selectedOptions: this.selectedOptions,
                multiple: this.multiple,
                renderTag: this.renderTag,
                renderLabel: this.renderLabel,
                filterable: this.filterable,
                clearable: this.clearable,
                disabled: this.mergedDisabled,
                size: this.mergedSize,
                theme: this.mergedTheme.peers.InternalSelection,
                labelField: this.labelField,
                valueField: this.valueField,
                themeOverrides: this.mergedTheme.peerOverrides.InternalSelection,
                loading: this.loading,
                focused: this.focused,
                onClick: this.handleTriggerClick,
                onDeleteOption: this.handleDeleteOption,
                onPatternInput: this.handlePatternInput,
                onClear: this.handleClear,
                onBlur: this.handleTriggerBlur,
                onFocus: this.handleTriggerFocus,
                onKeydown: this.handleKeydown,
                onPatternBlur: this.onTriggerInputBlur,
                onPatternFocus: this.onTriggerInputFocus,
                onResize: this.handleTriggerOrMenuResize
              }, {
                arrow: () => [this.$slots.arrow?.()]
              })
            }),
            /* @__PURE__ */ React.createElement(VFollower, {
              ref: "followerRef",
              show: this.mergedShow,
              to: this.adjustedTo,
              teleportDisabled: this.adjustedTo === useAdjustedTo.tdkey,
              containerClass: this.namespace,
              width: this.consistentMenuWidth ? "target" : void 0,
              minWidth: "target",
              placement: this.placement
            }, {
              default: () => /* @__PURE__ */ React.createElement(vue.Transition, {
                name: "fade-in-scale-up-transition",
                appear: this.isMounted,
                onAfterLeave: this.handleMenuAfterLeave
              }, {
                default: () => {
                  if (!(this.mergedShow || this.displayDirective === "show")) {
                    return null;
                  }
                  this.onRender?.();
                  return vue.withDirectives(
                    /* @__PURE__ */ React.createElement(NInternalSelectMenu, {
                      ...this.menuProps,
                      ref: "menuRef",
                      onResize: this.handleTriggerOrMenuResize,
                      inlineThemeDisabled: this.inlineThemeDisabled,
                      virtualScroll: this.consistentMenuWidth && this.virtualScroll,
                      class: [
                        `${this.mergedClsPrefix}-select-menu`,
                        this.themeClass,
                        this.menuProps?.class
                      ],
                      clsPrefix: this.mergedClsPrefix,
                      focusable: true,
                      labelField: this.labelField,
                      valueField: this.valueField,
                      autoPending: true,
                      nodeProps: this.nodeProps,
                      theme: this.mergedTheme.peers.InternalSelectMenu,
                      themeOverrides: this.mergedTheme.peerOverrides.InternalSelectMenu,
                      treeMate: this.treeMate,
                      multiple: this.multiple,
                      size: "medium",
                      renderOption: this.renderOption,
                      renderLabel: this.renderLabel,
                      value: this.mergedValue,
                      style: [this.menuProps?.style, this.cssVars],
                      onToggle: this.handleToggle,
                      onScroll: this.handleMenuScroll,
                      onFocus: this.handleMenuFocus,
                      onBlur: this.handleMenuBlur,
                      onKeydown: this.handleMenuKeydown,
                      onTabOut: this.handleMenuTabOut,
                      onMousedown: this.handleMenuMousedown,
                      show: this.mergedShow,
                      showCheckmark: this.internalShowCheckmark,
                      resetMenuOnOptionsChange: this.resetMenuOnOptionsChange
                    }, {
                      empty: () => [this.$slots.empty?.()],
                      action: () => [this.$slots.action?.()]
                    }),
                    this.displayDirective === "show" ? [
                      [vue.vShow, this.mergedShow],
                      [
                        clickoutside$1,
                        this.handleMenuClickOutside,
                        void 0,
                        { capture: true }
                      ]
                    ] : [
                      [
                        clickoutside$1,
                        this.handleMenuClickOutside,
                        void 0,
                        { capture: true }
                      ]
                    ]
                  );
                }
              })
            })
          ]
        }));
      }
    });

    var commonVariables$b = {
      itemPaddingSmall: "0 4px",
      itemMarginSmall: "0 0 0 8px",
      itemMarginSmallRtl: "0 8px 0 0",
      itemPaddingMedium: "0 4px",
      itemMarginMedium: "0 0 0 8px",
      itemMarginMediumRtl: "0 8px 0 0",
      itemPaddingLarge: "0 4px",
      itemMarginLarge: "0 0 0 8px",
      itemMarginLargeRtl: "0 8px 0 0",
      buttonIconSizeSmall: "14px",
      buttonIconSizeMedium: "16px",
      buttonIconSizeLarge: "18px",
      inputWidthSmall: "60px",
      selectWidthSmall: "unset",
      inputMarginSmall: "0 0 0 8px",
      inputMarginSmallRtl: "0 8px 0 0",
      selectMarginSmall: "0 0 0 8px",
      prefixMarginSmall: "0 8px 0 0",
      suffixMarginSmall: "0 0 0 8px",
      inputWidthMedium: "60px",
      selectWidthMedium: "unset",
      inputMarginMedium: "0 0 0 8px",
      inputMarginMediumRtl: "0 8px 0 0",
      selectMarginMedium: "0 0 0 8px",
      prefixMarginMedium: "0 8px 0 0",
      suffixMarginMedium: "0 0 0 8px",
      inputWidthLarge: "60px",
      selectWidthLarge: "unset",
      inputMarginLarge: "0 0 0 8px",
      inputMarginLargeRtl: "0 8px 0 0",
      selectMarginLarge: "0 0 0 8px",
      prefixMarginLarge: "0 8px 0 0",
      suffixMarginLarge: "0 0 0 8px"
    };

    const self$N = vars => {
      const {
        textColor2,
        primaryColor,
        primaryColorHover,
        primaryColorPressed,
        inputColorDisabled,
        textColorDisabled,
        borderColor,
        borderRadius,
        fontSizeTiny,
        fontSizeSmall,
        fontSizeMedium,
        heightTiny,
        heightSmall,
        heightMedium
      } = vars;
      return { ...commonVariables$b,
        buttonColor: "#0000",
        buttonColorHover: "#0000",
        buttonColorPressed: "#0000",
        buttonBorder: `1px solid ${borderColor}`,
        buttonBorderHover: `1px solid ${borderColor}`,
        buttonBorderPressed: `1px solid ${borderColor}`,
        buttonIconColor: textColor2,
        buttonIconColorHover: textColor2,
        buttonIconColorPressed: textColor2,
        itemTextColor: textColor2,
        itemTextColorHover: primaryColorHover,
        itemTextColorPressed: primaryColorPressed,
        itemTextColorActive: primaryColor,
        itemTextColorDisabled: textColorDisabled,
        itemColor: "#0000",
        itemColorHover: "#0000",
        itemColorPressed: "#0000",
        itemColorActive: "#0000",
        itemColorActiveHover: "#0000",
        itemColorDisabled: inputColorDisabled,
        itemBorder: "1px solid #0000",
        itemBorderHover: "1px solid #0000",
        itemBorderPressed: "1px solid #0000",
        itemBorderActive: `1px solid ${primaryColor}`,
        itemBorderDisabled: `1px solid ${borderColor}`,
        itemBorderRadius: borderRadius,
        itemSizeSmall: heightTiny,
        itemSizeMedium: heightSmall,
        itemSizeLarge: heightMedium,
        itemFontSizeSmall: fontSizeTiny,
        itemFontSizeMedium: fontSizeSmall,
        itemFontSizeLarge: fontSizeMedium,
        jumperFontSizeSmall: fontSizeTiny,
        jumperFontSizeMedium: fontSizeSmall,
        jumperFontSizeLarge: fontSizeMedium,
        jumperTextColor: textColor2,
        jumperTextColorDisabled: textColorDisabled
      };
    };
    const paginationLight = createTheme$1({
      name: "Pagination",
      common: commonLight,
      peers: {
        Select: selectLight$1,
        Input: inputLight$1,
        Popselect: popselectLight$1
      },
      self: self$N
    });
    var paginationLight$1 = paginationLight;

    const paginationDark = {
      name: "Pagination",
      common: commonDark,
      peers: {
        Select: selectDark$1,
        Input: inputDark$1,
        Popselect: popselectDark
      },

      self(vars) {
        const {
          primaryColor,
          opacity3
        } = vars;
        const borderColorActive = changeColor(primaryColor, {
          alpha: Number(opacity3)
        });
        const commonSelf = self$N(vars);
        commonSelf.itemBorderActive = `1px solid ${borderColorActive}`;
        commonSelf.itemBorderDisabled = "1px solid #0000";
        return commonSelf;
      }

    };
    var paginationDark$1 = paginationDark;

    var rtlStyle$g = cB("pagination", [cM("rtl", `
    direction: rtl;
  `, [c$1("> *:not(:first-child)", `
      margin: var(--n-item-margin-rtl);
    `), cB("pagination-quick-jumper", [cB("input", `
        margin: var(--n-input-margin-rtl);
      `)])])]);

    const paginationRtl = {
      name: "Pagination",
      style: rtlStyle$g,
      peers: [inputRtl]
    };

    function createPageItemsInfo(currentPage, pageCount, pageSlot) {
      let hasFastBackward = false;
      let hasFastForward = false;
      let fastBackwardTo = 1;
      let fastForwardTo = pageCount;

      if (pageCount === 1) {
        return {
          hasFastBackward: false,
          hasFastForward: false,
          fastForwardTo,
          fastBackwardTo,
          items: [{
            type: "page",
            label: 1,
            active: currentPage === 1,
            mayBeFastBackward: false,
            mayBeFastForward: false
          }]
        };
      }

      if (pageCount === 2) {
        return {
          hasFastBackward: false,
          hasFastForward: false,
          fastForwardTo,
          fastBackwardTo,
          items: [{
            type: "page",
            label: 1,
            active: currentPage === 1,
            mayBeFastBackward: false,
            mayBeFastForward: false
          }, {
            type: "page",
            label: 2,
            active: currentPage === 2,
            mayBeFastBackward: true,
            mayBeFastForward: false
          }]
        };
      }

      const firstPage = 1;
      const lastPage = pageCount;
      let middleStart = currentPage;
      let middleEnd = currentPage;
      const middleDelta = (pageSlot - 5) / 2;
      middleEnd += Math.ceil(middleDelta);
      middleEnd = Math.min(Math.max(middleEnd, firstPage + pageSlot - 3), lastPage - 2);
      middleStart -= Math.floor(middleDelta);
      middleStart = Math.max(Math.min(middleStart, lastPage - pageSlot + 3), firstPage + 2);
      let leftSplit = false;
      let rightSplit = false;
      if (middleStart > firstPage + 2) leftSplit = true;
      if (middleEnd < lastPage - 2) rightSplit = true;
      const items = [];
      items.push({
        type: "page",
        label: 1,
        active: currentPage === 1,
        mayBeFastBackward: false,
        mayBeFastForward: false
      });

      if (leftSplit) {
        hasFastBackward = true;
        fastBackwardTo = middleStart - 1;
        items.push({
          type: "fast-backward",
          active: false,
          label: void 0,
          options: createRange(firstPage + 1, middleStart - 1)
        });
      } else if (lastPage >= firstPage + 1) {
        items.push({
          type: "page",
          label: firstPage + 1,
          mayBeFastBackward: true,
          mayBeFastForward: false,
          active: currentPage === firstPage + 1
        });
      }

      for (let i = middleStart; i <= middleEnd; ++i) {
        items.push({
          type: "page",
          label: i,
          mayBeFastBackward: false,
          mayBeFastForward: false,
          active: currentPage === i
        });
      }

      if (rightSplit) {
        hasFastForward = true;
        fastForwardTo = middleEnd + 1;
        items.push({
          type: "fast-forward",
          active: false,
          label: void 0,
          options: createRange(middleEnd + 1, lastPage - 1)
        });
      } else if (middleEnd === lastPage - 2 && items[items.length - 1].label !== lastPage - 1) {
        items.push({
          type: "page",
          mayBeFastForward: true,
          mayBeFastBackward: false,
          label: lastPage - 1,
          active: currentPage === lastPage - 1
        });
      }

      if (items[items.length - 1].label !== lastPage) {
        items.push({
          type: "page",
          mayBeFastForward: false,
          mayBeFastBackward: false,
          label: lastPage,
          active: currentPage === lastPage
        });
      }

      return {
        hasFastBackward,
        hasFastForward,
        fastBackwardTo,
        fastForwardTo,
        items
      };
    }

    function createRange(from, to) {
      const range = [];

      for (let i = from; i <= to; ++i) {
        range.push({
          label: `${i}`,
          value: i
        });
      }

      return range;
    }

    const hoverStyleProps = `
  background: var(--n-item-color-hover);
  color: var(--n-item-text-color-hover);
  border: var(--n-item-border-hover);
`;
    const hoverStyleChildren$1 = [cM("button", `
    background: var(--n-button-color-hover);
    border: var(--n-button-border-hover);
    color: var(--n-button-icon-color-hover);
  `)];
    var style$Z = cB("pagination", `
  display: flex;
  vertical-align: middle;
  font-size: var(--n-item-font-size);
  flex-wrap: nowrap;
`, [cB("pagination-prefix", `
    display: flex;
    align-items: center;
    margin: var(--n-prefix-margin);
  `), cB("pagination-suffix", `
    display: flex;
    align-items: center;
    margin: var(--n-suffix-margin);
  `), c$1("> *:not(:first-child)", `
    margin: var(--n-item-margin);
  `), cB("select", `
    width: var(--n-select-width);
  `), c$1("&.transition-disabled", [cB("pagination-item", "transition: none!important;")]), cB("pagination-quick-jumper", `
    white-space: nowrap;
    display: flex;
    color: var(--n-jumper-text-color);
    transition: color .3s var(--n-bezier);
    align-items: center;
    font-size: var(--n-jumper-font-size);
  `, [cB("input", `
      margin: var(--n-input-margin);
      width: var(--n-input-width);
    `)]), cB("pagination-item", `
    position: relative;
    cursor: pointer;
    user-select: none;
    -webkit-user-select: none;
    display: flex;
    align-items: center;
    justify-content: center;
    box-sizing: border-box;
    min-width: var(--n-item-size);
    height: var(--n-item-size);
    padding: var(--n-item-padding);
    background-color: var(--n-item-color);
    color: var(--n-item-text-color);
    border-radius: var(--n-item-border-radius);
    border: var(--n-item-border);
    fill: var(--n-button-icon-color);
    transition:
      color .3s var(--n-bezier),
      border-color .3s var(--n-bezier),
      background-color .3s var(--n-bezier),
      fill .3s var(--n-bezier);
  `, [cM("button", `
      background: var(--n-button-color);
      color: var(--n-button-icon-color);
      border: var(--n-button-border);
      padding: 0;
    `, [cB("base-icon", `
        font-size: var(--n-button-icon-size);
      `)]), cNotM("disabled", [cM("hover", hoverStyleProps, hoverStyleChildren$1), c$1("&:hover", hoverStyleProps, hoverStyleChildren$1), c$1("&:active", `
        background: var(--n-item-color-pressed);
        color: var(--n-item-text-color-pressed);
        border: var(--n-item-border-pressed);
      `, [cM("button", `
          background: var(--n-button-color-pressed);
          border: var(--n-button-border-pressed);
          color: var(--n-button-icon-color-pressed);
        `)]), cM("active", `
        background: var(--n-item-color-active);
        color: var(--n-item-text-color-active);
        border: var(--n-item-border-active);
      `, [c$1("&:hover", `
          background: var(--n-item-color-active-hover);
        `)])]), cM("disabled", `
      cursor: not-allowed;
      color: var(--n-item-text-color-disabled);
    `, [cM("active, button", `
        background-color: var(--n-item-color-disabled);
        border: var(--n-item-border-disabled);
      `)])]), cM("disabled", `
    cursor: not-allowed;
  `, [cB("pagination-quick-jumper", `
      color: var(--n-jumper-text-color-disabled);
    `)]), cM("simple", `
    display: flex;
    align-items: center;
    flex-wrap: nowrap;
  `, [cB("pagination-quick-jumper", [cB("input", `
        margin: 0;
      `)])])]);

    const paginationProps = {
      ...useTheme.props,
      simple: Boolean,
      page: Number,
      defaultPage: {
        type: Number,
        default: 1
      },
      itemCount: Number,
      pageCount: Number,
      defaultPageCount: {
        type: Number,
        default: 1
      },
      showSizePicker: Boolean,
      pageSize: Number,
      defaultPageSize: Number,
      pageSizes: {
        type: Array,
        default() {
          return [10];
        }
      },
      showQuickJumper: Boolean,
      size: {
        type: String,
        default: "medium"
      },
      disabled: Boolean,
      pageSlot: {
        type: Number,
        default: 9
      },
      prev: Function,
      next: Function,
      prefix: Function,
      suffix: Function,
      label: Function,
      displayOrder: {
        type: Array,
        default: ["pages", "size-picker", "quick-jumper"]
      },
      "onUpdate:page": [Function, Array],
      onUpdatePage: [Function, Array],
      "onUpdate:pageSize": [Function, Array],
      onUpdatePageSize: [Function, Array],
      onPageSizeChange: [Function, Array],
      onChange: [Function, Array]
    };
    var NPagination = vue.defineComponent({
      name: "Pagination",
      props: paginationProps,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.pageCount !== void 0 && props.itemCount !== void 0) {
              warn$2(
                "pagination",
                "`page-count` and `item-count` should't be specified together. Only `item-count` will take effect."
              );
            }
            if (props.onPageSizeChange) {
              warnOnce(
                "pagination",
                "`on-page-size-change` is deprecated, please use `on-update:page-size` instead."
              );
            }
            if (props.onChange) {
              warnOnce(
                "pagination",
                "`on-change` is deprecated, please use `on-update:page` instead."
              );
            }
          });
        }
        const {
          mergedComponentPropsRef,
          mergedClsPrefixRef,
          inlineThemeDisabled,
          mergedRtlRef
        } = useConfig(props);
        const themeRef = useTheme(
          "Pagination",
          "-pagination",
          style$Z,
          paginationLight$1,
          props,
          mergedClsPrefixRef
        );
        const { localeRef } = useLocale("Pagination");
        const selfRef = vue.ref(null);
        const uncontrolledPageRef = vue.ref(props.defaultPage);
        const getDefaultPageSize = () => {
          const { defaultPageSize } = props;
          if (defaultPageSize !== void 0)
            return defaultPageSize;
          const pageSizeOption = props.pageSizes[0];
          if (typeof pageSizeOption === "number")
            return pageSizeOption;
          return pageSizeOption.value || 10;
        };
        const uncontrolledPageSizeRef = vue.ref(getDefaultPageSize());
        const mergedPageRef = useMergedState(
          vue.toRef(props, "page"),
          uncontrolledPageRef
        );
        const mergedPageSizeRef = useMergedState(
          vue.toRef(props, "pageSize"),
          uncontrolledPageSizeRef
        );
        const mergedPageCountRef = vue.computed(() => {
          const { itemCount } = props;
          if (itemCount !== void 0) {
            return Math.max(1, Math.ceil(itemCount / mergedPageSizeRef.value));
          }
          const { pageCount } = props;
          if (pageCount !== void 0)
            return Math.max(pageCount, 1);
          return 1;
        });
        const jumperValueRef = vue.ref("");
        vue.watchEffect(() => {
          void props.simple;
          jumperValueRef.value = String(mergedPageRef.value);
        });
        const fastForwardActiveRef = vue.ref(false);
        const fastBackwardActiveRef = vue.ref(false);
        const showFastForwardMenuRef = vue.ref(false);
        const showFastBackwardMenuRef = vue.ref(false);
        const handleFastForwardMouseenter = () => {
          if (props.disabled)
            return;
          fastForwardActiveRef.value = true;
          disableTransitionOneTick();
        };
        const handleFastForwardMouseleave = () => {
          if (props.disabled)
            return;
          fastForwardActiveRef.value = false;
          disableTransitionOneTick();
        };
        const handleFastBackwardMouseenter = () => {
          fastBackwardActiveRef.value = true;
          disableTransitionOneTick();
        };
        const handleFastBackwardMouseleave = () => {
          fastBackwardActiveRef.value = false;
          disableTransitionOneTick();
        };
        const handleMenuSelect = (value) => {
          doUpdatePage(value);
        };
        const pageItemsInfo = vue.computed(
          () => createPageItemsInfo(
            mergedPageRef.value,
            mergedPageCountRef.value,
            props.pageSlot
          )
        );
        vue.watchEffect(() => {
          if (!pageItemsInfo.value.hasFastBackward) {
            fastBackwardActiveRef.value = false;
            showFastBackwardMenuRef.value = false;
          } else if (!pageItemsInfo.value.hasFastForward) {
            fastForwardActiveRef.value = false;
            showFastForwardMenuRef.value = false;
          }
        });
        const pageSizeOptionsRef = vue.computed(() => {
          const suffix = localeRef.value.selectionSuffix;
          return props.pageSizes.map((size) => {
            if (typeof size === "number") {
              return {
                label: `${size} / ${suffix}`,
                value: size
              };
            } else {
              return size;
            }
          });
        });
        const inputSizeRef = vue.computed(() => {
          return mergedComponentPropsRef?.value?.Pagination?.inputSize || smallerSize(props.size);
        });
        const selectSizeRef = vue.computed(() => {
          return mergedComponentPropsRef?.value?.Pagination?.selectSize || smallerSize(props.size);
        });
        const startIndexRef = vue.computed(() => {
          return (mergedPageRef.value - 1) * mergedPageSizeRef.value;
        });
        const endIndexRef = vue.computed(() => {
          const endIndex = mergedPageRef.value * mergedPageSizeRef.value - 1;
          const { itemCount } = props;
          if (itemCount !== void 0) {
            return endIndex > itemCount ? itemCount : endIndex;
          }
          return endIndex;
        });
        const mergedItemCountRef = vue.computed(() => {
          const { itemCount } = props;
          if (itemCount !== void 0)
            return itemCount;
          return (props.pageCount || 1) * mergedPageSizeRef.value;
        });
        const rtlEnabledRef = useRtl("Pagination", mergedRtlRef, mergedClsPrefixRef);
        const disableTransitionOneTick = () => {
          void vue.nextTick(() => {
            const { value: selfEl } = selfRef;
            if (!selfEl)
              return;
            selfEl.classList.add("transition-disabled");
            void selfRef.value?.offsetWidth;
            selfEl.classList.remove("transition-disabled");
          });
        };
        function doUpdatePage(page) {
          if (page === mergedPageRef.value)
            return;
          const {
            "onUpdate:page": _onUpdatePage,
            onUpdatePage,
            onChange,
            simple
          } = props;
          if (_onUpdatePage)
            call(_onUpdatePage, page);
          if (onUpdatePage)
            call(onUpdatePage, page);
          if (onChange)
            call(onChange, page);
          uncontrolledPageRef.value = page;
          if (simple) {
            jumperValueRef.value = String(page);
          }
        }
        function doUpdatePageSize(pageSize) {
          if (pageSize === mergedPageSizeRef.value)
            return;
          const {
            "onUpdate:pageSize": _onUpdatePageSize,
            onUpdatePageSize,
            onPageSizeChange
          } = props;
          if (_onUpdatePageSize)
            call(_onUpdatePageSize, pageSize);
          if (onUpdatePageSize)
            call(onUpdatePageSize, pageSize);
          if (onPageSizeChange)
            call(onPageSizeChange, pageSize);
          uncontrolledPageSizeRef.value = pageSize;
          if (mergedPageCountRef.value < mergedPageRef.value) {
            doUpdatePage(mergedPageCountRef.value);
          }
        }
        function forward() {
          if (props.disabled)
            return;
          const page = Math.min(mergedPageRef.value + 1, mergedPageCountRef.value);
          doUpdatePage(page);
        }
        function backward() {
          if (props.disabled)
            return;
          const page = Math.max(mergedPageRef.value - 1, 1);
          doUpdatePage(page);
        }
        function fastForward() {
          if (props.disabled)
            return;
          const page = Math.min(
            pageItemsInfo.value.fastForwardTo,
            mergedPageCountRef.value
          );
          doUpdatePage(page);
        }
        function fastBackward() {
          if (props.disabled)
            return;
          const page = Math.max(pageItemsInfo.value.fastBackwardTo, 1);
          doUpdatePage(page);
        }
        function handleSizePickerChange(value) {
          doUpdatePageSize(value);
        }
        function doQuickJump() {
          const page = parseInt(jumperValueRef.value);
          if (Number.isNaN(page))
            return;
          doUpdatePage(Math.max(1, Math.min(page, mergedPageCountRef.value)));
          if (!props.simple) {
            jumperValueRef.value = "";
          }
        }
        function handleQuickJumperChange() {
          doQuickJump();
        }
        function handlePageItemClick(pageItem) {
          if (props.disabled)
            return;
          switch (pageItem.type) {
            case "page":
              doUpdatePage(pageItem.label);
              break;
            case "fast-backward":
              fastBackward();
              break;
            case "fast-forward":
              fastForward();
              break;
          }
        }
        function handleJumperInput(value) {
          jumperValueRef.value = value.replace(/\D+/g, "");
        }
        vue.watchEffect(() => {
          void mergedPageRef.value;
          void mergedPageSizeRef.value;
          disableTransitionOneTick();
        });
        const cssVarsRef = vue.computed(() => {
          const { size } = props;
          const {
            self: {
              buttonBorder,
              buttonBorderHover,
              buttonBorderPressed,
              buttonIconColor,
              buttonIconColorHover,
              buttonIconColorPressed,
              itemTextColor,
              itemTextColorHover,
              itemTextColorPressed,
              itemTextColorActive,
              itemTextColorDisabled,
              itemColor,
              itemColorHover,
              itemColorPressed,
              itemColorActive,
              itemColorActiveHover,
              itemColorDisabled,
              itemBorder,
              itemBorderHover,
              itemBorderPressed,
              itemBorderActive,
              itemBorderDisabled,
              itemBorderRadius,
              jumperTextColor,
              jumperTextColorDisabled,
              buttonColor,
              buttonColorHover,
              buttonColorPressed,
              [createKey("itemPadding", size)]: itemPadding,
              [createKey("itemMargin", size)]: itemMargin,
              [createKey("inputWidth", size)]: inputWidth,
              [createKey("selectWidth", size)]: selectWidth,
              [createKey("inputMargin", size)]: inputMargin,
              [createKey("selectMargin", size)]: selectMargin,
              [createKey("jumperFontSize", size)]: jumperFontSize,
              [createKey("prefixMargin", size)]: prefixMargin,
              [createKey("suffixMargin", size)]: suffixMargin,
              [createKey("itemSize", size)]: itemSize,
              [createKey("buttonIconSize", size)]: buttonIconSize,
              [createKey("itemFontSize", size)]: itemFontSize,
              [`${createKey("itemMargin", size)}Rtl`]: itemMarginRtl,
              [`${createKey("inputMargin", size)}Rtl`]: inputMarginRtl
            },
            common: { cubicBezierEaseInOut }
          } = themeRef.value;
          return {
            "--n-prefix-margin": prefixMargin,
            "--n-suffix-margin": suffixMargin,
            "--n-item-font-size": itemFontSize,
            "--n-select-width": selectWidth,
            "--n-select-margin": selectMargin,
            "--n-input-width": inputWidth,
            "--n-input-margin": inputMargin,
            "--n-input-margin-rtl": inputMarginRtl,
            "--n-item-size": itemSize,
            "--n-item-text-color": itemTextColor,
            "--n-item-text-color-disabled": itemTextColorDisabled,
            "--n-item-text-color-hover": itemTextColorHover,
            "--n-item-text-color-active": itemTextColorActive,
            "--n-item-text-color-pressed": itemTextColorPressed,
            "--n-item-color": itemColor,
            "--n-item-color-hover": itemColorHover,
            "--n-item-color-disabled": itemColorDisabled,
            "--n-item-color-active": itemColorActive,
            "--n-item-color-active-hover": itemColorActiveHover,
            "--n-item-color-pressed": itemColorPressed,
            "--n-item-border": itemBorder,
            "--n-item-border-hover": itemBorderHover,
            "--n-item-border-disabled": itemBorderDisabled,
            "--n-item-border-active": itemBorderActive,
            "--n-item-border-pressed": itemBorderPressed,
            "--n-item-padding": itemPadding,
            "--n-item-border-radius": itemBorderRadius,
            "--n-bezier": cubicBezierEaseInOut,
            "--n-jumper-font-size": jumperFontSize,
            "--n-jumper-text-color": jumperTextColor,
            "--n-jumper-text-color-disabled": jumperTextColorDisabled,
            "--n-item-margin": itemMargin,
            "--n-item-margin-rtl": itemMarginRtl,
            "--n-button-icon-size": buttonIconSize,
            "--n-button-icon-color": buttonIconColor,
            "--n-button-icon-color-hover": buttonIconColorHover,
            "--n-button-icon-color-pressed": buttonIconColorPressed,
            "--n-button-color-hover": buttonColorHover,
            "--n-button-color": buttonColor,
            "--n-button-color-pressed": buttonColorPressed,
            "--n-button-border": buttonBorder,
            "--n-button-border-hover": buttonBorderHover,
            "--n-button-border-pressed": buttonBorderPressed
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "pagination",
          vue.computed(() => {
            let hash = "";
            const { size } = props;
            hash += size[0];
            return hash;
          }),
          cssVarsRef,
          props
        ) : void 0;
        return {
          rtlEnabled: rtlEnabledRef,
          mergedClsPrefix: mergedClsPrefixRef,
          locale: localeRef,
          selfRef,
          mergedPage: mergedPageRef,
          pageItems: vue.computed(() => {
            return pageItemsInfo.value.items;
          }),
          mergedItemCount: mergedItemCountRef,
          jumperValue: jumperValueRef,
          pageSizeOptions: pageSizeOptionsRef,
          mergedPageSize: mergedPageSizeRef,
          inputSize: inputSizeRef,
          selectSize: selectSizeRef,
          mergedTheme: themeRef,
          mergedPageCount: mergedPageCountRef,
          startIndex: startIndexRef,
          endIndex: endIndexRef,
          showFastForwardMenu: showFastForwardMenuRef,
          showFastBackwardMenu: showFastBackwardMenuRef,
          fastForwardActive: fastForwardActiveRef,
          fastBackwardActive: fastBackwardActiveRef,
          handleMenuSelect,
          handleFastForwardMouseenter,
          handleFastForwardMouseleave,
          handleFastBackwardMouseenter,
          handleFastBackwardMouseleave,
          handleJumperInput,
          handleBackwardClick: backward,
          handleForwardClick: forward,
          handlePageItemClick,
          handleSizePickerChange,
          handleQuickJumperChange,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const {
          $slots,
          mergedClsPrefix,
          disabled,
          cssVars,
          mergedPage,
          mergedPageCount,
          pageItems,
          showSizePicker,
          showQuickJumper,
          mergedTheme,
          locale,
          inputSize,
          selectSize,
          mergedPageSize,
          pageSizeOptions,
          jumperValue,
          simple,
          prev,
          next,
          prefix,
          suffix,
          label,
          handleJumperInput,
          handleSizePickerChange,
          handleBackwardClick,
          handlePageItemClick,
          handleForwardClick,
          handleQuickJumperChange,
          onRender
        } = this;
        onRender?.();
        const renderPrefix = $slots.prefix || prefix;
        const renderSuffix = $slots.suffix || suffix;
        const renderPrev = prev || $slots.prev;
        const renderNext = next || $slots.next;
        const renderLabel = label || $slots.label;
        return /* @__PURE__ */ React.createElement("div", {
          ref: "selfRef",
          class: [
            `${mergedClsPrefix}-pagination`,
            this.themeClass,
            this.rtlEnabled && `${mergedClsPrefix}-pagination--rtl`,
            disabled && `${mergedClsPrefix}-pagination--disabled`,
            simple && `${mergedClsPrefix}-pagination--simple`
          ],
          style: cssVars
        }, renderPrefix ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-pagination-prefix`
        }, renderPrefix({
          page: mergedPage,
          pageSize: mergedPageSize,
          pageCount: mergedPageCount,
          startIndex: this.startIndex,
          endIndex: this.endIndex,
          itemCount: this.mergedItemCount
        })) : null, this.displayOrder.map((part) => {
          switch (part) {
            case "pages":
              return /* @__PURE__ */ React.createElement(vue.Fragment, null, /* @__PURE__ */ React.createElement("div", {
                class: [
                  `${mergedClsPrefix}-pagination-item`,
                  !renderPrev && `${mergedClsPrefix}-pagination-item--button`,
                  (mergedPage <= 1 || mergedPage > mergedPageCount || disabled) && `${mergedClsPrefix}-pagination-item--disabled`
                ],
                onClick: handleBackwardClick
              }, renderPrev ? renderPrev({
                page: mergedPage,
                pageSize: mergedPageSize,
                pageCount: mergedPageCount,
                startIndex: this.startIndex,
                endIndex: this.endIndex,
                itemCount: this.mergedItemCount
              }) : /* @__PURE__ */ React.createElement(NBaseIcon, {
                clsPrefix: mergedClsPrefix
              }, {
                default: () => this.rtlEnabled ? /* @__PURE__ */ React.createElement(ForwardIcon, null) : /* @__PURE__ */ React.createElement(BackwardIcon, null)
              })), simple ? /* @__PURE__ */ React.createElement(vue.Fragment, null, /* @__PURE__ */ React.createElement("div", {
                class: `${mergedClsPrefix}-pagination-quick-jumper`
              }, /* @__PURE__ */ React.createElement(NInput, {
                value: jumperValue,
                onUpdateValue: handleJumperInput,
                size: inputSize,
                placeholder: "",
                disabled,
                theme: mergedTheme.peers.Input,
                themeOverrides: mergedTheme.peerOverrides.Input,
                onChange: handleQuickJumperChange
              })), "\xA0/ ", mergedPageCount) : pageItems.map((pageItem, index) => {
                let contentNode;
                let onMouseenter;
                let onMouseleave;
                const { type } = pageItem;
                switch (type) {
                  case "page":
                    const pageNode = pageItem.label;
                    if (renderLabel) {
                      contentNode = renderLabel({
                        type: "page",
                        node: pageNode,
                        active: pageItem.active
                      });
                    } else {
                      contentNode = pageNode;
                    }
                    break;
                  case "fast-forward":
                    const fastForwardNode = this.fastForwardActive ? /* @__PURE__ */ React.createElement(NBaseIcon, {
                      clsPrefix: mergedClsPrefix
                    }, {
                      default: () => this.rtlEnabled ? /* @__PURE__ */ React.createElement(FastBackwardIcon, null) : /* @__PURE__ */ React.createElement(FastForwardIcon, null)
                    }) : /* @__PURE__ */ React.createElement(NBaseIcon, {
                      clsPrefix: mergedClsPrefix
                    }, { default: () => /* @__PURE__ */ React.createElement(MoreIcon, null) });
                    if (renderLabel) {
                      contentNode = renderLabel({
                        type: "fast-forward",
                        node: fastForwardNode,
                        active: this.fastForwardActive || this.showFastForwardMenu
                      });
                    } else {
                      contentNode = fastForwardNode;
                    }
                    onMouseenter = this.handleFastForwardMouseenter;
                    onMouseleave = this.handleFastForwardMouseleave;
                    break;
                  case "fast-backward":
                    const fastBackwardNode = this.fastBackwardActive ? /* @__PURE__ */ React.createElement(NBaseIcon, {
                      clsPrefix: mergedClsPrefix
                    }, {
                      default: () => this.rtlEnabled ? /* @__PURE__ */ React.createElement(FastForwardIcon, null) : /* @__PURE__ */ React.createElement(FastBackwardIcon, null)
                    }) : /* @__PURE__ */ React.createElement(NBaseIcon, {
                      clsPrefix: mergedClsPrefix
                    }, { default: () => /* @__PURE__ */ React.createElement(MoreIcon, null) });
                    if (renderLabel) {
                      contentNode = renderLabel({
                        type: "fast-backward",
                        node: fastBackwardNode,
                        active: this.fastBackwardActive || this.showFastBackwardMenu
                      });
                    } else {
                      contentNode = fastBackwardNode;
                    }
                    onMouseenter = this.handleFastBackwardMouseenter;
                    onMouseleave = this.handleFastBackwardMouseleave;
                    break;
                }
                const itemNode = /* @__PURE__ */ React.createElement("div", {
                  key: index,
                  class: [
                    `${mergedClsPrefix}-pagination-item`,
                    pageItem.active && `${mergedClsPrefix}-pagination-item--active`,
                    type !== "page" && (type === "fast-backward" && this.showFastBackwardMenu || type === "fast-forward" && this.showFastForwardMenu) && `${mergedClsPrefix}-pagination-item--hover`,
                    disabled && `${mergedClsPrefix}-pagination-item--disabled`,
                    type === "page" && `${mergedClsPrefix}-pagination-item--clickable`
                  ],
                  onClick: () => handlePageItemClick(pageItem),
                  onMouseenter,
                  onMouseleave
                }, contentNode);
                if (type === "page" && !pageItem.mayBeFastBackward && !pageItem.mayBeFastForward) {
                  return itemNode;
                } else {
                  const key = pageItem.type === "page" ? pageItem.mayBeFastBackward ? "fast-backward" : "fast-forward" : pageItem.type;
                  return /* @__PURE__ */ React.createElement(NPopselect, {
                    key,
                    disabled,
                    trigger: "hover",
                    virtualScroll: true,
                    style: { width: "60px" },
                    theme: mergedTheme.peers.Popselect,
                    themeOverrides: mergedTheme.peerOverrides.Popselect,
                    builtinThemeOverrides: {
                      peers: {
                        InternalSelectMenu: {
                          height: "calc(var(--n-option-height) * 4.6)"
                        }
                      }
                    },
                    nodeProps: () => ({
                      style: {
                        justifyContent: "center"
                      }
                    }),
                    show: type === "page" ? false : type === "fast-backward" ? this.showFastBackwardMenu : this.showFastForwardMenu,
                    onUpdateShow: (value) => {
                      if (type === "page")
                        return;
                      if (value) {
                        if (type === "fast-backward") {
                          this.showFastBackwardMenu = value;
                        } else {
                          this.showFastForwardMenu = value;
                        }
                      } else {
                        this.showFastBackwardMenu = false;
                        this.showFastForwardMenu = false;
                      }
                    },
                    options: pageItem.type !== "page" ? pageItem.options : [],
                    onUpdateValue: this.handleMenuSelect,
                    scrollable: true,
                    internalShowCheckmark: false
                  }, { default: () => itemNode });
                }
              }), /* @__PURE__ */ React.createElement("div", {
                class: [
                  `${mergedClsPrefix}-pagination-item`,
                  !renderNext && `${mergedClsPrefix}-pagination-item--button`,
                  {
                    [`${mergedClsPrefix}-pagination-item--disabled`]: mergedPage < 1 || mergedPage >= mergedPageCount || disabled
                  }
                ],
                onClick: handleForwardClick
              }, renderNext ? renderNext({
                page: mergedPage,
                pageSize: mergedPageSize,
                pageCount: mergedPageCount,
                itemCount: this.mergedItemCount,
                startIndex: this.startIndex,
                endIndex: this.endIndex
              }) : /* @__PURE__ */ React.createElement(NBaseIcon, {
                clsPrefix: mergedClsPrefix
              }, {
                default: () => this.rtlEnabled ? /* @__PURE__ */ React.createElement(BackwardIcon, null) : /* @__PURE__ */ React.createElement(ForwardIcon, null)
              })));
            case "size-picker": {
              return !simple && showSizePicker ? /* @__PURE__ */ React.createElement(NSelect, {
                internalShowCheckmark: false,
                size: selectSize,
                placeholder: "",
                options: pageSizeOptions,
                value: mergedPageSize,
                disabled,
                theme: mergedTheme.peers.Select,
                themeOverrides: mergedTheme.peerOverrides.Select,
                onUpdateValue: handleSizePickerChange
              }) : null;
            }
            case "quick-jumper":
              return !simple && showQuickJumper ? /* @__PURE__ */ React.createElement("div", {
                class: `${mergedClsPrefix}-pagination-quick-jumper`
              }, resolveSlot(this.$slots.goto, () => [locale.goto]), /* @__PURE__ */ React.createElement(NInput, {
                value: jumperValue,
                onUpdateValue: handleJumperInput,
                size: inputSize,
                placeholder: "",
                disabled,
                theme: mergedTheme.peers.Input,
                themeOverrides: mergedTheme.peerOverrides.Input,
                onChange: handleQuickJumperChange
              })) : null;
            default:
              return null;
          }
        }), renderSuffix ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-pagination-suffix`
        }, renderSuffix({
          page: mergedPage,
          pageSize: mergedPageSize,
          pageCount: mergedPageCount,
          startIndex: this.startIndex,
          endIndex: this.endIndex,
          itemCount: this.mergedItemCount
        })) : null);
      }
    });

    var commonVars$8 = {
      padding: "8px 14px"
    };

    const tooltipDark = {
      name: "Tooltip",
      common: commonDark,
      peers: {
        Popover: popoverDark$1
      },

      self(vars) {
        const {
          borderRadius,
          boxShadow2,
          popoverColor,
          textColor2
        } = vars;
        return { ...commonVars$8,
          borderRadius,
          boxShadow: boxShadow2,
          color: popoverColor,
          textColor: textColor2
        };
      }

    };
    var tooltipDark$1 = tooltipDark;

    const self$M = vars => {
      const {
        borderRadius,
        boxShadow2,
        baseColor
      } = vars;
      return { ...commonVars$8,
        borderRadius,
        boxShadow: boxShadow2,
        color: composite(baseColor, "rgba(0, 0, 0, .85)"),
        textColor: baseColor
      };
    };

    const tooltipLight = createTheme$1({
      name: "Tooltip",
      common: commonLight,
      peers: {
        Popover: popoverLight$1
      },
      self: self$M
    });
    var tooltipLight$1 = tooltipLight;

    const ellipsisDark = {
      name: "Ellipsis",
      common: commonDark,
      peers: {
        Tooltip: tooltipDark$1
      }
    };
    var ellipsisDark$1 = ellipsisDark;

    const ellipsisLight = createTheme$1({
      name: "Ellipsis",
      common: commonLight,
      peers: {
        Tooltip: tooltipLight$1
      }
    });
    var ellipsisLight$1 = ellipsisLight;

    var commonVariables$a = {
      radioSizeSmall: "14px",
      radioSizeMedium: "16px",
      radioSizeLarge: "18px",
      labelPadding: "0 8px"
    };

    const radioDark = {
      name: "Radio",
      common: commonDark,

      self(vars) {
        const {
          borderColor,
          primaryColor,
          baseColor,
          textColorDisabled,
          inputColorDisabled,
          textColor2,
          opacityDisabled,
          borderRadius,
          fontSizeSmall,
          fontSizeMedium,
          fontSizeLarge,
          heightSmall,
          heightMedium,
          heightLarge,
          lineHeight
        } = vars;
        return { ...commonVariables$a,
          labelLineHeight: lineHeight,
          buttonHeightSmall: heightSmall,
          buttonHeightMedium: heightMedium,
          buttonHeightLarge: heightLarge,
          fontSizeSmall,
          fontSizeMedium,
          fontSizeLarge,
          boxShadow: `inset 0 0 0 1px ${borderColor}`,
          boxShadowActive: `inset 0 0 0 1px ${primaryColor}`,
          boxShadowFocus: `inset 0 0 0 1px ${primaryColor}, 0 0 0 2px ${changeColor(primaryColor, {
        alpha: 0.3
      })}`,
          boxShadowHover: `inset 0 0 0 1px ${primaryColor}`,
          boxShadowDisabled: `inset 0 0 0 1px ${borderColor}`,
          color: "#0000",
          colorDisabled: inputColorDisabled,
          textColor: textColor2,
          textColorDisabled,
          dotColorActive: primaryColor,
          dotColorDisabled: borderColor,
          buttonBorderColor: borderColor,
          buttonBorderColorActive: primaryColor,
          buttonBorderColorHover: primaryColor,
          buttonColor: "#0000",
          buttonColorActive: primaryColor,
          buttonTextColor: textColor2,
          buttonTextColorActive: baseColor,
          buttonTextColorHover: primaryColor,
          opacityDisabled,
          buttonBoxShadowFocus: `inset 0 0 0 1px ${primaryColor}, 0 0 0 2px ${changeColor(primaryColor, {
        alpha: 0.3
      })}`,
          buttonBoxShadowHover: `inset 0 0 0 1px ${primaryColor}`,
          buttonBoxShadow: "inset 0 0 0 1px #0000",
          buttonBorderRadius: borderRadius
        };
      }

    };
    var radioDark$1 = radioDark;

    const self$L = vars => {
      const {
        borderColor,
        primaryColor,
        baseColor,
        textColorDisabled,
        inputColorDisabled,
        textColor2,
        opacityDisabled,
        borderRadius,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge,
        heightSmall,
        heightMedium,
        heightLarge,
        lineHeight
      } = vars;
      return { ...commonVariables$a,
        labelLineHeight: lineHeight,
        buttonHeightSmall: heightSmall,
        buttonHeightMedium: heightMedium,
        buttonHeightLarge: heightLarge,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge,
        boxShadow: `inset 0 0 0 1px ${borderColor}`,
        boxShadowActive: `inset 0 0 0 1px ${primaryColor}`,
        boxShadowFocus: `inset 0 0 0 1px ${primaryColor}, 0 0 0 2px ${changeColor(primaryColor, {
      alpha: 0.2
    })}`,
        boxShadowHover: `inset 0 0 0 1px ${primaryColor}`,
        boxShadowDisabled: `inset 0 0 0 1px ${borderColor}`,
        color: baseColor,
        colorDisabled: inputColorDisabled,
        textColor: textColor2,
        textColorDisabled,
        dotColorActive: primaryColor,
        dotColorDisabled: borderColor,
        buttonBorderColor: borderColor,
        buttonBorderColorActive: primaryColor,
        buttonBorderColorHover: borderColor,
        buttonColor: baseColor,
        buttonColorActive: baseColor,
        buttonTextColor: textColor2,
        buttonTextColorActive: primaryColor,
        buttonTextColorHover: primaryColor,
        opacityDisabled,
        buttonBoxShadowFocus: `inset 0 0 0 1px ${primaryColor}, 0 0 0 2px ${changeColor(primaryColor, {
      alpha: 0.3
    })}`,
        buttonBoxShadowHover: "inset 0 0 0 1px #0000",
        buttonBoxShadow: "inset 0 0 0 1px #0000",
        buttonBorderRadius: borderRadius
      };
    };

    const radioLight = {
      name: "Radio",
      common: commonLight,
      self: self$L
    };
    var radioLight$1 = radioLight;

    var rtlStyle$f = c$1([cB("radio", [cM("rtl", `
      direction: rtl;
    `)]), cB("radio-group", [cM("rtl", `
      direction: rtl;
    `, [cB("radio-button", [c$1("&:first-child", `
          border-radius: 0 var(--n-button-border-radius) var(--n-button-border-radius) 0;
          border-right: 1px solid var(--n-button-border-color);
          border-left: 0;
        `, [cE("state-border", `
            border-radius: 0 var(--n-button-border-radius) var(--n-button-border-radius) 0;
          `)]), c$1("&:last-child", `
          border-radius: var(--n-button-border-radius) 0 0 var(--n-button-border-radius);
          border-left: 1px solid var(--n-button-border-color);
          border-right: 0;
        `, [cE("state-border", `
            border-radius: var(--n-button-border-radius) 0 0 var(--n-button-border-radius);
          `)]), cM("checked", `
          border-color: var(--n-button-border-color-active);
        `)])])])]);

    const radioRtl = {
      name: "Radio",
      style: rtlStyle$f
    };

    var commonVariables$9 = {
      thPaddingSmall: "8px",
      thPaddingMedium: "12px",
      thPaddingLarge: "12px",
      tdPaddingSmall: "8px",
      tdPaddingMedium: "12px",
      tdPaddingLarge: "12px",
      sorterSize: "15px",
      filterSize: "15px",
      paginationMargin: "12px 0 0 0",
      emptyPadding: "48px 0",
      actionPadding: "8px 12px",
      actionButtonMargin: "0 8px 0 0"
    };

    const self$K = vars => {
      const {
        cardColor,
        modalColor,
        popoverColor,
        textColor2,
        textColor1,
        tableHeaderColor,
        tableColorHover,
        iconColor,
        primaryColor,
        fontWeightStrong,
        borderRadius,
        lineHeight,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge,
        dividerColor,
        heightSmall,
        opacityDisabled,
        tableColorStriped
      } = vars;
      return { ...commonVariables$9,
        actionDividerColor: dividerColor,
        lineHeight,
        borderRadius,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge,
        borderColor: composite(cardColor, dividerColor),
        tdColorHover: composite(cardColor, tableColorHover),
        tdColorStriped: composite(cardColor, tableColorStriped),
        thColor: composite(cardColor, tableHeaderColor),
        thColorHover: composite(composite(cardColor, tableHeaderColor), tableColorHover),
        tdColor: cardColor,
        tdTextColor: textColor2,
        thTextColor: textColor1,
        thFontWeight: fontWeightStrong,
        thButtonColorHover: tableColorHover,
        thIconColor: iconColor,
        thIconColorActive: primaryColor,
        borderColorModal: composite(modalColor, dividerColor),
        tdColorHoverModal: composite(modalColor, tableColorHover),
        tdColorStripedModal: composite(modalColor, tableColorStriped),
        thColorModal: composite(modalColor, tableHeaderColor),
        thColorHoverModal: composite(composite(modalColor, tableHeaderColor), tableColorHover),
        tdColorModal: modalColor,
        borderColorPopover: composite(popoverColor, dividerColor),
        tdColorHoverPopover: composite(popoverColor, tableColorHover),
        tdColorStripedPopover: composite(popoverColor, tableColorStriped),
        thColorPopover: composite(popoverColor, tableHeaderColor),
        thColorHoverPopover: composite(composite(popoverColor, tableHeaderColor), tableColorHover),
        tdColorPopover: popoverColor,
        boxShadowBefore: "inset -12px 0 8px -12px rgba(0, 0, 0, .18)",
        boxShadowAfter: "inset 12px 0 8px -12px rgba(0, 0, 0, .18)",
        loadingColor: primaryColor,
        loadingSize: heightSmall,
        opacityLoading: opacityDisabled
      };
    };
    const dataTableLight = createTheme$1({
      name: "DataTable",
      common: commonLight,
      peers: {
        Button: buttonLight$1,
        Checkbox: checkboxLight$1,
        Radio: radioLight$1,
        Pagination: paginationLight$1,
        Scrollbar: scrollbarLight$1,
        Empty: emptyLight$1,
        Popover: popoverLight$1,
        Ellipsis: ellipsisLight$1
      },
      self: self$K
    });
    var dataTableLight$1 = dataTableLight;

    const dataTableDark = {
      name: "DataTable",
      common: commonDark,
      peers: {
        Button: buttonDark$1,
        Checkbox: checkboxDark$1,
        Radio: radioDark$1,
        Pagination: paginationDark$1,
        Scrollbar: scrollbarDark$1,
        Empty: emptyDark$1,
        Popover: popoverDark$1,
        Ellipsis: ellipsisDark$1
      },

      self(vars) {
        const commonSelf = self$K(vars);
        commonSelf.boxShadowAfter = "inset 12px 0 8px -12px rgba(0, 0, 0, .36)";
        commonSelf.boxShadowBefore = "inset -12px 0 8px -12px rgba(0, 0, 0, .36)";
        return commonSelf;
      }

    };
    var dataTableDark$1 = dataTableDark;

    const tooltipProps = { ...popoverBaseProps,
      ...useTheme.props
    };
    var NTooltip = vue.defineComponent({
      name: "Tooltip",
      props: tooltipProps,
      __popover__: true,

      setup(props) {
        const themeRef = useTheme("Tooltip", "-tooltip", void 0, tooltipLight$1, props);
        const popoverRef = vue.ref(null);
        const tooltipExposedMethod = {
          syncPosition() {
            popoverRef.value.syncPosition();
          },

          setShow(show) {
            popoverRef.value.setShow(show);
          }

        };
        return { ...tooltipExposedMethod,
          popoverRef,
          mergedTheme: themeRef,
          popoverThemeOverrides: vue.computed(() => {
            return themeRef.value.self;
          })
        };
      },

      render() {
        const {
          mergedTheme,
          internalExtraClass
        } = this;
        return vue.h(NPopover, { ...this.$props,
          theme: mergedTheme.peers.Popover,
          themeOverrides: mergedTheme.peerOverrides.Popover,
          builtinThemeOverrides: this.popoverThemeOverrides,
          internalExtraClass: internalExtraClass.concat("tooltip"),
          ref: "popoverRef"
        }, this.$slots);
      }

    });

    var style$Y = cB("ellipsis", {
      overflow: "hidden"
    }, [cNotM("line-clamp", `
    white-space: nowrap;
    display: inline-block;
    vertical-align: bottom;
    max-width: 100%;
  `), cM("line-clamp", `
    display: -webkit-inline-box;
    -webkit-box-orient: vertical;
  `), cM("cursor-pointer", `
    cursor: pointer;
  `)]);

    function createLineClampClass(clsPrefix) {
      return `${clsPrefix}-ellipsis--line-clamp`;
    }
    function createCursorClass(clsPrefix, cursor) {
      return `${clsPrefix}-ellipsis--cursor-${cursor}`;
    }
    const ellipsisProps = {
      ...useTheme.props,
      expandTrigger: String,
      lineClamp: [Number, String],
      tooltip: {
        type: [Boolean, Object],
        default: true
      }
    };
    var NEllipsis = vue.defineComponent({
      name: "Ellipsis",
      inheritAttrs: false,
      props: ellipsisProps,
      setup(props, { slots, attrs }) {
        const { mergedClsPrefixRef } = useConfig(props);
        const mergedTheme = useTheme(
          "Ellipsis",
          "-ellipsis",
          style$Y,
          ellipsisLight$1,
          props,
          mergedClsPrefixRef
        );
        const triggerRef = vue.ref(null);
        const triggerInnerRef = vue.ref(null);
        const tooltipRef = vue.ref(null);
        const expandedRef = vue.ref(false);
        const ellipsisStyleRef = vue.computed(() => {
          const { lineClamp } = props;
          const { value: expanded } = expandedRef;
          if (lineClamp !== void 0) {
            return {
              textOverflow: "",
              "-webkit-line-clamp": expanded ? "" : lineClamp
            };
          } else {
            return {
              textOverflow: expanded ? "" : "ellipsis",
              "-webkit-line-clamp": ""
            };
          }
        });
        function getTooltipDisabled() {
          let tooltipDisabled = false;
          const { value: expanded } = expandedRef;
          if (expanded)
            return true;
          const { value: trigger } = triggerRef;
          if (trigger) {
            const { lineClamp } = props;
            syncEllipsisStyle(trigger);
            if (lineClamp !== void 0) {
              tooltipDisabled = trigger.scrollHeight <= trigger.offsetHeight;
            } else {
              const { value: triggerInner } = triggerInnerRef;
              if (triggerInner) {
                tooltipDisabled = triggerInner.getBoundingClientRect().width <= trigger.getBoundingClientRect().width;
              }
            }
            syncCursorStyle(trigger, tooltipDisabled);
          }
          return tooltipDisabled;
        }
        const handleClickRef = vue.computed(() => {
          return props.expandTrigger === "click" ? () => {
            const { value: expanded } = expandedRef;
            if (expanded) {
              tooltipRef.value?.setShow(false);
            }
            expandedRef.value = !expanded;
          } : void 0;
        });
        const renderTrigger = () => /* @__PURE__ */ React.createElement("span", {
          ...vue.mergeProps(attrs, {
            class: [
              `${mergedClsPrefixRef.value}-ellipsis`,
              props.lineClamp !== void 0 ? createLineClampClass(mergedClsPrefixRef.value) : void 0,
              props.expandTrigger === "click" ? createCursorClass(mergedClsPrefixRef.value, "pointer") : void 0
            ],
            style: ellipsisStyleRef.value
          }),
          ref: "triggerRef",
          onClick: handleClickRef.value,
          onMouseenter: props.expandTrigger === "click" ? getTooltipDisabled : void 0
        }, props.lineClamp ? slots : /* @__PURE__ */ React.createElement("span", {
          ref: "triggerInnerRef"
        }, slots));
        function syncEllipsisStyle(trigger) {
          if (!trigger)
            return;
          const latestStyle = ellipsisStyleRef.value;
          const lineClampClass = createLineClampClass(mergedClsPrefixRef.value);
          if (props.lineClamp !== void 0) {
            syncTriggerClass(trigger, lineClampClass, "add");
          } else {
            syncTriggerClass(trigger, lineClampClass, "remove");
          }
          for (const key in latestStyle) {
            if (trigger.style[key] !== latestStyle[key]) {
              trigger.style[key] = latestStyle[key];
            }
          }
        }
        function syncCursorStyle(trigger, tooltipDisabled) {
          const cursorClass = createCursorClass(mergedClsPrefixRef.value, "pointer");
          if (props.expandTrigger === "click" && !tooltipDisabled) {
            syncTriggerClass(trigger, cursorClass, "add");
          } else {
            syncTriggerClass(trigger, cursorClass, "remove");
          }
        }
        function syncTriggerClass(trigger, styleClass, action) {
          if (action === "add") {
            if (!trigger.classList.contains(styleClass)) {
              trigger.classList.add(styleClass);
            }
          } else {
            if (trigger.classList.contains(styleClass)) {
              trigger.classList.remove(styleClass);
            }
          }
        }
        return {
          mergedTheme,
          triggerRef,
          triggerInnerRef,
          tooltipRef,
          handleClick: handleClickRef,
          renderTrigger,
          getTooltipDisabled
        };
      },
      render() {
        const { tooltip, renderTrigger, $slots } = this;
        if (tooltip) {
          const { mergedTheme } = this;
          return /* @__PURE__ */ React.createElement(NTooltip, {
            ref: "tooltipRef",
            placement: "top",
            ...tooltip,
            getDisabled: this.getTooltipDisabled,
            theme: mergedTheme.peers.Tooltip,
            themeOverrides: mergedTheme.peerOverrides.Tooltip
          }, {
            trigger: renderTrigger,
            default: $slots.tooltip ?? $slots.default
          });
        } else
          return renderTrigger();
      }
    });

    var RenderSorter = vue.defineComponent({
      name: "DataTableRenderSorter",
      props: {
        render: {
          type: Function,
          required: true
        },
        order: {
          type: [String, Boolean],
          default: false
        }
      },

      render() {
        const {
          render,
          order
        } = this;
        return render({
          order
        });
      }

    });

    const dataTableInjectionKey = createInjectionKey("n-data-table");

    var SortButton = vue.defineComponent({
      name: "SortIcon",
      props: {
        column: {
          type: Object,
          required: true
        }
      },
      setup(props) {
        const { mergedComponentPropsRef } = useConfig();
        const { mergedSortStateRef, mergedClsPrefixRef } = vue.inject(
          dataTableInjectionKey
        );
        const sortStateRef = vue.computed(
          () => mergedSortStateRef.value.find(
            (state) => state.columnKey === props.column.key
          )
        );
        const activeRef = vue.computed(() => {
          return sortStateRef.value !== void 0;
        });
        const mergedSortOrderRef = vue.computed(() => {
          const { value: sortState } = sortStateRef;
          if (sortState && activeRef.value) {
            return sortState.order;
          }
          return false;
        });
        const mergedRenderSorterRef = vue.computed(() => {
          return mergedComponentPropsRef?.value?.DataTable?.renderSorter || props.column.renderSorter;
        });
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          active: activeRef,
          mergedSortOrder: mergedSortOrderRef,
          mergedRenderSorter: mergedRenderSorterRef
        };
      },
      render() {
        const { mergedRenderSorter, mergedSortOrder, mergedClsPrefix } = this;
        const { renderSorterIcon } = this.column;
        return mergedRenderSorter ? /* @__PURE__ */ React.createElement(RenderSorter, {
          render: mergedRenderSorter,
          order: mergedSortOrder
        }) : /* @__PURE__ */ React.createElement("span", {
          class: [
            `${mergedClsPrefix}-data-table-sorter`,
            mergedSortOrder === "ascend" && `${mergedClsPrefix}-data-table-sorter--asc`,
            mergedSortOrder === "descend" && `${mergedClsPrefix}-data-table-sorter--desc`
          ]
        }, renderSorterIcon ? renderSorterIcon({ order: mergedSortOrder }) : /* @__PURE__ */ React.createElement(NBaseIcon, {
          clsPrefix: mergedClsPrefix
        }, { default: () => /* @__PURE__ */ React.createElement(ArrowDownIcon, null) }));
      }
    });

    var RenderFilter = vue.defineComponent({
      name: "DataTableRenderFilter",
      props: {
        render: {
          type: Function,
          required: true
        },
        active: {
          type: Boolean,
          default: false
        },
        show: {
          type: Boolean,
          default: false
        }
      },

      render() {
        const {
          render,
          active,
          show
        } = this;
        return render({
          active,
          show
        });
      }

    });

    const radioProps = {
      name: String,
      value: {
        type: [String, Number, Boolean],
        default: "on"
      },
      checked: {
        type: Boolean,
        default: void 0
      },
      defaultChecked: Boolean,
      disabled: {
        type: Boolean,
        default: void 0
      },
      label: String,
      size: String,
      onUpdateChecked: [Function, Array],
      "onUpdate:checked": [Function, Array],
      checkedValue: {
        type: Boolean,
        default: void 0
      }
    };
    const radioGroupInjectionKey = createInjectionKey("n-radio-group");

    function setup(props) {
      {
        vue.watchEffect(() => {
          if (props.checkedValue !== void 0) {
            warnOnce("radio", "`checked-value` is deprecated, please use `checked` instead.");
          }
        });
      }

      const formItem = useFormItem(props, {
        mergedSize(NFormItem) {
          const {
            size
          } = props;
          if (size !== void 0) return size;

          if (NRadioGroup) {
            const {
              mergedSizeRef: {
                value: mergedSize
              }
            } = NRadioGroup;

            if (mergedSize !== void 0) {
              return mergedSize;
            }
          }

          if (NFormItem) {
            return NFormItem.mergedSize.value;
          }

          return "medium";
        },

        mergedDisabled(NFormItem) {
          if (props.disabled) return true;
          if (NRadioGroup !== null && NRadioGroup !== void 0 && NRadioGroup.disabledRef.value) return true;
          if (NFormItem !== null && NFormItem !== void 0 && NFormItem.disabled.value) return true;
          return false;
        }

      });
      const {
        mergedSizeRef,
        mergedDisabledRef
      } = formItem;
      const inputRef = vue.ref(null);
      const labelRef = vue.ref(null);
      const NRadioGroup = vue.inject(radioGroupInjectionKey, null);
      const uncontrolledCheckedRef = vue.ref(props.defaultChecked);
      const controlledCheckedRef = vue.toRef(props, "checked");
      const mergedCheckedRef = useMergedState(controlledCheckedRef, uncontrolledCheckedRef);
      const renderSafeCheckedRef = useMemo(() => {
        if (NRadioGroup) return NRadioGroup.valueRef.value === props.value;
        return mergedCheckedRef.value;
      });
      const mergedNameRef = useMemo(() => {
        const {
          name
        } = props;
        if (name !== void 0) return name;
        if (NRadioGroup) return NRadioGroup.nameRef.value;
      });
      const focusRef = vue.ref(false);

      function doUpdateChecked() {
        if (NRadioGroup) {
          const {
            doUpdateValue
          } = NRadioGroup;
          const {
            value
          } = props;
          call(doUpdateValue, value);
        } else {
          const {
            onUpdateChecked,
            "onUpdate:checked": _onUpdateChecked
          } = props;
          const {
            nTriggerFormInput,
            nTriggerFormChange
          } = formItem;
          if (onUpdateChecked) call(onUpdateChecked, true);
          if (_onUpdateChecked) call(_onUpdateChecked, true);
          nTriggerFormInput();
          nTriggerFormChange();
          uncontrolledCheckedRef.value = true;
        }
      }

      function toggle() {
        if (mergedDisabledRef.value) return;

        if (!renderSafeCheckedRef.value) {
          doUpdateChecked();
        }
      }

      function handleRadioInputChange() {
        toggle();
      }

      function handleRadioInputBlur() {
        focusRef.value = false;
      }

      function handleRadioInputFocus() {
        focusRef.value = true;
      }

      return {
        mergedClsPrefix: NRadioGroup ? NRadioGroup.mergedClsPrefixRef : useConfig(props).mergedClsPrefixRef,
        inputRef,
        labelRef,
        mergedName: mergedNameRef,
        mergedDisabled: mergedDisabledRef,
        uncontrolledChecked: uncontrolledCheckedRef,
        renderSafeChecked: renderSafeCheckedRef,
        focus: focusRef,
        mergedSize: mergedSizeRef,
        handleRadioInputChange,
        handleRadioInputBlur,
        handleRadioInputFocus
      };
    }

    var style$X = cB("radio", `
  line-height: var(--n-label-line-height);
  outline: none;
  position: relative;
  user-select: none;
  -webkit-user-select: none;
  display: inline-flex;
  align-items: flex-start;
  flex-wrap: nowrap;
  font-size: var(--n-font-size);
  word-break: break-word;
`, [cE("dot-wrapper", `
    position: relative;
    flex-shrink: 0;
    flex-grow: 0;
    width: var(--n-radio-size);
  `), cB("radio-input", `
    position: absolute;
    border: 0;
    border-radius: inherit;
    left: 0;
    right: 0;
    top: 0;
    bottom: 0;
    opacity: 0;
    z-index: 1;
    cursor: pointer;
  `), cE("dot", `
    position: absolute;
    top: 50%;
    left: 0;
    transform: translateY(-50%);
    height: var(--n-radio-size);
    width: var(--n-radio-size);
    background: var(--n-color);
    box-shadow: var(--n-box-shadow);
    border-radius: 50%;
    transition:
      background-color .3s var(--n-bezier),
      box-shadow .3s var(--n-bezier);
  `, [c$1("&::before", `
      content: "";
      opacity: 0;
      position: absolute;
      left: 4px;
      top: 4px;
      height: calc(100% - 8px);
      width: calc(100% - 8px);
      border-radius: 50%;
      transform: scale(.8);
      background: var(--n-dot-color-active);
      transition: 
        opacity .3s var(--n-bezier),
        background-color .3s var(--n-bezier),
        transform .3s var(--n-bezier);
    `), cM("checked", {
      boxShadow: "var(--n-box-shadow-active)"
    }, [c$1("&::before", `
        opacity: 1;
        transform: scale(1);
      `)])]), cE("label", `
    color: var(--n-text-color);
    padding: var(--n-label-padding);
    display: inline-block;
    transition: color .3s var(--n-bezier);
  `), cNotM("disabled", `
    cursor: pointer;
  `, [c$1("&:hover", [cE("dot", {
      boxShadow: "var(--n-box-shadow-hover)"
    })]), cM("focus", [c$1("&:not(:active)", [cE("dot", {
      boxShadow: "var(--n-box-shadow-focus)"
    })])])]), cM("disabled", `
    cursor: not-allowed;
  `, [cE("dot", {
      boxShadow: "var(--n-box-shadow-disabled)",
      backgroundColor: "var(--n-color-disabled)"
    }, [c$1("&::before", {
      backgroundColor: "var(--n-dot-color-disabled)"
    }), cM("checked", `
        opacity: 1;
      `)]), cE("label", {
      color: "var(--n-text-color-disabled)"
    }), cB("radio-input", `
      cursor: not-allowed;
    `)])]);

    var NRadio = vue.defineComponent({
      name: "Radio",
      props: {
        ...useTheme.props,
        ...radioProps
      },
      setup(props) {
        const radio = setup(props);
        const themeRef = useTheme(
          "Radio",
          "-radio",
          style$X,
          radioLight$1,
          props,
          radio.mergedClsPrefix
        );
        const cssVarsRef = vue.computed(() => {
          const {
            mergedSize: { value: size }
          } = radio;
          const {
            common: { cubicBezierEaseInOut },
            self: {
              boxShadow,
              boxShadowActive,
              boxShadowDisabled,
              boxShadowFocus,
              boxShadowHover,
              color,
              colorDisabled,
              textColor,
              textColorDisabled,
              dotColorActive,
              dotColorDisabled,
              labelPadding,
              labelLineHeight,
              [createKey("fontSize", size)]: fontSize,
              [createKey("radioSize", size)]: radioSize
            }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-label-line-height": labelLineHeight,
            "--n-box-shadow": boxShadow,
            "--n-box-shadow-active": boxShadowActive,
            "--n-box-shadow-disabled": boxShadowDisabled,
            "--n-box-shadow-focus": boxShadowFocus,
            "--n-box-shadow-hover": boxShadowHover,
            "--n-color": color,
            "--n-color-disabled": colorDisabled,
            "--n-dot-color-active": dotColorActive,
            "--n-dot-color-disabled": dotColorDisabled,
            "--n-font-size": fontSize,
            "--n-radio-size": radioSize,
            "--n-text-color": textColor,
            "--n-text-color-disabled": textColorDisabled,
            "--n-label-padding": labelPadding
          };
        });
        const { inlineThemeDisabled, mergedClsPrefixRef, mergedRtlRef } = useConfig(props);
        const rtlEnabledRef = useRtl("Radio", mergedRtlRef, mergedClsPrefixRef);
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "radio",
          vue.computed(() => radio.mergedSize.value[0]),
          cssVarsRef,
          props
        ) : void 0;
        return Object.assign(radio, {
          rtlEnabled: rtlEnabledRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        });
      },
      render() {
        const { $slots, mergedClsPrefix, onRender, label } = this;
        onRender?.();
        return /* @__PURE__ */ React.createElement("label", {
          class: [
            `${mergedClsPrefix}-radio`,
            this.themeClass,
            {
              [`${mergedClsPrefix}-radio--rtl`]: this.rtlEnabled,
              [`${mergedClsPrefix}-radio--disabled`]: this.mergedDisabled,
              [`${mergedClsPrefix}-radio--checked`]: this.renderSafeChecked,
              [`${mergedClsPrefix}-radio--focus`]: this.focus
            }
          ],
          style: this.cssVars
        }, /* @__PURE__ */ React.createElement("input", {
          ref: "inputRef",
          type: "radio",
          class: `${mergedClsPrefix}-radio-input`,
          value: this.value,
          name: this.mergedName,
          checked: this.renderSafeChecked,
          disabled: this.mergedDisabled,
          onChange: this.handleRadioInputChange,
          onFocus: this.handleRadioInputFocus,
          onBlur: this.handleRadioInputBlur
        }), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-radio__dot-wrapper`
        }, "\xA0", /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-radio__dot`,
            this.renderSafeChecked && `${mergedClsPrefix}-radio__dot--checked`
          ]
        })), resolveWrappedSlot($slots.default, (children) => {
          if (!children && !label)
            return null;
          return /* @__PURE__ */ React.createElement("div", {
            ref: "labelRef",
            class: `${mergedClsPrefix}-radio__label`
          }, children || label);
        }));
      }
    });

    var style$W = cB("radio-group", `
  display: inline-block;
  font-size: var(--n-font-size);
`, [cE("splitor", `
    display: inline-block;
    vertical-align: bottom;
    width: 1px;
    transition:
      background-color .3s var(--n-bezier),
      opacity .3s var(--n-bezier);
    background: var(--n-button-border-color);
  `, [cM("checked", {
      backgroundColor: "var(--n-button-border-color-active)"
    }), cM("disabled", {
      opacity: "var(--n-opacity-disabled)"
    })]), cM("button-group", `
    white-space: nowrap;
    height: var(--n-height);
    line-height: var(--n-height);
  `, [cB("radio-button", {
      height: "var(--n-height)",
      lineHeight: "var(--n-height)"
    }), cE("splitor", {
      height: "var(--n-height)"
    })]), cB("radio-button", `
    vertical-align: bottom;
    outline: none;
    position: relative;
    user-select: none;
    -webkit-user-select: none;
    display: inline-block;
    box-sizing: border-box;
    padding-left: 14px;
    padding-right: 14px;
    white-space: nowrap;
    transition:
      background-color .3s var(--n-bezier),
      opacity .3s var(--n-bezier),
      border-color .3s var(--n-bezier),
      color .3s var(--n-bezier);
    color: var(--n-button-text-color);
    border-top: 1px solid var(--n-button-border-color);
    border-bottom: 1px solid var(--n-button-border-color);
  `, [cB("radio-input", `
      pointer-events: none;
      position: absolute;
      border: 0;
      border-radius: inherit;
      left: 0;
      right: 0;
      top: 0;
      bottom: 0;
      opacity: 0;
      z-index: 1;
    `), cE("state-border", `
      z-index: 1;
      pointer-events: none;
      position: absolute;
      box-shadow: var(--n-button-box-shadow);
      transition: box-shadow .3s var(--n-bezier);
      left: -1px;
      bottom: -1px;
      right: -1px;
      top: -1px;
    `), c$1("&:first-child", `
      border-top-left-radius: var(--n-button-border-radius);
      border-bottom-left-radius: var(--n-button-border-radius);
      border-left: 1px solid var(--n-button-border-color);
    `, [cE("state-border", `
        border-top-left-radius: var(--n-button-border-radius);
        border-bottom-left-radius: var(--n-button-border-radius);
      `)]), c$1("&:last-child", `
      border-top-right-radius: var(--n-button-border-radius);
      border-bottom-right-radius: var(--n-button-border-radius);
      border-right: 1px solid var(--n-button-border-color);
    `, [cE("state-border", `
        border-top-right-radius: var(--n-button-border-radius);
        border-bottom-right-radius: var(--n-button-border-radius);
      `)]), cNotM("disabled", `
      cursor: pointer;
    `, [c$1("&:hover", [cE("state-border", `
          transition: box-shadow .3s var(--n-bezier);
          box-shadow: var(--n-button-box-shadow-hover);
        `), cNotM("checked", {
      color: "var(--n-button-text-color-hover)"
    })]), cM("focus", [c$1("&:not(:active)", [cE("state-border", {
      boxShadow: "var(--n-button-box-shadow-focus)"
    })])])]), cM("checked", `
      background: var(--n-button-color-active);
      color: var(--n-button-text-color-active);
      border-color: var(--n-button-border-color-active);
    `), cM("disabled", `
      cursor: not-allowed;
      opacity: var(--n-opacity-disabled);
    `)])]);

    function mapSlot(defaultSlot, value, clsPrefix) {
      const children = [];
      let isButtonGroup = false;
      for (let i = 0; i < defaultSlot.length; ++i) {
        const wrappedInstance = defaultSlot[i];
        const name = wrappedInstance.type?.name;
        if (name === "RadioButton") {
          isButtonGroup = true;
        }
        if (isButtonGroup && name !== "RadioButton") {
          warn$2(
            "radio-group",
            "`n-radio-group` in button mode only takes `n-radio-button` as children."
          );
          continue;
        }
        const instanceProps = wrappedInstance.props;
        if (name !== "RadioButton") {
          children.push(wrappedInstance);
          continue;
        }
        if (i === 0) {
          children.push(wrappedInstance);
        } else {
          const lastInstanceProps = children[children.length - 1].props;
          const lastInstanceChecked = value === lastInstanceProps.value;
          const lastInstanceDisabled = lastInstanceProps.disabled;
          const currentInstanceChecked = value === instanceProps.value;
          const currentInstanceDisabled = instanceProps.disabled;
          const lastInstancePriority = (lastInstanceChecked ? 2 : 0) + (!lastInstanceDisabled ? 1 : 0);
          const currentInstancePriority = (currentInstanceChecked ? 2 : 0) + (!currentInstanceDisabled ? 1 : 0);
          const lastInstanceClass = {
            [`${clsPrefix}-radio-group__splitor--disabled`]: lastInstanceDisabled,
            [`${clsPrefix}-radio-group__splitor--checked`]: lastInstanceChecked
          };
          const currentInstanceClass = {
            [`${clsPrefix}-radio-group__splitor--disabled`]: currentInstanceDisabled,
            [`${clsPrefix}-radio-group__splitor--checked`]: currentInstanceChecked
          };
          const splitorClass = lastInstancePriority < currentInstancePriority ? currentInstanceClass : lastInstanceClass;
          children.push(
            /* @__PURE__ */ React.createElement("div", {
              class: [`${clsPrefix}-radio-group__splitor`, splitorClass]
            }),
            wrappedInstance
          );
        }
      }
      return {
        children,
        isButtonGroup
      };
    }
    const radioGroupProps = {
      ...useTheme.props,
      name: String,
      value: [String, Number, Boolean],
      defaultValue: {
        type: [String, Number, Boolean],
        default: null
      },
      size: String,
      disabled: {
        type: Boolean,
        default: void 0
      },
      "onUpdate:value": [Function, Array],
      onUpdateValue: [Function, Array]
    };
    var NRadioGroup = vue.defineComponent({
      name: "RadioGroup",
      props: radioGroupProps,
      setup(props) {
        const selfElRef = vue.ref(null);
        const {
          mergedSizeRef,
          mergedDisabledRef,
          nTriggerFormChange,
          nTriggerFormInput,
          nTriggerFormBlur,
          nTriggerFormFocus
        } = useFormItem(props);
        const { mergedClsPrefixRef, inlineThemeDisabled, mergedRtlRef } = useConfig(props);
        const themeRef = useTheme(
          "Radio",
          "-radio-group",
          style$W,
          radioLight$1,
          props,
          mergedClsPrefixRef
        );
        const uncontrolledValueRef = vue.ref(props.defaultValue);
        const controlledValueRef = vue.toRef(props, "value");
        const mergedValueRef = useMergedState(
          controlledValueRef,
          uncontrolledValueRef
        );
        function doUpdateValue(value) {
          const { onUpdateValue, "onUpdate:value": _onUpdateValue } = props;
          if (onUpdateValue) {
            call(onUpdateValue, value);
          }
          if (_onUpdateValue) {
            call(_onUpdateValue, value);
          }
          uncontrolledValueRef.value = value;
          nTriggerFormChange();
          nTriggerFormInput();
        }
        function handleFocusin(e) {
          const { value: selfEl } = selfElRef;
          if (!selfEl)
            return;
          if (selfEl.contains(e.relatedTarget))
            return;
          nTriggerFormFocus();
        }
        function handleFocusout(e) {
          const { value: selfEl } = selfElRef;
          if (!selfEl)
            return;
          if (selfEl.contains(e.relatedTarget))
            return;
          nTriggerFormBlur();
        }
        vue.provide(radioGroupInjectionKey, {
          mergedClsPrefixRef,
          nameRef: vue.toRef(props, "name"),
          valueRef: mergedValueRef,
          disabledRef: mergedDisabledRef,
          mergedSizeRef,
          doUpdateValue
        });
        const rtlEnabledRef = useRtl("Radio", mergedRtlRef, mergedClsPrefixRef);
        const cssVarsRef = vue.computed(() => {
          const { value: size } = mergedSizeRef;
          const {
            common: { cubicBezierEaseInOut },
            self: {
              buttonBorderColor,
              buttonBorderColorActive,
              buttonBorderRadius,
              buttonBoxShadow,
              buttonBoxShadowFocus,
              buttonBoxShadowHover,
              buttonColorActive,
              buttonTextColor,
              buttonTextColorActive,
              buttonTextColorHover,
              opacityDisabled,
              [createKey("buttonHeight", size)]: height,
              [createKey("fontSize", size)]: fontSize
            }
          } = themeRef.value;
          return {
            "--n-font-size": fontSize,
            "--n-bezier": cubicBezierEaseInOut,
            "--n-button-border-color": buttonBorderColor,
            "--n-button-border-color-active": buttonBorderColorActive,
            "--n-button-border-radius": buttonBorderRadius,
            "--n-button-box-shadow": buttonBoxShadow,
            "--n-button-box-shadow-focus": buttonBoxShadowFocus,
            "--n-button-box-shadow-hover": buttonBoxShadowHover,
            "--n-button-color-active": buttonColorActive,
            "--n-button-text-color": buttonTextColor,
            "--n-button-text-color-hover": buttonTextColorHover,
            "--n-button-text-color-active": buttonTextColorActive,
            "--n-height": height,
            "--n-opacity-disabled": opacityDisabled
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "radio-group",
          vue.computed(() => mergedSizeRef.value[0]),
          cssVarsRef,
          props
        ) : void 0;
        return {
          selfElRef,
          rtlEnabled: rtlEnabledRef,
          mergedClsPrefix: mergedClsPrefixRef,
          mergedValue: mergedValueRef,
          handleFocusout,
          handleFocusin,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedValue, mergedClsPrefix, handleFocusin, handleFocusout } = this;
        const { children, isButtonGroup } = mapSlot(
          flatten$3(getSlot$1(this)),
          mergedValue,
          mergedClsPrefix
        );
        this.onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          onFocusin: handleFocusin,
          onFocusout: handleFocusout,
          ref: "selfElRef",
          class: [
            `${mergedClsPrefix}-radio-group`,
            this.rtlEnabled && `${mergedClsPrefix}-radio-group--rtl`,
            this.themeClass,
            isButtonGroup && `${mergedClsPrefix}-radio-group--button-group`
          ],
          style: this.cssVars
        }, children);
      }
    });

    const radioButtonProps = radioProps;
    var RadioButton = vue.defineComponent({
      name: "RadioButton",
      props: radioProps,
      setup,
      render() {
        const { mergedClsPrefix } = this;
        return /* @__PURE__ */ React.createElement("label", {
          class: [
            `${mergedClsPrefix}-radio-button`,
            this.mergedDisabled && `${mergedClsPrefix}-radio-button--disabled`,
            this.renderSafeChecked && `${mergedClsPrefix}-radio-button--checked`,
            this.focus && [`${mergedClsPrefix}-radio-button--focus`]
          ]
        }, /* @__PURE__ */ React.createElement("input", {
          ref: "inputRef",
          type: "radio",
          class: `${mergedClsPrefix}-radio-input`,
          value: this.value,
          name: this.mergedName,
          checked: this.renderSafeChecked,
          disabled: this.mergedDisabled,
          onChange: this.handleRadioInputChange,
          onFocus: this.handleRadioInputFocus,
          onBlur: this.handleRadioInputBlur
        }), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-radio-button__state-border`
        }), resolveWrappedSlot(this.$slots.default, (children) => {
          if (!children && !this.label)
            return null;
          return /* @__PURE__ */ React.createElement("div", {
            ref: "labelRef",
            class: `${mergedClsPrefix}-radio__label`
          }, children || this.label);
        }));
      }
    });

    const SELECTION_COL_WIDTH = 40;
    const EXPAND_COL_WIDTH = 40;
    function getNumberColWidth(col) {
      if (col.type === "selection") {
        return col.width === void 0 ? SELECTION_COL_WIDTH : depx(col.width);
      }

      if (col.type === "expand") {
        return col.width === void 0 ? EXPAND_COL_WIDTH : depx(col.width);
      }

      if ("children" in col) return void 0;

      if (typeof col.width === "string") {
        return depx(col.width);
      }

      return col.width;
    }
    function getStringColWidth(col) {
      if (col.type === "selection") {
        return formatLength(col.width ?? SELECTION_COL_WIDTH);
      }

      if (col.type === "expand") {
        return formatLength(col.width ?? EXPAND_COL_WIDTH);
      }

      if ("children" in col) {
        return void 0;
      }

      return formatLength(col.width);
    }
    function getColKey(col) {
      if (col.type === "selection") return "__n_selection__";
      if (col.type === "expand") return "__n_expand__";
      return col.key;
    }
    function createShallowClonedObject(object) {
      if (!object) return object;

      if (typeof object === "object") {
        return Object.assign({}, object);
      }

      return object;
    }
    function getFlagOfOrder(order) {
      if (order === "ascend") return 1;else if (order === "descend") return -1;
      return 0;
    }
    function createCustomWidthStyle(column) {
      const width = getStringColWidth(column);
      return {
        width,
        minWidth: formatLength(column.minWidth) || width
      };
    }
    function createRowClassName(row, index, rowClassName) {
      if (typeof rowClassName === "function") return rowClassName(row, index);
      return rowClassName || "";
    }
    function shouldUseArrayInSingleMode(column) {
      return column.filterOptionValues !== void 0 || column.filterOptionValue === void 0 && column.defaultFilterOptionValues !== void 0;
    }
    function isColumnSortable(column) {
      if ("children" in column) return false;
      return !!column.sorter;
    }
    function isColumnFilterable(column) {
      if ("children" in column) return false;
      return !!column.filter && (!!column.filterOptions || !!column.renderFilterMenu);
    }

    function getNextOrderOf(order) {
      if (!order) return "descend";else if (order === "descend") return "ascend";
      return false;
    }

    function createNextSorter(column, currentSortState) {
      if (column.sorter === void 0) return null;

      if (currentSortState === null || currentSortState.columnKey !== column.key) {
        return {
          columnKey: column.key,
          sorter: column.sorter,
          order: getNextOrderOf(false)
        };
      } else {
        return { ...currentSortState,
          order: getNextOrderOf(currentSortState.order)
        };
      }
    }
    function isColumnSorting(column, mergedSortState) {
      return mergedSortState.find(state => state.columnKey === column.key && state.order) !== void 0;
    }

    var NDataTableFilterMenu = vue.defineComponent({
      name: "DataTableFilterMenu",
      props: {
        column: {
          type: Object,
          required: true
        },
        radioGroupName: {
          type: String,
          required: true
        },
        multiple: {
          type: Boolean,
          required: true
        },
        value: {
          type: [Array, String, Number],
          default: null
        },
        options: {
          type: Array,
          required: true
        },
        onConfirm: {
          type: Function,
          required: true
        },
        onClear: {
          type: Function,
          required: true
        },
        onChange: {
          type: Function,
          required: true
        }
      },
      setup(props) {
        const {
          mergedClsPrefixRef,
          mergedThemeRef,
          localeRef
        } = vue.inject(dataTableInjectionKey);
        const temporalValueRef = vue.ref(props.value);
        const checkboxGroupValueRef = vue.computed(() => {
          const { value: temporalValue } = temporalValueRef;
          if (!Array.isArray(temporalValue))
            return null;
          return temporalValue;
        });
        const radioGroupValueRef = vue.computed(() => {
          const { value: temporalValue } = temporalValueRef;
          if (shouldUseArrayInSingleMode(props.column)) {
            return Array.isArray(temporalValue) && temporalValue.length && temporalValue[0] || null;
          }
          if (!Array.isArray(temporalValue))
            return temporalValue;
          return null;
        });
        function doChange(value) {
          props.onChange(value);
        }
        function handleChange(value) {
          if (props.multiple && Array.isArray(value)) {
            temporalValueRef.value = value;
          } else if (shouldUseArrayInSingleMode(props.column) && !Array.isArray(value)) {
            temporalValueRef.value = [value];
          } else {
            temporalValueRef.value = value;
          }
        }
        function handleConfirmClick() {
          doChange(temporalValueRef.value);
          props.onConfirm();
        }
        function handleClearClick() {
          if (props.multiple || shouldUseArrayInSingleMode(props.column)) {
            doChange([]);
          } else {
            doChange(null);
          }
          props.onClear();
        }
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          mergedTheme: mergedThemeRef,
          locale: localeRef,
          checkboxGroupValue: checkboxGroupValueRef,
          radioGroupValue: radioGroupValueRef,
          handleChange,
          handleConfirmClick,
          handleClearClick
        };
      },
      render() {
        const { mergedTheme, locale, mergedClsPrefix } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-data-table-filter-menu`
        }, /* @__PURE__ */ React.createElement(NScrollbar, null, {
          default: () => {
            const { checkboxGroupValue, handleChange } = this;
            return this.multiple ? /* @__PURE__ */ React.createElement(NCheckboxGroup, {
              value: checkboxGroupValue,
              class: `${mergedClsPrefix}-data-table-filter-menu__group`,
              onUpdateValue: handleChange
            }, {
              default: () => this.options.map((option) => {
                return /* @__PURE__ */ React.createElement(NCheckbox, {
                  key: option.value,
                  theme: mergedTheme.peers.Checkbox,
                  themeOverrides: mergedTheme.peerOverrides.Checkbox,
                  value: option.value
                }, { default: () => option.label });
              })
            }) : /* @__PURE__ */ React.createElement(NRadioGroup, {
              name: this.radioGroupName,
              class: `${mergedClsPrefix}-data-table-filter-menu__group`,
              value: this.radioGroupValue,
              onUpdateValue: this.handleChange
            }, {
              default: () => this.options.map((option) => /* @__PURE__ */ React.createElement(NRadio, {
                key: option.value,
                value: option.value,
                theme: mergedTheme.peers.Radio,
                themeOverrides: mergedTheme.peerOverrides.Radio
              }, { default: () => option.label }))
            });
          }
        }), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-data-table-filter-menu__action`
        }, /* @__PURE__ */ React.createElement(NButton, {
          size: "tiny",
          theme: mergedTheme.peers.Button,
          themeOverrides: mergedTheme.peerOverrides.Button,
          onClick: this.handleClearClick
        }, { default: () => locale.clear }), /* @__PURE__ */ React.createElement(NButton, {
          theme: mergedTheme.peers.Button,
          themeOverrides: mergedTheme.peerOverrides.Button,
          type: "primary",
          size: "tiny",
          onClick: this.handleConfirmClick
        }, { default: () => locale.confirm })));
      }
    });

    function createFilterState(currentFilterState, columnKey, mergedFilterValue) {
      const nextFilterState = Object.assign({}, currentFilterState);
      nextFilterState[columnKey] = mergedFilterValue;
      return nextFilterState;
    }
    var FilterButton = vue.defineComponent({
      name: "DataTableFilterButton",
      props: {
        column: {
          type: Object,
          required: true
        },
        options: {
          type: Array,
          default: () => []
        }
      },
      setup(props) {
        const { mergedComponentPropsRef } = useConfig();
        const {
          mergedThemeRef,
          mergedClsPrefixRef,
          mergedFilterStateRef,
          filterMenuCssVarsRef,
          paginationBehaviorOnFilterRef,
          doUpdatePage,
          doUpdateFilters
        } = vue.inject(dataTableInjectionKey);
        const showPopoverRef = vue.ref(false);
        const filterStateRef = mergedFilterStateRef;
        const filterMultipleRef = vue.computed(() => {
          return props.column.filterMultiple !== false;
        });
        const mergedFilterValueRef = vue.computed(() => {
          const filterValue = filterStateRef.value[props.column.key];
          if (filterValue === void 0) {
            const { value: multiple } = filterMultipleRef;
            if (multiple)
              return [];
            else
              return null;
          }
          return filterValue;
        });
        const activeRef = vue.computed(() => {
          const { value: filterValue } = mergedFilterValueRef;
          if (Array.isArray(filterValue)) {
            return filterValue.length > 0;
          }
          return filterValue !== null;
        });
        const mergedRenderFilterRef = vue.computed(() => {
          return mergedComponentPropsRef?.value?.DataTable?.renderFilter || props.column.renderFilter;
        });
        function handleFilterChange(mergedFilterValue) {
          const nextFilterState = createFilterState(
            filterStateRef.value,
            props.column.key,
            mergedFilterValue
          );
          doUpdateFilters(nextFilterState, props.column);
          if (paginationBehaviorOnFilterRef.value === "first") {
            doUpdatePage(1);
          }
        }
        function handleFilterMenuCancel() {
          showPopoverRef.value = false;
        }
        function handleFilterMenuConfirm() {
          showPopoverRef.value = false;
        }
        return {
          mergedTheme: mergedThemeRef,
          mergedClsPrefix: mergedClsPrefixRef,
          active: activeRef,
          showPopover: showPopoverRef,
          mergedRenderFilter: mergedRenderFilterRef,
          filterMultiple: filterMultipleRef,
          mergedFilterValue: mergedFilterValueRef,
          filterMenuCssVars: filterMenuCssVarsRef,
          handleFilterChange,
          handleFilterMenuConfirm,
          handleFilterMenuCancel
        };
      },
      render() {
        const { mergedTheme, mergedClsPrefix, handleFilterMenuCancel } = this;
        return /* @__PURE__ */ React.createElement(NPopover, {
          show: this.showPopover,
          onUpdateShow: (v) => this.showPopover = v,
          trigger: "click",
          theme: mergedTheme.peers.Popover,
          themeOverrides: mergedTheme.peerOverrides.Popover,
          placement: "bottom",
          style: { padding: 0 }
        }, {
          trigger: () => {
            const { mergedRenderFilter } = this;
            if (mergedRenderFilter) {
              return /* @__PURE__ */ React.createElement(RenderFilter, {
                "data-data-table-filter": true,
                render: mergedRenderFilter,
                active: this.active,
                show: this.showPopover
              });
            }
            const { renderFilterIcon } = this.column;
            return /* @__PURE__ */ React.createElement("div", {
              "data-data-table-filter": true,
              class: [
                `${mergedClsPrefix}-data-table-filter`,
                {
                  [`${mergedClsPrefix}-data-table-filter--active`]: this.active,
                  [`${mergedClsPrefix}-data-table-filter--show`]: this.showPopover
                }
              ]
            }, renderFilterIcon ? renderFilterIcon({
              active: this.active,
              show: this.showPopover
            }) : /* @__PURE__ */ React.createElement(NBaseIcon, {
              clsPrefix: mergedClsPrefix
            }, { default: () => /* @__PURE__ */ React.createElement(FilterIcon, null) }));
          },
          default: () => {
            const { renderFilterMenu } = this.column;
            return renderFilterMenu ? renderFilterMenu({ hide: handleFilterMenuCancel }) : /* @__PURE__ */ React.createElement(NDataTableFilterMenu, {
              style: this.filterMenuCssVars,
              radioGroupName: String(this.column.key),
              multiple: this.filterMultiple,
              value: this.mergedFilterValue,
              options: this.options,
              column: this.column,
              onChange: this.handleFilterChange,
              onClear: this.handleFilterMenuCancel,
              onConfirm: this.handleFilterMenuConfirm
            });
          }
        });
      }
    });

    var commonVariables$8 = {
      padding: "4px 0",
      optionIconSizeSmall: "14px",
      optionIconSizeMedium: "16px",
      optionIconSizeLarge: "16px",
      optionIconSizeHuge: "18px",
      optionSuffixWidthSmall: "14px",
      optionSuffixWidthMedium: "14px",
      optionSuffixWidthLarge: "16px",
      optionSuffixWidthHuge: "16px",
      optionIconSuffixWidthSmall: "32px",
      optionIconSuffixWidthMedium: "32px",
      optionIconSuffixWidthLarge: "36px",
      optionIconSuffixWidthHuge: "36px",
      optionPrefixWidthSmall: "14px",
      optionPrefixWidthMedium: "14px",
      optionPrefixWidthLarge: "16px",
      optionPrefixWidthHuge: "16px",
      optionIconPrefixWidthSmall: "36px",
      optionIconPrefixWidthMedium: "36px",
      optionIconPrefixWidthLarge: "40px",
      optionIconPrefixWidthHuge: "40px"
    };

    const self$J = vars => {
      const {
        primaryColor,
        textColor2,
        dividerColor,
        hoverColor,
        popoverColor,
        invertedColor,
        borderRadius,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge,
        fontSizeHuge,
        heightSmall,
        heightMedium,
        heightLarge,
        heightHuge,
        textColor3,
        opacityDisabled
      } = vars;
      return { ...commonVariables$8,
        optionHeightSmall: heightSmall,
        optionHeightMedium: heightMedium,
        optionHeightLarge: heightLarge,
        optionHeightHuge: heightHuge,
        borderRadius,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge,
        fontSizeHuge,
        optionTextColor: textColor2,
        optionTextColorHover: textColor2,
        optionTextColorActive: primaryColor,
        optionTextColorChildActive: primaryColor,
        color: popoverColor,
        dividerColor,
        suffixColor: textColor2,
        prefixColor: textColor2,
        optionColorHover: hoverColor,
        optionColorActive: changeColor(primaryColor, {
          alpha: 0.1
        }),
        groupHeaderTextColor: textColor3,
        optionTextColorInverted: "#BBB",
        optionTextColorHoverInverted: "#FFF",
        optionTextColorActiveInverted: "#FFF",
        optionTextColorChildActiveInverted: "#FFF",
        colorInverted: invertedColor,
        dividerColorInverted: "#BBB",
        suffixColorInverted: "#BBB",
        prefixColorInverted: "#BBB",
        optionColorHoverInverted: primaryColor,
        optionColorActiveInverted: primaryColor,
        groupHeaderTextColorInverted: "#AAA",
        optionOpacityDisabled: opacityDisabled
      };
    };
    const dropdownLight = createTheme$1({
      name: "Dropdown",
      common: commonLight,
      peers: {
        Popover: popoverLight$1
      },
      self: self$J
    });
    var dropdownLight$1 = dropdownLight;

    const dropdownDark = {
      name: "Dropdown",
      common: commonDark,
      peers: {
        Popover: popoverDark$1
      },

      self(vars) {
        const {
          primaryColorSuppl,
          primaryColor,
          popoverColor
        } = vars;
        const commonSelf = self$J(vars);
        commonSelf.colorInverted = popoverColor;
        commonSelf.optionColorActive = changeColor(primaryColor, {
          alpha: 0.15
        });
        commonSelf.optionColorActiveInverted = primaryColorSuppl;
        commonSelf.optionColorHoverInverted = primaryColorSuppl;
        return commonSelf;
      }

    };
    var dropdownDark$1 = dropdownDark;

    var NDropdownDivider = vue.defineComponent({
      name: "DropdownDivider",
      props: {
        clsPrefix: {
          type: String,
          required: true
        }
      },
      render() {
        return /* @__PURE__ */ React.createElement("div", {
          class: `${this.clsPrefix}-dropdown-divider`
        });
      }
    });

    const self$I = vars => {
      const {
        textColorBase,
        opacity1,
        opacity2,
        opacity3,
        opacity4,
        opacity5
      } = vars;
      return {
        color: textColorBase,
        opacity1Depth: opacity1,
        opacity2Depth: opacity2,
        opacity3Depth: opacity3,
        opacity4Depth: opacity4,
        opacity5Depth: opacity5
      };
    };
    const iconLight = {
      name: "Icon",
      common: commonLight,
      self: self$I
    };
    var iconLight$1 = iconLight;

    const iconDark$1 = {
      name: "Icon",
      common: commonDark,
      self: self$I
    };
    var iconDark$2 = iconDark$1;

    var style$V = cB("icon", `
  height: 1em;
  width: 1em;
  line-height: 1em;
  text-align: center;
  display: inline-block;
  position: relative;
  fill: currentColor;
  transform: translateZ(0);
`, [cM("color-transition", {
      transition: "color .3s var(--n-bezier)"
    }), cM("depth", {
      color: "var(--n-color)"
    }, [c$1("svg", {
      opacity: "var(--n-opacity)",
      transition: "opacity .3s var(--n-bezier)"
    })]), c$1("svg", {
      height: "1em",
      width: "1em"
    })]);

    const iconProps = { ...useTheme.props,
      depth: [String, Number],
      size: [Number, String],
      color: String,
      component: Object
    };
    const NIcon = vue.defineComponent({
      _n_icon__: true,
      name: "Icon",
      inheritAttrs: false,
      props: iconProps,

      setup(props) {
        const {
          mergedClsPrefixRef,
          inlineThemeDisabled
        } = useConfig(props);
        const themeRef = useTheme("Icon", "-icon", style$V, iconLight$1, props, mergedClsPrefixRef);
        const cssVarsRef = vue.computed(() => {
          const {
            depth
          } = props;
          const {
            common: {
              cubicBezierEaseInOut
            },
            self
          } = themeRef.value;

          if (depth !== void 0) {
            const {
              color,
              [`opacity${depth}Depth`]: opacity
            } = self;
            return {
              "--n-bezier": cubicBezierEaseInOut,
              "--n-color": color,
              "--n-opacity": opacity
            };
          }

          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-color": "",
            "--n-opacity": ""
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("icon", vue.computed(() => `${props.depth || "d"}`), cssVarsRef, props) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          mergedStyle: vue.computed(() => {
            const {
              size,
              color
            } = props;
            return {
              fontSize: formatLength(size),
              color
            };
          }),
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle === null || themeClassHandle === void 0 ? void 0 : themeClassHandle.themeClass,
          onRender: themeClassHandle === null || themeClassHandle === void 0 ? void 0 : themeClassHandle.onRender
        };
      },

      render() {
        var _$parent$$options;

        const {
          $parent,
          depth,
          mergedClsPrefix,
          component,
          onRender,
          themeClass
        } = this;

        if ($parent !== null && $parent !== void 0 && (_$parent$$options = $parent.$options) !== null && _$parent$$options !== void 0 && _$parent$$options._n_icon__) {
          warn$2("icon", "don't wrap `n-icon` inside `n-icon`");
        }

        onRender === null || onRender === void 0 ? void 0 : onRender();
        return vue.h("i", vue.mergeProps(this.$attrs, {
          role: "img",
          class: [`${mergedClsPrefix}-icon`, themeClass, {
            [`${mergedClsPrefix}-icon--depth`]: depth,
            [`${mergedClsPrefix}-icon--color-transition`]: depth !== void 0
          }],
          style: [this.cssVars, this.mergedStyle]
        }), component ? vue.h(component) : this.$slots);
      }

    });

    const dropdownMenuInjectionKey = createInjectionKey("n-dropdown-menu");
    const dropdownInjectionKey = createInjectionKey("n-dropdown");
    const dropdownOptionInjectionKey = createInjectionKey("n-dropdown-option");

    function isSubmenuNode(rawNode, childrenField) {
      return rawNode.type === "submenu" || rawNode.type === void 0 && rawNode[childrenField] !== void 0;
    }
    function isGroupNode(rawNode) {
      return rawNode.type === "group";
    }
    function isDividerNode$1(rawNode) {
      return rawNode.type === "divider";
    }
    function isRenderNode(rawNode) {
      return rawNode.type === "render";
    }

    var NDropdownOption = vue.defineComponent({
      name: "DropdownOption",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        tmNode: {
          type: Object,
          required: true
        },
        parentKey: {
          type: [String, Number],
          default: null
        },
        placement: {
          type: String,
          default: "right-start"
        },
        props: Object,
        scrollable: Boolean
      },
      setup(props) {
        const NDropdown = vue.inject(dropdownInjectionKey);
        const {
          hoverKeyRef,
          keyboardKeyRef,
          lastToggledSubmenuKeyRef,
          pendingKeyPathRef,
          activeKeyPathRef,
          animatedRef,
          mergedShowRef,
          renderLabelRef,
          renderIconRef,
          labelFieldRef,
          childrenFieldRef,
          renderOptionRef,
          nodePropsRef,
          menuPropsRef
        } = NDropdown;
        const NDropdownOption = vue.inject(dropdownOptionInjectionKey, null);
        const NDropdownMenu2 = vue.inject(dropdownMenuInjectionKey);
        const NPopoverBody = vue.inject(popoverBodyInjectionKey);
        const rawNodeRef = vue.computed(() => props.tmNode.rawNode);
        const hasSubmenuRef = vue.computed(() => {
          const { value: childrenField } = childrenFieldRef;
          return isSubmenuNode(props.tmNode.rawNode, childrenField);
        });
        const mergedDisabledRef = vue.computed(() => {
          const { disabled } = props.tmNode;
          return disabled;
        });
        const showSubmenuRef = vue.computed(() => {
          if (!hasSubmenuRef.value)
            return false;
          const { key, disabled } = props.tmNode;
          if (disabled)
            return false;
          const { value: hoverKey } = hoverKeyRef;
          const { value: keyboardKey } = keyboardKeyRef;
          const { value: lastToggledSubmenuKey } = lastToggledSubmenuKeyRef;
          const { value: pendingKeyPath } = pendingKeyPathRef;
          if (hoverKey !== null)
            return pendingKeyPath.includes(key);
          if (keyboardKey !== null) {
            return pendingKeyPath.includes(key) && pendingKeyPath[pendingKeyPath.length - 1] !== key;
          }
          if (lastToggledSubmenuKey !== null)
            return pendingKeyPath.includes(key);
          return false;
        });
        const shouldDelayRef = vue.computed(() => {
          return keyboardKeyRef.value === null && !animatedRef.value;
        });
        const deferredShowSubmenuRef = useDeferredTrue(
          showSubmenuRef,
          300,
          shouldDelayRef
        );
        const parentEnteringSubmenuRef = vue.computed(() => {
          return !!NDropdownOption?.enteringSubmenuRef.value;
        });
        const enteringSubmenuRef = vue.ref(false);
        vue.provide(dropdownOptionInjectionKey, {
          enteringSubmenuRef
        });
        function handleSubmenuBeforeEnter() {
          enteringSubmenuRef.value = true;
        }
        function handleSubmenuAfterEnter() {
          enteringSubmenuRef.value = false;
        }
        function handleMouseEnter() {
          const { parentKey, tmNode } = props;
          if (tmNode.disabled)
            return;
          if (!mergedShowRef.value)
            return;
          lastToggledSubmenuKeyRef.value = parentKey;
          keyboardKeyRef.value = null;
          hoverKeyRef.value = tmNode.key;
        }
        function handleMouseMove() {
          const { tmNode } = props;
          if (tmNode.disabled)
            return;
          if (!mergedShowRef.value)
            return;
          if (hoverKeyRef.value === tmNode.key)
            return;
          handleMouseEnter();
        }
        function handleMouseLeave(e) {
          if (props.tmNode.disabled)
            return;
          if (!mergedShowRef.value)
            return;
          const { relatedTarget } = e;
          if (relatedTarget && !happensIn({ target: relatedTarget }, "dropdownOption") && !happensIn({ target: relatedTarget }, "scrollbarRail")) {
            hoverKeyRef.value = null;
          }
        }
        function handleClick() {
          const { value: hasSubmenu } = hasSubmenuRef;
          const { tmNode } = props;
          if (!mergedShowRef.value)
            return;
          if (!hasSubmenu && !tmNode.disabled) {
            NDropdown.doSelect(
              tmNode.key,
              tmNode.rawNode
            );
            NDropdown.doUpdateShow(false);
          }
        }
        return {
          labelField: labelFieldRef,
          renderLabel: renderLabelRef,
          renderIcon: renderIconRef,
          siblingHasIcon: NDropdownMenu2.showIconRef,
          siblingHasSubmenu: NDropdownMenu2.hasSubmenuRef,
          menuProps: menuPropsRef,
          popoverBody: NPopoverBody,
          animated: animatedRef,
          mergedShowSubmenu: vue.computed(() => {
            return deferredShowSubmenuRef.value && !parentEnteringSubmenuRef.value;
          }),
          rawNode: rawNodeRef,
          hasSubmenu: hasSubmenuRef,
          pending: useMemo(() => {
            const { value: pendingKeyPath } = pendingKeyPathRef;
            const { key } = props.tmNode;
            return pendingKeyPath.includes(key);
          }),
          childActive: useMemo(() => {
            const { value: activeKeyPath } = activeKeyPathRef;
            const { key } = props.tmNode;
            const index = activeKeyPath.findIndex((k) => key === k);
            if (index === -1)
              return false;
            return index < activeKeyPath.length - 1;
          }),
          active: useMemo(() => {
            const { value: activeKeyPath } = activeKeyPathRef;
            const { key } = props.tmNode;
            const index = activeKeyPath.findIndex((k) => key === k);
            if (index === -1)
              return false;
            return index === activeKeyPath.length - 1;
          }),
          mergedDisabled: mergedDisabledRef,
          renderOption: renderOptionRef,
          nodeProps: nodePropsRef,
          handleClick,
          handleMouseMove,
          handleMouseEnter,
          handleMouseLeave,
          handleSubmenuBeforeEnter,
          handleSubmenuAfterEnter
        };
      },
      render() {
        const {
          animated,
          rawNode,
          mergedShowSubmenu,
          clsPrefix,
          siblingHasIcon,
          siblingHasSubmenu,
          renderLabel,
          renderIcon,
          renderOption,
          nodeProps,
          props,
          scrollable
        } = this;
        let submenuVNode = null;
        if (mergedShowSubmenu) {
          const submenuNodeProps = this.menuProps?.(
            rawNode,
            rawNode.children
          );
          submenuVNode = /* @__PURE__ */ React.createElement(NDropdownMenu, {
            ...submenuNodeProps,
            clsPrefix,
            scrollable: this.scrollable,
            tmNodes: this.tmNode.children,
            parentKey: this.tmNode.key
          });
        }
        const builtinProps = {
          class: [
            `${clsPrefix}-dropdown-option-body`,
            this.pending && `${clsPrefix}-dropdown-option-body--pending`,
            this.active && `${clsPrefix}-dropdown-option-body--active`,
            this.childActive && `${clsPrefix}-dropdown-option-body--child-active`,
            this.mergedDisabled && `${clsPrefix}-dropdown-option-body--disabled`
          ],
          onMousemove: this.handleMouseMove,
          onMouseenter: this.handleMouseEnter,
          onMouseleave: this.handleMouseLeave,
          onClick: this.handleClick
        };
        const optionNodeProps = nodeProps?.(rawNode);
        const node = /* @__PURE__ */ React.createElement("div", {
          class: [`${clsPrefix}-dropdown-option`, optionNodeProps?.class],
          "data-dropdown-option": true,
          ...optionNodeProps
        }, vue.h("div", vue.mergeProps(builtinProps, props), [
          /* @__PURE__ */ React.createElement("div", {
            class: [
              `${clsPrefix}-dropdown-option-body__prefix`,
              siblingHasIcon && `${clsPrefix}-dropdown-option-body__prefix--show-icon`
            ]
          }, [renderIcon ? renderIcon(rawNode) : render$1(rawNode.icon)]),
          /* @__PURE__ */ React.createElement("div", {
            "data-dropdown-option": true,
            class: `${clsPrefix}-dropdown-option-body__label`
          }, renderLabel ? renderLabel(rawNode) : render$1(rawNode[this.labelField] ?? rawNode.title)),
          /* @__PURE__ */ React.createElement("div", {
            "data-dropdown-option": true,
            class: [
              `${clsPrefix}-dropdown-option-body__suffix`,
              siblingHasSubmenu && `${clsPrefix}-dropdown-option-body__suffix--has-submenu`
            ]
          }, this.hasSubmenu ? /* @__PURE__ */ React.createElement(NIcon, null, {
            default: () => /* @__PURE__ */ React.createElement(ChevronRightIcon, null)
          }) : null)
        ]), this.hasSubmenu ? /* @__PURE__ */ React.createElement(VBinder, null, {
          default: () => [
            /* @__PURE__ */ React.createElement(VTarget, null, {
              default: () => /* @__PURE__ */ React.createElement("div", {
                class: `${clsPrefix}-dropdown-offset-container`
              }, /* @__PURE__ */ React.createElement(VFollower, {
                show: this.mergedShowSubmenu,
                placement: this.placement,
                to: scrollable ? this.popoverBody || void 0 : void 0,
                teleportDisabled: !scrollable
              }, {
                default: () => {
                  return /* @__PURE__ */ React.createElement("div", {
                    class: `${clsPrefix}-dropdown-menu-wrapper`
                  }, animated ? /* @__PURE__ */ React.createElement(vue.Transition, {
                    onBeforeEnter: this.handleSubmenuBeforeEnter,
                    onAfterEnter: this.handleSubmenuAfterEnter,
                    name: "fade-in-scale-up-transition",
                    appear: true
                  }, {
                    default: () => submenuVNode
                  }) : submenuVNode);
                }
              }))
            })
          ]
        }) : null);
        if (renderOption) {
          return renderOption({ node, option: rawNode });
        }
        return node;
      }
    });

    var NDropdownGroupHeader = vue.defineComponent({
      name: "DropdownGroupHeader",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        tmNode: {
          type: Object,
          required: true
        }
      },
      setup() {
        const {
          showIconRef,
          hasSubmenuRef
        } = vue.inject(dropdownMenuInjectionKey);
        const { renderLabelRef, labelFieldRef, nodePropsRef, renderOptionRef } = vue.inject(dropdownInjectionKey);
        return {
          labelField: labelFieldRef,
          showIcon: showIconRef,
          hasSubmenu: hasSubmenuRef,
          renderLabel: renderLabelRef,
          nodeProps: nodePropsRef,
          renderOption: renderOptionRef
        };
      },
      render() {
        const {
          clsPrefix,
          hasSubmenu,
          showIcon,
          nodeProps,
          renderLabel,
          renderOption
        } = this;
        const { rawNode } = this.tmNode;
        const node = /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-dropdown-option`,
          ...nodeProps?.(rawNode)
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-dropdown-option-body ${clsPrefix}-dropdown-option-body--group`
        }, /* @__PURE__ */ React.createElement("div", {
          "data-dropdown-option": true,
          class: [
            `${clsPrefix}-dropdown-option-body__prefix`,
            showIcon && `${clsPrefix}-dropdown-option-body__prefix--show-icon`
          ]
        }, render$1(rawNode.icon)), /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-dropdown-option-body__label`,
          "data-dropdown-option": true
        }, renderLabel ? renderLabel(rawNode) : render$1(rawNode.title ?? rawNode[this.labelField])), /* @__PURE__ */ React.createElement("div", {
          class: [
            `${clsPrefix}-dropdown-option-body__suffix`,
            hasSubmenu && `${clsPrefix}-dropdown-option-body__suffix--has-submenu`
          ],
          "data-dropdown-option": true
        })));
        if (renderOption) {
          return renderOption({ node, option: rawNode });
        }
        return node;
      }
    });

    var NDropdownGroup = vue.defineComponent({
      name: "NDropdownGroup",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        tmNode: {
          type: Object,
          required: true
        },
        parentKey: {
          type: [String, Number],
          default: null
        }
      },
      render() {
        const { tmNode, parentKey, clsPrefix } = this;
        const { children } = tmNode;
        return /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(NDropdownGroupHeader, {
          clsPrefix,
          tmNode,
          key: tmNode.key
        }), children?.map((child) => {
          if (isDividerNode$1(child.rawNode)) {
            return vue.h(NDropdownDivider, {
              clsPrefix,
              key: child.key
            });
          }
          if (child.isGroup) {
            warn$2(
              "dropdown",
              "`group` node is not allowed to be put in `group` node."
            );
            return null;
          }
          return /* @__PURE__ */ React.createElement(NDropdownOption, {
            clsPrefix,
            tmNode: child,
            parentKey,
            key: child.key
          });
        }));
      }
    });

    var NDropdownRenderOption = vue.defineComponent({
      name: "DropdownRenderOption",
      props: {
        tmNode: {
          type: Object,
          required: true
        }
      },
      render() {
        const {
          rawNode: { render, props }
        } = this.tmNode;
        return vue.h("div", props, [render?.()]);
      }
    });

    var NDropdownMenu = vue.defineComponent({
      name: "DropdownMenu",
      props: {
        scrollable: Boolean,
        showArrow: Boolean,
        arrowStyle: [String, Object],
        clsPrefix: {
          type: String,
          required: true
        },
        tmNodes: {
          type: Array,
          default: () => []
        },
        parentKey: {
          type: [String, Number],
          default: null
        }
      },
      setup(props) {
        const { renderIconRef, childrenFieldRef } = vue.inject(dropdownInjectionKey);
        vue.provide(dropdownMenuInjectionKey, {
          showIconRef: vue.computed(() => {
            const renderIcon = renderIconRef.value;
            return props.tmNodes.some((tmNode) => {
              if (tmNode.isGroup) {
                return tmNode.children?.some(
                  ({ rawNode: rawChild }) => renderIcon ? renderIcon(rawChild) : rawChild.icon
                );
              }
              const { rawNode } = tmNode;
              return renderIcon ? renderIcon(rawNode) : rawNode.icon;
            });
          }),
          hasSubmenuRef: vue.computed(() => {
            const { value: childrenField } = childrenFieldRef;
            return props.tmNodes.some((tmNode) => {
              if (tmNode.isGroup) {
                return tmNode.children?.some(
                  ({ rawNode: rawChild }) => isSubmenuNode(rawChild, childrenField)
                );
              }
              const { rawNode } = tmNode;
              return isSubmenuNode(rawNode, childrenField);
            });
          })
        });
        const bodyRef = vue.ref(null);
        vue.provide(modalBodyInjectionKey, null);
        vue.provide(drawerBodyInjectionKey, null);
        vue.provide(popoverBodyInjectionKey, bodyRef);
        return {
          bodyRef
        };
      },
      render() {
        const { parentKey, clsPrefix, scrollable } = this;
        const menuOptionsNode = this.tmNodes.map((tmNode) => {
          const { rawNode } = tmNode;
          if (isRenderNode(rawNode)) {
            return /* @__PURE__ */ React.createElement(NDropdownRenderOption, {
              tmNode,
              key: tmNode.key
            });
          }
          if (isDividerNode$1(rawNode)) {
            return /* @__PURE__ */ React.createElement(NDropdownDivider, {
              clsPrefix,
              key: tmNode.key
            });
          }
          if (isGroupNode(rawNode)) {
            return /* @__PURE__ */ React.createElement(NDropdownGroup, {
              clsPrefix,
              tmNode,
              parentKey,
              key: tmNode.key
            });
          }
          return /* @__PURE__ */ React.createElement(NDropdownOption, {
            clsPrefix,
            tmNode,
            parentKey,
            key: tmNode.key,
            props: rawNode.props,
            scrollable
          });
        });
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${clsPrefix}-dropdown-menu`,
            scrollable && `${clsPrefix}-dropdown-menu--scrollable`
          ],
          ref: "bodyRef"
        }, scrollable ? /* @__PURE__ */ React.createElement(XScrollbar, {
          contentClass: `${clsPrefix}-dropdown-menu__content`
        }, {
          default: () => menuOptionsNode
        }) : menuOptionsNode, this.showArrow ? renderArrow({
          clsPrefix,
          arrowStyle: this.arrowStyle
        }) : null);
      }
    });

    var style$U = cB("dropdown-menu", `
  transform-origin: var(--v-transform-origin);
  background-color: var(--n-color);
  border-radius: var(--n-border-radius);
  box-shadow: var(--n-box-shadow);
  position: relative;
  transition:
    background-color .3s var(--n-bezier),
    box-shadow .3s var(--n-bezier);
`, [fadeInScaleUpTransition(), cB("dropdown-option", `
    position: relative;
  `, [c$1("a", `
      text-decoration: none;
      color: inherit;
      outline: none;
    `, [c$1("&::before", `
        content: "";
        position: absolute;
        left: 0;
        right: 0;
        top: 0;
        bottom: 0;
      `)]), cB("dropdown-option-body", `
      display: flex;
      cursor: pointer;
      position: relative;
      height: var(--n-option-height);
      line-height: var(--n-option-height);
      font-size: var(--n-font-size);
      color: var(--n-option-text-color);
      transition: color .3s var(--n-bezier);
    `, [c$1("&::before", `
        content: "";
        position: absolute;
        top: 0;
        bottom: 0;
        left: 4px;
        right: 4px;
        transition: background-color .3s var(--n-bezier);
        border-radius: var(--n-border-radius);
      `), cNotM("disabled", [cM("pending", `
          color: var(--n-option-text-color-hover);
        `, [cE("prefix, suffix", `
            color: var(--n-option-text-color-hover);
          `), c$1("&::before", "background-color: var(--n-option-color-hover);")]), cM("active", `
          color: var(--n-option-text-color-active);
        `, [cE("prefix, suffix", `
            color: var(--n-option-text-color-active);
          `), c$1("&::before", "background-color: var(--n-option-color-active);")]), cM("child-active", `
          color: var(--n-option-text-color-child-active);
        `, [cE("prefix, suffix", `
            color: var(--n-option-text-color-child-active);
          `)])]), cM("disabled", `
        cursor: not-allowed;
        opacity: var(--n-option-opacity-disabled);
      `), cM("group", `
        font-size: calc(var(--n-font-size) - 1px);
        color: var(--n-group-header-text-color);
      `, [cE("prefix", `
          width: calc(var(--n-option-prefix-width) / 2);
        `, [cM("show-icon", `
            width: calc(var(--n-option-icon-prefix-width) / 2);
          `)])]), cE("prefix", `
        width: var(--n-option-prefix-width);
        display: flex;
        justify-content: center;
        align-items: center;
        color: var(--n-prefix-color);
        transition: color .3s var(--n-bezier);
        z-index: 1;
      `, [cM("show-icon", `
          width: var(--n-option-icon-prefix-width);
        `), cB("icon", `
          font-size: var(--n-option-icon-size);
        `)]), cE("label", `
        white-space: nowrap;
        flex: 1;
        z-index: 1;
      `), cE("suffix", `
        box-sizing: border-box;
        flex-grow: 0;
        flex-shrink: 0;
        display: flex;
        justify-content: flex-end;
        align-items: center;
        min-width: var(--n-option-suffix-width);
        padding: 0 8px;
        transition: color .3s var(--n-bezier);
        color: var(--n-suffix-color);
        z-index: 1;
      `, [cM("has-submenu", `
          width: var(--n-option-icon-suffix-width);
        `), cB("icon", `
          font-size: var(--n-option-icon-size);
        `)]), cB("dropdown-menu", "pointer-events: all;")]), cB("dropdown-offset-container", `
      pointer-events: none;
      position: absolute;
      left: 0;
      right: 0;
      top: -4px;
      bottom: -4px;
    `)]), cB("dropdown-divider", `
    transition: background-color .3s var(--n-bezier);
    background-color: var(--n-divider-color);
    height: 1px;
    margin: 4px 0;
  `), cB("dropdown-menu-wrapper", `
    transform-origin: var(--v-transform-origin);
    width: fit-content;
  `), c$1(">", [cB("scrollbar", `
      height: inherit;
      max-height: inherit;
    `)]), cNotM("scrollable", `
    padding: var(--n-padding);
  `), cM("scrollable", [cE("content", `
      padding: var(--n-padding);
    `)])]);

    const dropdownBaseProps = {
      animated: {
        type: Boolean,
        default: true
      },
      keyboard: {
        type: Boolean,
        default: true
      },
      size: {
        type: String,
        default: "medium"
      },
      inverted: Boolean,
      placement: {
        type: String,
        default: "bottom"
      },
      onSelect: [Function, Array],
      options: {
        type: Array,
        default: () => []
      },
      menuProps: Function,
      showArrow: Boolean,
      renderLabel: Function,
      renderIcon: Function,
      renderOption: Function,
      nodeProps: Function,
      labelField: {
        type: String,
        default: "label"
      },
      keyField: {
        type: String,
        default: "key"
      },
      childrenField: {
        type: String,
        default: "children"
      },
      value: [String, Number]
    };
    const popoverPropKeys = Object.keys(popoverBaseProps);
    const dropdownProps = {
      ...popoverBaseProps,
      ...dropdownBaseProps,
      ...useTheme.props
    };
    var NDropdown = vue.defineComponent({
      name: "Dropdown",
      inheritAttrs: false,
      props: dropdownProps,
      setup(props) {
        const uncontrolledShowRef = vue.ref(false);
        const mergedShowRef = useMergedState(
          vue.toRef(props, "show"),
          uncontrolledShowRef
        );
        const treemateRef = vue.computed(() => {
          const { keyField, childrenField } = props;
          return createTreeMate(props.options, {
            getKey(node) {
              return node[keyField];
            },
            getDisabled(node) {
              return node.disabled === true;
            },
            getIgnored(node) {
              return node.type === "divider" || node.type === "render";
            },
            getChildren(node) {
              return node[childrenField];
            }
          });
        });
        const tmNodesRef = vue.computed(() => {
          return treemateRef.value.treeNodes;
        });
        const hoverKeyRef = vue.ref(null);
        const keyboardKeyRef = vue.ref(null);
        const lastToggledSubmenuKeyRef = vue.ref(null);
        const pendingKeyRef = vue.computed(() => {
          return hoverKeyRef.value ?? keyboardKeyRef.value ?? lastToggledSubmenuKeyRef.value ?? null;
        });
        const pendingKeyPathRef = vue.computed(
          () => treemateRef.value.getPath(pendingKeyRef.value).keyPath
        );
        const activeKeyPathRef = vue.computed(
          () => treemateRef.value.getPath(props.value).keyPath
        );
        const keyboardEnabledRef = useMemo(() => {
          return props.keyboard && mergedShowRef.value;
        });
        useKeyboard$1(
          {
            keydown: {
              ArrowUp: {
                prevent: true,
                handler: handleKeyDownUp
              },
              ArrowRight: {
                prevent: true,
                handler: handleKeyDownRight
              },
              ArrowDown: {
                prevent: true,
                handler: handleKeyDownDown
              },
              ArrowLeft: {
                prevent: true,
                handler: handleKeyDownLeft
              },
              Escape: handleKeyDownEsc
            },
            keyup: {
              Enter: handleKeyUpEnter
            }
          },
          keyboardEnabledRef
        );
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Dropdown",
          "-dropdown",
          style$U,
          dropdownLight$1,
          props,
          mergedClsPrefixRef
        );
        vue.provide(dropdownInjectionKey, {
          labelFieldRef: vue.toRef(props, "labelField"),
          childrenFieldRef: vue.toRef(props, "childrenField"),
          renderLabelRef: vue.toRef(props, "renderLabel"),
          renderIconRef: vue.toRef(props, "renderIcon"),
          hoverKeyRef,
          keyboardKeyRef,
          lastToggledSubmenuKeyRef,
          pendingKeyPathRef,
          activeKeyPathRef,
          animatedRef: vue.toRef(props, "animated"),
          mergedShowRef,
          nodePropsRef: vue.toRef(props, "nodeProps"),
          renderOptionRef: vue.toRef(props, "renderOption"),
          menuPropsRef: vue.toRef(props, "menuProps"),
          doSelect,
          doUpdateShow
        });
        vue.watch(mergedShowRef, (value) => {
          if (!props.animated && !value) {
            clearPendingState();
          }
        });
        function doSelect(key, node) {
          const { onSelect } = props;
          if (onSelect)
            call(onSelect, key, node);
        }
        function doUpdateShow(value) {
          const { "onUpdate:show": _onUpdateShow, onUpdateShow } = props;
          if (_onUpdateShow)
            call(_onUpdateShow, value);
          if (onUpdateShow)
            call(onUpdateShow, value);
          uncontrolledShowRef.value = value;
        }
        function clearPendingState() {
          hoverKeyRef.value = null;
          keyboardKeyRef.value = null;
          lastToggledSubmenuKeyRef.value = null;
        }
        function handleKeyDownEsc() {
          doUpdateShow(false);
        }
        function handleKeyDownLeft() {
          handleKeyDown("left");
        }
        function handleKeyDownRight() {
          handleKeyDown("right");
        }
        function handleKeyDownUp() {
          handleKeyDown("up");
        }
        function handleKeyDownDown() {
          handleKeyDown("down");
        }
        function handleKeyUpEnter() {
          const pendingNode = getPendingNode();
          if (pendingNode?.isLeaf) {
            doSelect(pendingNode.key, pendingNode.rawNode);
            doUpdateShow(false);
          }
        }
        function getPendingNode() {
          const { value: treeMate } = treemateRef;
          const { value: pendingKey } = pendingKeyRef;
          if (!treeMate || pendingKey === null)
            return null;
          return treeMate.getNode(pendingKey) ?? null;
        }
        function handleKeyDown(direction) {
          const { value: pendingKey } = pendingKeyRef;
          const {
            value: { getFirstAvailableNode }
          } = treemateRef;
          let nextKeyboardKey = null;
          if (pendingKey === null) {
            const firstNode = getFirstAvailableNode();
            if (firstNode !== null) {
              nextKeyboardKey = firstNode.key;
            }
          } else {
            const currentNode = getPendingNode();
            if (currentNode) {
              let nextNode;
              switch (direction) {
                case "down":
                  nextNode = currentNode.getNext();
                  break;
                case "up":
                  nextNode = currentNode.getPrev();
                  break;
                case "right":
                  nextNode = currentNode.getChild();
                  break;
                case "left":
                  nextNode = currentNode.getParent();
                  break;
              }
              if (nextNode)
                nextKeyboardKey = nextNode.key;
            }
          }
          if (nextKeyboardKey !== null) {
            hoverKeyRef.value = null;
            keyboardKeyRef.value = nextKeyboardKey;
          }
        }
        const cssVarsRef = vue.computed(() => {
          const { size, inverted } = props;
          const {
            common: { cubicBezierEaseInOut },
            self
          } = themeRef.value;
          const {
            padding,
            dividerColor,
            borderRadius,
            optionOpacityDisabled,
            [createKey("optionIconSuffixWidth", size)]: optionIconSuffixWidth,
            [createKey("optionSuffixWidth", size)]: optionSuffixWidth,
            [createKey("optionIconPrefixWidth", size)]: optionIconPrefixWidth,
            [createKey("optionPrefixWidth", size)]: optionPrefixWidth,
            [createKey("fontSize", size)]: fontSize,
            [createKey("optionHeight", size)]: optionHeight,
            [createKey("optionIconSize", size)]: optionIconSize
          } = self;
          const vars = {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-font-size": fontSize,
            "--n-padding": padding,
            "--n-border-radius": borderRadius,
            "--n-option-height": optionHeight,
            "--n-option-prefix-width": optionPrefixWidth,
            "--n-option-icon-prefix-width": optionIconPrefixWidth,
            "--n-option-suffix-width": optionSuffixWidth,
            "--n-option-icon-suffix-width": optionIconSuffixWidth,
            "--n-option-icon-size": optionIconSize,
            "--n-divider-color": dividerColor,
            "--n-option-opacity-disabled": optionOpacityDisabled
          };
          if (inverted) {
            vars["--n-color"] = self.colorInverted;
            vars["--n-option-color-hover"] = self.optionColorHoverInverted;
            vars["--n-option-color-active"] = self.optionColorActiveInverted;
            vars["--n-option-text-color"] = self.optionTextColorInverted;
            vars["--n-option-text-color-hover"] = self.optionTextColorHoverInverted;
            vars["--n-option-text-color-active"] = self.optionTextColorActiveInverted;
            vars["--n-option-text-color-child-active"] = self.optionTextColorChildActiveInverted;
            vars["--n-prefix-color"] = self.prefixColorInverted;
            vars["--n-suffix-color"] = self.suffixColorInverted;
            vars["--n-group-header-text-color"] = self.groupHeaderTextColorInverted;
          } else {
            vars["--n-color"] = self.color;
            vars["--n-option-color-hover"] = self.optionColorHover;
            vars["--n-option-color-active"] = self.optionColorActive;
            vars["--n-option-text-color"] = self.optionTextColor;
            vars["--n-option-text-color-hover"] = self.optionTextColorHover;
            vars["--n-option-text-color-active"] = self.optionTextColorActive;
            vars["--n-option-text-color-child-active"] = self.optionTextColorChildActive;
            vars["--n-prefix-color"] = self.prefixColor;
            vars["--n-suffix-color"] = self.suffixColor;
            vars["--n-group-header-text-color"] = self.groupHeaderTextColor;
          }
          return vars;
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "dropdown",
          vue.computed(() => `${props.size[0]}${props.inverted ? "i" : ""}`),
          cssVarsRef,
          props
        ) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          mergedTheme: themeRef,
          tmNodes: tmNodesRef,
          mergedShow: mergedShowRef,
          handleAfterLeave: () => {
            if (!props.animated)
              return;
            clearPendingState();
          },
          doUpdateShow,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const renderPopoverBody = (className, ref2, style2, onMouseenter, onMouseleave) => {
          const { mergedClsPrefix, menuProps } = this;
          this.onRender?.();
          const menuNodeProps = menuProps?.(
            void 0,
            this.tmNodes.map((v) => v.rawNode)
          ) || {};
          const dropdownProps2 = {
            ref: createRefSetter(ref2),
            class: [className, `${mergedClsPrefix}-dropdown`, this.themeClass],
            clsPrefix: mergedClsPrefix,
            tmNodes: this.tmNodes,
            style: [style2, this.cssVars],
            showArrow: this.showArrow,
            arrowStyle: this.arrowStyle,
            scrollable: this.scrollable,
            onMouseenter,
            onMouseleave
          };
          return vue.h(
            NDropdownMenu,
            vue.mergeProps(
              this.$attrs,
              dropdownProps2,
              menuNodeProps
            )
          );
        };
        const { mergedTheme } = this;
        const popoverProps = {
          show: this.mergedShow,
          theme: mergedTheme.peers.Popover,
          themeOverrides: mergedTheme.peerOverrides.Popover,
          internalOnAfterLeave: this.handleAfterLeave,
          internalRenderBody: renderPopoverBody,
          onUpdateShow: this.doUpdateShow,
          "onUpdate:show": void 0
        };
        return /* @__PURE__ */ React.createElement(NPopover, {
          ...keep(this.$props, popoverPropKeys),
          ...popoverProps
        }, {
          trigger: () => this.$slots.default?.()
        });
      }
    });

    const allKey = "_n_all__";
    const noneKey = "_n_none__";
    function createSelectHandler(options, rawPaginatedDataRef, doCheckAll, doUncheckAll) {
      if (!options)
        return () => {
        };
      return (key) => {
        for (const option of options) {
          switch (key) {
            case allKey:
              doCheckAll(true);
              return;
            case noneKey:
              doUncheckAll(true);
              return;
            default:
              if (typeof option === "object" && option.key === key) {
                option.onSelect(rawPaginatedDataRef.value);
                return;
              }
          }
        }
      };
    }
    function createDropdownOptions(options, localeRef) {
      if (!options)
        return [];
      return options.map((option) => {
        switch (option) {
          case "all":
            return {
              label: localeRef.checkTableAll,
              key: allKey
            };
          case "none":
            return {
              label: localeRef.uncheckTableAll,
              key: noneKey
            };
          default:
            return option;
        }
      });
    }
    var SelectionMenu = vue.defineComponent({
      name: "DataTableSelectionMenu",
      props: {
        clsPrefix: {
          type: String,
          required: true
        }
      },
      setup() {
        const {
          localeRef,
          checkOptionsRef,
          rawPaginatedDataRef,
          doCheckAll,
          doUncheckAll
        } = vue.inject(dataTableInjectionKey);
        return {
          handleSelect: vue.computed(
            () => createSelectHandler(
              checkOptionsRef.value,
              rawPaginatedDataRef,
              doCheckAll,
              doUncheckAll
            )
          ),
          options: vue.computed(
            () => createDropdownOptions(checkOptionsRef.value, localeRef.value)
          )
        };
      },
      render() {
        const { clsPrefix } = this;
        return /* @__PURE__ */ React.createElement(NDropdown, {
          options: this.options,
          onSelect: this.handleSelect
        }, {
          default: () => /* @__PURE__ */ React.createElement(NBaseIcon, {
            clsPrefix,
            class: `${clsPrefix}-data-table-check-extra`
          }, {
            default: () => /* @__PURE__ */ React.createElement(ChevronDownIcon, null)
          })
        });
      }
    });

    function renderTitle(column) {
      return typeof column.title === "function" ? column.title(column) : column.title;
    }
    var TableHeader = vue.defineComponent({
      name: "DataTableHeader",
      props: {
        discrete: {
          type: Boolean,
          default: true
        }
      },
      setup() {
        const {
          mergedClsPrefixRef,
          scrollXRef,
          fixedColumnLeftMapRef,
          fixedColumnRightMapRef,
          mergedCurrentPageRef,
          allRowsCheckedRef,
          someRowsCheckedRef,
          rowsRef,
          colsRef,
          mergedThemeRef,
          checkOptionsRef,
          mergedSortStateRef,
          componentId,
          scrollPartRef,
          mergedTableLayoutRef,
          headerCheckboxDisabledRef,
          handleTableHeaderScroll,
          deriveNextSorter,
          doUncheckAll,
          doCheckAll
        } = vue.inject(dataTableInjectionKey);
        function handleCheckboxUpdateChecked() {
          if (allRowsCheckedRef.value) {
            doUncheckAll();
          } else {
            doCheckAll();
          }
        }
        function handleColHeaderClick(e, column) {
          if (happensIn(e, "dataTableFilter"))
            return;
          if (!isColumnSortable(column))
            return;
          const activeSorter = mergedSortStateRef.value.find(
            (state) => state.columnKey === column.key
          ) || null;
          const nextSorter = createNextSorter(column, activeSorter);
          deriveNextSorter(nextSorter);
        }
        function handleMouseenter() {
          scrollPartRef.value = "head";
        }
        function handleMouseleave() {
          scrollPartRef.value = "body";
        }
        return {
          componentId,
          mergedSortState: mergedSortStateRef,
          mergedClsPrefix: mergedClsPrefixRef,
          scrollX: scrollXRef,
          fixedColumnLeftMap: fixedColumnLeftMapRef,
          fixedColumnRightMap: fixedColumnRightMapRef,
          currentPage: mergedCurrentPageRef,
          allRowsChecked: allRowsCheckedRef,
          someRowsChecked: someRowsCheckedRef,
          rows: rowsRef,
          cols: colsRef,
          mergedTheme: mergedThemeRef,
          checkOptions: checkOptionsRef,
          mergedTableLayout: mergedTableLayoutRef,
          headerCheckboxDisabled: headerCheckboxDisabledRef,
          handleMouseenter,
          handleMouseleave,
          handleCheckboxUpdateChecked,
          handleColHeaderClick,
          handleTableHeaderScroll
        };
      },
      render() {
        const {
          mergedClsPrefix,
          fixedColumnLeftMap,
          fixedColumnRightMap,
          currentPage,
          allRowsChecked,
          someRowsChecked,
          rows,
          cols,
          mergedTheme,
          checkOptions,
          componentId,
          discrete,
          mergedTableLayout,
          headerCheckboxDisabled,
          mergedSortState,
          handleColHeaderClick,
          handleCheckboxUpdateChecked
        } = this;
        const theadVNode = /* @__PURE__ */ React.createElement("thead", {
          class: `${mergedClsPrefix}-data-table-thead`,
          "data-n-id": componentId
        }, rows.map((row) => {
          return /* @__PURE__ */ React.createElement("tr", {
            class: `${mergedClsPrefix}-data-table-tr`
          }, row.map(({ column, colSpan, rowSpan, isLast }) => {
            const key = getColKey(column);
            const { ellipsis } = column;
            const leftFixed = key in fixedColumnLeftMap;
            const rightFixed = key in fixedColumnRightMap;
            return /* @__PURE__ */ React.createElement("th", {
              key,
              style: {
                textAlign: column.align,
                left: pxfy(fixedColumnLeftMap[key]?.start),
                right: pxfy(fixedColumnRightMap[key]?.start)
              },
              colspan: colSpan,
              rowspan: rowSpan,
              "data-col-key": key,
              class: [
                `${mergedClsPrefix}-data-table-th`,
                (leftFixed || rightFixed) && `${mergedClsPrefix}-data-table-th--fixed-${leftFixed ? "left" : "right"}`,
                {
                  [`${mergedClsPrefix}-data-table-th--hover`]: isColumnSorting(column, mergedSortState),
                  [`${mergedClsPrefix}-data-table-th--filterable`]: isColumnFilterable(column),
                  [`${mergedClsPrefix}-data-table-th--sortable`]: isColumnSortable(column),
                  [`${mergedClsPrefix}-data-table-th--selection`]: column.type === "selection",
                  [`${mergedClsPrefix}-data-table-th--last`]: isLast
                },
                column.className
              ],
              onClick: column.type !== "selection" && column.type !== "expand" && !("children" in column) ? (e) => {
                handleColHeaderClick(e, column);
              } : void 0
            }, column.type === "selection" ? column.multiple !== false ? /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(NCheckbox, {
              key: currentPage,
              privateInsideTable: true,
              checked: allRowsChecked,
              indeterminate: someRowsChecked,
              disabled: headerCheckboxDisabled,
              onUpdateChecked: handleCheckboxUpdateChecked
            }), checkOptions ? /* @__PURE__ */ React.createElement(SelectionMenu, {
              clsPrefix: mergedClsPrefix
            }) : null) : null : ellipsis === true || ellipsis && !ellipsis.tooltip ? /* @__PURE__ */ React.createElement("div", {
              class: `${mergedClsPrefix}-data-table-th__ellipsis`
            }, renderTitle(column)) : ellipsis && typeof ellipsis === "object" ? /* @__PURE__ */ React.createElement(NEllipsis, {
              ...ellipsis,
              theme: mergedTheme.peers.Ellipsis,
              themeOverrides: mergedTheme.peerOverrides.Ellipsis
            }, {
              default: () => renderTitle(column)
            }) : renderTitle(column), isColumnSortable(column) ? /* @__PURE__ */ React.createElement(SortButton, {
              column
            }) : null, isColumnFilterable(column) ? /* @__PURE__ */ React.createElement(FilterButton, {
              column,
              options: column.filterOptions
            }) : null);
          }));
        }));
        if (!discrete) {
          return theadVNode;
        }
        const {
          handleTableHeaderScroll,
          handleMouseenter,
          handleMouseleave,
          scrollX
        } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-data-table-base-table-header`,
          onScroll: handleTableHeaderScroll,
          onMouseenter: handleMouseenter,
          onMouseleave: handleMouseleave
        }, /* @__PURE__ */ React.createElement("table", {
          ref: "body",
          class: `${mergedClsPrefix}-data-table-table`,
          style: {
            minWidth: formatLength(scrollX),
            tableLayout: mergedTableLayout
          }
        }, /* @__PURE__ */ React.createElement("colgroup", null, cols.map((col) => /* @__PURE__ */ React.createElement("col", {
          key: col.key,
          style: col.style
        }))), theadVNode));
      }
    });

    var Cell = vue.defineComponent({
      name: "DataTableCell",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        row: {
          type: Object,
          required: true
        },
        index: {
          type: Number,
          required: true
        },
        column: {
          type: Object,
          required: true
        },
        isSummary: Boolean,
        mergedTheme: {
          type: Object,
          required: true
        },
        renderCell: Function
      },
      render() {
        const { isSummary, column, row, renderCell } = this;
        let cell;
        const { render, key, ellipsis } = column;
        if (render && !isSummary) {
          cell = render(row, this.index);
        } else {
          if (isSummary) {
            cell = row[key].value;
          } else {
            cell = renderCell ? renderCell(lodash.exports.get(row, key), row, column) : lodash.exports.get(row, key);
          }
        }
        if (ellipsis) {
          if (typeof ellipsis === "object") {
            const { mergedTheme } = this;
            return /* @__PURE__ */ React.createElement(NEllipsis, {
              ...ellipsis,
              theme: mergedTheme.peers.Ellipsis,
              themeOverrides: mergedTheme.peerOverrides.Ellipsis
            }, { default: () => cell });
          } else {
            return /* @__PURE__ */ React.createElement("span", {
              class: `${this.clsPrefix}-data-table-td__ellipsis`
            }, cell);
          }
        }
        return cell;
      }
    });

    var ExpandTrigger = vue.defineComponent({
      name: "DataTableExpandTrigger",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        expanded: Boolean,
        loading: Boolean,
        onClick: {
          type: Function,
          required: true
        },
        renderExpandIcon: {
          type: Function
        }
      },
      render() {
        const { clsPrefix } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${clsPrefix}-data-table-expand-trigger`,
            this.expanded && `${clsPrefix}-data-table-expand-trigger--expanded`
          ],
          onClick: this.onClick
        }, /* @__PURE__ */ React.createElement(NIconSwitchTransition, null, {
          default: () => {
            return this.loading ? /* @__PURE__ */ React.createElement(NBaseLoading, {
              key: "loading",
              clsPrefix: this.clsPrefix,
              radius: 85,
              strokeWidth: 15,
              scale: 0.88
            }) : this.renderExpandIcon ? this.renderExpandIcon() : /* @__PURE__ */ React.createElement(NBaseIcon, {
              clsPrefix,
              key: "base-icon"
            }, {
              default: () => /* @__PURE__ */ React.createElement(ChevronRightIcon, null)
            });
          }
        }));
      }
    });

    var RenderSafeCheckbox = vue.defineComponent({
      name: "DataTableBodyCheckbox",
      props: {
        rowKey: {
          type: [String, Number],
          required: true
        },
        disabled: {
          type: Boolean,
          required: true
        },
        onUpdateChecked: {
          type: Function,
          required: true
        }
      },
      setup(props) {
        const {
          mergedCheckedRowKeySetRef,
          mergedInderminateRowKeySetRef
        } = vue.inject(dataTableInjectionKey);
        return () => {
          const { rowKey } = props;
          return /* @__PURE__ */ React.createElement(NCheckbox, {
            privateInsideTable: true,
            disabled: props.disabled,
            indeterminate: mergedInderminateRowKeySetRef.value.has(rowKey),
            checked: mergedCheckedRowKeySetRef.value.has(rowKey),
            onUpdateChecked: props.onUpdateChecked
          });
        };
      }
    });

    var RenderSafeRadio = vue.defineComponent({
      name: "DataTableBodyRadio",
      props: {
        rowKey: {
          type: [String, Number],
          required: true
        },
        disabled: {
          type: Boolean,
          required: true
        },
        onUpdateChecked: {
          type: Function,
          required: true
        }
      },
      setup(props) {
        const {
          mergedCheckedRowKeySetRef,
          componentId
        } = vue.inject(dataTableInjectionKey);
        return () => {
          const { rowKey } = props;
          return /* @__PURE__ */ React.createElement(NRadio, {
            name: componentId,
            disabled: props.disabled,
            checked: mergedCheckedRowKeySetRef.value.has(rowKey),
            onUpdateChecked: props.onUpdateChecked
          });
        };
      }
    });

    function flatten(rowInfos, expandedRowKeys) {
      const fRows = [];
      function traverse(rs, rootIndex) {
        rs.forEach((r) => {
          if (r.children && expandedRowKeys.has(r.key)) {
            fRows.push({
              tmNode: r,
              striped: false,
              key: r.key,
              index: rootIndex
            });
            traverse(r.children, rootIndex);
          } else {
            fRows.push({
              key: r.key,
              tmNode: r,
              striped: false,
              index: rootIndex
            });
          }
        });
      }
      rowInfos.forEach((rowInfo) => {
        fRows.push(rowInfo);
        const { children } = rowInfo.tmNode;
        if (children && expandedRowKeys.has(rowInfo.key)) {
          traverse(children, rowInfo.index);
        }
      });
      return fRows;
    }
    const VirtualListItemWrapper = vue.defineComponent({
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        id: {
          type: String,
          required: true
        },
        cols: {
          type: Array,
          required: true
        },
        onMouseenter: Function,
        onMouseleave: Function
      },
      render() {
        const { clsPrefix, id, cols, onMouseenter, onMouseleave } = this;
        return /* @__PURE__ */ React.createElement("table", {
          style: { tableLayout: "fixed" },
          class: `${clsPrefix}-data-table-table`,
          onMouseenter,
          onMouseleave
        }, /* @__PURE__ */ React.createElement("colgroup", null, cols.map((col) => /* @__PURE__ */ React.createElement("col", {
          key: col.key,
          style: col.style
        }))), /* @__PURE__ */ React.createElement("tbody", {
          "data-n-id": id,
          class: `${clsPrefix}-data-table-tbody`
        }, this.$slots));
      }
    });
    var TableBody = vue.defineComponent({
      name: "DataTableBody",
      props: {
        onResize: Function,
        showHeader: Boolean,
        flexHeight: Boolean,
        bodyStyle: Object
      },
      setup(props) {
        const {
          slots: dataTableSlots,
          bodyWidthRef,
          mergedExpandedRowKeysRef,
          mergedClsPrefixRef,
          mergedThemeRef,
          scrollXRef,
          colsRef,
          paginatedDataRef,
          rawPaginatedDataRef,
          fixedColumnLeftMapRef,
          fixedColumnRightMapRef,
          mergedCurrentPageRef,
          rowClassNameRef,
          leftActiveFixedColKeyRef,
          leftActiveFixedChildrenColKeysRef,
          rightActiveFixedColKeyRef,
          rightActiveFixedChildrenColKeysRef,
          renderExpandRef,
          hoverKeyRef,
          summaryRef,
          mergedSortStateRef,
          virtualScrollRef,
          componentId,
          scrollPartRef,
          mergedTableLayoutRef,
          childTriggerColIndexRef,
          indentRef,
          rowPropsRef,
          maxHeightRef,
          stripedRef,
          loadingRef,
          onLoadRef,
          loadingKeySetRef,
          expandableRef,
          stickyExpandedRowsRef,
          renderExpandIconRef,
          setHeaderScrollLeft,
          doUpdateExpandedRowKeys,
          handleTableBodyScroll,
          doCheck,
          doUncheck,
          renderCell
        } = vue.inject(dataTableInjectionKey);
        const scrollbarInstRef = vue.ref(null);
        const virtualListRef = vue.ref(null);
        const emptyElRef = vue.ref(null);
        const emptyRef = useMemo(() => paginatedDataRef.value.length === 0);
        const shouldDisplaySomeTablePartRef = useMemo(
          () => props.showHeader || !emptyRef.value
        );
        const bodyShowHeaderOnlyRef = useMemo(() => {
          return props.showHeader || emptyRef.value;
        });
        let lastSelectedKey = "";
        const mergedExpandedRowKeySetRef = vue.computed(() => {
          return new Set(mergedExpandedRowKeysRef.value);
        });
        function handleCheckboxUpdateChecked(tmNode, checked, shiftKey) {
          if (shiftKey) {
            const lastIndex = paginatedDataRef.value.findIndex(
              (item) => item.key === lastSelectedKey
            );
            if (lastIndex !== -1) {
              const currentIndex = paginatedDataRef.value.findIndex(
                (item) => item.key === tmNode.key
              );
              const start = Math.min(lastIndex, currentIndex);
              const end = Math.max(lastIndex, currentIndex);
              const rowKeysToCheck = [];
              paginatedDataRef.value.slice(start, end + 1).forEach((r) => {
                if (!r.disabled) {
                  rowKeysToCheck.push(r.key);
                }
              });
              if (checked) {
                doCheck(rowKeysToCheck, false);
              } else {
                doUncheck(rowKeysToCheck);
              }
              lastSelectedKey = tmNode.key;
              return;
            }
          }
          if (checked) {
            doCheck(tmNode.key, false);
          } else {
            doUncheck(tmNode.key);
          }
          lastSelectedKey = tmNode.key;
        }
        function handleRadioUpdateChecked(tmNode) {
          doCheck(tmNode.key, true);
        }
        function getScrollContainer() {
          if (!shouldDisplaySomeTablePartRef.value) {
            const { value: emptyEl } = emptyElRef;
            if (emptyEl) {
              return emptyEl;
            } else {
              return null;
            }
          }
          if (virtualScrollRef.value) {
            return virtualListContainer();
          }
          const { value } = scrollbarInstRef;
          if (value)
            return value.containerRef;
          return null;
        }
        function handleUpdateExpanded(key, tmNode) {
          if (loadingKeySetRef.value.has(key))
            return;
          const { value: mergedExpandedRowKeys } = mergedExpandedRowKeysRef;
          const index = mergedExpandedRowKeys.indexOf(key);
          const nextExpandedKeys = Array.from(mergedExpandedRowKeys);
          if (~index) {
            nextExpandedKeys.splice(index, 1);
            doUpdateExpandedRowKeys(nextExpandedKeys);
          } else {
            if (tmNode && !tmNode.isLeaf && !tmNode.shallowLoaded) {
              loadingKeySetRef.value.add(key);
              void onLoadRef.value?.(tmNode.rawNode).then(() => {
                const { value: futureMergedExpandedRowKeys } = mergedExpandedRowKeysRef;
                const futureNextExpandedKeys = Array.from(
                  futureMergedExpandedRowKeys
                );
                const index2 = futureNextExpandedKeys.indexOf(key);
                if (!~index2) {
                  futureNextExpandedKeys.push(key);
                }
                doUpdateExpandedRowKeys(futureNextExpandedKeys);
              }).finally(() => {
                loadingKeySetRef.value.delete(key);
              });
            } else {
              nextExpandedKeys.push(key);
              doUpdateExpandedRowKeys(nextExpandedKeys);
            }
          }
        }
        function handleMouseleaveTable() {
          hoverKeyRef.value = null;
        }
        function handleMouseenterTable() {
          scrollPartRef.value = "body";
        }
        function virtualListContainer() {
          const { value } = virtualListRef;
          return value?.listElRef;
        }
        function virtualListContent() {
          const { value } = virtualListRef;
          return value?.itemsElRef;
        }
        function handleVirtualListScroll(e) {
          handleTableBodyScroll(e);
          scrollbarInstRef.value?.sync();
        }
        function handleVirtualListResize(e) {
          const { onResize } = props;
          if (onResize)
            onResize(e);
          scrollbarInstRef.value?.sync();
        }
        const exposedMethods = {
          getScrollContainer,
          scrollTo(arg0, arg1) {
            if (virtualScrollRef.value) {
              virtualListRef.value?.scrollTo(arg0, arg1);
            } else {
              scrollbarInstRef.value?.scrollTo(arg0, arg1);
            }
          }
        };
        const style = c$1([
          ({ props: cProps }) => {
            const createActiveLeftFixedStyle = (leftActiveFixedColKey) => {
              if (leftActiveFixedColKey === null)
                return null;
              return c$1(
                `[data-n-id="${cProps.componentId}"] [data-col-key="${leftActiveFixedColKey}"]::after`,
                { boxShadow: "var(--n-box-shadow-after)" }
              );
            };
            const createActiveRightFixedStyle = (rightActiveFixedColKey) => {
              if (rightActiveFixedColKey === null)
                return null;
              return c$1(
                `[data-n-id="${cProps.componentId}"] [data-col-key="${rightActiveFixedColKey}"]::before`,
                { boxShadow: "var(--n-box-shadow-before)" }
              );
            };
            return c$1([
              createActiveLeftFixedStyle(cProps.leftActiveFixedColKey),
              createActiveRightFixedStyle(cProps.rightActiveFixedColKey),
              cProps.leftActiveFixedChildrenColKeys.map(
                (leftActiveFixedColKey) => createActiveLeftFixedStyle(leftActiveFixedColKey)
              ),
              cProps.rightActiveFixedChildrenColKeys.map(
                (rightActiveFixedColKey) => createActiveRightFixedStyle(rightActiveFixedColKey)
              )
            ]);
          }
        ]);
        let fixedStyleMounted = false;
        vue.watchEffect(() => {
          const { value: leftActiveFixedColKey } = leftActiveFixedColKeyRef;
          const { value: leftActiveFixedChildrenColKeys } = leftActiveFixedChildrenColKeysRef;
          const { value: rightActiveFixedColKey } = rightActiveFixedColKeyRef;
          const { value: rightActiveFixedChildrenColKeys } = rightActiveFixedChildrenColKeysRef;
          if (!fixedStyleMounted && leftActiveFixedColKey === null && rightActiveFixedColKey === null) {
            return;
          }
          const cProps = {
            leftActiveFixedColKey,
            leftActiveFixedChildrenColKeys,
            rightActiveFixedColKey,
            rightActiveFixedChildrenColKeys,
            componentId
          };
          style.mount({
            id: `n-${componentId}`,
            force: true,
            props: cProps,
            anchorMetaName: cssrAnchorMetaName
          });
          fixedStyleMounted = true;
        });
        vue.onUnmounted(() => {
          style.unmount({
            id: `n-${componentId}`
          });
        });
        return {
          bodyWidth: bodyWidthRef,
          dataTableSlots,
          componentId,
          scrollbarInstRef,
          virtualListRef,
          emptyElRef,
          summary: summaryRef,
          mergedClsPrefix: mergedClsPrefixRef,
          mergedTheme: mergedThemeRef,
          scrollX: scrollXRef,
          cols: colsRef,
          loading: loadingRef,
          bodyShowHeaderOnly: bodyShowHeaderOnlyRef,
          shouldDisplaySomeTablePart: shouldDisplaySomeTablePartRef,
          empty: emptyRef,
          paginatedDataAndInfo: vue.computed(() => {
            const { value: striped } = stripedRef;
            let hasChildren = false;
            const data = paginatedDataRef.value.map(
              striped ? (tmNode, index) => {
                if (!tmNode.isLeaf)
                  hasChildren = true;
                return {
                  tmNode,
                  key: tmNode.key,
                  striped: index % 2 === 1,
                  index
                };
              } : (tmNode, index) => {
                if (!tmNode.isLeaf)
                  hasChildren = true;
                return {
                  tmNode,
                  key: tmNode.key,
                  striped: false,
                  index
                };
              }
            );
            return {
              data,
              hasChildren
            };
          }),
          rawPaginatedData: rawPaginatedDataRef,
          fixedColumnLeftMap: fixedColumnLeftMapRef,
          fixedColumnRightMap: fixedColumnRightMapRef,
          currentPage: mergedCurrentPageRef,
          rowClassName: rowClassNameRef,
          renderExpand: renderExpandRef,
          mergedExpandedRowKeySet: mergedExpandedRowKeySetRef,
          hoverKey: hoverKeyRef,
          mergedSortState: mergedSortStateRef,
          virtualScroll: virtualScrollRef,
          mergedTableLayout: mergedTableLayoutRef,
          childTriggerColIndex: childTriggerColIndexRef,
          indent: indentRef,
          rowProps: rowPropsRef,
          maxHeight: maxHeightRef,
          loadingKeySet: loadingKeySetRef,
          expandable: expandableRef,
          stickyExpandedRows: stickyExpandedRowsRef,
          renderExpandIcon: renderExpandIconRef,
          setHeaderScrollLeft,
          handleMouseenterTable,
          handleVirtualListScroll,
          handleVirtualListResize,
          handleMouseleaveTable,
          virtualListContainer,
          virtualListContent,
          handleTableBodyScroll,
          handleCheckboxUpdateChecked,
          handleRadioUpdateChecked,
          handleUpdateExpanded,
          renderCell,
          ...exposedMethods
        };
      },
      render() {
        const {
          mergedTheme,
          scrollX,
          mergedClsPrefix,
          virtualScroll,
          maxHeight,
          mergedTableLayout,
          flexHeight,
          loadingKeySet,
          onResize,
          setHeaderScrollLeft
        } = this;
        const scrollable = scrollX !== void 0 || maxHeight !== void 0 || flexHeight;
        const isBasicAutoLayout = !scrollable && mergedTableLayout === "auto";
        const xScrollable = scrollX !== void 0 || isBasicAutoLayout;
        const contentStyle = {
          minWidth: formatLength(scrollX) || "100%"
        };
        if (scrollX)
          contentStyle.width = "100%";
        const tableNode = /* @__PURE__ */ React.createElement(NScrollbar, {
          ref: "scrollbarInstRef",
          scrollable: scrollable || isBasicAutoLayout,
          class: `${mergedClsPrefix}-data-table-base-table-body`,
          style: this.bodyStyle,
          theme: mergedTheme.peers.Scrollbar,
          themeOverrides: mergedTheme.peerOverrides.Scrollbar,
          contentStyle,
          container: virtualScroll ? this.virtualListContainer : void 0,
          content: virtualScroll ? this.virtualListContent : void 0,
          horizontalRailStyle: { zIndex: 3 },
          verticalRailStyle: { zIndex: 3 },
          xScrollable,
          onScroll: virtualScroll ? void 0 : this.handleTableBodyScroll,
          internalOnUpdateScrollLeft: setHeaderScrollLeft,
          onResize
        }, {
          default: () => {
            const cordToPass = {};
            const cordKey = {};
            const {
              cols,
              paginatedDataAndInfo,
              mergedTheme: mergedTheme2,
              fixedColumnLeftMap,
              fixedColumnRightMap,
              currentPage,
              rowClassName,
              mergedSortState,
              mergedExpandedRowKeySet,
              stickyExpandedRows,
              componentId,
              childTriggerColIndex,
              expandable,
              rowProps,
              handleMouseenterTable,
              handleMouseleaveTable,
              renderExpand,
              summary,
              handleCheckboxUpdateChecked,
              handleRadioUpdateChecked,
              handleUpdateExpanded
            } = this;
            const { length: colCount } = cols;
            let mergedData;
            const { data: paginatedData, hasChildren } = paginatedDataAndInfo;
            const mergedPaginationData = hasChildren ? flatten(paginatedData, mergedExpandedRowKeySet) : paginatedData;
            if (summary) {
              const summaryRows = summary(this.rawPaginatedData);
              if (Array.isArray(summaryRows)) {
                mergedData = [
                  ...mergedPaginationData,
                  ...summaryRows.map((row, i) => ({
                    isSummaryRow: true,
                    key: `__n_summary__${i}`,
                    tmNode: {
                      rawNode: row,
                      disabled: true
                    },
                    index: -1
                  }))
                ];
              } else {
                mergedData = [
                  ...mergedPaginationData,
                  {
                    isSummaryRow: true,
                    key: "__n_summary__",
                    tmNode: {
                      rawNode: summaryRows,
                      disabled: true
                    },
                    index: -1
                  }
                ];
              }
            } else {
              mergedData = mergedPaginationData;
            }
            const indentStyle = hasChildren ? { width: pxfy(this.indent) } : void 0;
            const displayedData = [];
            mergedData.forEach((rowInfo) => {
              if (renderExpand && mergedExpandedRowKeySet.has(rowInfo.key) && (!expandable || expandable(rowInfo.tmNode.rawNode))) {
                displayedData.push(rowInfo, {
                  isExpandedRow: true,
                  key: `${rowInfo.key}-expand`,
                  tmNode: rowInfo.tmNode,
                  index: rowInfo.index
                });
              } else {
                displayedData.push(rowInfo);
              }
            });
            const { length: rowCount } = displayedData;
            const rowIndexToKey = {};
            paginatedData.forEach(({ tmNode }, rowIndex) => {
              rowIndexToKey[rowIndex] = tmNode.key;
            });
            const bodyWidth = stickyExpandedRows ? this.bodyWidth : null;
            const bodyWidthPx = bodyWidth === null ? void 0 : `${bodyWidth}px`;
            const renderRow = (rowInfo, displayedRowIndex, isVirtual) => {
              const { index: actualRowIndex } = rowInfo;
              if ("isExpandedRow" in rowInfo) {
                const {
                  tmNode: { key, rawNode }
                } = rowInfo;
                return /* @__PURE__ */ React.createElement("tr", {
                  class: `${mergedClsPrefix}-data-table-tr`,
                  key: `${key}__expand`
                }, /* @__PURE__ */ React.createElement("td", {
                  class: [
                    `${mergedClsPrefix}-data-table-td`,
                    `${mergedClsPrefix}-data-table-td--last-col`,
                    displayedRowIndex + 1 === rowCount && `${mergedClsPrefix}-data-table-td--last-row`
                  ],
                  colspan: colCount
                }, stickyExpandedRows ? /* @__PURE__ */ React.createElement("div", {
                  class: `${mergedClsPrefix}-data-table-expand`,
                  style: {
                    width: bodyWidthPx
                  }
                }, renderExpand(rawNode, actualRowIndex)) : renderExpand(rawNode, actualRowIndex)));
              }
              const isSummary = "isSummaryRow" in rowInfo;
              const striped = !isSummary && rowInfo.striped;
              const { tmNode, key: rowKey } = rowInfo;
              const { rawNode: rowData } = tmNode;
              const expanded = mergedExpandedRowKeySet.has(rowKey);
              const props = rowProps ? rowProps(rowData, actualRowIndex) : void 0;
              const mergedRowClassName = typeof rowClassName === "string" ? rowClassName : createRowClassName(rowData, actualRowIndex, rowClassName);
              const row = /* @__PURE__ */ React.createElement("tr", {
                onMouseenter: () => {
                  this.hoverKey = rowKey;
                },
                key: rowKey,
                class: [
                  `${mergedClsPrefix}-data-table-tr`,
                  isSummary && `${mergedClsPrefix}-data-table-tr--summary`,
                  striped && `${mergedClsPrefix}-data-table-tr--striped`,
                  mergedRowClassName
                ],
                ...props
              }, cols.map((col, colIndex) => {
                if (displayedRowIndex in cordToPass) {
                  const cordOfRowToPass = cordToPass[displayedRowIndex];
                  const indexInCordOfRowToPass = cordOfRowToPass.indexOf(colIndex);
                  if (~indexInCordOfRowToPass) {
                    cordOfRowToPass.splice(indexInCordOfRowToPass, 1);
                    return null;
                  }
                }
                const { column } = col;
                const colKey = getColKey(col);
                const { rowSpan, colSpan } = column;
                const mergedColSpan = isSummary ? rowInfo.tmNode.rawNode[colKey]?.colSpan || 1 : colSpan ? colSpan(rowData, actualRowIndex) : 1;
                const mergedRowSpan = isSummary ? rowInfo.tmNode.rawNode[colKey]?.rowSpan || 1 : rowSpan ? rowSpan(rowData, actualRowIndex) : 1;
                const isLastCol = colIndex + mergedColSpan === colCount;
                const isLastRow = displayedRowIndex + mergedRowSpan === rowCount;
                const isCrossRowTd = mergedRowSpan > 1;
                if (isCrossRowTd) {
                  cordKey[displayedRowIndex] = {
                    [colIndex]: []
                  };
                }
                if (mergedColSpan > 1 || isCrossRowTd) {
                  for (let i = displayedRowIndex; i < displayedRowIndex + mergedRowSpan; ++i) {
                    if (isCrossRowTd) {
                      cordKey[displayedRowIndex][colIndex].push(
                        rowIndexToKey[i]
                      );
                    }
                    for (let j = colIndex; j < colIndex + mergedColSpan; ++j) {
                      if (i === displayedRowIndex && j === colIndex) {
                        continue;
                      }
                      if (!(i in cordToPass)) {
                        cordToPass[i] = [j];
                      } else {
                        cordToPass[i].push(j);
                      }
                    }
                  }
                }
                const hoverKey = isCrossRowTd ? this.hoverKey : null;
                const { cellProps } = column;
                const resolvedCellProps = cellProps?.(
                  rowData,
                  actualRowIndex
                );
                return /* @__PURE__ */ React.createElement("td", {
                  ...resolvedCellProps,
                  key: colKey,
                  style: [
                    {
                      textAlign: column.align || void 0,
                      left: pxfy(fixedColumnLeftMap[colKey]?.start),
                      right: pxfy(fixedColumnRightMap[colKey]?.start)
                    },
                    resolvedCellProps?.style || ""
                  ],
                  colspan: mergedColSpan,
                  rowspan: isVirtual ? void 0 : mergedRowSpan,
                  "data-col-key": colKey,
                  class: [
                    `${mergedClsPrefix}-data-table-td`,
                    column.className,
                    resolvedCellProps?.class,
                    isSummary && `${mergedClsPrefix}-data-table-td--summary`,
                    (hoverKey !== null && cordKey[displayedRowIndex][colIndex].includes(
                      hoverKey
                    ) || isColumnSorting(column, mergedSortState)) && `${mergedClsPrefix}-data-table-td--hover`,
                    column.fixed && `${mergedClsPrefix}-data-table-td--fixed-${column.fixed}`,
                    column.align && `${mergedClsPrefix}-data-table-td--${column.align}-align`,
                    column.type === "selection" && `${mergedClsPrefix}-data-table-td--selection`,
                    column.type === "expand" && `${mergedClsPrefix}-data-table-td--expand`,
                    isLastCol && `${mergedClsPrefix}-data-table-td--last-col`,
                    isLastRow && `${mergedClsPrefix}-data-table-td--last-row`
                  ]
                }, hasChildren && colIndex === childTriggerColIndex ? [
                  repeat(
                    isSummary ? 0 : rowInfo.tmNode.level,
                    /* @__PURE__ */ React.createElement("div", {
                      class: `${mergedClsPrefix}-data-table-indent`,
                      style: indentStyle
                    })
                  ),
                  isSummary || rowInfo.tmNode.isLeaf ? /* @__PURE__ */ React.createElement("div", {
                    class: `${mergedClsPrefix}-data-table-expand-placeholder`
                  }) : /* @__PURE__ */ React.createElement(ExpandTrigger, {
                    class: `${mergedClsPrefix}-data-table-expand-trigger`,
                    clsPrefix: mergedClsPrefix,
                    expanded,
                    renderExpandIcon: this.renderExpandIcon,
                    loading: loadingKeySet.has(rowInfo.key),
                    onClick: () => {
                      handleUpdateExpanded(rowKey, rowInfo.tmNode);
                    }
                  })
                ] : null, column.type === "selection" ? !isSummary ? column.multiple === false ? /* @__PURE__ */ React.createElement(RenderSafeRadio, {
                  key: currentPage,
                  rowKey,
                  disabled: rowInfo.tmNode.disabled,
                  onUpdateChecked: () => handleRadioUpdateChecked(rowInfo.tmNode)
                }) : /* @__PURE__ */ React.createElement(RenderSafeCheckbox, {
                  key: currentPage,
                  rowKey,
                  disabled: rowInfo.tmNode.disabled,
                  onUpdateChecked: (checked, e) => handleCheckboxUpdateChecked(
                    rowInfo.tmNode,
                    checked,
                    e.shiftKey
                  )
                }) : null : column.type === "expand" ? !isSummary ? !column.expandable || column.expandable?.(rowData) ? /* @__PURE__ */ React.createElement(ExpandTrigger, {
                  clsPrefix: mergedClsPrefix,
                  expanded,
                  renderExpandIcon: this.renderExpandIcon,
                  onClick: () => handleUpdateExpanded(rowKey, null)
                }) : null : null : /* @__PURE__ */ React.createElement(Cell, {
                  clsPrefix: mergedClsPrefix,
                  index: actualRowIndex,
                  row: rowData,
                  column,
                  isSummary,
                  mergedTheme: mergedTheme2,
                  renderCell: this.renderCell
                }));
              }));
              return row;
            };
            if (!virtualScroll) {
              return /* @__PURE__ */ React.createElement("table", {
                class: `${mergedClsPrefix}-data-table-table`,
                onMouseleave: handleMouseleaveTable,
                onMouseenter: handleMouseenterTable,
                style: {
                  tableLayout: this.mergedTableLayout
                }
              }, /* @__PURE__ */ React.createElement("colgroup", null, cols.map((col) => /* @__PURE__ */ React.createElement("col", {
                key: col.key,
                style: col.style
              }))), this.showHeader ? /* @__PURE__ */ React.createElement(TableHeader, {
                discrete: false
              }) : null, !this.empty ? /* @__PURE__ */ React.createElement("tbody", {
                "data-n-id": componentId,
                class: `${mergedClsPrefix}-data-table-tbody`
              }, displayedData.map((rowInfo, displayedRowIndex) => {
                return renderRow(rowInfo, displayedRowIndex, false);
              })) : null);
            } else {
              return /* @__PURE__ */ React.createElement(VVirtualList, {
                ref: "virtualListRef",
                items: displayedData,
                itemSize: 28,
                visibleItemsTag: VirtualListItemWrapper,
                visibleItemsProps: {
                  clsPrefix: mergedClsPrefix,
                  id: componentId,
                  cols,
                  onMouseenter: handleMouseenterTable,
                  onMouseleave: handleMouseleaveTable
                },
                showScrollbar: false,
                onResize: this.handleVirtualListResize,
                onScroll: this.handleVirtualListScroll,
                itemsStyle: contentStyle,
                itemResizable: true
              }, {
                default: ({
                  item,
                  index
                }) => renderRow(item, index, true)
              });
            }
          }
        });
        if (this.empty) {
          const createEmptyNode = () => /* @__PURE__ */ React.createElement("div", {
            class: [
              `${mergedClsPrefix}-data-table-empty`,
              this.loading && `${mergedClsPrefix}-data-table-empty--hide`
            ],
            style: this.bodyStyle,
            ref: "emptyElRef"
          }, resolveSlot(this.dataTableSlots.empty, () => [
            /* @__PURE__ */ React.createElement(NEmpty, {
              theme: this.mergedTheme.peers.Empty,
              themeOverrides: this.mergedTheme.peerOverrides.Empty
            })
          ]));
          if (this.shouldDisplaySomeTablePart) {
            return /* @__PURE__ */ React.createElement(React.Fragment, null, tableNode, createEmptyNode());
          } else {
            return /* @__PURE__ */ React.createElement(VResizeObserver, {
              onResize: this.onResize
            }, { default: createEmptyNode });
          }
        }
        return tableNode;
      }
    });

    var MainTable = vue.defineComponent({
      setup() {
        const {
          mergedClsPrefixRef,
          rightFixedColumnsRef,
          leftFixedColumnsRef,
          bodyWidthRef,
          maxHeightRef,
          minHeightRef,
          flexHeightRef,
          syncScrollState
        } = vue.inject(dataTableInjectionKey);
        const headerInstRef = vue.ref(null);
        const bodyInstRef = vue.ref(null);
        const selfElRef = vue.ref(null);
        const fixedStateInitializedRef = vue.ref(
          !(leftFixedColumnsRef.value.length || rightFixedColumnsRef.value.length)
        );
        const bodyStyleRef = vue.computed(() => {
          return {
            maxHeight: formatLength(maxHeightRef.value),
            minHeight: formatLength(minHeightRef.value)
          };
        });
        function handleBodyResize(entry) {
          bodyWidthRef.value = entry.contentRect.width;
          syncScrollState();
          if (!fixedStateInitializedRef.value) {
            fixedStateInitializedRef.value = true;
          }
        }
        function getHeaderElement() {
          const { value } = headerInstRef;
          if (value) {
            return value.$el;
          }
          return null;
        }
        function getBodyElement() {
          const { value } = bodyInstRef;
          if (value) {
            return value.getScrollContainer();
          }
          return null;
        }
        const exposedMethods = {
          getBodyElement,
          getHeaderElement,
          scrollTo(arg0, arg1) {
            bodyInstRef.value?.scrollTo(arg0, arg1);
          }
        };
        vue.watchEffect(() => {
          const { value: selfEl } = selfElRef;
          if (!selfEl)
            return;
          const transitionDisabledClass = `${mergedClsPrefixRef.value}-data-table-base-table--transition-disabled`;
          if (fixedStateInitializedRef.value) {
            setTimeout(() => {
              selfEl.classList.remove(transitionDisabledClass);
            }, 0);
          } else {
            selfEl.classList.add(transitionDisabledClass);
          }
        });
        return {
          maxHeight: maxHeightRef,
          mergedClsPrefix: mergedClsPrefixRef,
          selfElRef,
          headerInstRef,
          bodyInstRef,
          bodyStyle: bodyStyleRef,
          flexHeight: flexHeightRef,
          handleBodyResize,
          ...exposedMethods
        };
      },
      render() {
        const { mergedClsPrefix, maxHeight, flexHeight } = this;
        const headerInBody = maxHeight === void 0 && !flexHeight;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-data-table-base-table`,
          ref: "selfElRef"
        }, headerInBody ? null : /* @__PURE__ */ React.createElement(TableHeader, {
          ref: "headerInstRef"
        }), /* @__PURE__ */ React.createElement(TableBody, {
          ref: "bodyInstRef",
          bodyStyle: this.bodyStyle,
          showHeader: headerInBody,
          flexHeight,
          onResize: this.handleBodyResize
        }));
      }
    });

    function useCheck(props, data) {
      const {
        paginatedDataRef,
        treeMateRef,
        selectionColumnRef
      } = data;
      const uncontrolledCheckedRowKeysRef = vue.ref(props.defaultCheckedRowKeys);
      const mergedCheckState = vue.computed(() => {
        var _selectionColumnRef$v;

        const {
          checkedRowKeys
        } = props;
        const sourceKeys = checkedRowKeys === void 0 ? uncontrolledCheckedRowKeysRef.value : checkedRowKeys;

        if (((_selectionColumnRef$v = selectionColumnRef.value) === null || _selectionColumnRef$v === void 0 ? void 0 : _selectionColumnRef$v.multiple) === false) {
          return {
            checkedKeys: sourceKeys.slice(0, 1),
            indeterminateKeys: []
          };
        }

        return treeMateRef.value.getCheckedKeys(sourceKeys, {
          cascade: props.cascade,
          allowNotLoaded: props.allowCheckingNotLoaded
        });
      });
      const mergedCheckedRowKeysRef = vue.computed(() => mergedCheckState.value.checkedKeys);
      const mergedInderminateRowKeysRef = vue.computed(() => mergedCheckState.value.indeterminateKeys);
      const mergedCheckedRowKeySetRef = vue.computed(() => {
        return new Set(mergedCheckedRowKeysRef.value);
      });
      const mergedInderminateRowKeySetRef = vue.computed(() => {
        return new Set(mergedInderminateRowKeysRef.value);
      });
      const countOfCurrentPageCheckedRowsRef = vue.computed(() => {
        const {
          value: mergedCheckedRowKeySet
        } = mergedCheckedRowKeySetRef;
        return paginatedDataRef.value.reduce((total, tmNode) => {
          const {
            key,
            disabled
          } = tmNode;
          return total + (!disabled && mergedCheckedRowKeySet.has(key) ? 1 : 0);
        }, 0);
      });
      const countOfCurrentPageDisabledRowsRef = vue.computed(() => {
        return paginatedDataRef.value.filter(item => item.disabled).length;
      });
      const someRowsCheckedRef = vue.computed(() => {
        const {
          length
        } = paginatedDataRef.value;
        const {
          value: mergedInderminateRowKeySet
        } = mergedInderminateRowKeySetRef;
        return countOfCurrentPageCheckedRowsRef.value > 0 && countOfCurrentPageCheckedRowsRef.value < length - countOfCurrentPageDisabledRowsRef.value || paginatedDataRef.value.some(rowData => mergedInderminateRowKeySet.has(rowData.key));
      });
      const allRowsCheckedRef = vue.computed(() => {
        const {
          length
        } = paginatedDataRef.value;
        return countOfCurrentPageCheckedRowsRef.value !== 0 && countOfCurrentPageCheckedRowsRef.value === length - countOfCurrentPageDisabledRowsRef.value;
      });
      const headerCheckboxDisabledRef = vue.computed(() => {
        return paginatedDataRef.value.length === 0;
      });

      function doUpdateCheckedRowKeys(keys) {
        const {
          "onUpdate:checkedRowKeys": _onUpdateCheckedRowKeys,
          onUpdateCheckedRowKeys,
          onCheckedRowKeysChange
        } = props;
        const rows = [];
        const {
          value: {
            getNode
          }
        } = treeMateRef;
        keys.forEach(key => {
          var _getNode;

          const row = (_getNode = getNode(key)) === null || _getNode === void 0 ? void 0 : _getNode.rawNode;
          rows.push(row);
        });
        if (_onUpdateCheckedRowKeys) call(_onUpdateCheckedRowKeys, keys, rows);
        if (onUpdateCheckedRowKeys) call(onUpdateCheckedRowKeys, keys, rows);
        if (onCheckedRowKeysChange) call(onCheckedRowKeysChange, keys, rows);
        uncontrolledCheckedRowKeysRef.value = keys;
      }

      function doCheck(rowKey) {
        let single = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
        if (props.loading) return;

        if (single) {
          doUpdateCheckedRowKeys(Array.isArray(rowKey) ? rowKey.slice(0, 1) : [rowKey]);
          return;
        }

        doUpdateCheckedRowKeys(treeMateRef.value.check(rowKey, mergedCheckedRowKeysRef.value, {
          cascade: props.cascade,
          allowNotLoaded: props.allowCheckingNotLoaded
        }).checkedKeys);
      }

      function doUncheck(rowKey) {
        if (props.loading) return;
        doUpdateCheckedRowKeys(treeMateRef.value.uncheck(rowKey, mergedCheckedRowKeysRef.value, {
          cascade: props.cascade,
          allowNotLoaded: props.allowCheckingNotLoaded
        }).checkedKeys);
      }

      function doCheckAll() {
        let checkWholeTable = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
        const {
          value: column
        } = selectionColumnRef;
        if (!column || props.loading) return;
        const rowKeysToCheck = [];
        (checkWholeTable ? treeMateRef.value.treeNodes : paginatedDataRef.value).forEach(tmNode => {
          if (!tmNode.disabled) {
            rowKeysToCheck.push(tmNode.key);
          }
        });
        doUpdateCheckedRowKeys(treeMateRef.value.check(rowKeysToCheck, mergedCheckedRowKeysRef.value, {
          cascade: true,
          allowNotLoaded: props.allowCheckingNotLoaded
        }).checkedKeys);
      }

      function doUncheckAll() {
        let checkWholeTable = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
        const {
          value: column
        } = selectionColumnRef;
        if (!column || props.loading) return;
        const rowKeysToUncheck = [];
        (checkWholeTable ? treeMateRef.value.treeNodes : paginatedDataRef.value).forEach(tmNode => {
          if (!tmNode.disabled) {
            rowKeysToUncheck.push(tmNode.key);
          }
        });
        doUpdateCheckedRowKeys(treeMateRef.value.uncheck(rowKeysToUncheck, mergedCheckedRowKeysRef.value, {
          cascade: true,
          allowNotLoaded: props.allowCheckingNotLoaded
        }).checkedKeys);
      }

      return {
        mergedCheckedRowKeySetRef,
        mergedCheckedRowKeysRef,
        mergedInderminateRowKeySetRef,
        someRowsCheckedRef,
        allRowsCheckedRef,
        headerCheckboxDisabledRef,
        doUpdateCheckedRowKeys,
        doCheckAll,
        doUncheckAll,
        doCheck,
        doUncheck
      };
    }

    function getMultiplePriority(sorter) {
      if (typeof sorter === "object" && typeof sorter.multiple === "number") {
        return sorter.multiple;
      }

      return false;
    }

    function getSortFunction(sorter, columnKey) {
      if (columnKey && (sorter === void 0 || sorter === "default" || typeof sorter === "object" && sorter.compare === "default")) {
        return getDefaultSorterFn(columnKey);
      }

      if (typeof sorter === "function") {
        return sorter;
      }

      if (sorter && typeof sorter === "object" && sorter.compare && sorter.compare !== "default") {
        return sorter.compare;
      }

      return false;
    }

    function getDefaultSorterFn(columnKey) {
      return (row1, row2) => {
        const value1 = row1[columnKey];
        const value2 = row2[columnKey];

        if (typeof value1 === "number" && typeof value2 === "number") {
          return value1 - value2;
        } else if (typeof value1 === "string" && typeof value2 === "string") {
          return value1.localeCompare(value2);
        }

        return 0;
      };
    }

    function useSorter(props, _ref) {
      let {
        dataRelatedColsRef,
        filteredDataRef
      } = _ref;
      const defaultSortState = [];
      dataRelatedColsRef.value.forEach(column => {
        if (column.sorter !== void 0) {
          updateSortStatesByNewSortState(defaultSortState, {
            columnKey: column.key,
            sorter: column.sorter,
            order: column.defaultSortOrder ?? false
          });
        }
      });
      const uncontrolledSortStateRef = vue.ref(defaultSortState);
      const mergedSortStateRef = vue.computed(() => {
        const columnsWithControlledSortOrder = dataRelatedColsRef.value.filter(column => column.type !== "selection" && column.sorter !== void 0 && (column.sortOrder === "ascend" || column.sortOrder === "descend" || column.sortOrder === false));
        const columnToSort = columnsWithControlledSortOrder.filter(col => col.sortOrder !== false);

        if (columnToSort.length) {
          return columnToSort.map(column => {
            return {
              columnKey: column.key,
              order: column.sortOrder,
              sorter: column.sorter
            };
          });
        }

        if (columnsWithControlledSortOrder.length) return [];
        const {
          value: uncontrolledSortState
        } = uncontrolledSortStateRef;

        if (Array.isArray(uncontrolledSortState)) {
          return uncontrolledSortState;
        } else if (uncontrolledSortState) {
          return [uncontrolledSortState];
        } else {
          return [];
        }
      });
      const sortedDataRef = vue.computed(() => {
        const activeSorters = mergedSortStateRef.value.slice().sort((a, b) => {
          const item1Priority = getMultiplePriority(a.sorter) || 0;
          const item2Priority = getMultiplePriority(b.sorter) || 0;
          return item2Priority - item1Priority;
        });

        if (activeSorters.length) {
          const filteredData = filteredDataRef.value.slice();
          return filteredData.sort((tmNode1, tmNode2) => {
            let compareResult = 0;
            activeSorters.some(sorterState => {
              const {
                columnKey,
                sorter,
                order
              } = sorterState;
              const compareFn = getSortFunction(sorter, columnKey);

              if (compareFn && order) {
                compareResult = compareFn(tmNode1.rawNode, tmNode2.rawNode);

                if (compareResult !== 0) {
                  compareResult = compareResult * getFlagOfOrder(order);
                  return true;
                }
              }

              return false;
            });
            return compareResult;
          });
        }

        return filteredDataRef.value;
      });

      function getUpdatedSorterState(sortState) {
        let currentSortState = mergedSortStateRef.value.slice();

        if (sortState && getMultiplePriority(sortState.sorter) !== false) {
          currentSortState = currentSortState.filter(sortState2 => getMultiplePriority(sortState2.sorter) !== false);
          updateSortStatesByNewSortState(currentSortState, sortState);
          return currentSortState;
        } else if (sortState) {
          return sortState;
        }

        return null;
      }

      function deriveNextSorter(sortState) {
        const nextSorterState = getUpdatedSorterState(sortState);
        doUpdateSorter(nextSorterState);
      }

      function doUpdateSorter(sortState) {
        const {
          "onUpdate:sorter": _onUpdateSorter,
          onUpdateSorter,
          onSorterChange
        } = props;

        if (_onUpdateSorter) {
          call(_onUpdateSorter, sortState);
        }

        if (onUpdateSorter) {
          call(onUpdateSorter, sortState);
        }

        if (onSorterChange) {
          call(onSorterChange, sortState);
        }

        uncontrolledSortStateRef.value = sortState;
      }

      function sort(columnKey) {
        let order = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : "ascend";

        if (!columnKey) {
          clearSorter();
        } else {
          const columnToSort = dataRelatedColsRef.value.find(column => column.type !== "selection" && column.type !== "expand" && column.key === columnKey);
          if (!(columnToSort !== null && columnToSort !== void 0 && columnToSort.sorter)) return;
          const sorter = columnToSort.sorter;
          deriveNextSorter({
            columnKey,
            sorter,
            order
          });
        }
      }

      function clearSorter() {
        doUpdateSorter(null);
      }

      function updateSortStatesByNewSortState(sortStates, sortState) {
        const index = sortStates.findIndex(state => (sortState === null || sortState === void 0 ? void 0 : sortState.columnKey) && state.columnKey === sortState.columnKey);

        if (index !== void 0 && index >= 0) {
          sortStates[index] = sortState;
        } else {
          sortStates.push(sortState);
        }
      }

      return {
        clearSorter,
        sort,
        sortedDataRef,
        mergedSortStateRef,
        deriveNextSorter
      };
    }

    function useTableData(props, _ref) {
      let {
        dataRelatedColsRef
      } = _ref;
      const selectionColumnRef = vue.computed(() => {
        const getSelectionColumn = cols => {
          for (let i = 0; i < cols.length; ++i) {
            const col = cols[i];

            if ("children" in col) {
              return getSelectionColumn(col.children);
            } else if (col.type === "selection") {
              return col;
            }
          }

          return null;
        };

        return getSelectionColumn(props.columns);
      });
      const treeMateRef = vue.computed(() => {
        const {
          childrenKey
        } = props;
        return createTreeMate(props.data, {
          ignoreEmptyChildren: true,
          getKey: props.rowKey,
          getChildren: rowData => rowData[childrenKey],
          getDisabled: rowData => {
            var _selectionColumnRef$v, _selectionColumnRef$v2;

            if ((_selectionColumnRef$v = selectionColumnRef.value) !== null && _selectionColumnRef$v !== void 0 && (_selectionColumnRef$v2 = _selectionColumnRef$v.disabled) !== null && _selectionColumnRef$v2 !== void 0 && _selectionColumnRef$v2.call(_selectionColumnRef$v, rowData)) {
              return true;
            }

            return false;
          }
        });
      });
      const childTriggerColIndexRef = useMemo(() => {
        const {
          columns
        } = props;
        const {
          length
        } = columns;
        let firstContentfulColIndex = null;

        for (let i = 0; i < length; ++i) {
          const col = columns[i];

          if (!col.type && firstContentfulColIndex === null) {
            firstContentfulColIndex = i;
          }

          if ("tree" in col && col.tree) {
            return i;
          }
        }

        return firstContentfulColIndex || 0;
      });
      const uncontrolledFilterStateRef = vue.ref({});
      const uncontrolledCurrentPageRef = vue.ref(1);
      const uncontrolledPageSizeRef = vue.ref(10);
      const mergedFilterStateRef = vue.computed(() => {
        const columnsWithControlledFilter = dataRelatedColsRef.value.filter(column => {
          return column.filterOptionValues !== void 0 || column.filterOptionValue !== void 0;
        });
        const controlledFilterState = {};
        columnsWithControlledFilter.forEach(column => {
          if (column.type === "selection" || column.type === "expand") return;

          if (column.filterOptionValues === void 0) {
            controlledFilterState[column.key] = column.filterOptionValue ?? null;
          } else {
            controlledFilterState[column.key] = column.filterOptionValues;
          }
        });
        const activeFilters = Object.assign(createShallowClonedObject(uncontrolledFilterStateRef.value), controlledFilterState);
        return activeFilters;
      });
      const filteredDataRef = vue.computed(() => {
        const mergedFilterState = mergedFilterStateRef.value;
        const {
          columns
        } = props;

        function createDefaultFilter(columnKey) {
          return (filterOptionValue, row) => !!~String(row[columnKey]).indexOf(String(filterOptionValue));
        }

        const {
          value: {
            treeNodes: data
          }
        } = treeMateRef;
        const columnEntries = [];
        columns.forEach(column => {
          if (column.type === "selection" || column.type === "expand" || "children" in column) {
            return;
          }

          columnEntries.push([column.key, column]);
        });
        return data ? data.filter(tmNode => {
          const {
            rawNode: row
          } = tmNode;

          for (const [columnKey, column] of columnEntries) {
            let activeFilterOptionValues = mergedFilterState[columnKey];
            if (activeFilterOptionValues == null) continue;

            if (!Array.isArray(activeFilterOptionValues)) {
              activeFilterOptionValues = [activeFilterOptionValues];
            }

            if (!activeFilterOptionValues.length) continue;
            const filter2 = column.filter === "default" ? createDefaultFilter(columnKey) : column.filter;

            if (column && typeof filter2 === "function") {
              if (column.filterMode === "and") {
                if (activeFilterOptionValues.some(filterOptionValue => !filter2(filterOptionValue, row))) {
                  return false;
                }
              } else {
                if (activeFilterOptionValues.some(filterOptionValue => filter2(filterOptionValue, row))) {
                  continue;
                } else {
                  return false;
                }
              }
            }
          }

          return true;
        }) : [];
      });
      const {
        sortedDataRef,
        deriveNextSorter,
        mergedSortStateRef,
        sort,
        clearSorter
      } = useSorter(props, {
        dataRelatedColsRef,
        filteredDataRef
      });
      dataRelatedColsRef.value.forEach(column => {
        if (column.filter) {
          const defaultFilterOptionValues = column.defaultFilterOptionValues;

          if (column.filterMultiple) {
            uncontrolledFilterStateRef.value[column.key] = defaultFilterOptionValues || [];
          } else if (defaultFilterOptionValues !== void 0) {
            uncontrolledFilterStateRef.value[column.key] = defaultFilterOptionValues === null ? [] : defaultFilterOptionValues;
          } else {
            uncontrolledFilterStateRef.value[column.key] = column.defaultFilterOptionValue ?? null;
          }
        }
      });
      const controlledCurrentPageRef = vue.computed(() => {
        const {
          pagination
        } = props;
        if (pagination === false) return void 0;
        return pagination.page;
      });
      const controlledPageSizeRef = vue.computed(() => {
        const {
          pagination
        } = props;
        if (pagination === false) return void 0;
        return pagination.pageSize;
      });

      const _mergedCurrentPageRef = useMergedState(controlledCurrentPageRef, uncontrolledCurrentPageRef);

      const mergedPageSizeRef = useMergedState(controlledPageSizeRef, uncontrolledPageSizeRef);
      const boundedMergedCurrentPageRef = useMemo(() => {
        const page2 = _mergedCurrentPageRef.value;
        return props.remote ? page2 : Math.max(1, Math.min(Math.ceil(filteredDataRef.value.length / mergedPageSizeRef.value), page2));
      });
      const mergedPageCountRef = vue.computed(() => {
        const {
          pagination
        } = props;

        if (pagination) {
          const {
            pageCount
          } = pagination;
          if (pageCount !== void 0) return pageCount;
        }

        return void 0;
      });
      const paginatedDataRef = vue.computed(() => {
        if (props.remote) return treeMateRef.value.treeNodes;
        if (!props.pagination) return sortedDataRef.value;
        const pageSize = mergedPageSizeRef.value;
        const startIndex = (boundedMergedCurrentPageRef.value - 1) * pageSize;
        return sortedDataRef.value.slice(startIndex, startIndex + pageSize);
      });
      const rawPaginatedDataRef = vue.computed(() => {
        return paginatedDataRef.value.map(tmNode => tmNode.rawNode);
      });

      function mergedOnUpdatePage(page2) {
        const {
          pagination
        } = props;

        if (pagination) {
          const {
            onChange,
            "onUpdate:page": _onUpdatePage,
            onUpdatePage
          } = pagination;
          if (onChange) call(onChange, page2);
          if (onUpdatePage) call(onUpdatePage, page2);
          if (_onUpdatePage) call(_onUpdatePage, page2);
          doUpdatePage(page2);
        }
      }

      function mergedOnUpdatePageSize(pageSize) {
        const {
          pagination
        } = props;

        if (pagination) {
          const {
            onPageSizeChange,
            "onUpdate:pageSize": _onUpdatePageSize,
            onUpdatePageSize
          } = pagination;
          if (onPageSizeChange) call(onPageSizeChange, pageSize);
          if (onUpdatePageSize) call(onUpdatePageSize, pageSize);
          if (_onUpdatePageSize) call(_onUpdatePageSize, pageSize);
          doUpdatePageSize(pageSize);
        }
      }

      const mergedItemCountRef = vue.computed(() => {
        if (props.remote) {
          const {
            pagination
          } = props;

          if (pagination) {
            const {
              itemCount
            } = pagination;
            if (itemCount !== void 0) return itemCount;
          }

          return void 0;
        }

        return filteredDataRef.value.length;
      });
      const mergedPaginationRef = vue.computed(() => {
        return { ...props.pagination,
          onChange: void 0,
          onUpdatePage: void 0,
          onUpdatePageSize: void 0,
          onPageSizeChange: void 0,
          "onUpdate:page": mergedOnUpdatePage,
          "onUpdate:pageSize": mergedOnUpdatePageSize,
          page: boundedMergedCurrentPageRef.value,
          pageSize: mergedPageSizeRef.value,
          pageCount: mergedItemCountRef.value === void 0 ? mergedPageCountRef.value : void 0,
          itemCount: mergedItemCountRef.value
        };
      });

      function doUpdatePage(page2) {
        const {
          "onUpdate:page": _onUpdatePage,
          onPageChange,
          onUpdatePage
        } = props;
        if (onUpdatePage) call(onUpdatePage, page2);
        if (_onUpdatePage) call(_onUpdatePage, page2);
        if (onPageChange) call(onPageChange, page2);
        uncontrolledCurrentPageRef.value = page2;
      }

      function doUpdatePageSize(pageSize) {
        const {
          "onUpdate:pageSize": _onUpdatePageSize,
          onPageSizeChange,
          onUpdatePageSize
        } = props;
        if (onPageSizeChange) call(onPageSizeChange, pageSize);
        if (onUpdatePageSize) call(onUpdatePageSize, pageSize);
        if (_onUpdatePageSize) call(_onUpdatePageSize, pageSize);
        uncontrolledPageSizeRef.value = pageSize;
      }

      function doUpdateFilters(filters2, sourceColumn) {
        const {
          onUpdateFilters,
          "onUpdate:filters": _onUpdateFilters,
          onFiltersChange
        } = props;
        if (onUpdateFilters) call(onUpdateFilters, filters2, sourceColumn);
        if (_onUpdateFilters) call(_onUpdateFilters, filters2, sourceColumn);
        if (onFiltersChange) call(onFiltersChange, filters2, sourceColumn);
        uncontrolledFilterStateRef.value = filters2;
      }

      function page(page2) {
        doUpdatePage(page2);
      }

      function clearFilter() {
        clearFilters();
      }

      function clearFilters() {
        filters({});
      }

      function filters(filters2) {
        filter(filters2);
      }

      function filter(filters2) {
        if (!filters2) {
          uncontrolledFilterStateRef.value = {};
        } else if (filters2) {
          uncontrolledFilterStateRef.value = createShallowClonedObject(filters2);
        } else {
          warn$2("data-table", "`filters` is not an object");
        }
      }

      return {
        treeMateRef,
        mergedCurrentPageRef: boundedMergedCurrentPageRef,
        mergedPaginationRef,
        paginatedDataRef,
        rawPaginatedDataRef,
        mergedFilterStateRef,
        mergedSortStateRef,
        hoverKeyRef: vue.ref(null),
        selectionColumnRef,
        childTriggerColIndexRef,
        doUpdateFilters,
        deriveNextSorter,
        doUpdatePageSize,
        doUpdatePage,
        filter,
        filters,
        clearFilter,
        clearFilters,
        clearSorter,
        page,
        sort
      };
    }

    function useScroll(props, _ref) {
      let {
        mainTableInstRef,
        mergedCurrentPageRef,
        bodyWidthRef,
        scrollPartRef
      } = _ref;
      let scrollLeft = 0;
      const leftActiveFixedColKeyRef = vue.ref(null);
      const leftActiveFixedChildrenColKeysRef = vue.ref([]);
      const rightActiveFixedColKeyRef = vue.ref(null);
      const rightActiveFixedChildrenColKeysRef = vue.ref([]);
      const styleScrollXRef = vue.computed(() => {
        return formatLength(props.scrollX);
      });
      const leftFixedColumnsRef = vue.computed(() => {
        return props.columns.filter(column => column.fixed === "left");
      });
      const rightFixedColumnsRef = vue.computed(() => {
        return props.columns.filter(column => column.fixed === "right");
      });
      const fixedColumnLeftMapRef = vue.computed(() => {
        const columns = {};
        let left = 0;

        function traverse(cols) {
          cols.forEach(col => {
            const positionInfo = {
              start: left,
              end: 0
            };
            columns[getColKey(col)] = positionInfo;

            if ("children" in col) {
              traverse(col.children);
              positionInfo.end = left;
            } else {
              left += getNumberColWidth(col) || 0;
              positionInfo.end = left;
            }
          });
        }

        traverse(leftFixedColumnsRef.value);
        return columns;
      });
      const fixedColumnRightMapRef = vue.computed(() => {
        const columns = {};
        let right = 0;

        function traverse(cols) {
          for (let i = cols.length - 1; i >= 0; --i) {
            const col = cols[i];
            const positionInfo = {
              start: right,
              end: 0
            };
            columns[getColKey(col)] = positionInfo;

            if ("children" in col) {
              traverse(col.children);
              positionInfo.end = right;
            } else {
              right += getNumberColWidth(col) || 0;
              positionInfo.end = right;
            }
          }
        }

        traverse(rightFixedColumnsRef.value);
        return columns;
      });

      function deriveActiveLeftFixedColumn() {
        const {
          value: leftFixedColumns
        } = leftFixedColumnsRef;
        let leftWidth = 0;
        const {
          value: fixedColumnLeftMap
        } = fixedColumnLeftMapRef;
        let leftActiveFixedColKey = null;

        for (let i = 0; i < leftFixedColumns.length; ++i) {
          var _fixedColumnLeftMap$k;

          const key = getColKey(leftFixedColumns[i]);

          if (scrollLeft > (((_fixedColumnLeftMap$k = fixedColumnLeftMap[key]) === null || _fixedColumnLeftMap$k === void 0 ? void 0 : _fixedColumnLeftMap$k.start) || 0) - leftWidth) {
            var _fixedColumnLeftMap$k2;

            leftActiveFixedColKey = key;
            leftWidth = ((_fixedColumnLeftMap$k2 = fixedColumnLeftMap[key]) === null || _fixedColumnLeftMap$k2 === void 0 ? void 0 : _fixedColumnLeftMap$k2.end) || 0;
          } else {
            break;
          }
        }

        leftActiveFixedColKeyRef.value = leftActiveFixedColKey;
      }

      function deriveActiveLeftFixedChildrenColumns() {
        leftActiveFixedChildrenColKeysRef.value = [];
        let activeLeftFixedColumn = props.columns.find(col => getColKey(col) === leftActiveFixedColKeyRef.value);

        while (activeLeftFixedColumn && "children" in activeLeftFixedColumn) {
          const length = activeLeftFixedColumn.children.length;
          if (length === 0) break;
          const nextActiveLeftFixedColumn = activeLeftFixedColumn.children[length - 1];
          leftActiveFixedChildrenColKeysRef.value.push(getColKey(nextActiveLeftFixedColumn));
          activeLeftFixedColumn = nextActiveLeftFixedColumn;
        }
      }

      function deriveActiveRightFixedColumn() {
        const {
          value: rightFixedColumns
        } = rightFixedColumnsRef;
        const scrollWidth = Number(props.scrollX);
        const {
          value: tableWidth
        } = bodyWidthRef;
        if (tableWidth === null) return;
        let rightWidth = 0;
        let rightActiveFixedColKey = null;
        const {
          value: fixedColumnRightMap
        } = fixedColumnRightMapRef;

        for (let i = rightFixedColumns.length - 1; i >= 0; --i) {
          var _fixedColumnRightMap$;

          const key = getColKey(rightFixedColumns[i]);

          if (Math.round(scrollLeft + (((_fixedColumnRightMap$ = fixedColumnRightMap[key]) === null || _fixedColumnRightMap$ === void 0 ? void 0 : _fixedColumnRightMap$.start) || 0) + tableWidth - rightWidth) < scrollWidth) {
            var _fixedColumnRightMap$2;

            rightActiveFixedColKey = key;
            rightWidth = ((_fixedColumnRightMap$2 = fixedColumnRightMap[key]) === null || _fixedColumnRightMap$2 === void 0 ? void 0 : _fixedColumnRightMap$2.end) || 0;
          } else {
            break;
          }
        }

        rightActiveFixedColKeyRef.value = rightActiveFixedColKey;
      }

      function deriveActiveRightFixedChildrenColumns() {
        rightActiveFixedChildrenColKeysRef.value = [];
        let activeRightFixedColumn = props.columns.find(col => getColKey(col) === rightActiveFixedColKeyRef.value);

        while (activeRightFixedColumn && "children" in activeRightFixedColumn && activeRightFixedColumn.children.length) {
          const nextActiveRightFixedColumn = activeRightFixedColumn.children[0];
          rightActiveFixedChildrenColKeysRef.value.push(getColKey(nextActiveRightFixedColumn));
          activeRightFixedColumn = nextActiveRightFixedColumn;
        }
      }

      function getScrollElements() {
        const header = mainTableInstRef.value ? mainTableInstRef.value.getHeaderElement() : null;
        const body = mainTableInstRef.value ? mainTableInstRef.value.getBodyElement() : null;
        return {
          header,
          body
        };
      }

      function scrollMainTableBodyToTop() {
        const {
          body
        } = getScrollElements();

        if (body) {
          body.scrollTop = 0;
        }
      }

      function handleTableHeaderScroll() {
        if (scrollPartRef.value === "head") {
          beforeNextFrameOnce(syncScrollState);
        }
      }

      function handleTableBodyScroll(e) {
        var _props$onScroll;

        (_props$onScroll = props.onScroll) === null || _props$onScroll === void 0 ? void 0 : _props$onScroll.call(props, e);

        if (scrollPartRef.value === "body") {
          beforeNextFrameOnce(syncScrollState);
        }
      }

      function syncScrollState() {
        const {
          header,
          body
        } = getScrollElements();
        if (!body) return;
        const {
          value: tableWidth
        } = bodyWidthRef;
        if (tableWidth === null) return;
        const {
          value: scrollPart
        } = scrollPartRef;

        if (props.maxHeight || props.flexHeight) {
          if (!header) return;

          if (scrollPart === "head") {
            scrollLeft = header.scrollLeft;
            body.scrollLeft = scrollLeft;
          } else {
            scrollLeft = body.scrollLeft;
            header.scrollLeft = scrollLeft;
          }
        } else {
          scrollLeft = body.scrollLeft;
        }

        deriveActiveLeftFixedColumn();
        deriveActiveLeftFixedChildrenColumns();
        deriveActiveRightFixedColumn();
        deriveActiveRightFixedChildrenColumns();
      }

      function setHeaderScrollLeft(left) {
        const {
          header
        } = getScrollElements();
        if (!header) return;
        header.scrollLeft = left;
        syncScrollState();
      }

      vue.watch(mergedCurrentPageRef, () => {
        scrollMainTableBodyToTop();
      });
      return {
        styleScrollXRef,
        fixedColumnLeftMapRef,
        fixedColumnRightMapRef,
        leftFixedColumnsRef,
        rightFixedColumnsRef,
        leftActiveFixedColKeyRef,
        leftActiveFixedChildrenColKeysRef,
        rightActiveFixedColKeyRef,
        rightActiveFixedChildrenColKeysRef,
        syncScrollState,
        handleTableBodyScroll,
        handleTableHeaderScroll,
        setHeaderScrollLeft
      };
    }

    function getRowsAndCols(columns) {
      const rows = [];
      const cols = [];
      const dataRelatedCols = [];
      const rowItemMap = /* @__PURE__ */new WeakMap();
      let maxDepth = -1;
      let totalRowSpan = 0;
      let hasEllipsis = false;

      function ensureMaxDepth(columns2, currentDepth) {
        if (currentDepth > maxDepth) {
          rows[currentDepth] = [];
          maxDepth = currentDepth;
        }

        for (const column of columns2) {
          if ("children" in column) {
            ensureMaxDepth(column.children, currentDepth + 1);
          } else {
            cols.push({
              key: getColKey(column),
              style: createCustomWidthStyle(column),
              column
            });
            totalRowSpan += 1;

            if (!hasEllipsis) {
              hasEllipsis = !!column.ellipsis;
            }

            dataRelatedCols.push(column);
          }
        }
      }

      ensureMaxDepth(columns, 0);
      let currentLeafIndex = 0;

      function ensureColLayout(columns2, currentDepth) {
        let hideUntilIndex = 0;
        columns2.forEach((column, index) => {
          if ("children" in column) {
            const cachedCurrentLeafIndex = currentLeafIndex;
            const rowItem = {
              column,
              colSpan: 0,
              rowSpan: 1,
              isLast: false
            };
            ensureColLayout(column.children, currentDepth + 1);
            column.children.forEach(childColumn => {
              var _rowItemMap$get;

              rowItem.colSpan += ((_rowItemMap$get = rowItemMap.get(childColumn)) === null || _rowItemMap$get === void 0 ? void 0 : _rowItemMap$get.colSpan) ?? 0;
            });

            if (cachedCurrentLeafIndex + rowItem.colSpan === totalRowSpan) {
              rowItem.isLast = true;
            }

            rowItemMap.set(column, rowItem);
            rows[currentDepth].push(rowItem);
          } else {
            if (currentLeafIndex < hideUntilIndex) {
              currentLeafIndex += 1;
              return;
            }

            let colSpan = 1;

            if ("titleColSpan" in column) {
              colSpan = column.titleColSpan ?? 1;
            }

            if (colSpan > 1) {
              hideUntilIndex = currentLeafIndex + colSpan;
            }

            const isLast = currentLeafIndex + colSpan === totalRowSpan;
            const rowItem = {
              column,
              colSpan,
              rowSpan: maxDepth - currentDepth + 1,
              isLast
            };
            rowItemMap.set(column, rowItem);
            rows[currentDepth].push(rowItem);
            currentLeafIndex += 1;
          }
        });
      }

      ensureColLayout(columns, 0);
      return {
        hasEllipsis,
        rows,
        cols,
        dataRelatedCols
      };
    }

    function useGroupHeader(props) {
      const rowsAndCols = vue.computed(() => getRowsAndCols(props.columns));
      return {
        rowsRef: vue.computed(() => rowsAndCols.value.rows),
        colsRef: vue.computed(() => rowsAndCols.value.cols),
        hasEllipsisRef: vue.computed(() => rowsAndCols.value.hasEllipsis),
        dataRelatedColsRef: vue.computed(() => rowsAndCols.value.dataRelatedCols)
      };
    }

    function useExpand(props, treeMateRef) {
      const renderExpandRef = useMemo(() => {
        for (const col of props.columns) {
          if (col.type === "expand") {
            if (!col.renderExpand) {
              warn$2("data-table", "column with type `expand` has no `renderExpand` prop.");
            }

            return col.renderExpand;
          }
        }
      });
      const expandableRef = useMemo(() => {
        let expandable;

        for (const col of props.columns) {
          if (col.type === "expand") {
            expandable = col.expandable;
            break;
          }
        }

        return expandable;
      });
      const uncontrolledExpandedRowKeysRef = vue.ref(props.defaultExpandAll ? renderExpandRef !== null && renderExpandRef !== void 0 && renderExpandRef.value ? (() => {
        const expandedKeys = [];
        treeMateRef.value.treeNodes.forEach(tmNode => {
          var _expandableRef$value;

          if ((_expandableRef$value = expandableRef.value) !== null && _expandableRef$value !== void 0 && _expandableRef$value.call(expandableRef, tmNode.rawNode)) {
            expandedKeys.push(tmNode.key);
          }
        });
        return expandedKeys;
      })() : treeMateRef.value.getNonLeafKeys() : props.defaultExpandedRowKeys);
      const controlledExpandedRowKeysRef = vue.toRef(props, "expandedRowKeys");
      const stickyExpandedRowsRef = vue.toRef(props, "stickyExpandedRows");
      const mergedExpandedRowKeysRef = useMergedState(controlledExpandedRowKeysRef, uncontrolledExpandedRowKeysRef);

      function doUpdateExpandedRowKeys(expandedKeys) {
        const {
          onUpdateExpandedRowKeys,
          "onUpdate:expandedRowKeys": _onUpdateExpandedRowKeys
        } = props;

        if (onUpdateExpandedRowKeys) {
          call(onUpdateExpandedRowKeys, expandedKeys);
        }

        if (_onUpdateExpandedRowKeys) {
          call(_onUpdateExpandedRowKeys, expandedKeys);
        }

        uncontrolledExpandedRowKeysRef.value = expandedKeys;
      }

      return {
        stickyExpandedRowsRef,
        mergedExpandedRowKeysRef,
        renderExpandRef,
        expandableRef,
        doUpdateExpandedRowKeys
      };
    }

    const fixedColumnStyle = createFixedColumnStyle();
    var style$T = c$1([cB("data-table", `
    width: 100%;
    font-size: var(--n-font-size);
    display: flex;
    flex-direction: column;
    position: relative;
    --n-merged-th-color: var(--n-th-color);
    --n-merged-td-color: var(--n-td-color);
    --n-merged-border-color: var(--n-border-color);
    --n-merged-th-color-hover: var(--n-th-color-hover);
    --n-merged-td-color-hover: var(--n-td-color-hover);
    --n-merged-td-color-striped: var(--n-td-color-striped);
  `, [cB("data-table-wrapper", `
      flex-grow: 1;
      display: flex;
      flex-direction: column;
    `), cM("flex-height", [c$1(">", [cB("data-table-wrapper", [c$1(">", [cB("data-table-base-table", `
              display: flex;
              flex-direction: column;
              flex-grow: 1;
            `, [c$1(">", [cB("data-table-base-table-body", "flex-basis: 0;", [c$1("&:last-child", "flex-grow: 1;")])])])])])])]), c$1(">", [cB("base-loading", `
        color: var(--n-loading-color);
        font-size: var(--n-loading-size);
        position: absolute;
        left: 50%;
        top: 50%;
        transform: translateX(-50%) translateY(-50%);
        transition: color .3s var(--n-bezier);
      `, [fadeInScaleUpTransition({
      originalTransform: "translateX(-50%) translateY(-50%)"
    })])]), cB("data-table-expand-placeholder", `
      margin-right: 8px;
      display: inline-block;
      width: 16px;
      height: 1px;
    `), cB("data-table-indent", `
      display: inline-block;
      height: 1px;
    `), cB("data-table-expand-trigger", `
      display: inline-flex;
      margin-right: 8px;
      cursor: pointer;
      font-size: 16px;
      vertical-align: -0.2em;
      position: relative;
      width: 16px;
      height: 16px;
      color: var(--n-td-text-color);
      transition: color .3s var(--n-bezier);
    `, [cM("expanded", [cB("icon", "transform: rotate(90deg);", [iconSwitchTransition({
      originalTransform: "rotate(90deg)"
    })]), cB("base-icon", "transform: rotate(90deg);", [iconSwitchTransition({
      originalTransform: "rotate(90deg)"
    })])]), cB("base-loading", `
        color: var(--n-loading-color);
        transition: color .3s var(--n-bezier);
        position: absolute;
        left: 0;
        right: 0;
        top: 0;
        bottom: 0;
      `, [iconSwitchTransition()]), cB("icon", `
        position: absolute;
        left: 0;
        right: 0;
        top: 0;
        bottom: 0;
      `, [iconSwitchTransition()]), cB("base-icon", `
        position: absolute;
        left: 0;
        right: 0;
        top: 0;
        bottom: 0;
      `, [iconSwitchTransition()])]), cB("data-table-thead", `
      transition: background-color .3s var(--n-bezier);
      background-color: var(--n-merged-th-color);
    `), cB("data-table-tr", `
      box-sizing: border-box;
      background-clip: padding-box;
      transition: background-color .3s var(--n-bezier);
    `, [cB("data-table-expand", `
        position: sticky;
        left: 0;
        overflow: hidden;
        margin: calc(var(--n-th-padding) * -1);
        padding: var(--n-th-padding);
        box-sizing: border-box;
      `), cM("striped", "background-color: var(--n-merged-td-color-striped);", [cB("data-table-td", "background-color: var(--n-merged-td-color-striped);")]), cNotM("summary", [c$1("&:hover", "background-color: var(--n-merged-td-color-hover);", [cB("data-table-td", "background-color: var(--n-merged-td-color-hover);")])])]), cB("data-table-th", `
      padding: var(--n-th-padding);
      position: relative;
      text-align: start;
      box-sizing: border-box;
      background-color: var(--n-merged-th-color);
      border-color: var(--n-merged-border-color);
      border-bottom: 1px solid var(--n-merged-border-color);
      color: var(--n-th-text-color);
      transition:
        border-color .3s var(--n-bezier),
        color .3s var(--n-bezier),
        background-color .3s var(--n-bezier);
      font-weight: var(--n-th-font-weight);
    `, [cM("filterable", {
      paddingRight: "36px"
    }), fixedColumnStyle, cM("selection", `
        padding: 0;
        text-align: center;
        line-height: 0;
        z-index: 3;
      `), cE("ellipsis", `
        display: inline-block;
        vertical-align: bottom;
        text-overflow: ellipsis;
        overflow: hidden;
        white-space: nowrap;
        max-width: 100%;
      `), cM("hover", {
      backgroundColor: "var(--n-merged-th-color-hover)"
    }), cM("sortable", {
      cursor: "pointer"
    }, [cE("ellipsis", {
      maxWidth: "calc(100% - 18px)"
    }), c$1("&:hover", {
      backgroundColor: "var(--n-merged-th-color-hover)"
    })]), cB("data-table-sorter", `
        height: var(--n-sorter-size);
        width: var(--n-sorter-size);
        margin-left: 4px;
        position: relative;
        display: inline-flex;
        align-items: center;
        justify-content: center;
        vertical-align: -0.2em;
        color: var(--n-th-icon-color);
        transition: color .3s var(--n-bezier);
      `, [cB("base-icon", "transition: transform .3s var(--n-bezier)"), cM("desc", [cB("base-icon", {
      transform: "rotate(0deg)"
    })]), cM("asc", [cB("base-icon", {
      transform: "rotate(-180deg)"
    })]), cM("asc, desc", {
      color: "var(--n-th-icon-color-active)"
    })]), cB("data-table-filter", `
        position: absolute;
        z-index: auto;
        right: 0;
        width: 36px;
        top: 0;
        bottom: 0;
        cursor: pointer;
        display: flex;
        justify-content: center;
        align-items: center;
        transition:
          background-color .3s var(--n-bezier),
          color .3s var(--n-bezier);
        font-size: var(--n-filter-size);
        color: var(--n-th-icon-color);
      `, [c$1("&:hover", `
          background-color: var(--n-th-button-color-hover);
        `), cM("show", `
          background-color: var(--n-th-button-color-hover);
        `), cM("active", `
          background-color: var(--n-th-button-color-hover);
          color: var(--n-th-icon-color-active);
        `)])]), cB("data-table-td", `
      padding: var(--n-td-padding);
      text-align: start;
      box-sizing: border-box;
      border: none;
      background-color: var(--n-merged-td-color);
      color: var(--n-td-text-color);
      border-bottom: 1px solid var(--n-merged-border-color);
      transition:
        box-shadow .3s var(--n-bezier),
        background-color .3s var(--n-bezier),
        border-color .3s var(--n-bezier),
        color .3s var(--n-bezier);
    `, [cM("expand", [cB("data-table-expand-trigger", `
          margin-right: 0;
        `)]), cM("last-row", {
      borderBottom: "0 solid var(--n-merged-border-color)"
    }, [c$1("&::after", {
      bottom: "0 !important"
    }), c$1("&::before", {
      bottom: "0 !important"
    })]), cM("summary", `
        background-color: var(--n-merged-th-color);
      `), cM("hover", {
      backgroundColor: "var(--n-merged-td-color-hover)"
    }), cE("ellipsis", `
        display: inline-block;
        text-overflow: ellipsis;
        overflow: hidden;
        white-space: nowrap;
        max-width: 100%;
        vertical-align: bottom;
      `), cM("selection, expand", `
        text-align: center;
        padding: 0;
        line-height: 0;
      `), fixedColumnStyle]), cB("data-table-empty", `
      box-sizing: border-box;
      padding: var(--n-empty-padding);
      flex-grow: 1;
      flex-shrink: 0;
      opacity: 1;
      display: flex;
      align-items: center;
      justify-content: center;
      transition: opacity .3s var(--n-bezier);
    `, [cM("hide", {
      opacity: 0
    })]), cE("pagination", `
      margin: var(--n-pagination-margin);
      display: flex;
      justify-content: flex-end;
    `), cB("data-table-wrapper", `
      position: relative;
      opacity: 1;
      transition: opacity .3s var(--n-bezier), border-color .3s var(--n-bezier);
      border-top-left-radius: var(--n-border-radius);
      border-top-right-radius: var(--n-border-radius);
      line-height: var(--n-line-height);
    `), cM("loading", [cB("data-table-wrapper", `
        opacity: var(--n-opacity-loading);
        pointer-events: none;
      `)]), cM("single-column", [cB("data-table-td", {
      borderBottom: "0 solid var(--n-merged-border-color)"
    }, [c$1("&::after, &::before", {
      bottom: "0 !important"
    })])]), cNotM("single-line", [cB("data-table-th", {
      borderRight: "1px solid var(--n-merged-border-color)"
    }, [cM("last", {
      borderRight: "0 solid var(--n-merged-border-color)"
    })]), cB("data-table-td", {
      borderRight: "1px solid var(--n-merged-border-color)"
    }, [cM("last-col", {
      borderRight: "0 solid var(--n-merged-border-color)"
    })])]), cM("bordered", [cB("data-table-wrapper", `
        border: 1px solid var(--n-merged-border-color);
        border-bottom-left-radius: var(--n-border-radius);
        border-bottom-right-radius: var(--n-border-radius);
        overflow: hidden;
      `)]), cB("data-table-base-table", [cM("transition-disabled", [cB("data-table-th", [c$1("&::after, &::before", {
      transition: "none"
    })]), cB("data-table-td", [c$1("&::after, &::before", {
      transition: "none"
    })])])]), cM("bottom-bordered", [cB("data-table-td", [cM("last-row", {
      borderBottom: "1px solid var(--n-merged-border-color)"
    })])]), cB("data-table-table", `
      font-variant-numeric: tabular-nums;
      width: 100%;
      word-break: break-word;
      transition: background-color .3s var(--n-bezier);
      border-collapse: separate;
      border-spacing: 0;
      background-color: var(--n-merged-td-color);
    `), cB("data-table-base-table-header", `
      border-top-left-radius: calc(var(--n-border-radius) - 1px);
      border-top-right-radius: calc(var(--n-border-radius) - 1px);
      z-index: 3;
      overflow: scroll;
      flex-shrink: 0;
      transition: border-color .3s var(--n-bezier);
      scrollbar-width: none;
    `, [c$1("&::-webkit-scrollbar", {
      width: 0,
      height: 0
    })]), cB("data-table-check-extra", `
      transition: color .3s var(--n-bezier);
      color: var(--n-th-icon-color);
      position: absolute;
      font-size: 14px;
      right: -4px;
      top: 50%;
      transform: translateY(-50%);
      z-index: 1;
    `)]), cB("data-table-filter-menu", [cB("scrollbar", {
      maxHeight: "240px"
    }), cE("group", {
      display: "flex",
      flexDirection: "column",
      padding: "12px 12px 0 12px"
    }, [cB("checkbox", {
      marginBottom: "12px",
      marginRight: 0
    }), cB("radio", {
      marginBottom: "12px",
      marginRight: 0
    })]), cE("action", `
      padding: var(--n-action-padding);
      display: flex;
      flex-wrap: nowrap;
      justify-content: space-evenly;
      border-top: 1px solid var(--n-action-divider-color);
    `, [cB("button", [c$1("&:not(:last-child)", {
      margin: "var(--n-action-button-margin)"
    }), c$1("&:last-child", {
      marginRight: 0
    })])]), cB("divider", {
      margin: "0!important"
    })]), insideModal(cB("data-table", `
    --n-merged-th-color: var(--n-th-color-modal);
    --n-merged-td-color: var(--n-td-color-modal);
    --n-merged-border-color: var(--n-border-color-modal);
    --n-merged-th-color-hover: var(--n-th-color-hover-modal);
    --n-merged-td-color-hover: var(--n-td-color-hover-modal);
    --n-merged-td-color-striped: var(--n-td-color-striped-modal);
  `)), insidePopover(cB("data-table", `
    --n-merged-th-color: var(--n-th-color-popover);
    --n-merged-td-color: var(--n-td-color-popover);
    --n-merged-border-color: var(--n-border-color-popover);
    --n-merged-th-color-hover: var(--n-th-color-hover-popover);
    --n-merged-td-color-hover: var(--n-td-color-hover-popover);
    --n-merged-td-color-striped: var(--n-td-color-striped-popover);
  `))]);

    function createFixedColumnStyle() {
      return [cM("fixed-left", `
      left: 0;
      position: sticky;
      z-index: 2;
    `, [c$1("&::after", `
        pointer-events: none;
        content: "";
        width: 36px;
        display: inline-block;
        position: absolute;
        top: 0;
        bottom: -1px;
        transition: box-shadow .2s var(--n-bezier);
        right: -36px;
      `)]), cM("fixed-right", {
        right: 0,
        position: "sticky",
        zIndex: 1
      }, [c$1("&::before", `
        pointer-events: none;
        content: "";
        width: 36px;
        display: inline-block;
        position: absolute;
        top: 0;
        bottom: -1px;
        transition: box-shadow .2s var(--n-bezier);
        left: -36px;
      `)])];
    }

    const dataTableProps = {
      ...useTheme.props,
      pagination: {
        type: [Object, Boolean],
        default: false
      },
      paginateSinglePage: {
        type: Boolean,
        default: true
      },
      minHeight: [Number, String],
      maxHeight: [Number, String],
      columns: {
        type: Array,
        default: () => []
      },
      rowClassName: [String, Function],
      rowProps: Function,
      rowKey: Function,
      summary: [Function],
      data: {
        type: Array,
        default: () => []
      },
      loading: Boolean,
      bordered: {
        type: Boolean,
        default: void 0
      },
      bottomBordered: {
        type: Boolean,
        default: void 0
      },
      striped: Boolean,
      scrollX: [Number, String],
      defaultCheckedRowKeys: {
        type: Array,
        default: () => []
      },
      checkedRowKeys: Array,
      singleLine: {
        type: Boolean,
        default: true
      },
      singleColumn: Boolean,
      size: {
        type: String,
        default: "medium"
      },
      remote: Boolean,
      defaultExpandedRowKeys: {
        type: Array,
        default: []
      },
      defaultExpandAll: Boolean,
      expandedRowKeys: Array,
      stickyExpandedRows: Boolean,
      virtualScroll: Boolean,
      tableLayout: {
        type: String,
        default: "auto"
      },
      allowCheckingNotLoaded: Boolean,
      cascade: {
        type: Boolean,
        default: true
      },
      childrenKey: {
        type: String,
        default: "children"
      },
      indent: {
        type: Number,
        default: 16
      },
      flexHeight: Boolean,
      paginationBehaviorOnFilter: {
        type: String,
        default: "current"
      },
      renderCell: Function,
      renderExpandIcon: Function,
      onLoad: Function,
      "onUpdate:page": [Function, Array],
      onUpdatePage: [Function, Array],
      "onUpdate:pageSize": [Function, Array],
      onUpdatePageSize: [Function, Array],
      "onUpdate:sorter": [Function, Array],
      onUpdateSorter: [Function, Array],
      "onUpdate:filters": [Function, Array],
      onUpdateFilters: [Function, Array],
      "onUpdate:checkedRowKeys": [Function, Array],
      onUpdateCheckedRowKeys: [Function, Array],
      "onUpdate:expandedRowKeys": [Function, Array],
      onUpdateExpandedRowKeys: [Function, Array],
      onScroll: Function,
      onPageChange: [Function, Array],
      onPageSizeChange: [Function, Array],
      onSorterChange: [Function, Array],
      onFiltersChange: [Function, Array],
      onCheckedRowKeysChange: [Function, Array]
    };
    var DataTable = vue.defineComponent({
      name: "DataTable",
      alias: ["AdvancedTable"],
      props: dataTableProps,
      setup(props, { slots }) {
        {
          vue.watchEffect(() => {
            if (props.onPageChange !== void 0) {
              warnOnce(
                "data-table",
                "`on-page-change` is deprecated, please use `on-update:page` instead."
              );
            }
            if (props.onPageSizeChange !== void 0) {
              warnOnce(
                "data-table",
                "`on-page-size-change` is deprecated, please use `on-update:page-size` instead."
              );
            }
            if (props.onSorterChange !== void 0) {
              warnOnce(
                "data-table",
                "`on-sorter-change` is deprecated, please use `on-update:sorter` instead."
              );
            }
            if (props.onFiltersChange !== void 0) {
              warnOnce(
                "data-table",
                "`on-filters-change` is deprecated, please use `on-update:filters` instead."
              );
            }
            if (props.onCheckedRowKeysChange !== void 0) {
              warnOnce(
                "data-table",
                "`on-checked-row-keys-change` is deprecated, please use `on-update:checked-row-keys` instead."
              );
            }
          });
        }
        const { mergedBorderedRef, mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const mergedBottomBorderedRef = vue.computed(() => {
          const { bottomBordered } = props;
          if (mergedBorderedRef.value)
            return false;
          if (bottomBordered !== void 0)
            return bottomBordered;
          return true;
        });
        const themeRef = useTheme(
          "DataTable",
          "-data-table",
          style$T,
          dataTableLight$1,
          props,
          mergedClsPrefixRef
        );
        const bodyWidthRef = vue.ref(null);
        const scrollPartRef = vue.ref("body");
        vue.onDeactivated(() => {
          scrollPartRef.value = "body";
        });
        const mainTableInstRef = vue.ref(null);
        const { rowsRef, colsRef, dataRelatedColsRef, hasEllipsisRef } = useGroupHeader(props);
        const {
          treeMateRef,
          mergedCurrentPageRef,
          paginatedDataRef,
          rawPaginatedDataRef,
          selectionColumnRef,
          hoverKeyRef,
          mergedPaginationRef,
          mergedFilterStateRef,
          mergedSortStateRef,
          childTriggerColIndexRef,
          doUpdatePage,
          doUpdateFilters,
          deriveNextSorter,
          filter,
          filters,
          clearFilter,
          clearFilters,
          clearSorter,
          page,
          sort
        } = useTableData(props, { dataRelatedColsRef });
        const {
          doCheckAll,
          doUncheckAll,
          doCheck,
          doUncheck,
          headerCheckboxDisabledRef,
          someRowsCheckedRef,
          allRowsCheckedRef,
          mergedCheckedRowKeySetRef,
          mergedInderminateRowKeySetRef
        } = useCheck(props, {
          selectionColumnRef,
          treeMateRef,
          paginatedDataRef
        });
        const {
          stickyExpandedRowsRef,
          mergedExpandedRowKeysRef,
          renderExpandRef,
          expandableRef,
          doUpdateExpandedRowKeys
        } = useExpand(props, treeMateRef);
        const {
          handleTableBodyScroll,
          handleTableHeaderScroll,
          syncScrollState,
          setHeaderScrollLeft,
          leftActiveFixedColKeyRef,
          leftActiveFixedChildrenColKeysRef,
          rightActiveFixedColKeyRef,
          rightActiveFixedChildrenColKeysRef,
          leftFixedColumnsRef,
          rightFixedColumnsRef,
          fixedColumnLeftMapRef,
          fixedColumnRightMapRef
        } = useScroll(props, {
          scrollPartRef,
          bodyWidthRef,
          mainTableInstRef,
          mergedCurrentPageRef
        });
        const { localeRef } = useLocale("DataTable");
        const mergedTableLayoutRef = vue.computed(() => {
          if (props.virtualScroll || props.flexHeight || props.maxHeight !== void 0 || hasEllipsisRef.value) {
            return "fixed";
          }
          return props.tableLayout;
        });
        vue.provide(dataTableInjectionKey, {
          renderExpandIconRef: vue.toRef(props, "renderExpandIcon"),
          loadingKeySetRef: vue.ref(/* @__PURE__ */ new Set()),
          slots,
          indentRef: vue.toRef(props, "indent"),
          childTriggerColIndexRef,
          bodyWidthRef,
          componentId: createId(),
          hoverKeyRef,
          mergedClsPrefixRef,
          mergedThemeRef: themeRef,
          scrollXRef: vue.computed(() => props.scrollX),
          rowsRef,
          colsRef,
          paginatedDataRef,
          leftActiveFixedColKeyRef,
          leftActiveFixedChildrenColKeysRef,
          rightActiveFixedColKeyRef,
          rightActiveFixedChildrenColKeysRef,
          leftFixedColumnsRef,
          rightFixedColumnsRef,
          fixedColumnLeftMapRef,
          fixedColumnRightMapRef,
          mergedCurrentPageRef,
          someRowsCheckedRef,
          allRowsCheckedRef,
          mergedSortStateRef,
          mergedFilterStateRef,
          loadingRef: vue.toRef(props, "loading"),
          rowClassNameRef: vue.toRef(props, "rowClassName"),
          mergedCheckedRowKeySetRef,
          mergedExpandedRowKeysRef,
          mergedInderminateRowKeySetRef,
          localeRef,
          scrollPartRef,
          expandableRef,
          stickyExpandedRowsRef,
          rowKeyRef: vue.toRef(props, "rowKey"),
          renderExpandRef,
          summaryRef: vue.toRef(props, "summary"),
          virtualScrollRef: vue.toRef(props, "virtualScroll"),
          rowPropsRef: vue.toRef(props, "rowProps"),
          stripedRef: vue.toRef(props, "striped"),
          checkOptionsRef: vue.computed(() => {
            const { value: selectionColumn } = selectionColumnRef;
            return selectionColumn?.options;
          }),
          rawPaginatedDataRef,
          filterMenuCssVarsRef: vue.computed(() => {
            const {
              self: { actionDividerColor, actionPadding, actionButtonMargin }
            } = themeRef.value;
            return {
              "--n-action-padding": actionPadding,
              "--n-action-button-margin": actionButtonMargin,
              "--n-action-divider-color": actionDividerColor
            };
          }),
          onLoadRef: vue.toRef(props, "onLoad"),
          mergedTableLayoutRef,
          maxHeightRef: vue.toRef(props, "maxHeight"),
          minHeightRef: vue.toRef(props, "minHeight"),
          flexHeightRef: vue.toRef(props, "flexHeight"),
          headerCheckboxDisabledRef,
          paginationBehaviorOnFilterRef: vue.toRef(props, "paginationBehaviorOnFilter"),
          syncScrollState,
          doUpdatePage,
          doUpdateFilters,
          deriveNextSorter,
          doCheck,
          doUncheck,
          doCheckAll,
          doUncheckAll,
          doUpdateExpandedRowKeys,
          handleTableHeaderScroll,
          handleTableBodyScroll,
          setHeaderScrollLeft,
          renderCell: vue.toRef(props, "renderCell")
        });
        const exposedMethods = {
          filter,
          filters,
          clearFilters,
          clearSorter,
          page,
          sort,
          clearFilter,
          scrollTo: (arg0, arg1) => {
            mainTableInstRef.value?.scrollTo(arg0, arg1);
          }
        };
        const cssVarsRef = vue.computed(() => {
          const { size } = props;
          const {
            common: { cubicBezierEaseInOut },
            self: {
              borderColor,
              tdColorHover,
              thColor,
              thColorHover,
              tdColor,
              tdTextColor,
              thTextColor,
              thFontWeight,
              thButtonColorHover,
              thIconColor,
              thIconColorActive,
              filterSize,
              borderRadius,
              lineHeight,
              tdColorModal,
              thColorModal,
              borderColorModal,
              thColorHoverModal,
              tdColorHoverModal,
              borderColorPopover,
              thColorPopover,
              tdColorPopover,
              tdColorHoverPopover,
              thColorHoverPopover,
              paginationMargin,
              emptyPadding,
              boxShadowAfter,
              boxShadowBefore,
              sorterSize,
              loadingColor,
              loadingSize,
              opacityLoading,
              tdColorStriped,
              tdColorStripedModal,
              tdColorStripedPopover,
              [createKey("fontSize", size)]: fontSize,
              [createKey("thPadding", size)]: thPadding,
              [createKey("tdPadding", size)]: tdPadding
            }
          } = themeRef.value;
          return {
            "--n-font-size": fontSize,
            "--n-th-padding": thPadding,
            "--n-td-padding": tdPadding,
            "--n-bezier": cubicBezierEaseInOut,
            "--n-border-radius": borderRadius,
            "--n-line-height": lineHeight,
            "--n-border-color": borderColor,
            "--n-border-color-modal": borderColorModal,
            "--n-border-color-popover": borderColorPopover,
            "--n-th-color": thColor,
            "--n-th-color-hover": thColorHover,
            "--n-th-color-modal": thColorModal,
            "--n-th-color-hover-modal": thColorHoverModal,
            "--n-th-color-popover": thColorPopover,
            "--n-th-color-hover-popover": thColorHoverPopover,
            "--n-td-color": tdColor,
            "--n-td-color-hover": tdColorHover,
            "--n-td-color-modal": tdColorModal,
            "--n-td-color-hover-modal": tdColorHoverModal,
            "--n-td-color-popover": tdColorPopover,
            "--n-td-color-hover-popover": tdColorHoverPopover,
            "--n-th-text-color": thTextColor,
            "--n-td-text-color": tdTextColor,
            "--n-th-font-weight": thFontWeight,
            "--n-th-button-color-hover": thButtonColorHover,
            "--n-th-icon-color": thIconColor,
            "--n-th-icon-color-active": thIconColorActive,
            "--n-filter-size": filterSize,
            "--n-pagination-margin": paginationMargin,
            "--n-empty-padding": emptyPadding,
            "--n-box-shadow-before": boxShadowBefore,
            "--n-box-shadow-after": boxShadowAfter,
            "--n-sorter-size": sorterSize,
            "--n-loading-size": loadingSize,
            "--n-loading-color": loadingColor,
            "--n-opacity-loading": opacityLoading,
            "--n-td-color-striped": tdColorStriped,
            "--n-td-color-striped-modal": tdColorStripedModal,
            "--n-td-color-striped-popover": tdColorStripedPopover
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "data-table",
          vue.computed(() => props.size[0]),
          cssVarsRef,
          props
        ) : void 0;
        const mergedShowPaginationRef = vue.computed(() => {
          if (!props.pagination)
            return false;
          if (props.paginateSinglePage)
            return true;
          const mergedPagination = mergedPaginationRef.value;
          const { pageCount } = mergedPagination;
          if (pageCount !== void 0)
            return pageCount > 1;
          return mergedPagination.itemCount && mergedPagination.pageSize && mergedPagination.itemCount > mergedPagination.pageSize;
        });
        return {
          mainTableInstRef,
          mergedClsPrefix: mergedClsPrefixRef,
          mergedTheme: themeRef,
          paginatedData: paginatedDataRef,
          mergedBordered: mergedBorderedRef,
          mergedBottomBordered: mergedBottomBorderedRef,
          mergedPagination: mergedPaginationRef,
          mergedShowPagination: mergedShowPaginationRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender,
          ...exposedMethods
        };
      },
      render() {
        const { mergedClsPrefix, themeClass, onRender } = this;
        onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-data-table`,
            themeClass,
            {
              [`${mergedClsPrefix}-data-table--bordered`]: this.mergedBordered,
              [`${mergedClsPrefix}-data-table--bottom-bordered`]: this.mergedBottomBordered,
              [`${mergedClsPrefix}-data-table--single-line`]: this.singleLine,
              [`${mergedClsPrefix}-data-table--single-column`]: this.singleColumn,
              [`${mergedClsPrefix}-data-table--loading`]: this.loading,
              [`${mergedClsPrefix}-data-table--flex-height`]: this.flexHeight
            }
          ],
          style: this.cssVars
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-data-table-wrapper`
        }, /* @__PURE__ */ React.createElement(MainTable, {
          ref: "mainTableInstRef"
        })), this.mergedShowPagination ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-data-table__pagination`
        }, /* @__PURE__ */ React.createElement(NPagination, {
          theme: this.mergedTheme.peers.Pagination,
          themeOverrides: this.mergedTheme.peerOverrides.Pagination,
          disabled: this.loading,
          ...this.mergedPagination
        })) : null, /* @__PURE__ */ React.createElement(vue.Transition, {
          name: "fade-in-scale-up-transition"
        }, {
          default: () => {
            return this.loading ? /* @__PURE__ */ React.createElement(NBaseLoading, {
              clsPrefix: mergedClsPrefix,
              strokeWidth: 20
            }) : null;
          }
        }));
      }
    });

    var commonVars$7 = {
      itemFontSize: "12px",
      itemHeight: "36px",
      itemWidth: "52px",
      panelActionPadding: "8px 0"
    };

    const self$H = vars => {
      const {
        popoverColor,
        textColor2,
        primaryColor,
        hoverColor,
        dividerColor,
        opacityDisabled,
        boxShadow2,
        borderRadius,
        iconColor,
        iconColorDisabled
      } = vars;
      return { ...commonVars$7,
        panelColor: popoverColor,
        panelBoxShadow: boxShadow2,
        panelDividerColor: dividerColor,
        itemTextColor: textColor2,
        itemTextColorActive: primaryColor,
        itemColorHover: hoverColor,
        itemOpacityDisabled: opacityDisabled,
        itemBorderRadius: borderRadius,
        borderRadius,
        iconColor,
        iconColorDisabled
      };
    };
    const timePickerLight = createTheme$1({
      name: "TimePicker",
      common: commonLight,
      peers: {
        Scrollbar: scrollbarLight$1,
        Button: buttonLight$1,
        Input: inputLight$1
      },
      self: self$H
    });
    var timePickerLight$1 = timePickerLight;

    const timePickerDark = {
      name: "TimePicker",
      common: commonDark,
      peers: {
        Scrollbar: scrollbarDark$1,
        Button: buttonDark$1,
        Input: inputDark$1
      },
      self: self$H
    };
    var timePickerDark$1 = timePickerDark;

    var commonVars$6 = {
      itemSize: "24px",
      itemCellWidth: "38px",
      itemCellHeight: "32px",
      scrollItemWidth: "80px",
      scrollItemHeight: "40px",
      panelExtraFooterPadding: "8px 12px",
      panelActionPadding: "8px 12px",
      calendarTitlePadding: "0",
      calendarTitleHeight: "28px",
      arrowSize: "14px",
      panelHeaderPadding: "8px 12px",
      calendarDaysHeight: "32px",
      calendarTitleGridTempateColumns: "28px 28px 1fr 28px 28px",
      calendarLeftPaddingDate: "6px 12px 4px 12px",
      calendarLeftPaddingDatetime: "4px 12px",
      calendarLeftPaddingDaterange: "6px 12px 4px 12px",
      calendarLeftPaddingDatetimerange: "4px 12px",
      calendarLeftPaddingMonth: "0",
      calendarLeftPaddingYear: "0",
      calendarLeftPaddingQuarter: "0",
      calendarLeftPaddingMonthrange: "0",
      calendarLeftPaddingQuarterrange: "0",
      calendarLeftPaddingYearrange: "0",
      calendarRightPaddingDate: "6px 12px 4px 12px",
      calendarRightPaddingDatetime: "4px 12px",
      calendarRightPaddingDaterange: "6px 12px 4px 12px",
      calendarRightPaddingDatetimerange: "4px 12px",
      calendarRightPaddingMonth: "0",
      calendarRightPaddingYear: "0",
      calendarRightPaddingQuarter: "0",
      calendarRightPaddingMonthrange: "0",
      calendarRightPaddingQuarterrange: "0",
      calendarRightPaddingYearrange: "0"
    };

    const self$G = vars => {
      const {
        hoverColor,
        fontSize,
        textColor2,
        textColorDisabled,
        popoverColor,
        primaryColor,
        borderRadiusSmall,
        iconColor,
        iconColorDisabled,
        textColor1,
        dividerColor,
        boxShadow2,
        borderRadius,
        fontWeightStrong
      } = vars;
      return { ...commonVars$6,
        itemFontSize: fontSize,
        calendarDaysFontSize: fontSize,
        calendarTitleFontSize: fontSize,
        itemTextColor: textColor2,
        itemTextColorDisabled: textColorDisabled,
        itemTextColorActive: popoverColor,
        itemTextColorCurrent: primaryColor,
        itemColorIncluded: changeColor(primaryColor, {
          alpha: 0.1
        }),
        itemColorHover: hoverColor,
        itemColorDisabled: hoverColor,
        itemColorActive: primaryColor,
        itemBorderRadius: borderRadiusSmall,
        panelColor: popoverColor,
        panelTextColor: textColor2,
        arrowColor: iconColor,
        calendarTitleTextColor: textColor1,
        calendarTitleColorHover: hoverColor,
        calendarDaysTextColor: textColor2,
        panelHeaderDividerColor: dividerColor,
        calendarDaysDividerColor: dividerColor,
        calendarDividerColor: dividerColor,
        panelActionDividerColor: dividerColor,
        panelBoxShadow: boxShadow2,
        panelBorderRadius: borderRadius,
        calendarTitleFontWeight: fontWeightStrong,
        scrollItemBorderRadius: borderRadius,
        iconColor,
        iconColorDisabled
      };
    };
    const datePickerLight = createTheme$1({
      name: "DatePicker",
      common: commonLight,
      peers: {
        Input: inputLight$1,
        Button: buttonLight$1,
        TimePicker: timePickerLight$1,
        Scrollbar: scrollbarLight$1
      },
      self: self$G
    });
    var datePickerLight$1 = datePickerLight;

    const datePickerDark = {
      name: "DatePicker",
      common: commonDark,
      peers: {
        Input: inputDark$1,
        Button: buttonDark$1,
        TimePicker: timePickerDark$1,
        Scrollbar: scrollbarDark$1
      },

      self(vars) {
        const {
          popoverColor,
          hoverColor,
          primaryColor
        } = vars;
        const commonSelf = self$G(vars);
        commonSelf.itemColorDisabled = composite(popoverColor, hoverColor);
        commonSelf.itemColorIncluded = changeColor(primaryColor, {
          alpha: 0.15
        });
        commonSelf.itemColorHover = composite(popoverColor, hoverColor);
        return commonSelf;
      }

    };
    var datePickerDark$1 = datePickerDark;

    function uniCalendarValidation(props, mergedValueRef) {
      const timePickerValidatorRef = vue.computed(() => {
        const {
          isTimeDisabled
        } = props;
        const {
          value
        } = mergedValueRef;
        if (value === null || Array.isArray(value)) return void 0;
        return isTimeDisabled === null || isTimeDisabled === void 0 ? void 0 : isTimeDisabled(value);
      });
      const isHourDisabledRef = vue.computed(() => {
        var _timePickerValidatorR;

        return (_timePickerValidatorR = timePickerValidatorRef.value) === null || _timePickerValidatorR === void 0 ? void 0 : _timePickerValidatorR.isHourDisabled;
      });
      const isMinuteDisabledRef = vue.computed(() => {
        var _timePickerValidatorR2;

        return (_timePickerValidatorR2 = timePickerValidatorRef.value) === null || _timePickerValidatorR2 === void 0 ? void 0 : _timePickerValidatorR2.isMinuteDisabled;
      });
      const isSecondDisabledRef = vue.computed(() => {
        var _timePickerValidatorR3;

        return (_timePickerValidatorR3 = timePickerValidatorRef.value) === null || _timePickerValidatorR3 === void 0 ? void 0 : _timePickerValidatorR3.isSecondDisabled;
      });
      const isDateInvalidRef = vue.computed(() => {
        const {
          type,
          isDateDisabled
        } = props;
        const {
          value
        } = mergedValueRef;

        if (value === null || Array.isArray(value) || !["date", "datetime"].includes(type) || !isDateDisabled) {
          return false;
        }

        return isDateDisabled(value);
      });
      const isTimeInvalidRef = vue.computed(() => {
        const {
          type
        } = props;
        const {
          value
        } = mergedValueRef;

        if (value === null || !(type !== "datetime") || Array.isArray(value)) {
          return false;
        }

        const time = new Date(value);
        const hour = time.getHours();
        const minute = time.getMinutes();
        const second = time.getMinutes();
        return (isHourDisabledRef.value ? isHourDisabledRef.value(hour) : false) || (isMinuteDisabledRef.value ? isMinuteDisabledRef.value(minute, hour) : false) || (isSecondDisabledRef.value ? isSecondDisabledRef.value(second, minute, hour) : false);
      });
      const isDateTimeInvalidRef = vue.computed(() => {
        return isDateInvalidRef.value || isTimeInvalidRef.value;
      });
      const isValueInvalidRef = vue.computed(() => {
        const {
          type
        } = props;
        if (type === "date") return isDateInvalidRef.value;
        if (type === "datetime") return isDateTimeInvalidRef.value;
        return false;
      });
      return {
        isValueInvalidRef,
        isDateInvalidRef,
        isTimeInvalidRef,
        isDateTimeInvalidRef,
        isHourDisabledRef,
        isMinuteDisabledRef,
        isSecondDisabledRef
      };
    }
    function dualCalendarValidation(props, mergedValueRef) {
      const timePickerValidatorRef = vue.computed(() => {
        const {
          isTimeDisabled
        } = props;
        const {
          value
        } = mergedValueRef;

        if (!Array.isArray(value) || !isTimeDisabled) {
          return [void 0, void 0];
        }

        return [isTimeDisabled === null || isTimeDisabled === void 0 ? void 0 : isTimeDisabled(value[0], "start", value), isTimeDisabled === null || isTimeDisabled === void 0 ? void 0 : isTimeDisabled(value[1], "end", value)];
      });
      const timeValidator = {
        isStartHourDisabledRef: vue.computed(() => {
          var _timePickerValidatorR4;

          return (_timePickerValidatorR4 = timePickerValidatorRef.value[0]) === null || _timePickerValidatorR4 === void 0 ? void 0 : _timePickerValidatorR4.isHourDisabled;
        }),
        isEndHourDisabledRef: vue.computed(() => {
          var _timePickerValidatorR5;

          return (_timePickerValidatorR5 = timePickerValidatorRef.value[1]) === null || _timePickerValidatorR5 === void 0 ? void 0 : _timePickerValidatorR5.isHourDisabled;
        }),
        isStartMinuteDisabledRef: vue.computed(() => {
          var _timePickerValidatorR6;

          return (_timePickerValidatorR6 = timePickerValidatorRef.value[0]) === null || _timePickerValidatorR6 === void 0 ? void 0 : _timePickerValidatorR6.isMinuteDisabled;
        }),
        isEndMinuteDisabledRef: vue.computed(() => {
          var _timePickerValidatorR7;

          return (_timePickerValidatorR7 = timePickerValidatorRef.value[1]) === null || _timePickerValidatorR7 === void 0 ? void 0 : _timePickerValidatorR7.isMinuteDisabled;
        }),
        isStartSecondDisabledRef: vue.computed(() => {
          var _timePickerValidatorR8;

          return (_timePickerValidatorR8 = timePickerValidatorRef.value[0]) === null || _timePickerValidatorR8 === void 0 ? void 0 : _timePickerValidatorR8.isSecondDisabled;
        }),
        isEndSecondDisabledRef: vue.computed(() => {
          var _timePickerValidatorR9;

          return (_timePickerValidatorR9 = timePickerValidatorRef.value[1]) === null || _timePickerValidatorR9 === void 0 ? void 0 : _timePickerValidatorR9.isSecondDisabled;
        })
      };
      const isStartDateInvalidRef = vue.computed(() => {
        const {
          type,
          isDateDisabled
        } = props;
        const {
          value
        } = mergedValueRef;

        if (value === null || !Array.isArray(value) || !["daterange", "datetimerange"].includes(type) || !isDateDisabled) {
          return false;
        }

        return isDateDisabled(value[0], "start", value);
      });
      const isEndDateInvalidRef = vue.computed(() => {
        const {
          type,
          isDateDisabled
        } = props;
        const {
          value
        } = mergedValueRef;

        if (value === null || !Array.isArray(value) || !["daterange", "datetimerange"].includes(type) || !isDateDisabled) {
          return false;
        }

        return isDateDisabled(value[1], "end", value);
      });
      const isStartTimeInvalidRef = vue.computed(() => {
        const {
          type
        } = props;
        const {
          value
        } = mergedValueRef;

        if (value === null || !Array.isArray(value) || type !== "datetimerange") {
          return false;
        }

        const startHours = getHours(value[0]);
        const startMinutes = getMinutes(value[0]);
        const startSeconds = getSeconds(value[0]);
        const {
          isStartHourDisabledRef,
          isStartMinuteDisabledRef,
          isStartSecondDisabledRef
        } = timeValidator;
        const startTimeInvalid = (isStartHourDisabledRef.value ? isStartHourDisabledRef.value(startHours) : false) || (isStartMinuteDisabledRef.value ? isStartMinuteDisabledRef.value(startMinutes, startHours) : false) || (isStartSecondDisabledRef.value ? isStartSecondDisabledRef.value(startSeconds, startMinutes, startHours) : false);
        return startTimeInvalid;
      });
      const isEndTimeInvalidRef = vue.computed(() => {
        const {
          type
        } = props;
        const {
          value
        } = mergedValueRef;

        if (value === null || !Array.isArray(value) || type !== "datetimerange") {
          return false;
        }

        const endHours = getHours(value[1]);
        const endMinutes = getMinutes(value[1]);
        const endSeconds = getSeconds(value[1]);
        const {
          isEndHourDisabledRef,
          isEndMinuteDisabledRef,
          isEndSecondDisabledRef
        } = timeValidator;
        const endTimeInvalid = (isEndHourDisabledRef.value ? isEndHourDisabledRef.value(endHours) : false) || (isEndMinuteDisabledRef.value ? isEndMinuteDisabledRef.value(endMinutes, endHours) : false) || (isEndSecondDisabledRef.value ? isEndSecondDisabledRef.value(endSeconds, endMinutes, endHours) : false);
        return endTimeInvalid;
      });
      const isStartValueInvalidRef = vue.computed(() => {
        return isStartDateInvalidRef.value || isStartTimeInvalidRef.value;
      });
      const isEndValueInvalidRef = vue.computed(() => {
        return isEndDateInvalidRef.value || isEndTimeInvalidRef.value;
      });
      const isRangeInvalidRef = vue.computed(() => {
        return isStartValueInvalidRef.value || isEndValueInvalidRef.value;
      });
      return { ...timeValidator,
        isStartDateInvalidRef,
        isEndDateInvalidRef,
        isStartTimeInvalidRef,
        isEndTimeInvalidRef,
        isStartValueInvalidRef,
        isEndValueInvalidRef,
        isRangeInvalidRef
      };
    }

    const datePickerInjectionKey = createInjectionKey("n-date-picker");

    var formatInTimeZone$1 = {exports: {}};

    var cloneObject = {exports: {}};

    var assign = {exports: {}};

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = assign;

    	function assign(target, object) {
    	  if (target == null) {
    	    throw new TypeError('assign requires that input parameter not be null or undefined');
    	  }

    	  for (var property in object) {
    	    if (Object.prototype.hasOwnProperty.call(object, property)) {
    	      target[property] = object[property];
    	    }
    	  }

    	  return target;
    	}

    	module.exports = exports.default;
    } (assign, assign.exports));

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = cloneObject;

    	var _index = _interopRequireDefault(assign.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}

    	function cloneObject(object) {
    	  return (0, _index.default)({}, object);
    	}

    	module.exports = exports.default;
    } (cloneObject, cloneObject.exports));

    var format$3 = {exports: {}};

    var format$2 = {exports: {}};

    var isValid = {exports: {}};

    var isDate = {exports: {}};

    var requiredArgs = {exports: {}};

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = requiredArgs;

    	function requiredArgs(required, args) {
    	  if (args.length < required) {
    	    throw new TypeError(required + ' argument' + (required > 1 ? 's' : '') + ' required, but only ' + args.length + ' present');
    	  }
    	}

    	module.exports = exports.default;
    } (requiredArgs, requiredArgs.exports));

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = isDate;

    	var _index = _interopRequireDefault(requiredArgs.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}
    	/**
    	 * @name isDate
    	 * @category Common Helpers
    	 * @summary Is the given value a date?
    	 *
    	 * @description
    	 * Returns true if the given value is an instance of Date. The function works for dates transferred across iframes.
    	 *
    	 * @param {*} value - the value to check
    	 * @returns {boolean} true if the given value is a date
    	 * @throws {TypeError} 1 arguments required
    	 *
    	 * @example
    	 * // For a valid date:
    	 * const result = isDate(new Date())
    	 * //=> true
    	 *
    	 * @example
    	 * // For an invalid date:
    	 * const result = isDate(new Date(NaN))
    	 * //=> true
    	 *
    	 * @example
    	 * // For some value:
    	 * const result = isDate('2014-02-31')
    	 * //=> false
    	 *
    	 * @example
    	 * // For an object:
    	 * const result = isDate({})
    	 * //=> false
    	 */


    	function isDate(value) {
    	  (0, _index.default)(1, arguments);
    	  return value instanceof Date || typeof value === 'object' && Object.prototype.toString.call(value) === '[object Date]';
    	}

    	module.exports = exports.default;
    } (isDate, isDate.exports));

    var toDate$1 = {exports: {}};

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = toDate;

    	var _index = _interopRequireDefault(requiredArgs.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}
    	/**
    	 * @name toDate
    	 * @category Common Helpers
    	 * @summary Convert the given argument to an instance of Date.
    	 *
    	 * @description
    	 * Convert the given argument to an instance of Date.
    	 *
    	 * If the argument is an instance of Date, the function returns its clone.
    	 *
    	 * If the argument is a number, it is treated as a timestamp.
    	 *
    	 * If the argument is none of the above, the function returns Invalid Date.
    	 *
    	 * **Note**: *all* Date arguments passed to any *date-fns* function is processed by `toDate`.
    	 *
    	 * @param {Date|Number} argument - the value to convert
    	 * @returns {Date} the parsed date in the local time zone
    	 * @throws {TypeError} 1 argument required
    	 *
    	 * @example
    	 * // Clone the date:
    	 * const result = toDate(new Date(2014, 1, 11, 11, 30, 30))
    	 * //=> Tue Feb 11 2014 11:30:30
    	 *
    	 * @example
    	 * // Convert the timestamp to date:
    	 * const result = toDate(1392098430000)
    	 * //=> Tue Feb 11 2014 11:30:30
    	 */


    	function toDate(argument) {
    	  (0, _index.default)(1, arguments);
    	  var argStr = Object.prototype.toString.call(argument); // Clone the date

    	  if (argument instanceof Date || typeof argument === 'object' && argStr === '[object Date]') {
    	    // Prevent the date to lose the milliseconds when passed to new Date() in IE10
    	    return new Date(argument.getTime());
    	  } else if (typeof argument === 'number' || argStr === '[object Number]') {
    	    return new Date(argument);
    	  } else {
    	    if ((typeof argument === 'string' || argStr === '[object String]') && typeof console !== 'undefined') {
    	      // eslint-disable-next-line no-console
    	      console.warn("Starting with v2.0.0-beta.1 date-fns doesn't accept strings as date arguments. Please use `parseISO` to parse strings. See: https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#string-arguments"); // eslint-disable-next-line no-console

    	      console.warn(new Error().stack);
    	    }

    	    return new Date(NaN);
    	  }
    	}

    	module.exports = exports.default;
    } (toDate$1, toDate$1.exports));

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = isValid;

    	var _index = _interopRequireDefault(isDate.exports);

    	var _index2 = _interopRequireDefault(toDate$1.exports);

    	var _index3 = _interopRequireDefault(requiredArgs.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}
    	/**
    	 * @name isValid
    	 * @category Common Helpers
    	 * @summary Is the given date valid?
    	 *
    	 * @description
    	 * Returns false if argument is Invalid Date and true otherwise.
    	 * Argument is converted to Date using `toDate`. See [toDate]{@link https://date-fns.org/docs/toDate}
    	 * Invalid Date is a Date, whose time value is NaN.
    	 *
    	 * Time value of Date: http://es5.github.io/#x15.9.1.1
    	 *
    	 * @param {*} date - the date to check
    	 * @returns {Boolean} the date is valid
    	 * @throws {TypeError} 1 argument required
    	 *
    	 * @example
    	 * // For the valid date:
    	 * const result = isValid(new Date(2014, 1, 31))
    	 * //=> true
    	 *
    	 * @example
    	 * // For the value, convertable into a date:
    	 * const result = isValid(1393804800000)
    	 * //=> true
    	 *
    	 * @example
    	 * // For the invalid date:
    	 * const result = isValid(new Date(''))
    	 * //=> false
    	 */


    	function isValid(dirtyDate) {
    	  (0, _index3.default)(1, arguments);

    	  if (!(0, _index.default)(dirtyDate) && typeof dirtyDate !== 'number') {
    	    return false;
    	  }

    	  var date = (0, _index2.default)(dirtyDate);
    	  return !isNaN(Number(date));
    	}

    	module.exports = exports.default;
    } (isValid, isValid.exports));

    var subMilliseconds = {exports: {}};

    var addMilliseconds = {exports: {}};

    var toInteger = {exports: {}};

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = toInteger;

    	function toInteger(dirtyNumber) {
    	  if (dirtyNumber === null || dirtyNumber === true || dirtyNumber === false) {
    	    return NaN;
    	  }

    	  var number = Number(dirtyNumber);

    	  if (isNaN(number)) {
    	    return number;
    	  }

    	  return number < 0 ? Math.ceil(number) : Math.floor(number);
    	}

    	module.exports = exports.default;
    } (toInteger, toInteger.exports));

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = addMilliseconds;

    	var _index = _interopRequireDefault(toInteger.exports);

    	var _index2 = _interopRequireDefault(toDate$1.exports);

    	var _index3 = _interopRequireDefault(requiredArgs.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}
    	/**
    	 * @name addMilliseconds
    	 * @category Millisecond Helpers
    	 * @summary Add the specified number of milliseconds to the given date.
    	 *
    	 * @description
    	 * Add the specified number of milliseconds to the given date.
    	 *
    	 * @param {Date|Number} date - the date to be changed
    	 * @param {Number} amount - the amount of milliseconds to be added. Positive decimals will be rounded using `Math.floor`, decimals less than zero will be rounded using `Math.ceil`.
    	 * @returns {Date} the new date with the milliseconds added
    	 * @throws {TypeError} 2 arguments required
    	 *
    	 * @example
    	 * // Add 750 milliseconds to 10 July 2014 12:45:30.000:
    	 * const result = addMilliseconds(new Date(2014, 6, 10, 12, 45, 30, 0), 750)
    	 * //=> Thu Jul 10 2014 12:45:30.750
    	 */


    	function addMilliseconds(dirtyDate, dirtyAmount) {
    	  (0, _index3.default)(2, arguments);
    	  var timestamp = (0, _index2.default)(dirtyDate).getTime();
    	  var amount = (0, _index.default)(dirtyAmount);
    	  return new Date(timestamp + amount);
    	}

    	module.exports = exports.default;
    } (addMilliseconds, addMilliseconds.exports));

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = subMilliseconds;

    	var _index = _interopRequireDefault(addMilliseconds.exports);

    	var _index2 = _interopRequireDefault(requiredArgs.exports);

    	var _index3 = _interopRequireDefault(toInteger.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}
    	/**
    	 * @name subMilliseconds
    	 * @category Millisecond Helpers
    	 * @summary Subtract the specified number of milliseconds from the given date.
    	 *
    	 * @description
    	 * Subtract the specified number of milliseconds from the given date.
    	 *
    	 * @param {Date|Number} date - the date to be changed
    	 * @param {Number} amount - the amount of milliseconds to be subtracted. Positive decimals will be rounded using `Math.floor`, decimals less than zero will be rounded using `Math.ceil`.
    	 * @returns {Date} the new date with the milliseconds subtracted
    	 * @throws {TypeError} 2 arguments required
    	 *
    	 * @example
    	 * // Subtract 750 milliseconds from 10 July 2014 12:45:30.000:
    	 * const result = subMilliseconds(new Date(2014, 6, 10, 12, 45, 30, 0), 750)
    	 * //=> Thu Jul 10 2014 12:45:29.250
    	 */


    	function subMilliseconds(dirtyDate, dirtyAmount) {
    	  (0, _index2.default)(2, arguments);
    	  var amount = (0, _index3.default)(dirtyAmount);
    	  return (0, _index.default)(dirtyDate, -amount);
    	}

    	module.exports = exports.default;
    } (subMilliseconds, subMilliseconds.exports));

    var formatters$1 = {exports: {}};

    var getUTCDayOfYear = {exports: {}};

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = getUTCDayOfYear;

    	var _index = _interopRequireDefault(toDate$1.exports);

    	var _index2 = _interopRequireDefault(requiredArgs.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}

    	var MILLISECONDS_IN_DAY = 86400000;

    	function getUTCDayOfYear(dirtyDate) {
    	  (0, _index2.default)(1, arguments);
    	  var date = (0, _index.default)(dirtyDate);
    	  var timestamp = date.getTime();
    	  date.setUTCMonth(0, 1);
    	  date.setUTCHours(0, 0, 0, 0);
    	  var startOfYearTimestamp = date.getTime();
    	  var difference = timestamp - startOfYearTimestamp;
    	  return Math.floor(difference / MILLISECONDS_IN_DAY) + 1;
    	}

    	module.exports = exports.default;
    } (getUTCDayOfYear, getUTCDayOfYear.exports));

    var getUTCISOWeek = {exports: {}};

    var startOfUTCISOWeek = {exports: {}};

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = startOfUTCISOWeek;

    	var _index = _interopRequireDefault(toDate$1.exports);

    	var _index2 = _interopRequireDefault(requiredArgs.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}

    	function startOfUTCISOWeek(dirtyDate) {
    	  (0, _index2.default)(1, arguments);
    	  var weekStartsOn = 1;
    	  var date = (0, _index.default)(dirtyDate);
    	  var day = date.getUTCDay();
    	  var diff = (day < weekStartsOn ? 7 : 0) + day - weekStartsOn;
    	  date.setUTCDate(date.getUTCDate() - diff);
    	  date.setUTCHours(0, 0, 0, 0);
    	  return date;
    	}

    	module.exports = exports.default;
    } (startOfUTCISOWeek, startOfUTCISOWeek.exports));

    var startOfUTCISOWeekYear = {exports: {}};

    var getUTCISOWeekYear = {exports: {}};

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = getUTCISOWeekYear;

    	var _index = _interopRequireDefault(toDate$1.exports);

    	var _index2 = _interopRequireDefault(requiredArgs.exports);

    	var _index3 = _interopRequireDefault(startOfUTCISOWeek.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}

    	function getUTCISOWeekYear(dirtyDate) {
    	  (0, _index2.default)(1, arguments);
    	  var date = (0, _index.default)(dirtyDate);
    	  var year = date.getUTCFullYear();
    	  var fourthOfJanuaryOfNextYear = new Date(0);
    	  fourthOfJanuaryOfNextYear.setUTCFullYear(year + 1, 0, 4);
    	  fourthOfJanuaryOfNextYear.setUTCHours(0, 0, 0, 0);
    	  var startOfNextYear = (0, _index3.default)(fourthOfJanuaryOfNextYear);
    	  var fourthOfJanuaryOfThisYear = new Date(0);
    	  fourthOfJanuaryOfThisYear.setUTCFullYear(year, 0, 4);
    	  fourthOfJanuaryOfThisYear.setUTCHours(0, 0, 0, 0);
    	  var startOfThisYear = (0, _index3.default)(fourthOfJanuaryOfThisYear);

    	  if (date.getTime() >= startOfNextYear.getTime()) {
    	    return year + 1;
    	  } else if (date.getTime() >= startOfThisYear.getTime()) {
    	    return year;
    	  } else {
    	    return year - 1;
    	  }
    	}

    	module.exports = exports.default;
    } (getUTCISOWeekYear, getUTCISOWeekYear.exports));

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = startOfUTCISOWeekYear;

    	var _index = _interopRequireDefault(getUTCISOWeekYear.exports);

    	var _index2 = _interopRequireDefault(startOfUTCISOWeek.exports);

    	var _index3 = _interopRequireDefault(requiredArgs.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}

    	function startOfUTCISOWeekYear(dirtyDate) {
    	  (0, _index3.default)(1, arguments);
    	  var year = (0, _index.default)(dirtyDate);
    	  var fourthOfJanuary = new Date(0);
    	  fourthOfJanuary.setUTCFullYear(year, 0, 4);
    	  fourthOfJanuary.setUTCHours(0, 0, 0, 0);
    	  var date = (0, _index2.default)(fourthOfJanuary);
    	  return date;
    	}

    	module.exports = exports.default;
    } (startOfUTCISOWeekYear, startOfUTCISOWeekYear.exports));

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = getUTCISOWeek;

    	var _index = _interopRequireDefault(toDate$1.exports);

    	var _index2 = _interopRequireDefault(startOfUTCISOWeek.exports);

    	var _index3 = _interopRequireDefault(startOfUTCISOWeekYear.exports);

    	var _index4 = _interopRequireDefault(requiredArgs.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}

    	var MILLISECONDS_IN_WEEK = 604800000;

    	function getUTCISOWeek(dirtyDate) {
    	  (0, _index4.default)(1, arguments);
    	  var date = (0, _index.default)(dirtyDate);
    	  var diff = (0, _index2.default)(date).getTime() - (0, _index3.default)(date).getTime(); // Round the number of days to the nearest integer
    	  // because the number of milliseconds in a week is not constant
    	  // (e.g. it's different in the week of the daylight saving time clock shift)

    	  return Math.round(diff / MILLISECONDS_IN_WEEK) + 1;
    	}

    	module.exports = exports.default;
    } (getUTCISOWeek, getUTCISOWeek.exports));

    var getUTCWeek = {exports: {}};

    var startOfUTCWeek = {exports: {}};

    var defaultOptions$1 = {};

    Object.defineProperty(defaultOptions$1, "__esModule", {
      value: true
    });
    defaultOptions$1.getDefaultOptions = getDefaultOptions;
    defaultOptions$1.setDefaultOptions = setDefaultOptions;
    var defaultOptions = {};

    function getDefaultOptions() {
      return defaultOptions;
    }

    function setDefaultOptions(newOptions) {
      defaultOptions = newOptions;
    }

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = startOfUTCWeek;

    	var _index = _interopRequireDefault(toDate$1.exports);

    	var _index2 = _interopRequireDefault(requiredArgs.exports);

    	var _index3 = _interopRequireDefault(toInteger.exports);

    	var _index4 = defaultOptions$1;

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}

    	function startOfUTCWeek(dirtyDate, options) {
    	  var _ref, _ref2, _ref3, _options$weekStartsOn, _options$locale, _options$locale$optio, _defaultOptions$local, _defaultOptions$local2;

    	  (0, _index2.default)(1, arguments);
    	  var defaultOptions = (0, _index4.getDefaultOptions)();
    	  var weekStartsOn = (0, _index3.default)((_ref = (_ref2 = (_ref3 = (_options$weekStartsOn = options === null || options === void 0 ? void 0 : options.weekStartsOn) !== null && _options$weekStartsOn !== void 0 ? _options$weekStartsOn : options === null || options === void 0 ? void 0 : (_options$locale = options.locale) === null || _options$locale === void 0 ? void 0 : (_options$locale$optio = _options$locale.options) === null || _options$locale$optio === void 0 ? void 0 : _options$locale$optio.weekStartsOn) !== null && _ref3 !== void 0 ? _ref3 : defaultOptions.weekStartsOn) !== null && _ref2 !== void 0 ? _ref2 : (_defaultOptions$local = defaultOptions.locale) === null || _defaultOptions$local === void 0 ? void 0 : (_defaultOptions$local2 = _defaultOptions$local.options) === null || _defaultOptions$local2 === void 0 ? void 0 : _defaultOptions$local2.weekStartsOn) !== null && _ref !== void 0 ? _ref : 0); // Test if weekStartsOn is between 0 and 6 _and_ is not NaN

    	  if (!(weekStartsOn >= 0 && weekStartsOn <= 6)) {
    	    throw new RangeError('weekStartsOn must be between 0 and 6 inclusively');
    	  }

    	  var date = (0, _index.default)(dirtyDate);
    	  var day = date.getUTCDay();
    	  var diff = (day < weekStartsOn ? 7 : 0) + day - weekStartsOn;
    	  date.setUTCDate(date.getUTCDate() - diff);
    	  date.setUTCHours(0, 0, 0, 0);
    	  return date;
    	}

    	module.exports = exports.default;
    } (startOfUTCWeek, startOfUTCWeek.exports));

    var startOfUTCWeekYear = {exports: {}};

    var getUTCWeekYear = {exports: {}};

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = getUTCWeekYear;

    	var _index = _interopRequireDefault(toDate$1.exports);

    	var _index2 = _interopRequireDefault(requiredArgs.exports);

    	var _index3 = _interopRequireDefault(startOfUTCWeek.exports);

    	var _index4 = _interopRequireDefault(toInteger.exports);

    	var _index5 = defaultOptions$1;

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}

    	function getUTCWeekYear(dirtyDate, options) {
    	  var _ref, _ref2, _ref3, _options$firstWeekCon, _options$locale, _options$locale$optio, _defaultOptions$local, _defaultOptions$local2;

    	  (0, _index2.default)(1, arguments);
    	  var date = (0, _index.default)(dirtyDate);
    	  var year = date.getUTCFullYear();
    	  var defaultOptions = (0, _index5.getDefaultOptions)();
    	  var firstWeekContainsDate = (0, _index4.default)((_ref = (_ref2 = (_ref3 = (_options$firstWeekCon = options === null || options === void 0 ? void 0 : options.firstWeekContainsDate) !== null && _options$firstWeekCon !== void 0 ? _options$firstWeekCon : options === null || options === void 0 ? void 0 : (_options$locale = options.locale) === null || _options$locale === void 0 ? void 0 : (_options$locale$optio = _options$locale.options) === null || _options$locale$optio === void 0 ? void 0 : _options$locale$optio.firstWeekContainsDate) !== null && _ref3 !== void 0 ? _ref3 : defaultOptions.firstWeekContainsDate) !== null && _ref2 !== void 0 ? _ref2 : (_defaultOptions$local = defaultOptions.locale) === null || _defaultOptions$local === void 0 ? void 0 : (_defaultOptions$local2 = _defaultOptions$local.options) === null || _defaultOptions$local2 === void 0 ? void 0 : _defaultOptions$local2.firstWeekContainsDate) !== null && _ref !== void 0 ? _ref : 1); // Test if weekStartsOn is between 1 and 7 _and_ is not NaN

    	  if (!(firstWeekContainsDate >= 1 && firstWeekContainsDate <= 7)) {
    	    throw new RangeError('firstWeekContainsDate must be between 1 and 7 inclusively');
    	  }

    	  var firstWeekOfNextYear = new Date(0);
    	  firstWeekOfNextYear.setUTCFullYear(year + 1, 0, firstWeekContainsDate);
    	  firstWeekOfNextYear.setUTCHours(0, 0, 0, 0);
    	  var startOfNextYear = (0, _index3.default)(firstWeekOfNextYear, options);
    	  var firstWeekOfThisYear = new Date(0);
    	  firstWeekOfThisYear.setUTCFullYear(year, 0, firstWeekContainsDate);
    	  firstWeekOfThisYear.setUTCHours(0, 0, 0, 0);
    	  var startOfThisYear = (0, _index3.default)(firstWeekOfThisYear, options);

    	  if (date.getTime() >= startOfNextYear.getTime()) {
    	    return year + 1;
    	  } else if (date.getTime() >= startOfThisYear.getTime()) {
    	    return year;
    	  } else {
    	    return year - 1;
    	  }
    	}

    	module.exports = exports.default;
    } (getUTCWeekYear, getUTCWeekYear.exports));

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = startOfUTCWeekYear;

    	var _index = _interopRequireDefault(getUTCWeekYear.exports);

    	var _index2 = _interopRequireDefault(requiredArgs.exports);

    	var _index3 = _interopRequireDefault(startOfUTCWeek.exports);

    	var _index4 = _interopRequireDefault(toInteger.exports);

    	var _index5 = defaultOptions$1;

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}

    	function startOfUTCWeekYear(dirtyDate, options) {
    	  var _ref, _ref2, _ref3, _options$firstWeekCon, _options$locale, _options$locale$optio, _defaultOptions$local, _defaultOptions$local2;

    	  (0, _index2.default)(1, arguments);
    	  var defaultOptions = (0, _index5.getDefaultOptions)();
    	  var firstWeekContainsDate = (0, _index4.default)((_ref = (_ref2 = (_ref3 = (_options$firstWeekCon = options === null || options === void 0 ? void 0 : options.firstWeekContainsDate) !== null && _options$firstWeekCon !== void 0 ? _options$firstWeekCon : options === null || options === void 0 ? void 0 : (_options$locale = options.locale) === null || _options$locale === void 0 ? void 0 : (_options$locale$optio = _options$locale.options) === null || _options$locale$optio === void 0 ? void 0 : _options$locale$optio.firstWeekContainsDate) !== null && _ref3 !== void 0 ? _ref3 : defaultOptions.firstWeekContainsDate) !== null && _ref2 !== void 0 ? _ref2 : (_defaultOptions$local = defaultOptions.locale) === null || _defaultOptions$local === void 0 ? void 0 : (_defaultOptions$local2 = _defaultOptions$local.options) === null || _defaultOptions$local2 === void 0 ? void 0 : _defaultOptions$local2.firstWeekContainsDate) !== null && _ref !== void 0 ? _ref : 1);
    	  var year = (0, _index.default)(dirtyDate, options);
    	  var firstWeek = new Date(0);
    	  firstWeek.setUTCFullYear(year, 0, firstWeekContainsDate);
    	  firstWeek.setUTCHours(0, 0, 0, 0);
    	  var date = (0, _index3.default)(firstWeek, options);
    	  return date;
    	}

    	module.exports = exports.default;
    } (startOfUTCWeekYear, startOfUTCWeekYear.exports));

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = getUTCWeek;

    	var _index = _interopRequireDefault(toDate$1.exports);

    	var _index2 = _interopRequireDefault(startOfUTCWeek.exports);

    	var _index3 = _interopRequireDefault(startOfUTCWeekYear.exports);

    	var _index4 = _interopRequireDefault(requiredArgs.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}

    	var MILLISECONDS_IN_WEEK = 604800000;

    	function getUTCWeek(dirtyDate, options) {
    	  (0, _index4.default)(1, arguments);
    	  var date = (0, _index.default)(dirtyDate);
    	  var diff = (0, _index2.default)(date, options).getTime() - (0, _index3.default)(date, options).getTime(); // Round the number of days to the nearest integer
    	  // because the number of milliseconds in a week is not constant
    	  // (e.g. it's different in the week of the daylight saving time clock shift)

    	  return Math.round(diff / MILLISECONDS_IN_WEEK) + 1;
    	}

    	module.exports = exports.default;
    } (getUTCWeek, getUTCWeek.exports));

    var addLeadingZeros = {exports: {}};

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = addLeadingZeros;

    	function addLeadingZeros(number, targetLength) {
    	  var sign = number < 0 ? '-' : '';
    	  var output = Math.abs(number).toString();

    	  while (output.length < targetLength) {
    	    output = '0' + output;
    	  }

    	  return sign + output;
    	}

    	module.exports = exports.default;
    } (addLeadingZeros, addLeadingZeros.exports));

    var lightFormatters = {exports: {}};

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = void 0;

    	var _index = _interopRequireDefault(addLeadingZeros.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}
    	/*
    	 * |     | Unit                           |     | Unit                           |
    	 * |-----|--------------------------------|-----|--------------------------------|
    	 * |  a  | AM, PM                         |  A* |                                |
    	 * |  d  | Day of month                   |  D  |                                |
    	 * |  h  | Hour [1-12]                    |  H  | Hour [0-23]                    |
    	 * |  m  | Minute                         |  M  | Month                          |
    	 * |  s  | Second                         |  S  | Fraction of second             |
    	 * |  y  | Year (abs)                     |  Y  |                                |
    	 *
    	 * Letters marked by * are not implemented but reserved by Unicode standard.
    	 */


    	var formatters = {
    	  // Year
    	  y: function (date, token) {
    	    // From http://www.unicode.org/reports/tr35/tr35-31/tr35-dates.html#Date_Format_tokens
    	    // | Year     |     y | yy |   yyy |  yyyy | yyyyy |
    	    // |----------|-------|----|-------|-------|-------|
    	    // | AD 1     |     1 | 01 |   001 |  0001 | 00001 |
    	    // | AD 12    |    12 | 12 |   012 |  0012 | 00012 |
    	    // | AD 123   |   123 | 23 |   123 |  0123 | 00123 |
    	    // | AD 1234  |  1234 | 34 |  1234 |  1234 | 01234 |
    	    // | AD 12345 | 12345 | 45 | 12345 | 12345 | 12345 |
    	    var signedYear = date.getUTCFullYear(); // Returns 1 for 1 BC (which is year 0 in JavaScript)

    	    var year = signedYear > 0 ? signedYear : 1 - signedYear;
    	    return (0, _index.default)(token === 'yy' ? year % 100 : year, token.length);
    	  },
    	  // Month
    	  M: function (date, token) {
    	    var month = date.getUTCMonth();
    	    return token === 'M' ? String(month + 1) : (0, _index.default)(month + 1, 2);
    	  },
    	  // Day of the month
    	  d: function (date, token) {
    	    return (0, _index.default)(date.getUTCDate(), token.length);
    	  },
    	  // AM or PM
    	  a: function (date, token) {
    	    var dayPeriodEnumValue = date.getUTCHours() / 12 >= 1 ? 'pm' : 'am';

    	    switch (token) {
    	      case 'a':
    	      case 'aa':
    	        return dayPeriodEnumValue.toUpperCase();

    	      case 'aaa':
    	        return dayPeriodEnumValue;

    	      case 'aaaaa':
    	        return dayPeriodEnumValue[0];

    	      case 'aaaa':
    	      default:
    	        return dayPeriodEnumValue === 'am' ? 'a.m.' : 'p.m.';
    	    }
    	  },
    	  // Hour [1-12]
    	  h: function (date, token) {
    	    return (0, _index.default)(date.getUTCHours() % 12 || 12, token.length);
    	  },
    	  // Hour [0-23]
    	  H: function (date, token) {
    	    return (0, _index.default)(date.getUTCHours(), token.length);
    	  },
    	  // Minute
    	  m: function (date, token) {
    	    return (0, _index.default)(date.getUTCMinutes(), token.length);
    	  },
    	  // Second
    	  s: function (date, token) {
    	    return (0, _index.default)(date.getUTCSeconds(), token.length);
    	  },
    	  // Fraction of second
    	  S: function (date, token) {
    	    var numberOfDigits = token.length;
    	    var milliseconds = date.getUTCMilliseconds();
    	    var fractionalSeconds = Math.floor(milliseconds * Math.pow(10, numberOfDigits - 3));
    	    return (0, _index.default)(fractionalSeconds, token.length);
    	  }
    	};
    	var _default = formatters;
    	exports.default = _default;
    	module.exports = exports.default;
    } (lightFormatters, lightFormatters.exports));

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = void 0;

    	var _index = _interopRequireDefault(getUTCDayOfYear.exports);

    	var _index2 = _interopRequireDefault(getUTCISOWeek.exports);

    	var _index3 = _interopRequireDefault(getUTCISOWeekYear.exports);

    	var _index4 = _interopRequireDefault(getUTCWeek.exports);

    	var _index5 = _interopRequireDefault(getUTCWeekYear.exports);

    	var _index6 = _interopRequireDefault(addLeadingZeros.exports);

    	var _index7 = _interopRequireDefault(lightFormatters.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}

    	var dayPeriodEnum = {
    	  am: 'am',
    	  pm: 'pm',
    	  midnight: 'midnight',
    	  noon: 'noon',
    	  morning: 'morning',
    	  afternoon: 'afternoon',
    	  evening: 'evening',
    	  night: 'night'
    	};
    	/*
    	 * |     | Unit                           |     | Unit                           |
    	 * |-----|--------------------------------|-----|--------------------------------|
    	 * |  a  | AM, PM                         |  A* | Milliseconds in day            |
    	 * |  b  | AM, PM, noon, midnight         |  B  | Flexible day period            |
    	 * |  c  | Stand-alone local day of week  |  C* | Localized hour w/ day period   |
    	 * |  d  | Day of month                   |  D  | Day of year                    |
    	 * |  e  | Local day of week              |  E  | Day of week                    |
    	 * |  f  |                                |  F* | Day of week in month           |
    	 * |  g* | Modified Julian day            |  G  | Era                            |
    	 * |  h  | Hour [1-12]                    |  H  | Hour [0-23]                    |
    	 * |  i! | ISO day of week                |  I! | ISO week of year               |
    	 * |  j* | Localized hour w/ day period   |  J* | Localized hour w/o day period  |
    	 * |  k  | Hour [1-24]                    |  K  | Hour [0-11]                    |
    	 * |  l* | (deprecated)                   |  L  | Stand-alone month              |
    	 * |  m  | Minute                         |  M  | Month                          |
    	 * |  n  |                                |  N  |                                |
    	 * |  o! | Ordinal number modifier        |  O  | Timezone (GMT)                 |
    	 * |  p! | Long localized time            |  P! | Long localized date            |
    	 * |  q  | Stand-alone quarter            |  Q  | Quarter                        |
    	 * |  r* | Related Gregorian year         |  R! | ISO week-numbering year        |
    	 * |  s  | Second                         |  S  | Fraction of second             |
    	 * |  t! | Seconds timestamp              |  T! | Milliseconds timestamp         |
    	 * |  u  | Extended year                  |  U* | Cyclic year                    |
    	 * |  v* | Timezone (generic non-locat.)  |  V* | Timezone (location)            |
    	 * |  w  | Local week of year             |  W* | Week of month                  |
    	 * |  x  | Timezone (ISO-8601 w/o Z)      |  X  | Timezone (ISO-8601)            |
    	 * |  y  | Year (abs)                     |  Y  | Local week-numbering year      |
    	 * |  z  | Timezone (specific non-locat.) |  Z* | Timezone (aliases)             |
    	 *
    	 * Letters marked by * are not implemented but reserved by Unicode standard.
    	 *
    	 * Letters marked by ! are non-standard, but implemented by date-fns:
    	 * - `o` modifies the previous token to turn it into an ordinal (see `format` docs)
    	 * - `i` is ISO day of week. For `i` and `ii` is returns numeric ISO week days,
    	 *   i.e. 7 for Sunday, 1 for Monday, etc.
    	 * - `I` is ISO week of year, as opposed to `w` which is local week of year.
    	 * - `R` is ISO week-numbering year, as opposed to `Y` which is local week-numbering year.
    	 *   `R` is supposed to be used in conjunction with `I` and `i`
    	 *   for universal ISO week-numbering date, whereas
    	 *   `Y` is supposed to be used in conjunction with `w` and `e`
    	 *   for week-numbering date specific to the locale.
    	 * - `P` is long localized date format
    	 * - `p` is long localized time format
    	 */

    	var formatters = {
    	  // Era
    	  G: function (date, token, localize) {
    	    var era = date.getUTCFullYear() > 0 ? 1 : 0;

    	    switch (token) {
    	      // AD, BC
    	      case 'G':
    	      case 'GG':
    	      case 'GGG':
    	        return localize.era(era, {
    	          width: 'abbreviated'
    	        });
    	      // A, B

    	      case 'GGGGG':
    	        return localize.era(era, {
    	          width: 'narrow'
    	        });
    	      // Anno Domini, Before Christ

    	      case 'GGGG':
    	      default:
    	        return localize.era(era, {
    	          width: 'wide'
    	        });
    	    }
    	  },
    	  // Year
    	  y: function (date, token, localize) {
    	    // Ordinal number
    	    if (token === 'yo') {
    	      var signedYear = date.getUTCFullYear(); // Returns 1 for 1 BC (which is year 0 in JavaScript)

    	      var year = signedYear > 0 ? signedYear : 1 - signedYear;
    	      return localize.ordinalNumber(year, {
    	        unit: 'year'
    	      });
    	    }

    	    return _index7.default.y(date, token);
    	  },
    	  // Local week-numbering year
    	  Y: function (date, token, localize, options) {
    	    var signedWeekYear = (0, _index5.default)(date, options); // Returns 1 for 1 BC (which is year 0 in JavaScript)

    	    var weekYear = signedWeekYear > 0 ? signedWeekYear : 1 - signedWeekYear; // Two digit year

    	    if (token === 'YY') {
    	      var twoDigitYear = weekYear % 100;
    	      return (0, _index6.default)(twoDigitYear, 2);
    	    } // Ordinal number


    	    if (token === 'Yo') {
    	      return localize.ordinalNumber(weekYear, {
    	        unit: 'year'
    	      });
    	    } // Padding


    	    return (0, _index6.default)(weekYear, token.length);
    	  },
    	  // ISO week-numbering year
    	  R: function (date, token) {
    	    var isoWeekYear = (0, _index3.default)(date); // Padding

    	    return (0, _index6.default)(isoWeekYear, token.length);
    	  },
    	  // Extended year. This is a single number designating the year of this calendar system.
    	  // The main difference between `y` and `u` localizers are B.C. years:
    	  // | Year | `y` | `u` |
    	  // |------|-----|-----|
    	  // | AC 1 |   1 |   1 |
    	  // | BC 1 |   1 |   0 |
    	  // | BC 2 |   2 |  -1 |
    	  // Also `yy` always returns the last two digits of a year,
    	  // while `uu` pads single digit years to 2 characters and returns other years unchanged.
    	  u: function (date, token) {
    	    var year = date.getUTCFullYear();
    	    return (0, _index6.default)(year, token.length);
    	  },
    	  // Quarter
    	  Q: function (date, token, localize) {
    	    var quarter = Math.ceil((date.getUTCMonth() + 1) / 3);

    	    switch (token) {
    	      // 1, 2, 3, 4
    	      case 'Q':
    	        return String(quarter);
    	      // 01, 02, 03, 04

    	      case 'QQ':
    	        return (0, _index6.default)(quarter, 2);
    	      // 1st, 2nd, 3rd, 4th

    	      case 'Qo':
    	        return localize.ordinalNumber(quarter, {
    	          unit: 'quarter'
    	        });
    	      // Q1, Q2, Q3, Q4

    	      case 'QQQ':
    	        return localize.quarter(quarter, {
    	          width: 'abbreviated',
    	          context: 'formatting'
    	        });
    	      // 1, 2, 3, 4 (narrow quarter; could be not numerical)

    	      case 'QQQQQ':
    	        return localize.quarter(quarter, {
    	          width: 'narrow',
    	          context: 'formatting'
    	        });
    	      // 1st quarter, 2nd quarter, ...

    	      case 'QQQQ':
    	      default:
    	        return localize.quarter(quarter, {
    	          width: 'wide',
    	          context: 'formatting'
    	        });
    	    }
    	  },
    	  // Stand-alone quarter
    	  q: function (date, token, localize) {
    	    var quarter = Math.ceil((date.getUTCMonth() + 1) / 3);

    	    switch (token) {
    	      // 1, 2, 3, 4
    	      case 'q':
    	        return String(quarter);
    	      // 01, 02, 03, 04

    	      case 'qq':
    	        return (0, _index6.default)(quarter, 2);
    	      // 1st, 2nd, 3rd, 4th

    	      case 'qo':
    	        return localize.ordinalNumber(quarter, {
    	          unit: 'quarter'
    	        });
    	      // Q1, Q2, Q3, Q4

    	      case 'qqq':
    	        return localize.quarter(quarter, {
    	          width: 'abbreviated',
    	          context: 'standalone'
    	        });
    	      // 1, 2, 3, 4 (narrow quarter; could be not numerical)

    	      case 'qqqqq':
    	        return localize.quarter(quarter, {
    	          width: 'narrow',
    	          context: 'standalone'
    	        });
    	      // 1st quarter, 2nd quarter, ...

    	      case 'qqqq':
    	      default:
    	        return localize.quarter(quarter, {
    	          width: 'wide',
    	          context: 'standalone'
    	        });
    	    }
    	  },
    	  // Month
    	  M: function (date, token, localize) {
    	    var month = date.getUTCMonth();

    	    switch (token) {
    	      case 'M':
    	      case 'MM':
    	        return _index7.default.M(date, token);
    	      // 1st, 2nd, ..., 12th

    	      case 'Mo':
    	        return localize.ordinalNumber(month + 1, {
    	          unit: 'month'
    	        });
    	      // Jan, Feb, ..., Dec

    	      case 'MMM':
    	        return localize.month(month, {
    	          width: 'abbreviated',
    	          context: 'formatting'
    	        });
    	      // J, F, ..., D

    	      case 'MMMMM':
    	        return localize.month(month, {
    	          width: 'narrow',
    	          context: 'formatting'
    	        });
    	      // January, February, ..., December

    	      case 'MMMM':
    	      default:
    	        return localize.month(month, {
    	          width: 'wide',
    	          context: 'formatting'
    	        });
    	    }
    	  },
    	  // Stand-alone month
    	  L: function (date, token, localize) {
    	    var month = date.getUTCMonth();

    	    switch (token) {
    	      // 1, 2, ..., 12
    	      case 'L':
    	        return String(month + 1);
    	      // 01, 02, ..., 12

    	      case 'LL':
    	        return (0, _index6.default)(month + 1, 2);
    	      // 1st, 2nd, ..., 12th

    	      case 'Lo':
    	        return localize.ordinalNumber(month + 1, {
    	          unit: 'month'
    	        });
    	      // Jan, Feb, ..., Dec

    	      case 'LLL':
    	        return localize.month(month, {
    	          width: 'abbreviated',
    	          context: 'standalone'
    	        });
    	      // J, F, ..., D

    	      case 'LLLLL':
    	        return localize.month(month, {
    	          width: 'narrow',
    	          context: 'standalone'
    	        });
    	      // January, February, ..., December

    	      case 'LLLL':
    	      default:
    	        return localize.month(month, {
    	          width: 'wide',
    	          context: 'standalone'
    	        });
    	    }
    	  },
    	  // Local week of year
    	  w: function (date, token, localize, options) {
    	    var week = (0, _index4.default)(date, options);

    	    if (token === 'wo') {
    	      return localize.ordinalNumber(week, {
    	        unit: 'week'
    	      });
    	    }

    	    return (0, _index6.default)(week, token.length);
    	  },
    	  // ISO week of year
    	  I: function (date, token, localize) {
    	    var isoWeek = (0, _index2.default)(date);

    	    if (token === 'Io') {
    	      return localize.ordinalNumber(isoWeek, {
    	        unit: 'week'
    	      });
    	    }

    	    return (0, _index6.default)(isoWeek, token.length);
    	  },
    	  // Day of the month
    	  d: function (date, token, localize) {
    	    if (token === 'do') {
    	      return localize.ordinalNumber(date.getUTCDate(), {
    	        unit: 'date'
    	      });
    	    }

    	    return _index7.default.d(date, token);
    	  },
    	  // Day of year
    	  D: function (date, token, localize) {
    	    var dayOfYear = (0, _index.default)(date);

    	    if (token === 'Do') {
    	      return localize.ordinalNumber(dayOfYear, {
    	        unit: 'dayOfYear'
    	      });
    	    }

    	    return (0, _index6.default)(dayOfYear, token.length);
    	  },
    	  // Day of week
    	  E: function (date, token, localize) {
    	    var dayOfWeek = date.getUTCDay();

    	    switch (token) {
    	      // Tue
    	      case 'E':
    	      case 'EE':
    	      case 'EEE':
    	        return localize.day(dayOfWeek, {
    	          width: 'abbreviated',
    	          context: 'formatting'
    	        });
    	      // T

    	      case 'EEEEE':
    	        return localize.day(dayOfWeek, {
    	          width: 'narrow',
    	          context: 'formatting'
    	        });
    	      // Tu

    	      case 'EEEEEE':
    	        return localize.day(dayOfWeek, {
    	          width: 'short',
    	          context: 'formatting'
    	        });
    	      // Tuesday

    	      case 'EEEE':
    	      default:
    	        return localize.day(dayOfWeek, {
    	          width: 'wide',
    	          context: 'formatting'
    	        });
    	    }
    	  },
    	  // Local day of week
    	  e: function (date, token, localize, options) {
    	    var dayOfWeek = date.getUTCDay();
    	    var localDayOfWeek = (dayOfWeek - options.weekStartsOn + 8) % 7 || 7;

    	    switch (token) {
    	      // Numerical value (Nth day of week with current locale or weekStartsOn)
    	      case 'e':
    	        return String(localDayOfWeek);
    	      // Padded numerical value

    	      case 'ee':
    	        return (0, _index6.default)(localDayOfWeek, 2);
    	      // 1st, 2nd, ..., 7th

    	      case 'eo':
    	        return localize.ordinalNumber(localDayOfWeek, {
    	          unit: 'day'
    	        });

    	      case 'eee':
    	        return localize.day(dayOfWeek, {
    	          width: 'abbreviated',
    	          context: 'formatting'
    	        });
    	      // T

    	      case 'eeeee':
    	        return localize.day(dayOfWeek, {
    	          width: 'narrow',
    	          context: 'formatting'
    	        });
    	      // Tu

    	      case 'eeeeee':
    	        return localize.day(dayOfWeek, {
    	          width: 'short',
    	          context: 'formatting'
    	        });
    	      // Tuesday

    	      case 'eeee':
    	      default:
    	        return localize.day(dayOfWeek, {
    	          width: 'wide',
    	          context: 'formatting'
    	        });
    	    }
    	  },
    	  // Stand-alone local day of week
    	  c: function (date, token, localize, options) {
    	    var dayOfWeek = date.getUTCDay();
    	    var localDayOfWeek = (dayOfWeek - options.weekStartsOn + 8) % 7 || 7;

    	    switch (token) {
    	      // Numerical value (same as in `e`)
    	      case 'c':
    	        return String(localDayOfWeek);
    	      // Padded numerical value

    	      case 'cc':
    	        return (0, _index6.default)(localDayOfWeek, token.length);
    	      // 1st, 2nd, ..., 7th

    	      case 'co':
    	        return localize.ordinalNumber(localDayOfWeek, {
    	          unit: 'day'
    	        });

    	      case 'ccc':
    	        return localize.day(dayOfWeek, {
    	          width: 'abbreviated',
    	          context: 'standalone'
    	        });
    	      // T

    	      case 'ccccc':
    	        return localize.day(dayOfWeek, {
    	          width: 'narrow',
    	          context: 'standalone'
    	        });
    	      // Tu

    	      case 'cccccc':
    	        return localize.day(dayOfWeek, {
    	          width: 'short',
    	          context: 'standalone'
    	        });
    	      // Tuesday

    	      case 'cccc':
    	      default:
    	        return localize.day(dayOfWeek, {
    	          width: 'wide',
    	          context: 'standalone'
    	        });
    	    }
    	  },
    	  // ISO day of week
    	  i: function (date, token, localize) {
    	    var dayOfWeek = date.getUTCDay();
    	    var isoDayOfWeek = dayOfWeek === 0 ? 7 : dayOfWeek;

    	    switch (token) {
    	      // 2
    	      case 'i':
    	        return String(isoDayOfWeek);
    	      // 02

    	      case 'ii':
    	        return (0, _index6.default)(isoDayOfWeek, token.length);
    	      // 2nd

    	      case 'io':
    	        return localize.ordinalNumber(isoDayOfWeek, {
    	          unit: 'day'
    	        });
    	      // Tue

    	      case 'iii':
    	        return localize.day(dayOfWeek, {
    	          width: 'abbreviated',
    	          context: 'formatting'
    	        });
    	      // T

    	      case 'iiiii':
    	        return localize.day(dayOfWeek, {
    	          width: 'narrow',
    	          context: 'formatting'
    	        });
    	      // Tu

    	      case 'iiiiii':
    	        return localize.day(dayOfWeek, {
    	          width: 'short',
    	          context: 'formatting'
    	        });
    	      // Tuesday

    	      case 'iiii':
    	      default:
    	        return localize.day(dayOfWeek, {
    	          width: 'wide',
    	          context: 'formatting'
    	        });
    	    }
    	  },
    	  // AM or PM
    	  a: function (date, token, localize) {
    	    var hours = date.getUTCHours();
    	    var dayPeriodEnumValue = hours / 12 >= 1 ? 'pm' : 'am';

    	    switch (token) {
    	      case 'a':
    	      case 'aa':
    	        return localize.dayPeriod(dayPeriodEnumValue, {
    	          width: 'abbreviated',
    	          context: 'formatting'
    	        });

    	      case 'aaa':
    	        return localize.dayPeriod(dayPeriodEnumValue, {
    	          width: 'abbreviated',
    	          context: 'formatting'
    	        }).toLowerCase();

    	      case 'aaaaa':
    	        return localize.dayPeriod(dayPeriodEnumValue, {
    	          width: 'narrow',
    	          context: 'formatting'
    	        });

    	      case 'aaaa':
    	      default:
    	        return localize.dayPeriod(dayPeriodEnumValue, {
    	          width: 'wide',
    	          context: 'formatting'
    	        });
    	    }
    	  },
    	  // AM, PM, midnight, noon
    	  b: function (date, token, localize) {
    	    var hours = date.getUTCHours();
    	    var dayPeriodEnumValue;

    	    if (hours === 12) {
    	      dayPeriodEnumValue = dayPeriodEnum.noon;
    	    } else if (hours === 0) {
    	      dayPeriodEnumValue = dayPeriodEnum.midnight;
    	    } else {
    	      dayPeriodEnumValue = hours / 12 >= 1 ? 'pm' : 'am';
    	    }

    	    switch (token) {
    	      case 'b':
    	      case 'bb':
    	        return localize.dayPeriod(dayPeriodEnumValue, {
    	          width: 'abbreviated',
    	          context: 'formatting'
    	        });

    	      case 'bbb':
    	        return localize.dayPeriod(dayPeriodEnumValue, {
    	          width: 'abbreviated',
    	          context: 'formatting'
    	        }).toLowerCase();

    	      case 'bbbbb':
    	        return localize.dayPeriod(dayPeriodEnumValue, {
    	          width: 'narrow',
    	          context: 'formatting'
    	        });

    	      case 'bbbb':
    	      default:
    	        return localize.dayPeriod(dayPeriodEnumValue, {
    	          width: 'wide',
    	          context: 'formatting'
    	        });
    	    }
    	  },
    	  // in the morning, in the afternoon, in the evening, at night
    	  B: function (date, token, localize) {
    	    var hours = date.getUTCHours();
    	    var dayPeriodEnumValue;

    	    if (hours >= 17) {
    	      dayPeriodEnumValue = dayPeriodEnum.evening;
    	    } else if (hours >= 12) {
    	      dayPeriodEnumValue = dayPeriodEnum.afternoon;
    	    } else if (hours >= 4) {
    	      dayPeriodEnumValue = dayPeriodEnum.morning;
    	    } else {
    	      dayPeriodEnumValue = dayPeriodEnum.night;
    	    }

    	    switch (token) {
    	      case 'B':
    	      case 'BB':
    	      case 'BBB':
    	        return localize.dayPeriod(dayPeriodEnumValue, {
    	          width: 'abbreviated',
    	          context: 'formatting'
    	        });

    	      case 'BBBBB':
    	        return localize.dayPeriod(dayPeriodEnumValue, {
    	          width: 'narrow',
    	          context: 'formatting'
    	        });

    	      case 'BBBB':
    	      default:
    	        return localize.dayPeriod(dayPeriodEnumValue, {
    	          width: 'wide',
    	          context: 'formatting'
    	        });
    	    }
    	  },
    	  // Hour [1-12]
    	  h: function (date, token, localize) {
    	    if (token === 'ho') {
    	      var hours = date.getUTCHours() % 12;
    	      if (hours === 0) hours = 12;
    	      return localize.ordinalNumber(hours, {
    	        unit: 'hour'
    	      });
    	    }

    	    return _index7.default.h(date, token);
    	  },
    	  // Hour [0-23]
    	  H: function (date, token, localize) {
    	    if (token === 'Ho') {
    	      return localize.ordinalNumber(date.getUTCHours(), {
    	        unit: 'hour'
    	      });
    	    }

    	    return _index7.default.H(date, token);
    	  },
    	  // Hour [0-11]
    	  K: function (date, token, localize) {
    	    var hours = date.getUTCHours() % 12;

    	    if (token === 'Ko') {
    	      return localize.ordinalNumber(hours, {
    	        unit: 'hour'
    	      });
    	    }

    	    return (0, _index6.default)(hours, token.length);
    	  },
    	  // Hour [1-24]
    	  k: function (date, token, localize) {
    	    var hours = date.getUTCHours();
    	    if (hours === 0) hours = 24;

    	    if (token === 'ko') {
    	      return localize.ordinalNumber(hours, {
    	        unit: 'hour'
    	      });
    	    }

    	    return (0, _index6.default)(hours, token.length);
    	  },
    	  // Minute
    	  m: function (date, token, localize) {
    	    if (token === 'mo') {
    	      return localize.ordinalNumber(date.getUTCMinutes(), {
    	        unit: 'minute'
    	      });
    	    }

    	    return _index7.default.m(date, token);
    	  },
    	  // Second
    	  s: function (date, token, localize) {
    	    if (token === 'so') {
    	      return localize.ordinalNumber(date.getUTCSeconds(), {
    	        unit: 'second'
    	      });
    	    }

    	    return _index7.default.s(date, token);
    	  },
    	  // Fraction of second
    	  S: function (date, token) {
    	    return _index7.default.S(date, token);
    	  },
    	  // Timezone (ISO-8601. If offset is 0, output is always `'Z'`)
    	  X: function (date, token, _localize, options) {
    	    var originalDate = options._originalDate || date;
    	    var timezoneOffset = originalDate.getTimezoneOffset();

    	    if (timezoneOffset === 0) {
    	      return 'Z';
    	    }

    	    switch (token) {
    	      // Hours and optional minutes
    	      case 'X':
    	        return formatTimezoneWithOptionalMinutes(timezoneOffset);
    	      // Hours, minutes and optional seconds without `:` delimiter
    	      // Note: neither ISO-8601 nor JavaScript supports seconds in timezone offsets
    	      // so this token always has the same output as `XX`

    	      case 'XXXX':
    	      case 'XX':
    	        // Hours and minutes without `:` delimiter
    	        return formatTimezone(timezoneOffset);
    	      // Hours, minutes and optional seconds with `:` delimiter
    	      // Note: neither ISO-8601 nor JavaScript supports seconds in timezone offsets
    	      // so this token always has the same output as `XXX`

    	      case 'XXXXX':
    	      case 'XXX': // Hours and minutes with `:` delimiter

    	      default:
    	        return formatTimezone(timezoneOffset, ':');
    	    }
    	  },
    	  // Timezone (ISO-8601. If offset is 0, output is `'+00:00'` or equivalent)
    	  x: function (date, token, _localize, options) {
    	    var originalDate = options._originalDate || date;
    	    var timezoneOffset = originalDate.getTimezoneOffset();

    	    switch (token) {
    	      // Hours and optional minutes
    	      case 'x':
    	        return formatTimezoneWithOptionalMinutes(timezoneOffset);
    	      // Hours, minutes and optional seconds without `:` delimiter
    	      // Note: neither ISO-8601 nor JavaScript supports seconds in timezone offsets
    	      // so this token always has the same output as `xx`

    	      case 'xxxx':
    	      case 'xx':
    	        // Hours and minutes without `:` delimiter
    	        return formatTimezone(timezoneOffset);
    	      // Hours, minutes and optional seconds with `:` delimiter
    	      // Note: neither ISO-8601 nor JavaScript supports seconds in timezone offsets
    	      // so this token always has the same output as `xxx`

    	      case 'xxxxx':
    	      case 'xxx': // Hours and minutes with `:` delimiter

    	      default:
    	        return formatTimezone(timezoneOffset, ':');
    	    }
    	  },
    	  // Timezone (GMT)
    	  O: function (date, token, _localize, options) {
    	    var originalDate = options._originalDate || date;
    	    var timezoneOffset = originalDate.getTimezoneOffset();

    	    switch (token) {
    	      // Short
    	      case 'O':
    	      case 'OO':
    	      case 'OOO':
    	        return 'GMT' + formatTimezoneShort(timezoneOffset, ':');
    	      // Long

    	      case 'OOOO':
    	      default:
    	        return 'GMT' + formatTimezone(timezoneOffset, ':');
    	    }
    	  },
    	  // Timezone (specific non-location)
    	  z: function (date, token, _localize, options) {
    	    var originalDate = options._originalDate || date;
    	    var timezoneOffset = originalDate.getTimezoneOffset();

    	    switch (token) {
    	      // Short
    	      case 'z':
    	      case 'zz':
    	      case 'zzz':
    	        return 'GMT' + formatTimezoneShort(timezoneOffset, ':');
    	      // Long

    	      case 'zzzz':
    	      default:
    	        return 'GMT' + formatTimezone(timezoneOffset, ':');
    	    }
    	  },
    	  // Seconds timestamp
    	  t: function (date, token, _localize, options) {
    	    var originalDate = options._originalDate || date;
    	    var timestamp = Math.floor(originalDate.getTime() / 1000);
    	    return (0, _index6.default)(timestamp, token.length);
    	  },
    	  // Milliseconds timestamp
    	  T: function (date, token, _localize, options) {
    	    var originalDate = options._originalDate || date;
    	    var timestamp = originalDate.getTime();
    	    return (0, _index6.default)(timestamp, token.length);
    	  }
    	};

    	function formatTimezoneShort(offset, dirtyDelimiter) {
    	  var sign = offset > 0 ? '-' : '+';
    	  var absOffset = Math.abs(offset);
    	  var hours = Math.floor(absOffset / 60);
    	  var minutes = absOffset % 60;

    	  if (minutes === 0) {
    	    return sign + String(hours);
    	  }

    	  var delimiter = dirtyDelimiter || '';
    	  return sign + String(hours) + delimiter + (0, _index6.default)(minutes, 2);
    	}

    	function formatTimezoneWithOptionalMinutes(offset, dirtyDelimiter) {
    	  if (offset % 60 === 0) {
    	    var sign = offset > 0 ? '-' : '+';
    	    return sign + (0, _index6.default)(Math.abs(offset) / 60, 2);
    	  }

    	  return formatTimezone(offset, dirtyDelimiter);
    	}

    	function formatTimezone(offset, dirtyDelimiter) {
    	  var delimiter = dirtyDelimiter || '';
    	  var sign = offset > 0 ? '-' : '+';
    	  var absOffset = Math.abs(offset);
    	  var hours = (0, _index6.default)(Math.floor(absOffset / 60), 2);
    	  var minutes = (0, _index6.default)(absOffset % 60, 2);
    	  return sign + hours + delimiter + minutes;
    	}

    	var _default = formatters;
    	exports.default = _default;
    	module.exports = exports.default;
    } (formatters$1, formatters$1.exports));

    var longFormatters = {exports: {}};

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = void 0;

    	var dateLongFormatter = function (pattern, formatLong) {
    	  switch (pattern) {
    	    case 'P':
    	      return formatLong.date({
    	        width: 'short'
    	      });

    	    case 'PP':
    	      return formatLong.date({
    	        width: 'medium'
    	      });

    	    case 'PPP':
    	      return formatLong.date({
    	        width: 'long'
    	      });

    	    case 'PPPP':
    	    default:
    	      return formatLong.date({
    	        width: 'full'
    	      });
    	  }
    	};

    	var timeLongFormatter = function (pattern, formatLong) {
    	  switch (pattern) {
    	    case 'p':
    	      return formatLong.time({
    	        width: 'short'
    	      });

    	    case 'pp':
    	      return formatLong.time({
    	        width: 'medium'
    	      });

    	    case 'ppp':
    	      return formatLong.time({
    	        width: 'long'
    	      });

    	    case 'pppp':
    	    default:
    	      return formatLong.time({
    	        width: 'full'
    	      });
    	  }
    	};

    	var dateTimeLongFormatter = function (pattern, formatLong) {
    	  var matchResult = pattern.match(/(P+)(p+)?/) || [];
    	  var datePattern = matchResult[1];
    	  var timePattern = matchResult[2];

    	  if (!timePattern) {
    	    return dateLongFormatter(pattern, formatLong);
    	  }

    	  var dateTimeFormat;

    	  switch (datePattern) {
    	    case 'P':
    	      dateTimeFormat = formatLong.dateTime({
    	        width: 'short'
    	      });
    	      break;

    	    case 'PP':
    	      dateTimeFormat = formatLong.dateTime({
    	        width: 'medium'
    	      });
    	      break;

    	    case 'PPP':
    	      dateTimeFormat = formatLong.dateTime({
    	        width: 'long'
    	      });
    	      break;

    	    case 'PPPP':
    	    default:
    	      dateTimeFormat = formatLong.dateTime({
    	        width: 'full'
    	      });
    	      break;
    	  }

    	  return dateTimeFormat.replace('{{date}}', dateLongFormatter(datePattern, formatLong)).replace('{{time}}', timeLongFormatter(timePattern, formatLong));
    	};

    	var longFormatters = {
    	  p: timeLongFormatter,
    	  P: dateTimeLongFormatter
    	};
    	var _default = longFormatters;
    	exports.default = _default;
    	module.exports = exports.default;
    } (longFormatters, longFormatters.exports));

    var getTimezoneOffsetInMilliseconds = {exports: {}};

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = getTimezoneOffsetInMilliseconds;
    	/**
    	 * Google Chrome as of 67.0.3396.87 introduced timezones with offset that includes seconds.
    	 * They usually appear for dates that denote time before the timezones were introduced
    	 * (e.g. for 'Europe/Prague' timezone the offset is GMT+00:57:44 before 1 October 1891
    	 * and GMT+01:00:00 after that date)
    	 *
    	 * Date#getTimezoneOffset returns the offset in minutes and would return 57 for the example above,
    	 * which would lead to incorrect calculations.
    	 *
    	 * This function returns the timezone offset in milliseconds that takes seconds in account.
    	 */

    	function getTimezoneOffsetInMilliseconds(date) {
    	  var utcDate = new Date(Date.UTC(date.getFullYear(), date.getMonth(), date.getDate(), date.getHours(), date.getMinutes(), date.getSeconds(), date.getMilliseconds()));
    	  utcDate.setUTCFullYear(date.getFullYear());
    	  return date.getTime() - utcDate.getTime();
    	}

    	module.exports = exports.default;
    } (getTimezoneOffsetInMilliseconds, getTimezoneOffsetInMilliseconds.exports));

    var protectedTokens = {};

    Object.defineProperty(protectedTokens, "__esModule", {
      value: true
    });
    protectedTokens.isProtectedDayOfYearToken = isProtectedDayOfYearToken;
    protectedTokens.isProtectedWeekYearToken = isProtectedWeekYearToken;
    protectedTokens.throwProtectedError = throwProtectedError;
    var protectedDayOfYearTokens = ['D', 'DD'];
    var protectedWeekYearTokens = ['YY', 'YYYY'];

    function isProtectedDayOfYearToken(token) {
      return protectedDayOfYearTokens.indexOf(token) !== -1;
    }

    function isProtectedWeekYearToken(token) {
      return protectedWeekYearTokens.indexOf(token) !== -1;
    }

    function throwProtectedError(token, format, input) {
      if (token === 'YYYY') {
        throw new RangeError("Use `yyyy` instead of `YYYY` (in `".concat(format, "`) for formatting years to the input `").concat(input, "`; see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md"));
      } else if (token === 'YY') {
        throw new RangeError("Use `yy` instead of `YY` (in `".concat(format, "`) for formatting years to the input `").concat(input, "`; see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md"));
      } else if (token === 'D') {
        throw new RangeError("Use `d` instead of `D` (in `".concat(format, "`) for formatting days of the month to the input `").concat(input, "`; see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md"));
      } else if (token === 'DD') {
        throw new RangeError("Use `dd` instead of `DD` (in `".concat(format, "`) for formatting days of the month to the input `").concat(input, "`; see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md"));
      }
    }

    var defaultLocale = {exports: {}};

    var enUS = {exports: {}};

    var formatDistance = {exports: {}};

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = void 0;
    	var formatDistanceLocale = {
    	  lessThanXSeconds: {
    	    one: 'less than a second',
    	    other: 'less than {{count}} seconds'
    	  },
    	  xSeconds: {
    	    one: '1 second',
    	    other: '{{count}} seconds'
    	  },
    	  halfAMinute: 'half a minute',
    	  lessThanXMinutes: {
    	    one: 'less than a minute',
    	    other: 'less than {{count}} minutes'
    	  },
    	  xMinutes: {
    	    one: '1 minute',
    	    other: '{{count}} minutes'
    	  },
    	  aboutXHours: {
    	    one: 'about 1 hour',
    	    other: 'about {{count}} hours'
    	  },
    	  xHours: {
    	    one: '1 hour',
    	    other: '{{count}} hours'
    	  },
    	  xDays: {
    	    one: '1 day',
    	    other: '{{count}} days'
    	  },
    	  aboutXWeeks: {
    	    one: 'about 1 week',
    	    other: 'about {{count}} weeks'
    	  },
    	  xWeeks: {
    	    one: '1 week',
    	    other: '{{count}} weeks'
    	  },
    	  aboutXMonths: {
    	    one: 'about 1 month',
    	    other: 'about {{count}} months'
    	  },
    	  xMonths: {
    	    one: '1 month',
    	    other: '{{count}} months'
    	  },
    	  aboutXYears: {
    	    one: 'about 1 year',
    	    other: 'about {{count}} years'
    	  },
    	  xYears: {
    	    one: '1 year',
    	    other: '{{count}} years'
    	  },
    	  overXYears: {
    	    one: 'over 1 year',
    	    other: 'over {{count}} years'
    	  },
    	  almostXYears: {
    	    one: 'almost 1 year',
    	    other: 'almost {{count}} years'
    	  }
    	};

    	var formatDistance = function (token, count, options) {
    	  var result;
    	  var tokenValue = formatDistanceLocale[token];

    	  if (typeof tokenValue === 'string') {
    	    result = tokenValue;
    	  } else if (count === 1) {
    	    result = tokenValue.one;
    	  } else {
    	    result = tokenValue.other.replace('{{count}}', count.toString());
    	  }

    	  if (options !== null && options !== void 0 && options.addSuffix) {
    	    if (options.comparison && options.comparison > 0) {
    	      return 'in ' + result;
    	    } else {
    	      return result + ' ago';
    	    }
    	  }

    	  return result;
    	};

    	var _default = formatDistance;
    	exports.default = _default;
    	module.exports = exports.default;
    } (formatDistance, formatDistance.exports));

    var formatLong = {exports: {}};

    var buildFormatLongFn = {exports: {}};

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = buildFormatLongFn;

    	function buildFormatLongFn(args) {
    	  return function () {
    	    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {}; // TODO: Remove String()

    	    var width = options.width ? String(options.width) : args.defaultWidth;
    	    var format = args.formats[width] || args.formats[args.defaultWidth];
    	    return format;
    	  };
    	}

    	module.exports = exports.default;
    } (buildFormatLongFn, buildFormatLongFn.exports));

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = void 0;

    	var _index = _interopRequireDefault(buildFormatLongFn.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}

    	var dateFormats = {
    	  full: 'EEEE, MMMM do, y',
    	  long: 'MMMM do, y',
    	  medium: 'MMM d, y',
    	  short: 'MM/dd/yyyy'
    	};
    	var timeFormats = {
    	  full: 'h:mm:ss a zzzz',
    	  long: 'h:mm:ss a z',
    	  medium: 'h:mm:ss a',
    	  short: 'h:mm a'
    	};
    	var dateTimeFormats = {
    	  full: "{{date}} 'at' {{time}}",
    	  long: "{{date}} 'at' {{time}}",
    	  medium: '{{date}}, {{time}}',
    	  short: '{{date}}, {{time}}'
    	};
    	var formatLong = {
    	  date: (0, _index.default)({
    	    formats: dateFormats,
    	    defaultWidth: 'full'
    	  }),
    	  time: (0, _index.default)({
    	    formats: timeFormats,
    	    defaultWidth: 'full'
    	  }),
    	  dateTime: (0, _index.default)({
    	    formats: dateTimeFormats,
    	    defaultWidth: 'full'
    	  })
    	};
    	var _default = formatLong;
    	exports.default = _default;
    	module.exports = exports.default;
    } (formatLong, formatLong.exports));

    var formatRelative = {exports: {}};

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = void 0;
    	var formatRelativeLocale = {
    	  lastWeek: "'last' eeee 'at' p",
    	  yesterday: "'yesterday at' p",
    	  today: "'today at' p",
    	  tomorrow: "'tomorrow at' p",
    	  nextWeek: "eeee 'at' p",
    	  other: 'P'
    	};

    	var formatRelative = function (token, _date, _baseDate, _options) {
    	  return formatRelativeLocale[token];
    	};

    	var _default = formatRelative;
    	exports.default = _default;
    	module.exports = exports.default;
    } (formatRelative, formatRelative.exports));

    var localize = {exports: {}};

    var buildLocalizeFn = {exports: {}};

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = buildLocalizeFn;

    	function buildLocalizeFn(args) {
    	  return function (dirtyIndex, options) {
    	    var context = options !== null && options !== void 0 && options.context ? String(options.context) : 'standalone';
    	    var valuesArray;

    	    if (context === 'formatting' && args.formattingValues) {
    	      var defaultWidth = args.defaultFormattingWidth || args.defaultWidth;
    	      var width = options !== null && options !== void 0 && options.width ? String(options.width) : defaultWidth;
    	      valuesArray = args.formattingValues[width] || args.formattingValues[defaultWidth];
    	    } else {
    	      var _defaultWidth = args.defaultWidth;

    	      var _width = options !== null && options !== void 0 && options.width ? String(options.width) : args.defaultWidth;

    	      valuesArray = args.values[_width] || args.values[_defaultWidth];
    	    }

    	    var index = args.argumentCallback ? args.argumentCallback(dirtyIndex) : dirtyIndex; // @ts-ignore: For some reason TypeScript just don't want to match it, no matter how hard we try. I challenge you to try to remove it!

    	    return valuesArray[index];
    	  };
    	}

    	module.exports = exports.default;
    } (buildLocalizeFn, buildLocalizeFn.exports));

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = void 0;

    	var _index = _interopRequireDefault(buildLocalizeFn.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}

    	var eraValues = {
    	  narrow: ['B', 'A'],
    	  abbreviated: ['BC', 'AD'],
    	  wide: ['Before Christ', 'Anno Domini']
    	};
    	var quarterValues = {
    	  narrow: ['1', '2', '3', '4'],
    	  abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
    	  wide: ['1st quarter', '2nd quarter', '3rd quarter', '4th quarter']
    	}; // Note: in English, the names of days of the week and months are capitalized.
    	// If you are making a new locale based on this one, check if the same is true for the language you're working on.
    	// Generally, formatted dates should look like they are in the middle of a sentence,
    	// e.g. in Spanish language the weekdays and months should be in the lowercase.

    	var monthValues = {
    	  narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
    	  abbreviated: ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
    	  wide: ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December']
    	};
    	var dayValues = {
    	  narrow: ['S', 'M', 'T', 'W', 'T', 'F', 'S'],
    	  short: ['Su', 'Mo', 'Tu', 'We', 'Th', 'Fr', 'Sa'],
    	  abbreviated: ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'],
    	  wide: ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday']
    	};
    	var dayPeriodValues = {
    	  narrow: {
    	    am: 'a',
    	    pm: 'p',
    	    midnight: 'mi',
    	    noon: 'n',
    	    morning: 'morning',
    	    afternoon: 'afternoon',
    	    evening: 'evening',
    	    night: 'night'
    	  },
    	  abbreviated: {
    	    am: 'AM',
    	    pm: 'PM',
    	    midnight: 'midnight',
    	    noon: 'noon',
    	    morning: 'morning',
    	    afternoon: 'afternoon',
    	    evening: 'evening',
    	    night: 'night'
    	  },
    	  wide: {
    	    am: 'a.m.',
    	    pm: 'p.m.',
    	    midnight: 'midnight',
    	    noon: 'noon',
    	    morning: 'morning',
    	    afternoon: 'afternoon',
    	    evening: 'evening',
    	    night: 'night'
    	  }
    	};
    	var formattingDayPeriodValues = {
    	  narrow: {
    	    am: 'a',
    	    pm: 'p',
    	    midnight: 'mi',
    	    noon: 'n',
    	    morning: 'in the morning',
    	    afternoon: 'in the afternoon',
    	    evening: 'in the evening',
    	    night: 'at night'
    	  },
    	  abbreviated: {
    	    am: 'AM',
    	    pm: 'PM',
    	    midnight: 'midnight',
    	    noon: 'noon',
    	    morning: 'in the morning',
    	    afternoon: 'in the afternoon',
    	    evening: 'in the evening',
    	    night: 'at night'
    	  },
    	  wide: {
    	    am: 'a.m.',
    	    pm: 'p.m.',
    	    midnight: 'midnight',
    	    noon: 'noon',
    	    morning: 'in the morning',
    	    afternoon: 'in the afternoon',
    	    evening: 'in the evening',
    	    night: 'at night'
    	  }
    	};

    	var ordinalNumber = function (dirtyNumber, _options) {
    	  var number = Number(dirtyNumber); // If ordinal numbers depend on context, for example,
    	  // if they are different for different grammatical genders,
    	  // use `options.unit`.
    	  //
    	  // `unit` can be 'year', 'quarter', 'month', 'week', 'date', 'dayOfYear',
    	  // 'day', 'hour', 'minute', 'second'.

    	  var rem100 = number % 100;

    	  if (rem100 > 20 || rem100 < 10) {
    	    switch (rem100 % 10) {
    	      case 1:
    	        return number + 'st';

    	      case 2:
    	        return number + 'nd';

    	      case 3:
    	        return number + 'rd';
    	    }
    	  }

    	  return number + 'th';
    	};

    	var localize = {
    	  ordinalNumber: ordinalNumber,
    	  era: (0, _index.default)({
    	    values: eraValues,
    	    defaultWidth: 'wide'
    	  }),
    	  quarter: (0, _index.default)({
    	    values: quarterValues,
    	    defaultWidth: 'wide',
    	    argumentCallback: function (quarter) {
    	      return quarter - 1;
    	    }
    	  }),
    	  month: (0, _index.default)({
    	    values: monthValues,
    	    defaultWidth: 'wide'
    	  }),
    	  day: (0, _index.default)({
    	    values: dayValues,
    	    defaultWidth: 'wide'
    	  }),
    	  dayPeriod: (0, _index.default)({
    	    values: dayPeriodValues,
    	    defaultWidth: 'wide',
    	    formattingValues: formattingDayPeriodValues,
    	    defaultFormattingWidth: 'wide'
    	  })
    	};
    	var _default = localize;
    	exports.default = _default;
    	module.exports = exports.default;
    } (localize, localize.exports));

    var match = {exports: {}};

    var buildMatchFn = {exports: {}};

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = buildMatchFn;

    	function buildMatchFn(args) {
    	  return function (string) {
    	    var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    	    var width = options.width;
    	    var matchPattern = width && args.matchPatterns[width] || args.matchPatterns[args.defaultMatchWidth];
    	    var matchResult = string.match(matchPattern);

    	    if (!matchResult) {
    	      return null;
    	    }

    	    var matchedString = matchResult[0];
    	    var parsePatterns = width && args.parsePatterns[width] || args.parsePatterns[args.defaultParseWidth];
    	    var key = Array.isArray(parsePatterns) ? findIndex(parsePatterns, function (pattern) {
    	      return pattern.test(matchedString);
    	    }) : findKey(parsePatterns, function (pattern) {
    	      return pattern.test(matchedString);
    	    });
    	    var value;
    	    value = args.valueCallback ? args.valueCallback(key) : key;
    	    value = options.valueCallback ? options.valueCallback(value) : value;
    	    var rest = string.slice(matchedString.length);
    	    return {
    	      value: value,
    	      rest: rest
    	    };
    	  };
    	}

    	function findKey(object, predicate) {
    	  for (var key in object) {
    	    if (object.hasOwnProperty(key) && predicate(object[key])) {
    	      return key;
    	    }
    	  }

    	  return undefined;
    	}

    	function findIndex(array, predicate) {
    	  for (var key = 0; key < array.length; key++) {
    	    if (predicate(array[key])) {
    	      return key;
    	    }
    	  }

    	  return undefined;
    	}

    	module.exports = exports.default;
    } (buildMatchFn, buildMatchFn.exports));

    var buildMatchPatternFn = {exports: {}};

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = buildMatchPatternFn;

    	function buildMatchPatternFn(args) {
    	  return function (string) {
    	    var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    	    var matchResult = string.match(args.matchPattern);
    	    if (!matchResult) return null;
    	    var matchedString = matchResult[0];
    	    var parseResult = string.match(args.parsePattern);
    	    if (!parseResult) return null;
    	    var value = args.valueCallback ? args.valueCallback(parseResult[0]) : parseResult[0];
    	    value = options.valueCallback ? options.valueCallback(value) : value;
    	    var rest = string.slice(matchedString.length);
    	    return {
    	      value: value,
    	      rest: rest
    	    };
    	  };
    	}

    	module.exports = exports.default;
    } (buildMatchPatternFn, buildMatchPatternFn.exports));

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = void 0;

    	var _index = _interopRequireDefault(buildMatchFn.exports);

    	var _index2 = _interopRequireDefault(buildMatchPatternFn.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}

    	var matchOrdinalNumberPattern = /^(\d+)(th|st|nd|rd)?/i;
    	var parseOrdinalNumberPattern = /\d+/i;
    	var matchEraPatterns = {
    	  narrow: /^(b|a)/i,
    	  abbreviated: /^(b\.?\s?c\.?|b\.?\s?c\.?\s?e\.?|a\.?\s?d\.?|c\.?\s?e\.?)/i,
    	  wide: /^(before christ|before common era|anno domini|common era)/i
    	};
    	var parseEraPatterns = {
    	  any: [/^b/i, /^(a|c)/i]
    	};
    	var matchQuarterPatterns = {
    	  narrow: /^[1234]/i,
    	  abbreviated: /^q[1234]/i,
    	  wide: /^[1234](th|st|nd|rd)? quarter/i
    	};
    	var parseQuarterPatterns = {
    	  any: [/1/i, /2/i, /3/i, /4/i]
    	};
    	var matchMonthPatterns = {
    	  narrow: /^[jfmasond]/i,
    	  abbreviated: /^(jan|feb|mar|apr|may|jun|jul|aug|sep|oct|nov|dec)/i,
    	  wide: /^(january|february|march|april|may|june|july|august|september|october|november|december)/i
    	};
    	var parseMonthPatterns = {
    	  narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
    	  any: [/^ja/i, /^f/i, /^mar/i, /^ap/i, /^may/i, /^jun/i, /^jul/i, /^au/i, /^s/i, /^o/i, /^n/i, /^d/i]
    	};
    	var matchDayPatterns = {
    	  narrow: /^[smtwf]/i,
    	  short: /^(su|mo|tu|we|th|fr|sa)/i,
    	  abbreviated: /^(sun|mon|tue|wed|thu|fri|sat)/i,
    	  wide: /^(sunday|monday|tuesday|wednesday|thursday|friday|saturday)/i
    	};
    	var parseDayPatterns = {
    	  narrow: [/^s/i, /^m/i, /^t/i, /^w/i, /^t/i, /^f/i, /^s/i],
    	  any: [/^su/i, /^m/i, /^tu/i, /^w/i, /^th/i, /^f/i, /^sa/i]
    	};
    	var matchDayPeriodPatterns = {
    	  narrow: /^(a|p|mi|n|(in the|at) (morning|afternoon|evening|night))/i,
    	  any: /^([ap]\.?\s?m\.?|midnight|noon|(in the|at) (morning|afternoon|evening|night))/i
    	};
    	var parseDayPeriodPatterns = {
    	  any: {
    	    am: /^a/i,
    	    pm: /^p/i,
    	    midnight: /^mi/i,
    	    noon: /^no/i,
    	    morning: /morning/i,
    	    afternoon: /afternoon/i,
    	    evening: /evening/i,
    	    night: /night/i
    	  }
    	};
    	var match = {
    	  ordinalNumber: (0, _index2.default)({
    	    matchPattern: matchOrdinalNumberPattern,
    	    parsePattern: parseOrdinalNumberPattern,
    	    valueCallback: function (value) {
    	      return parseInt(value, 10);
    	    }
    	  }),
    	  era: (0, _index.default)({
    	    matchPatterns: matchEraPatterns,
    	    defaultMatchWidth: 'wide',
    	    parsePatterns: parseEraPatterns,
    	    defaultParseWidth: 'any'
    	  }),
    	  quarter: (0, _index.default)({
    	    matchPatterns: matchQuarterPatterns,
    	    defaultMatchWidth: 'wide',
    	    parsePatterns: parseQuarterPatterns,
    	    defaultParseWidth: 'any',
    	    valueCallback: function (index) {
    	      return index + 1;
    	    }
    	  }),
    	  month: (0, _index.default)({
    	    matchPatterns: matchMonthPatterns,
    	    defaultMatchWidth: 'wide',
    	    parsePatterns: parseMonthPatterns,
    	    defaultParseWidth: 'any'
    	  }),
    	  day: (0, _index.default)({
    	    matchPatterns: matchDayPatterns,
    	    defaultMatchWidth: 'wide',
    	    parsePatterns: parseDayPatterns,
    	    defaultParseWidth: 'any'
    	  }),
    	  dayPeriod: (0, _index.default)({
    	    matchPatterns: matchDayPeriodPatterns,
    	    defaultMatchWidth: 'any',
    	    parsePatterns: parseDayPeriodPatterns,
    	    defaultParseWidth: 'any'
    	  })
    	};
    	var _default = match;
    	exports.default = _default;
    	module.exports = exports.default;
    } (match, match.exports));

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = void 0;

    	var _index = _interopRequireDefault(formatDistance.exports);

    	var _index2 = _interopRequireDefault(formatLong.exports);

    	var _index3 = _interopRequireDefault(formatRelative.exports);

    	var _index4 = _interopRequireDefault(localize.exports);

    	var _index5 = _interopRequireDefault(match.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}
    	/**
    	 * @type {Locale}
    	 * @category Locales
    	 * @summary English locale (United States).
    	 * @language English
    	 * @iso-639-2 eng
    	 * @author Sasha Koss [@kossnocorp]{@link https://github.com/kossnocorp}
    	 * @author Lesha Koss [@leshakoss]{@link https://github.com/leshakoss}
    	 */


    	var locale = {
    	  code: 'en-US',
    	  formatDistance: _index.default,
    	  formatLong: _index2.default,
    	  formatRelative: _index3.default,
    	  localize: _index4.default,
    	  match: _index5.default,
    	  options: {
    	    weekStartsOn: 0
    	    /* Sunday */
    	    ,
    	    firstWeekContainsDate: 1
    	  }
    	};
    	var _default = locale;
    	exports.default = _default;
    	module.exports = exports.default;
    } (enUS, enUS.exports));

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = void 0;

    	var _index = _interopRequireDefault(enUS.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}

    	var _default = _index.default;
    	exports.default = _default;
    	module.exports = exports.default;
    } (defaultLocale, defaultLocale.exports));

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = format;

    	var _index = _interopRequireDefault(isValid.exports);

    	var _index2 = _interopRequireDefault(subMilliseconds.exports);

    	var _index3 = _interopRequireDefault(toDate$1.exports);

    	var _index4 = _interopRequireDefault(formatters$1.exports);

    	var _index5 = _interopRequireDefault(longFormatters.exports);

    	var _index6 = _interopRequireDefault(getTimezoneOffsetInMilliseconds.exports);

    	var _index7 = protectedTokens;

    	var _index8 = _interopRequireDefault(toInteger.exports);

    	var _index9 = _interopRequireDefault(requiredArgs.exports);

    	var _index10 = defaultOptions$1;

    	var _index11 = _interopRequireDefault(defaultLocale.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	} // This RegExp consists of three parts separated by `|`:
    	// - [yYQqMLwIdDecihHKkms]o matches any available ordinal number token
    	//   (one of the certain letters followed by `o`)
    	// - (\w)\1* matches any sequences of the same letter
    	// - '' matches two quote characters in a row
    	// - '(''|[^'])+('|$) matches anything surrounded by two quote characters ('),
    	//   except a single quote symbol, which ends the sequence.
    	//   Two quote characters do not end the sequence.
    	//   If there is no matching single quote
    	//   then the sequence will continue until the end of the string.
    	// - . matches any single character unmatched by previous parts of the RegExps


    	var formattingTokensRegExp = /[yYQqMLwIdDecihHKkms]o|(\w)\1*|''|'(''|[^'])+('|$)|./g; // This RegExp catches symbols escaped by quotes, and also
    	// sequences of symbols P, p, and the combinations like `PPPPPPPppppp`

    	var longFormattingTokensRegExp = /P+p+|P+|p+|''|'(''|[^'])+('|$)|./g;
    	var escapedStringRegExp = /^'([^]*?)'?$/;
    	var doubleQuoteRegExp = /''/g;
    	var unescapedLatinCharacterRegExp = /[a-zA-Z]/;
    	/**
    	 * @name format
    	 * @category Common Helpers
    	 * @summary Format the date.
    	 *
    	 * @description
    	 * Return the formatted date string in the given format. The result may vary by locale.
    	 *
    	 * > ⚠️ Please note that the `format` tokens differ from Moment.js and other libraries.
    	 * > See: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
    	 *
    	 * The characters wrapped between two single quotes characters (') are escaped.
    	 * Two single quotes in a row, whether inside or outside a quoted sequence, represent a 'real' single quote.
    	 * (see the last example)
    	 *
    	 * Format of the string is based on Unicode Technical Standard #35:
    	 * https://www.unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table
    	 * with a few additions (see note 7 below the table).
    	 *
    	 * Accepted patterns:
    	 * | Unit                            | Pattern | Result examples                   | Notes |
    	 * |---------------------------------|---------|-----------------------------------|-------|
    	 * | Era                             | G..GGG  | AD, BC                            |       |
    	 * |                                 | GGGG    | Anno Domini, Before Christ        | 2     |
    	 * |                                 | GGGGG   | A, B                              |       |
    	 * | Calendar year                   | y       | 44, 1, 1900, 2017                 | 5     |
    	 * |                                 | yo      | 44th, 1st, 0th, 17th              | 5,7   |
    	 * |                                 | yy      | 44, 01, 00, 17                    | 5     |
    	 * |                                 | yyy     | 044, 001, 1900, 2017              | 5     |
    	 * |                                 | yyyy    | 0044, 0001, 1900, 2017            | 5     |
    	 * |                                 | yyyyy   | ...                               | 3,5   |
    	 * | Local week-numbering year       | Y       | 44, 1, 1900, 2017                 | 5     |
    	 * |                                 | Yo      | 44th, 1st, 1900th, 2017th         | 5,7   |
    	 * |                                 | YY      | 44, 01, 00, 17                    | 5,8   |
    	 * |                                 | YYY     | 044, 001, 1900, 2017              | 5     |
    	 * |                                 | YYYY    | 0044, 0001, 1900, 2017            | 5,8   |
    	 * |                                 | YYYYY   | ...                               | 3,5   |
    	 * | ISO week-numbering year         | R       | -43, 0, 1, 1900, 2017             | 5,7   |
    	 * |                                 | RR      | -43, 00, 01, 1900, 2017           | 5,7   |
    	 * |                                 | RRR     | -043, 000, 001, 1900, 2017        | 5,7   |
    	 * |                                 | RRRR    | -0043, 0000, 0001, 1900, 2017     | 5,7   |
    	 * |                                 | RRRRR   | ...                               | 3,5,7 |
    	 * | Extended year                   | u       | -43, 0, 1, 1900, 2017             | 5     |
    	 * |                                 | uu      | -43, 01, 1900, 2017               | 5     |
    	 * |                                 | uuu     | -043, 001, 1900, 2017             | 5     |
    	 * |                                 | uuuu    | -0043, 0001, 1900, 2017           | 5     |
    	 * |                                 | uuuuu   | ...                               | 3,5   |
    	 * | Quarter (formatting)            | Q       | 1, 2, 3, 4                        |       |
    	 * |                                 | Qo      | 1st, 2nd, 3rd, 4th                | 7     |
    	 * |                                 | QQ      | 01, 02, 03, 04                    |       |
    	 * |                                 | QQQ     | Q1, Q2, Q3, Q4                    |       |
    	 * |                                 | QQQQ    | 1st quarter, 2nd quarter, ...     | 2     |
    	 * |                                 | QQQQQ   | 1, 2, 3, 4                        | 4     |
    	 * | Quarter (stand-alone)           | q       | 1, 2, 3, 4                        |       |
    	 * |                                 | qo      | 1st, 2nd, 3rd, 4th                | 7     |
    	 * |                                 | qq      | 01, 02, 03, 04                    |       |
    	 * |                                 | qqq     | Q1, Q2, Q3, Q4                    |       |
    	 * |                                 | qqqq    | 1st quarter, 2nd quarter, ...     | 2     |
    	 * |                                 | qqqqq   | 1, 2, 3, 4                        | 4     |
    	 * | Month (formatting)              | M       | 1, 2, ..., 12                     |       |
    	 * |                                 | Mo      | 1st, 2nd, ..., 12th               | 7     |
    	 * |                                 | MM      | 01, 02, ..., 12                   |       |
    	 * |                                 | MMM     | Jan, Feb, ..., Dec                |       |
    	 * |                                 | MMMM    | January, February, ..., December  | 2     |
    	 * |                                 | MMMMM   | J, F, ..., D                      |       |
    	 * | Month (stand-alone)             | L       | 1, 2, ..., 12                     |       |
    	 * |                                 | Lo      | 1st, 2nd, ..., 12th               | 7     |
    	 * |                                 | LL      | 01, 02, ..., 12                   |       |
    	 * |                                 | LLL     | Jan, Feb, ..., Dec                |       |
    	 * |                                 | LLLL    | January, February, ..., December  | 2     |
    	 * |                                 | LLLLL   | J, F, ..., D                      |       |
    	 * | Local week of year              | w       | 1, 2, ..., 53                     |       |
    	 * |                                 | wo      | 1st, 2nd, ..., 53th               | 7     |
    	 * |                                 | ww      | 01, 02, ..., 53                   |       |
    	 * | ISO week of year                | I       | 1, 2, ..., 53                     | 7     |
    	 * |                                 | Io      | 1st, 2nd, ..., 53th               | 7     |
    	 * |                                 | II      | 01, 02, ..., 53                   | 7     |
    	 * | Day of month                    | d       | 1, 2, ..., 31                     |       |
    	 * |                                 | do      | 1st, 2nd, ..., 31st               | 7     |
    	 * |                                 | dd      | 01, 02, ..., 31                   |       |
    	 * | Day of year                     | D       | 1, 2, ..., 365, 366               | 9     |
    	 * |                                 | Do      | 1st, 2nd, ..., 365th, 366th       | 7     |
    	 * |                                 | DD      | 01, 02, ..., 365, 366             | 9     |
    	 * |                                 | DDD     | 001, 002, ..., 365, 366           |       |
    	 * |                                 | DDDD    | ...                               | 3     |
    	 * | Day of week (formatting)        | E..EEE  | Mon, Tue, Wed, ..., Sun           |       |
    	 * |                                 | EEEE    | Monday, Tuesday, ..., Sunday      | 2     |
    	 * |                                 | EEEEE   | M, T, W, T, F, S, S               |       |
    	 * |                                 | EEEEEE  | Mo, Tu, We, Th, Fr, Sa, Su        |       |
    	 * | ISO day of week (formatting)    | i       | 1, 2, 3, ..., 7                   | 7     |
    	 * |                                 | io      | 1st, 2nd, ..., 7th                | 7     |
    	 * |                                 | ii      | 01, 02, ..., 07                   | 7     |
    	 * |                                 | iii     | Mon, Tue, Wed, ..., Sun           | 7     |
    	 * |                                 | iiii    | Monday, Tuesday, ..., Sunday      | 2,7   |
    	 * |                                 | iiiii   | M, T, W, T, F, S, S               | 7     |
    	 * |                                 | iiiiii  | Mo, Tu, We, Th, Fr, Sa, Su        | 7     |
    	 * | Local day of week (formatting)  | e       | 2, 3, 4, ..., 1                   |       |
    	 * |                                 | eo      | 2nd, 3rd, ..., 1st                | 7     |
    	 * |                                 | ee      | 02, 03, ..., 01                   |       |
    	 * |                                 | eee     | Mon, Tue, Wed, ..., Sun           |       |
    	 * |                                 | eeee    | Monday, Tuesday, ..., Sunday      | 2     |
    	 * |                                 | eeeee   | M, T, W, T, F, S, S               |       |
    	 * |                                 | eeeeee  | Mo, Tu, We, Th, Fr, Sa, Su        |       |
    	 * | Local day of week (stand-alone) | c       | 2, 3, 4, ..., 1                   |       |
    	 * |                                 | co      | 2nd, 3rd, ..., 1st                | 7     |
    	 * |                                 | cc      | 02, 03, ..., 01                   |       |
    	 * |                                 | ccc     | Mon, Tue, Wed, ..., Sun           |       |
    	 * |                                 | cccc    | Monday, Tuesday, ..., Sunday      | 2     |
    	 * |                                 | ccccc   | M, T, W, T, F, S, S               |       |
    	 * |                                 | cccccc  | Mo, Tu, We, Th, Fr, Sa, Su        |       |
    	 * | AM, PM                          | a..aa   | AM, PM                            |       |
    	 * |                                 | aaa     | am, pm                            |       |
    	 * |                                 | aaaa    | a.m., p.m.                        | 2     |
    	 * |                                 | aaaaa   | a, p                              |       |
    	 * | AM, PM, noon, midnight          | b..bb   | AM, PM, noon, midnight            |       |
    	 * |                                 | bbb     | am, pm, noon, midnight            |       |
    	 * |                                 | bbbb    | a.m., p.m., noon, midnight        | 2     |
    	 * |                                 | bbbbb   | a, p, n, mi                       |       |
    	 * | Flexible day period             | B..BBB  | at night, in the morning, ...     |       |
    	 * |                                 | BBBB    | at night, in the morning, ...     | 2     |
    	 * |                                 | BBBBB   | at night, in the morning, ...     |       |
    	 * | Hour [1-12]                     | h       | 1, 2, ..., 11, 12                 |       |
    	 * |                                 | ho      | 1st, 2nd, ..., 11th, 12th         | 7     |
    	 * |                                 | hh      | 01, 02, ..., 11, 12               |       |
    	 * | Hour [0-23]                     | H       | 0, 1, 2, ..., 23                  |       |
    	 * |                                 | Ho      | 0th, 1st, 2nd, ..., 23rd          | 7     |
    	 * |                                 | HH      | 00, 01, 02, ..., 23               |       |
    	 * | Hour [0-11]                     | K       | 1, 2, ..., 11, 0                  |       |
    	 * |                                 | Ko      | 1st, 2nd, ..., 11th, 0th          | 7     |
    	 * |                                 | KK      | 01, 02, ..., 11, 00               |       |
    	 * | Hour [1-24]                     | k       | 24, 1, 2, ..., 23                 |       |
    	 * |                                 | ko      | 24th, 1st, 2nd, ..., 23rd         | 7     |
    	 * |                                 | kk      | 24, 01, 02, ..., 23               |       |
    	 * | Minute                          | m       | 0, 1, ..., 59                     |       |
    	 * |                                 | mo      | 0th, 1st, ..., 59th               | 7     |
    	 * |                                 | mm      | 00, 01, ..., 59                   |       |
    	 * | Second                          | s       | 0, 1, ..., 59                     |       |
    	 * |                                 | so      | 0th, 1st, ..., 59th               | 7     |
    	 * |                                 | ss      | 00, 01, ..., 59                   |       |
    	 * | Fraction of second              | S       | 0, 1, ..., 9                      |       |
    	 * |                                 | SS      | 00, 01, ..., 99                   |       |
    	 * |                                 | SSS     | 000, 001, ..., 999                |       |
    	 * |                                 | SSSS    | ...                               | 3     |
    	 * | Timezone (ISO-8601 w/ Z)        | X       | -08, +0530, Z                     |       |
    	 * |                                 | XX      | -0800, +0530, Z                   |       |
    	 * |                                 | XXX     | -08:00, +05:30, Z                 |       |
    	 * |                                 | XXXX    | -0800, +0530, Z, +123456          | 2     |
    	 * |                                 | XXXXX   | -08:00, +05:30, Z, +12:34:56      |       |
    	 * | Timezone (ISO-8601 w/o Z)       | x       | -08, +0530, +00                   |       |
    	 * |                                 | xx      | -0800, +0530, +0000               |       |
    	 * |                                 | xxx     | -08:00, +05:30, +00:00            | 2     |
    	 * |                                 | xxxx    | -0800, +0530, +0000, +123456      |       |
    	 * |                                 | xxxxx   | -08:00, +05:30, +00:00, +12:34:56 |       |
    	 * | Timezone (GMT)                  | O...OOO | GMT-8, GMT+5:30, GMT+0            |       |
    	 * |                                 | OOOO    | GMT-08:00, GMT+05:30, GMT+00:00   | 2     |
    	 * | Timezone (specific non-locat.)  | z...zzz | GMT-8, GMT+5:30, GMT+0            | 6     |
    	 * |                                 | zzzz    | GMT-08:00, GMT+05:30, GMT+00:00   | 2,6   |
    	 * | Seconds timestamp               | t       | 512969520                         | 7     |
    	 * |                                 | tt      | ...                               | 3,7   |
    	 * | Milliseconds timestamp          | T       | 512969520900                      | 7     |
    	 * |                                 | TT      | ...                               | 3,7   |
    	 * | Long localized date             | P       | 04/29/1453                        | 7     |
    	 * |                                 | PP      | Apr 29, 1453                      | 7     |
    	 * |                                 | PPP     | April 29th, 1453                  | 7     |
    	 * |                                 | PPPP    | Friday, April 29th, 1453          | 2,7   |
    	 * | Long localized time             | p       | 12:00 AM                          | 7     |
    	 * |                                 | pp      | 12:00:00 AM                       | 7     |
    	 * |                                 | ppp     | 12:00:00 AM GMT+2                 | 7     |
    	 * |                                 | pppp    | 12:00:00 AM GMT+02:00             | 2,7   |
    	 * | Combination of date and time    | Pp      | 04/29/1453, 12:00 AM              | 7     |
    	 * |                                 | PPpp    | Apr 29, 1453, 12:00:00 AM         | 7     |
    	 * |                                 | PPPppp  | April 29th, 1453 at ...           | 7     |
    	 * |                                 | PPPPpppp| Friday, April 29th, 1453 at ...   | 2,7   |
    	 * Notes:
    	 * 1. "Formatting" units (e.g. formatting quarter) in the default en-US locale
    	 *    are the same as "stand-alone" units, but are different in some languages.
    	 *    "Formatting" units are declined according to the rules of the language
    	 *    in the context of a date. "Stand-alone" units are always nominative singular:
    	 *
    	 *    `format(new Date(2017, 10, 6), 'do LLLL', {locale: cs}) //=> '6. listopad'`
    	 *
    	 *    `format(new Date(2017, 10, 6), 'do MMMM', {locale: cs}) //=> '6. listopadu'`
    	 *
    	 * 2. Any sequence of the identical letters is a pattern, unless it is escaped by
    	 *    the single quote characters (see below).
    	 *    If the sequence is longer than listed in table (e.g. `EEEEEEEEEEE`)
    	 *    the output will be the same as default pattern for this unit, usually
    	 *    the longest one (in case of ISO weekdays, `EEEE`). Default patterns for units
    	 *    are marked with "2" in the last column of the table.
    	 *
    	 *    `format(new Date(2017, 10, 6), 'MMM') //=> 'Nov'`
    	 *
    	 *    `format(new Date(2017, 10, 6), 'MMMM') //=> 'November'`
    	 *
    	 *    `format(new Date(2017, 10, 6), 'MMMMM') //=> 'N'`
    	 *
    	 *    `format(new Date(2017, 10, 6), 'MMMMMM') //=> 'November'`
    	 *
    	 *    `format(new Date(2017, 10, 6), 'MMMMMMM') //=> 'November'`
    	 *
    	 * 3. Some patterns could be unlimited length (such as `yyyyyyyy`).
    	 *    The output will be padded with zeros to match the length of the pattern.
    	 *
    	 *    `format(new Date(2017, 10, 6), 'yyyyyyyy') //=> '00002017'`
    	 *
    	 * 4. `QQQQQ` and `qqqqq` could be not strictly numerical in some locales.
    	 *    These tokens represent the shortest form of the quarter.
    	 *
    	 * 5. The main difference between `y` and `u` patterns are B.C. years:
    	 *
    	 *    | Year | `y` | `u` |
    	 *    |------|-----|-----|
    	 *    | AC 1 |   1 |   1 |
    	 *    | BC 1 |   1 |   0 |
    	 *    | BC 2 |   2 |  -1 |
    	 *
    	 *    Also `yy` always returns the last two digits of a year,
    	 *    while `uu` pads single digit years to 2 characters and returns other years unchanged:
    	 *
    	 *    | Year | `yy` | `uu` |
    	 *    |------|------|------|
    	 *    | 1    |   01 |   01 |
    	 *    | 14   |   14 |   14 |
    	 *    | 376  |   76 |  376 |
    	 *    | 1453 |   53 | 1453 |
    	 *
    	 *    The same difference is true for local and ISO week-numbering years (`Y` and `R`),
    	 *    except local week-numbering years are dependent on `options.weekStartsOn`
    	 *    and `options.firstWeekContainsDate` (compare [getISOWeekYear]{@link https://date-fns.org/docs/getISOWeekYear}
    	 *    and [getWeekYear]{@link https://date-fns.org/docs/getWeekYear}).
    	 *
    	 * 6. Specific non-location timezones are currently unavailable in `date-fns`,
    	 *    so right now these tokens fall back to GMT timezones.
    	 *
    	 * 7. These patterns are not in the Unicode Technical Standard #35:
    	 *    - `i`: ISO day of week
    	 *    - `I`: ISO week of year
    	 *    - `R`: ISO week-numbering year
    	 *    - `t`: seconds timestamp
    	 *    - `T`: milliseconds timestamp
    	 *    - `o`: ordinal number modifier
    	 *    - `P`: long localized date
    	 *    - `p`: long localized time
    	 *
    	 * 8. `YY` and `YYYY` tokens represent week-numbering years but they are often confused with years.
    	 *    You should enable `options.useAdditionalWeekYearTokens` to use them. See: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
    	 *
    	 * 9. `D` and `DD` tokens represent days of the year but they are often confused with days of the month.
    	 *    You should enable `options.useAdditionalDayOfYearTokens` to use them. See: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
    	 *
    	 * @param {Date|Number} date - the original date
    	 * @param {String} format - the string of tokens
    	 * @param {Object} [options] - an object with options.
    	 * @param {Locale} [options.locale=defaultLocale] - the locale object. See [Locale]{@link https://date-fns.org/docs/Locale}
    	 * @param {0|1|2|3|4|5|6} [options.weekStartsOn=0] - the index of the first day of the week (0 - Sunday)
    	 * @param {Number} [options.firstWeekContainsDate=1] - the day of January, which is
    	 * @param {Boolean} [options.useAdditionalWeekYearTokens=false] - if true, allows usage of the week-numbering year tokens `YY` and `YYYY`;
    	 *   see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
    	 * @param {Boolean} [options.useAdditionalDayOfYearTokens=false] - if true, allows usage of the day of year tokens `D` and `DD`;
    	 *   see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
    	 * @returns {String} the formatted date string
    	 * @throws {TypeError} 2 arguments required
    	 * @throws {RangeError} `date` must not be Invalid Date
    	 * @throws {RangeError} `options.locale` must contain `localize` property
    	 * @throws {RangeError} `options.locale` must contain `formatLong` property
    	 * @throws {RangeError} `options.weekStartsOn` must be between 0 and 6
    	 * @throws {RangeError} `options.firstWeekContainsDate` must be between 1 and 7
    	 * @throws {RangeError} use `yyyy` instead of `YYYY` for formatting years using [format provided] to the input [input provided]; see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
    	 * @throws {RangeError} use `yy` instead of `YY` for formatting years using [format provided] to the input [input provided]; see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
    	 * @throws {RangeError} use `d` instead of `D` for formatting days of the month using [format provided] to the input [input provided]; see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
    	 * @throws {RangeError} use `dd` instead of `DD` for formatting days of the month using [format provided] to the input [input provided]; see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md
    	 * @throws {RangeError} format string contains an unescaped latin alphabet character
    	 *
    	 * @example
    	 * // Represent 11 February 2014 in middle-endian format:
    	 * const result = format(new Date(2014, 1, 11), 'MM/dd/yyyy')
    	 * //=> '02/11/2014'
    	 *
    	 * @example
    	 * // Represent 2 July 2014 in Esperanto:
    	 * import { eoLocale } from 'date-fns/locale/eo'
    	 * const result = format(new Date(2014, 6, 2), "do 'de' MMMM yyyy", {
    	 *   locale: eoLocale
    	 * })
    	 * //=> '2-a de julio 2014'
    	 *
    	 * @example
    	 * // Escape string by single quote characters:
    	 * const result = format(new Date(2014, 6, 2, 15), "h 'o''clock'")
    	 * //=> "3 o'clock"
    	 */

    	function format(dirtyDate, dirtyFormatStr, options) {
    	  var _ref, _options$locale, _ref2, _ref3, _ref4, _options$firstWeekCon, _options$locale2, _options$locale2$opti, _defaultOptions$local, _defaultOptions$local2, _ref5, _ref6, _ref7, _options$weekStartsOn, _options$locale3, _options$locale3$opti, _defaultOptions$local3, _defaultOptions$local4;

    	  (0, _index9.default)(2, arguments);
    	  var formatStr = String(dirtyFormatStr);
    	  var defaultOptions = (0, _index10.getDefaultOptions)();
    	  var locale = (_ref = (_options$locale = options === null || options === void 0 ? void 0 : options.locale) !== null && _options$locale !== void 0 ? _options$locale : defaultOptions.locale) !== null && _ref !== void 0 ? _ref : _index11.default;
    	  var firstWeekContainsDate = (0, _index8.default)((_ref2 = (_ref3 = (_ref4 = (_options$firstWeekCon = options === null || options === void 0 ? void 0 : options.firstWeekContainsDate) !== null && _options$firstWeekCon !== void 0 ? _options$firstWeekCon : options === null || options === void 0 ? void 0 : (_options$locale2 = options.locale) === null || _options$locale2 === void 0 ? void 0 : (_options$locale2$opti = _options$locale2.options) === null || _options$locale2$opti === void 0 ? void 0 : _options$locale2$opti.firstWeekContainsDate) !== null && _ref4 !== void 0 ? _ref4 : defaultOptions.firstWeekContainsDate) !== null && _ref3 !== void 0 ? _ref3 : (_defaultOptions$local = defaultOptions.locale) === null || _defaultOptions$local === void 0 ? void 0 : (_defaultOptions$local2 = _defaultOptions$local.options) === null || _defaultOptions$local2 === void 0 ? void 0 : _defaultOptions$local2.firstWeekContainsDate) !== null && _ref2 !== void 0 ? _ref2 : 1); // Test if weekStartsOn is between 1 and 7 _and_ is not NaN

    	  if (!(firstWeekContainsDate >= 1 && firstWeekContainsDate <= 7)) {
    	    throw new RangeError('firstWeekContainsDate must be between 1 and 7 inclusively');
    	  }

    	  var weekStartsOn = (0, _index8.default)((_ref5 = (_ref6 = (_ref7 = (_options$weekStartsOn = options === null || options === void 0 ? void 0 : options.weekStartsOn) !== null && _options$weekStartsOn !== void 0 ? _options$weekStartsOn : options === null || options === void 0 ? void 0 : (_options$locale3 = options.locale) === null || _options$locale3 === void 0 ? void 0 : (_options$locale3$opti = _options$locale3.options) === null || _options$locale3$opti === void 0 ? void 0 : _options$locale3$opti.weekStartsOn) !== null && _ref7 !== void 0 ? _ref7 : defaultOptions.weekStartsOn) !== null && _ref6 !== void 0 ? _ref6 : (_defaultOptions$local3 = defaultOptions.locale) === null || _defaultOptions$local3 === void 0 ? void 0 : (_defaultOptions$local4 = _defaultOptions$local3.options) === null || _defaultOptions$local4 === void 0 ? void 0 : _defaultOptions$local4.weekStartsOn) !== null && _ref5 !== void 0 ? _ref5 : 0); // Test if weekStartsOn is between 0 and 6 _and_ is not NaN

    	  if (!(weekStartsOn >= 0 && weekStartsOn <= 6)) {
    	    throw new RangeError('weekStartsOn must be between 0 and 6 inclusively');
    	  }

    	  if (!locale.localize) {
    	    throw new RangeError('locale must contain localize property');
    	  }

    	  if (!locale.formatLong) {
    	    throw new RangeError('locale must contain formatLong property');
    	  }

    	  var originalDate = (0, _index3.default)(dirtyDate);

    	  if (!(0, _index.default)(originalDate)) {
    	    throw new RangeError('Invalid time value');
    	  } // Convert the date in system timezone to the same date in UTC+00:00 timezone.
    	  // This ensures that when UTC functions will be implemented, locales will be compatible with them.
    	  // See an issue about UTC functions: https://github.com/date-fns/date-fns/issues/376


    	  var timezoneOffset = (0, _index6.default)(originalDate);
    	  var utcDate = (0, _index2.default)(originalDate, timezoneOffset);
    	  var formatterOptions = {
    	    firstWeekContainsDate: firstWeekContainsDate,
    	    weekStartsOn: weekStartsOn,
    	    locale: locale,
    	    _originalDate: originalDate
    	  };
    	  var result = formatStr.match(longFormattingTokensRegExp).map(function (substring) {
    	    var firstCharacter = substring[0];

    	    if (firstCharacter === 'p' || firstCharacter === 'P') {
    	      var longFormatter = _index5.default[firstCharacter];
    	      return longFormatter(substring, locale.formatLong);
    	    }

    	    return substring;
    	  }).join('').match(formattingTokensRegExp).map(function (substring) {
    	    // Replace two single quote characters with one single quote character
    	    if (substring === "''") {
    	      return "'";
    	    }

    	    var firstCharacter = substring[0];

    	    if (firstCharacter === "'") {
    	      return cleanEscapedString(substring);
    	    }

    	    var formatter = _index4.default[firstCharacter];

    	    if (formatter) {
    	      if (!(options !== null && options !== void 0 && options.useAdditionalWeekYearTokens) && (0, _index7.isProtectedWeekYearToken)(substring)) {
    	        (0, _index7.throwProtectedError)(substring, dirtyFormatStr, String(dirtyDate));
    	      }

    	      if (!(options !== null && options !== void 0 && options.useAdditionalDayOfYearTokens) && (0, _index7.isProtectedDayOfYearToken)(substring)) {
    	        (0, _index7.throwProtectedError)(substring, dirtyFormatStr, String(dirtyDate));
    	      }

    	      return formatter(utcDate, substring, locale.localize, formatterOptions);
    	    }

    	    if (firstCharacter.match(unescapedLatinCharacterRegExp)) {
    	      throw new RangeError('Format string contains an unescaped latin alphabet character `' + firstCharacter + '`');
    	    }

    	    return substring;
    	  }).join('');
    	  return result;
    	}

    	function cleanEscapedString(input) {
    	  var matched = input.match(escapedStringRegExp);

    	  if (!matched) {
    	    return input;
    	  }

    	  return matched[1].replace(doubleQuoteRegExp, "'");
    	}

    	module.exports = exports.default;
    } (format$2, format$2.exports));

    var formatters = {exports: {}};

    var tzIntlTimeZoneName = {exports: {}};

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = tzIntlTimeZoneName;
    	/**
    	 * Returns the formatted time zone name of the provided `timeZone` or the current
    	 * system time zone if omitted, accounting for DST according to the UTC value of
    	 * the date.
    	 */

    	function tzIntlTimeZoneName(length, date, options) {
    	  var dtf = getDTF(length, options.timeZone, options.locale);
    	  return dtf.formatToParts ? partsTimeZone(dtf, date) : hackyTimeZone(dtf, date);
    	}

    	function partsTimeZone(dtf, date) {
    	  var formatted = dtf.formatToParts(date);
    	  return formatted[formatted.length - 1].value;
    	}

    	function hackyTimeZone(dtf, date) {
    	  var formatted = dtf.format(date).replace(/\u200E/g, '');
    	  var tzNameMatch = / [\w-+ ]+$/.exec(formatted);
    	  return tzNameMatch ? tzNameMatch[0].substr(1) : '';
    	} // If a locale has been provided `en-US` is used as a fallback in case it is an
    	// invalid locale, otherwise the locale is left undefined to use the system locale.


    	function getDTF(length, timeZone, locale) {
    	  if (locale && !locale.code) {
    	    throw new Error("date-fns-tz error: Please set a language code on the locale object imported from date-fns, e.g. `locale.code = 'en-US'`");
    	  }

    	  return new Intl.DateTimeFormat(locale ? [locale.code, 'en-US'] : undefined, {
    	    timeZone: timeZone,
    	    timeZoneName: length
    	  });
    	}

    	module.exports = exports.default;
    } (tzIntlTimeZoneName, tzIntlTimeZoneName.exports));

    var tzParseTimezone = {exports: {}};

    var tzTokenizeDate = {exports: {}};

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = tzTokenizeDate;
    	/**
    	 * Returns the [year, month, day, hour, minute, seconds] tokens of the provided
    	 * `date` as it will be rendered in the `timeZone`.
    	 */

    	function tzTokenizeDate(date, timeZone) {
    	  var dtf = getDateTimeFormat(timeZone);
    	  return dtf.formatToParts ? partsOffset(dtf, date) : hackyOffset(dtf, date);
    	}

    	var typeToPos = {
    	  year: 0,
    	  month: 1,
    	  day: 2,
    	  hour: 3,
    	  minute: 4,
    	  second: 5
    	};

    	function partsOffset(dtf, date) {
    	  try {
    	    var formatted = dtf.formatToParts(date);
    	    var filled = [];

    	    for (var i = 0; i < formatted.length; i++) {
    	      var pos = typeToPos[formatted[i].type];

    	      if (pos >= 0) {
    	        filled[pos] = parseInt(formatted[i].value, 10);
    	      }
    	    }

    	    return filled;
    	  } catch (error) {
    	    if (error instanceof RangeError) {
    	      return [NaN];
    	    }

    	    throw error;
    	  }
    	}

    	function hackyOffset(dtf, date) {
    	  var formatted = dtf.format(date).replace(/\u200E/g, '');
    	  var parsed = /(\d+)\/(\d+)\/(\d+),? (\d+):(\d+):(\d+)/.exec(formatted); // var [, fMonth, fDay, fYear, fHour, fMinute, fSecond] = parsed
    	  // return [fYear, fMonth, fDay, fHour, fMinute, fSecond]

    	  return [parsed[3], parsed[1], parsed[2], parsed[4], parsed[5], parsed[6]];
    	} // Get a cached Intl.DateTimeFormat instance for the IANA `timeZone`. This can be used
    	// to get deterministic local date/time output according to the `en-US` locale which
    	// can be used to extract local time parts as necessary.


    	var dtfCache = {};

    	function getDateTimeFormat(timeZone) {
    	  if (!dtfCache[timeZone]) {
    	    // New browsers use `hourCycle`, IE and Chrome <73 does not support it and uses `hour12`
    	    var testDateFormatted = new Intl.DateTimeFormat('en-US', {
    	      hour12: false,
    	      timeZone: 'America/New_York',
    	      year: 'numeric',
    	      month: '2-digit',
    	      day: '2-digit',
    	      hour: '2-digit',
    	      minute: '2-digit',
    	      second: '2-digit'
    	    }).format(new Date('2014-06-25T04:00:00.123Z'));
    	    var hourCycleSupported = testDateFormatted === '06/25/2014, 00:00:00' || testDateFormatted === '‎06‎/‎25‎/‎2014‎ ‎00‎:‎00‎:‎00';
    	    dtfCache[timeZone] = hourCycleSupported ? new Intl.DateTimeFormat('en-US', {
    	      hour12: false,
    	      timeZone: timeZone,
    	      year: 'numeric',
    	      month: '2-digit',
    	      day: '2-digit',
    	      hour: '2-digit',
    	      minute: '2-digit',
    	      second: '2-digit'
    	    }) : new Intl.DateTimeFormat('en-US', {
    	      hourCycle: 'h23',
    	      timeZone: timeZone,
    	      year: 'numeric',
    	      month: '2-digit',
    	      day: '2-digit',
    	      hour: '2-digit',
    	      minute: '2-digit',
    	      second: '2-digit'
    	    });
    	  }

    	  return dtfCache[timeZone];
    	}

    	module.exports = exports.default;
    } (tzTokenizeDate, tzTokenizeDate.exports));

    var newDateUTC = {exports: {}};

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = newDateUTC;
    	/**
    	 * Use instead of `new Date(Date.UTC(...))` to support years below 100 which doesn't work
    	 * otherwise due to the nature of the
    	 * [`Date` constructor](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date#interpretation_of_two-digit_years.
    	 *
    	 * For `Date.UTC(...)`, use `newDateUTC(...).getTime()`.
    	 */

    	function newDateUTC(fullYear, month, day, hour, minute, second, millisecond) {
    	  var utcDate = new Date(0);
    	  utcDate.setUTCFullYear(fullYear, month, day);
    	  utcDate.setUTCHours(hour, minute, second, millisecond);
    	  return utcDate;
    	}

    	module.exports = exports.default;
    } (newDateUTC, newDateUTC.exports));

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = tzParseTimezone;

    	var _index = _interopRequireDefault(tzTokenizeDate.exports);

    	var _index2 = _interopRequireDefault(newDateUTC.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}

    	var MILLISECONDS_IN_HOUR = 3600000;
    	var MILLISECONDS_IN_MINUTE = 60000;
    	var patterns = {
    	  timezone: /([Z+-].*)$/,
    	  timezoneZ: /^(Z)$/,
    	  timezoneHH: /^([+-]\d{2})$/,
    	  timezoneHHMM: /^([+-]\d{2}):?(\d{2})$/
    	}; // Parse various time zone offset formats to an offset in milliseconds

    	function tzParseTimezone(timezoneString, date, isUtcDate) {
    	  var token;
    	  var absoluteOffset; // Empty string

    	  if (timezoneString === '') {
    	    return 0;
    	  } // Z


    	  token = patterns.timezoneZ.exec(timezoneString);

    	  if (token) {
    	    return 0;
    	  }

    	  var hours; // ±hh

    	  token = patterns.timezoneHH.exec(timezoneString);

    	  if (token) {
    	    hours = parseInt(token[1], 10);

    	    if (!validateTimezone(hours)) {
    	      return NaN;
    	    }

    	    return -(hours * MILLISECONDS_IN_HOUR);
    	  } // ±hh:mm or ±hhmm


    	  token = patterns.timezoneHHMM.exec(timezoneString);

    	  if (token) {
    	    hours = parseInt(token[1], 10);
    	    var minutes = parseInt(token[2], 10);

    	    if (!validateTimezone(hours, minutes)) {
    	      return NaN;
    	    }

    	    absoluteOffset = Math.abs(hours) * MILLISECONDS_IN_HOUR + minutes * MILLISECONDS_IN_MINUTE;
    	    return hours > 0 ? -absoluteOffset : absoluteOffset;
    	  } // IANA time zone


    	  if (isValidTimezoneIANAString(timezoneString)) {
    	    date = new Date(date || Date.now());
    	    var utcDate = isUtcDate ? date : toUtcDate(date);
    	    var offset = calcOffset(utcDate, timezoneString);
    	    var fixedOffset = isUtcDate ? offset : fixOffset(date, offset, timezoneString);
    	    return -fixedOffset;
    	  }

    	  return NaN;
    	}

    	function toUtcDate(date) {
    	  return (0, _index2.default)(date.getFullYear(), date.getMonth(), date.getDate(), date.getHours(), date.getMinutes(), date.getSeconds(), date.getMilliseconds());
    	}

    	function calcOffset(date, timezoneString) {
    	  var tokens = (0, _index.default)(date, timezoneString); // ms dropped because it's not provided by tzTokenizeDate

    	  var asUTC = (0, _index2.default)(tokens[0], tokens[1] - 1, tokens[2], tokens[3] % 24, tokens[4], tokens[5], 0).getTime();
    	  var asTS = date.getTime();
    	  var over = asTS % 1000;
    	  asTS -= over >= 0 ? over : 1000 + over;
    	  return asUTC - asTS;
    	}

    	function fixOffset(date, offset, timezoneString) {
    	  var localTS = date.getTime(); // Our UTC time is just a guess because our offset is just a guess

    	  var utcGuess = localTS - offset; // Test whether the zone matches the offset for this ts

    	  var o2 = calcOffset(new Date(utcGuess), timezoneString); // If so, offset didn't change, and we're done

    	  if (offset === o2) {
    	    return offset;
    	  } // If not, change the ts by the difference in the offset


    	  utcGuess -= o2 - offset; // If that gives us the local time we want, we're done

    	  var o3 = calcOffset(new Date(utcGuess), timezoneString);

    	  if (o2 === o3) {
    	    return o2;
    	  } // If it's different, we're in a hole time. The offset has changed, but we don't adjust the time


    	  return Math.max(o2, o3);
    	}

    	function validateTimezone(hours, minutes) {
    	  return -23 <= hours && hours <= 23 && (minutes == null || 0 <= minutes && minutes <= 59);
    	}

    	var validIANATimezoneCache = {};

    	function isValidTimezoneIANAString(timeZoneString) {
    	  if (validIANATimezoneCache[timeZoneString]) return true;

    	  try {
    	    new Intl.DateTimeFormat(undefined, {
    	      timeZone: timeZoneString
    	    });
    	    validIANATimezoneCache[timeZoneString] = true;
    	    return true;
    	  } catch (error) {
    	    return false;
    	  }
    	}

    	module.exports = exports.default;
    } (tzParseTimezone, tzParseTimezone.exports));

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = void 0;

    	var _index = _interopRequireDefault(tzIntlTimeZoneName.exports);

    	var _index2 = _interopRequireDefault(tzParseTimezone.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}

    	var MILLISECONDS_IN_MINUTE = 60 * 1000;
    	var formatters = {
    	  // Timezone (ISO-8601. If offset is 0, output is always `'Z'`)
    	  X: function (date, token, localize, options) {
    	    var timezoneOffset = getTimeZoneOffset(options.timeZone, options._originalDate || date);

    	    if (timezoneOffset === 0) {
    	      return 'Z';
    	    }

    	    switch (token) {
    	      // Hours and optional minutes
    	      case 'X':
    	        return formatTimezoneWithOptionalMinutes(timezoneOffset);
    	      // Hours, minutes and optional seconds without `:` delimeter
    	      // Note: neither ISO-8601 nor JavaScript supports seconds in timezone offsets
    	      // so this token always has the same output as `XX`

    	      case 'XXXX':
    	      case 'XX':
    	        // Hours and minutes without `:` delimeter
    	        return formatTimezone(timezoneOffset);
    	      // Hours, minutes and optional seconds with `:` delimeter
    	      // Note: neither ISO-8601 nor JavaScript supports seconds in timezone offsets
    	      // so this token always has the same output as `XXX`

    	      case 'XXXXX':
    	      case 'XXX': // Hours and minutes with `:` delimeter

    	      default:
    	        return formatTimezone(timezoneOffset, ':');
    	    }
    	  },
    	  // Timezone (ISO-8601. If offset is 0, output is `'+00:00'` or equivalent)
    	  x: function (date, token, localize, options) {
    	    var timezoneOffset = getTimeZoneOffset(options.timeZone, options._originalDate || date);

    	    switch (token) {
    	      // Hours and optional minutes
    	      case 'x':
    	        return formatTimezoneWithOptionalMinutes(timezoneOffset);
    	      // Hours, minutes and optional seconds without `:` delimeter
    	      // Note: neither ISO-8601 nor JavaScript supports seconds in timezone offsets
    	      // so this token always has the same output as `xx`

    	      case 'xxxx':
    	      case 'xx':
    	        // Hours and minutes without `:` delimeter
    	        return formatTimezone(timezoneOffset);
    	      // Hours, minutes and optional seconds with `:` delimeter
    	      // Note: neither ISO-8601 nor JavaScript supports seconds in timezone offsets
    	      // so this token always has the same output as `xxx`

    	      case 'xxxxx':
    	      case 'xxx': // Hours and minutes with `:` delimeter

    	      default:
    	        return formatTimezone(timezoneOffset, ':');
    	    }
    	  },
    	  // Timezone (GMT)
    	  O: function (date, token, localize, options) {
    	    var timezoneOffset = getTimeZoneOffset(options.timeZone, options._originalDate || date);

    	    switch (token) {
    	      // Short
    	      case 'O':
    	      case 'OO':
    	      case 'OOO':
    	        return 'GMT' + formatTimezoneShort(timezoneOffset, ':');
    	      // Long

    	      case 'OOOO':
    	      default:
    	        return 'GMT' + formatTimezone(timezoneOffset, ':');
    	    }
    	  },
    	  // Timezone (specific non-location)
    	  z: function (date, token, localize, options) {
    	    var originalDate = options._originalDate || date;

    	    switch (token) {
    	      // Short
    	      case 'z':
    	      case 'zz':
    	      case 'zzz':
    	        return (0, _index.default)('short', originalDate, options);
    	      // Long

    	      case 'zzzz':
    	      default:
    	        return (0, _index.default)('long', originalDate, options);
    	    }
    	  }
    	};

    	function getTimeZoneOffset(timeZone, originalDate) {
    	  var timeZoneOffset = timeZone ? (0, _index2.default)(timeZone, originalDate, true) / MILLISECONDS_IN_MINUTE : originalDate.getTimezoneOffset();

    	  if (Number.isNaN(timeZoneOffset)) {
    	    throw new RangeError('Invalid time zone specified: ' + timeZone);
    	  }

    	  return timeZoneOffset;
    	}

    	function addLeadingZeros(number, targetLength) {
    	  var sign = number < 0 ? '-' : '';
    	  var output = Math.abs(number).toString();

    	  while (output.length < targetLength) {
    	    output = '0' + output;
    	  }

    	  return sign + output;
    	}

    	function formatTimezone(offset, dirtyDelimeter) {
    	  var delimeter = dirtyDelimeter || '';
    	  var sign = offset > 0 ? '-' : '+';
    	  var absOffset = Math.abs(offset);
    	  var hours = addLeadingZeros(Math.floor(absOffset / 60), 2);
    	  var minutes = addLeadingZeros(Math.floor(absOffset % 60), 2);
    	  return sign + hours + delimeter + minutes;
    	}

    	function formatTimezoneWithOptionalMinutes(offset, dirtyDelimeter) {
    	  if (offset % 60 === 0) {
    	    var sign = offset > 0 ? '-' : '+';
    	    return sign + addLeadingZeros(Math.abs(offset) / 60, 2);
    	  }

    	  return formatTimezone(offset, dirtyDelimeter);
    	}

    	function formatTimezoneShort(offset, dirtyDelimeter) {
    	  var sign = offset > 0 ? '-' : '+';
    	  var absOffset = Math.abs(offset);
    	  var hours = Math.floor(absOffset / 60);
    	  var minutes = absOffset % 60;

    	  if (minutes === 0) {
    	    return sign + String(hours);
    	  }

    	  var delimeter = dirtyDelimeter || '';
    	  return sign + String(hours) + delimeter + addLeadingZeros(minutes, 2);
    	}

    	var _default = formatters;
    	exports.default = _default;
    	module.exports = exports.default;
    } (formatters, formatters.exports));

    var toDate = {exports: {}};

    var tzPattern = {exports: {}};

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = void 0;
    	/** Regex to identify the presence of a time zone specifier in a date string */

    	var tzPattern = /(Z|[+-]\d{2}(?::?\d{2})?| UTC| [a-zA-Z]+\/[a-zA-Z_]+(?:\/[a-zA-Z_]+)?)$/;
    	var _default = tzPattern;
    	exports.default = _default;
    	module.exports = exports.default;
    } (tzPattern, tzPattern.exports));

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = toDate;

    	var _index = _interopRequireDefault(toInteger.exports);

    	var _index2 = _interopRequireDefault(getTimezoneOffsetInMilliseconds.exports);

    	var _index3 = _interopRequireDefault(tzParseTimezone.exports);

    	var _index4 = _interopRequireDefault(tzPattern.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}

    	var MILLISECONDS_IN_HOUR = 3600000;
    	var MILLISECONDS_IN_MINUTE = 60000;
    	var DEFAULT_ADDITIONAL_DIGITS = 2;
    	var patterns = {
    	  dateTimePattern: /^([0-9W+-]+)(T| )(.*)/,
    	  datePattern: /^([0-9W+-]+)(.*)/,
    	  plainTime: /:/,
    	  // year tokens
    	  YY: /^(\d{2})$/,
    	  YYY: [/^([+-]\d{2})$/, // 0 additional digits
    	  /^([+-]\d{3})$/, // 1 additional digit
    	  /^([+-]\d{4})$/ // 2 additional digits
    	  ],
    	  YYYY: /^(\d{4})/,
    	  YYYYY: [/^([+-]\d{4})/, // 0 additional digits
    	  /^([+-]\d{5})/, // 1 additional digit
    	  /^([+-]\d{6})/ // 2 additional digits
    	  ],
    	  // date tokens
    	  MM: /^-(\d{2})$/,
    	  DDD: /^-?(\d{3})$/,
    	  MMDD: /^-?(\d{2})-?(\d{2})$/,
    	  Www: /^-?W(\d{2})$/,
    	  WwwD: /^-?W(\d{2})-?(\d{1})$/,
    	  HH: /^(\d{2}([.,]\d*)?)$/,
    	  HHMM: /^(\d{2}):?(\d{2}([.,]\d*)?)$/,
    	  HHMMSS: /^(\d{2}):?(\d{2}):?(\d{2}([.,]\d*)?)$/,
    	  // time zone tokens (to identify the presence of a tz)
    	  timeZone: _index4.default
    	};
    	/**
    	 * @name toDate
    	 * @category Common Helpers
    	 * @summary Convert the given argument to an instance of Date.
    	 *
    	 * @description
    	 * Convert the given argument to an instance of Date.
    	 *
    	 * If the argument is an instance of Date, the function returns its clone.
    	 *
    	 * If the argument is a number, it is treated as a timestamp.
    	 *
    	 * If an argument is a string, the function tries to parse it.
    	 * Function accepts complete ISO 8601 formats as well as partial implementations.
    	 * ISO 8601: http://en.wikipedia.org/wiki/ISO_8601
    	 * If the function cannot parse the string or the values are invalid, it returns Invalid Date.
    	 *
    	 * If the argument is none of the above, the function returns Invalid Date.
    	 *
    	 * **Note**: *all* Date arguments passed to any *date-fns* function is processed by `toDate`.
    	 * All *date-fns* functions will throw `RangeError` if `options.additionalDigits` is not 0, 1, 2 or undefined.
    	 *
    	 * @param {Date|String|Number} argument - the value to convert
    	 * @param {OptionsWithTZ} [options] - the object with options. See [Options]{@link https://date-fns.org/docs/Options}
    	 * @param {0|1|2} [options.additionalDigits=2] - the additional number of digits in the extended year format
    	 * @param {String} [options.timeZone=''] - used to specify the IANA time zone offset of a date String.
    	 * @returns {Date} the parsed date in the local time zone
    	 * @throws {TypeError} 1 argument required
    	 * @throws {RangeError} `options.additionalDigits` must be 0, 1 or 2
    	 *
    	 * @example
    	 * // Convert string '2014-02-11T11:30:30' to date:
    	 * var result = toDate('2014-02-11T11:30:30')
    	 * //=> Tue Feb 11 2014 11:30:30
    	 *
    	 * @example
    	 * // Convert string '+02014101' to date,
    	 * // if the additional number of digits in the extended year format is 1:
    	 * var result = toDate('+02014101', {additionalDigits: 1})
    	 * //=> Fri Apr 11 2014 00:00:00
    	 */

    	function toDate(argument, dirtyOptions) {
    	  if (arguments.length < 1) {
    	    throw new TypeError('1 argument required, but only ' + arguments.length + ' present');
    	  }

    	  if (argument === null) {
    	    return new Date(NaN);
    	  }

    	  var options = dirtyOptions || {};
    	  var additionalDigits = options.additionalDigits == null ? DEFAULT_ADDITIONAL_DIGITS : (0, _index.default)(options.additionalDigits);

    	  if (additionalDigits !== 2 && additionalDigits !== 1 && additionalDigits !== 0) {
    	    throw new RangeError('additionalDigits must be 0, 1 or 2');
    	  } // Clone the date


    	  if (argument instanceof Date || typeof argument === 'object' && Object.prototype.toString.call(argument) === '[object Date]') {
    	    // Prevent the date to lose the milliseconds when passed to new Date() in IE10
    	    return new Date(argument.getTime());
    	  } else if (typeof argument === 'number' || Object.prototype.toString.call(argument) === '[object Number]') {
    	    return new Date(argument);
    	  } else if (!(typeof argument === 'string' || Object.prototype.toString.call(argument) === '[object String]')) {
    	    return new Date(NaN);
    	  }

    	  var dateStrings = splitDateString(argument);
    	  var parseYearResult = parseYear(dateStrings.date, additionalDigits);
    	  var year = parseYearResult.year;
    	  var restDateString = parseYearResult.restDateString;
    	  var date = parseDate(restDateString, year);

    	  if (isNaN(date)) {
    	    return new Date(NaN);
    	  }

    	  if (date) {
    	    var timestamp = date.getTime();
    	    var time = 0;
    	    var offset;

    	    if (dateStrings.time) {
    	      time = parseTime(dateStrings.time);

    	      if (isNaN(time)) {
    	        return new Date(NaN);
    	      }
    	    }

    	    if (dateStrings.timeZone || options.timeZone) {
    	      offset = (0, _index3.default)(dateStrings.timeZone || options.timeZone, new Date(timestamp + time));

    	      if (isNaN(offset)) {
    	        return new Date(NaN);
    	      }
    	    } else {
    	      // get offset accurate to hour in time zones that change offset
    	      offset = (0, _index2.default)(new Date(timestamp + time));
    	      offset = (0, _index2.default)(new Date(timestamp + time + offset));
    	    }

    	    return new Date(timestamp + time + offset);
    	  } else {
    	    return new Date(NaN);
    	  }
    	}

    	function splitDateString(dateString) {
    	  var dateStrings = {};
    	  var parts = patterns.dateTimePattern.exec(dateString);
    	  var timeString;

    	  if (!parts) {
    	    parts = patterns.datePattern.exec(dateString);

    	    if (parts) {
    	      dateStrings.date = parts[1];
    	      timeString = parts[2];
    	    } else {
    	      dateStrings.date = null;
    	      timeString = dateString;
    	    }
    	  } else {
    	    dateStrings.date = parts[1];
    	    timeString = parts[3];
    	  }

    	  if (timeString) {
    	    var token = patterns.timeZone.exec(timeString);

    	    if (token) {
    	      dateStrings.time = timeString.replace(token[1], '');
    	      dateStrings.timeZone = token[1].trim();
    	    } else {
    	      dateStrings.time = timeString;
    	    }
    	  }

    	  return dateStrings;
    	}

    	function parseYear(dateString, additionalDigits) {
    	  var patternYYY = patterns.YYY[additionalDigits];
    	  var patternYYYYY = patterns.YYYYY[additionalDigits];
    	  var token; // YYYY or ±YYYYY

    	  token = patterns.YYYY.exec(dateString) || patternYYYYY.exec(dateString);

    	  if (token) {
    	    var yearString = token[1];
    	    return {
    	      year: parseInt(yearString, 10),
    	      restDateString: dateString.slice(yearString.length)
    	    };
    	  } // YY or ±YYY


    	  token = patterns.YY.exec(dateString) || patternYYY.exec(dateString);

    	  if (token) {
    	    var centuryString = token[1];
    	    return {
    	      year: parseInt(centuryString, 10) * 100,
    	      restDateString: dateString.slice(centuryString.length)
    	    };
    	  } // Invalid ISO-formatted year


    	  return {
    	    year: null
    	  };
    	}

    	function parseDate(dateString, year) {
    	  // Invalid ISO-formatted year
    	  if (year === null) {
    	    return null;
    	  }

    	  var token;
    	  var date;
    	  var month;
    	  var week; // YYYY

    	  if (dateString.length === 0) {
    	    date = new Date(0);
    	    date.setUTCFullYear(year);
    	    return date;
    	  } // YYYY-MM


    	  token = patterns.MM.exec(dateString);

    	  if (token) {
    	    date = new Date(0);
    	    month = parseInt(token[1], 10) - 1;

    	    if (!validateDate(year, month)) {
    	      return new Date(NaN);
    	    }

    	    date.setUTCFullYear(year, month);
    	    return date;
    	  } // YYYY-DDD or YYYYDDD


    	  token = patterns.DDD.exec(dateString);

    	  if (token) {
    	    date = new Date(0);
    	    var dayOfYear = parseInt(token[1], 10);

    	    if (!validateDayOfYearDate(year, dayOfYear)) {
    	      return new Date(NaN);
    	    }

    	    date.setUTCFullYear(year, 0, dayOfYear);
    	    return date;
    	  } // yyyy-MM-dd or YYYYMMDD


    	  token = patterns.MMDD.exec(dateString);

    	  if (token) {
    	    date = new Date(0);
    	    month = parseInt(token[1], 10) - 1;
    	    var day = parseInt(token[2], 10);

    	    if (!validateDate(year, month, day)) {
    	      return new Date(NaN);
    	    }

    	    date.setUTCFullYear(year, month, day);
    	    return date;
    	  } // YYYY-Www or YYYYWww


    	  token = patterns.Www.exec(dateString);

    	  if (token) {
    	    week = parseInt(token[1], 10) - 1;

    	    if (!validateWeekDate(year, week)) {
    	      return new Date(NaN);
    	    }

    	    return dayOfISOWeekYear(year, week);
    	  } // YYYY-Www-D or YYYYWwwD


    	  token = patterns.WwwD.exec(dateString);

    	  if (token) {
    	    week = parseInt(token[1], 10) - 1;
    	    var dayOfWeek = parseInt(token[2], 10) - 1;

    	    if (!validateWeekDate(year, week, dayOfWeek)) {
    	      return new Date(NaN);
    	    }

    	    return dayOfISOWeekYear(year, week, dayOfWeek);
    	  } // Invalid ISO-formatted date


    	  return null;
    	}

    	function parseTime(timeString) {
    	  var token;
    	  var hours;
    	  var minutes; // hh

    	  token = patterns.HH.exec(timeString);

    	  if (token) {
    	    hours = parseFloat(token[1].replace(',', '.'));

    	    if (!validateTime(hours)) {
    	      return NaN;
    	    }

    	    return hours % 24 * MILLISECONDS_IN_HOUR;
    	  } // hh:mm or hhmm


    	  token = patterns.HHMM.exec(timeString);

    	  if (token) {
    	    hours = parseInt(token[1], 10);
    	    minutes = parseFloat(token[2].replace(',', '.'));

    	    if (!validateTime(hours, minutes)) {
    	      return NaN;
    	    }

    	    return hours % 24 * MILLISECONDS_IN_HOUR + minutes * MILLISECONDS_IN_MINUTE;
    	  } // hh:mm:ss or hhmmss


    	  token = patterns.HHMMSS.exec(timeString);

    	  if (token) {
    	    hours = parseInt(token[1], 10);
    	    minutes = parseInt(token[2], 10);
    	    var seconds = parseFloat(token[3].replace(',', '.'));

    	    if (!validateTime(hours, minutes, seconds)) {
    	      return NaN;
    	    }

    	    return hours % 24 * MILLISECONDS_IN_HOUR + minutes * MILLISECONDS_IN_MINUTE + seconds * 1000;
    	  } // Invalid ISO-formatted time


    	  return null;
    	}

    	function dayOfISOWeekYear(isoWeekYear, week, day) {
    	  week = week || 0;
    	  day = day || 0;
    	  var date = new Date(0);
    	  date.setUTCFullYear(isoWeekYear, 0, 4);
    	  var fourthOfJanuaryDay = date.getUTCDay() || 7;
    	  var diff = week * 7 + day + 1 - fourthOfJanuaryDay;
    	  date.setUTCDate(date.getUTCDate() + diff);
    	  return date;
    	} // Validation functions


    	var DAYS_IN_MONTH = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
    	var DAYS_IN_MONTH_LEAP_YEAR = [31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];

    	function isLeapYearIndex(year) {
    	  return year % 400 === 0 || year % 4 === 0 && year % 100 !== 0;
    	}

    	function validateDate(year, month, date) {
    	  if (month < 0 || month > 11) {
    	    return false;
    	  }

    	  if (date != null) {
    	    if (date < 1) {
    	      return false;
    	    }

    	    var isLeapYear = isLeapYearIndex(year);

    	    if (isLeapYear && date > DAYS_IN_MONTH_LEAP_YEAR[month]) {
    	      return false;
    	    }

    	    if (!isLeapYear && date > DAYS_IN_MONTH[month]) {
    	      return false;
    	    }
    	  }

    	  return true;
    	}

    	function validateDayOfYearDate(year, dayOfYear) {
    	  if (dayOfYear < 1) {
    	    return false;
    	  }

    	  var isLeapYear = isLeapYearIndex(year);

    	  if (isLeapYear && dayOfYear > 366) {
    	    return false;
    	  }

    	  if (!isLeapYear && dayOfYear > 365) {
    	    return false;
    	  }

    	  return true;
    	}

    	function validateWeekDate(year, week, day) {
    	  if (week < 0 || week > 52) {
    	    return false;
    	  }

    	  if (day != null && (day < 0 || day > 6)) {
    	    return false;
    	  }

    	  return true;
    	}

    	function validateTime(hours, minutes, seconds) {
    	  if (hours != null && (hours < 0 || hours >= 25)) {
    	    return false;
    	  }

    	  if (minutes != null && (minutes < 0 || minutes >= 60)) {
    	    return false;
    	  }

    	  if (seconds != null && (seconds < 0 || seconds >= 60)) {
    	    return false;
    	  }

    	  return true;
    	}

    	module.exports = exports.default;
    } (toDate, toDate.exports));

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = format;

    	var _index = _interopRequireDefault(format$2.exports);

    	var _index2 = _interopRequireDefault(formatters.exports);

    	var _index3 = _interopRequireDefault(toDate.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}

    	var tzFormattingTokensRegExp = /([xXOz]+)|''|'(''|[^'])+('|$)/g;
    	/**
    	 * @name format
    	 * @category Common Helpers
    	 * @summary Format the date.
    	 *
    	 * @description
    	 * Return the formatted date string in the given format. The result may vary by locale.
    	 *
    	 * > ⚠️ Please note that the `format` tokens differ from Moment.js and other libraries.
    	 * > See: https://git.io/fxCyr
    	 *
    	 * The characters wrapped between two single quotes characters (') are escaped.
    	 * Two single quotes in a row, whether inside or outside a quoted sequence, represent a 'real' single quote.
    	 * (see the last example)
    	 *
    	 * Format of the string is based on Unicode Technical Standard #35:
    	 * https://www.unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table
    	 * with a few additions (see note 7 below the table).
    	 *
    	 * Accepted patterns:
    	 * | Unit                            | Pattern | Result examples                   | Notes |
    	 * |---------------------------------|---------|-----------------------------------|-------|
    	 * | Era                             | G..GGG  | AD, BC                            |       |
    	 * |                                 | GGGG    | Anno Domini, Before Christ        | 2     |
    	 * |                                 | GGGGG   | A, B                              |       |
    	 * | Calendar year                   | y       | 44, 1, 1900, 2017                 | 5     |
    	 * |                                 | yo      | 44th, 1st, 0th, 17th              | 5,7   |
    	 * |                                 | yy      | 44, 01, 00, 17                    | 5     |
    	 * |                                 | yyy     | 044, 001, 1900, 2017              | 5     |
    	 * |                                 | yyyy    | 0044, 0001, 1900, 2017            | 5     |
    	 * |                                 | yyyyy   | ...                               | 3,5   |
    	 * | Local week-numbering year       | Y       | 44, 1, 1900, 2017                 | 5     |
    	 * |                                 | Yo      | 44th, 1st, 1900th, 2017th         | 5,7   |
    	 * |                                 | YY      | 44, 01, 00, 17                    | 5,8   |
    	 * |                                 | YYY     | 044, 001, 1900, 2017              | 5     |
    	 * |                                 | YYYY    | 0044, 0001, 1900, 2017            | 5,8   |
    	 * |                                 | YYYYY   | ...                               | 3,5   |
    	 * | ISO week-numbering year         | R       | -43, 0, 1, 1900, 2017             | 5,7   |
    	 * |                                 | RR      | -43, 00, 01, 1900, 2017           | 5,7   |
    	 * |                                 | RRR     | -043, 000, 001, 1900, 2017        | 5,7   |
    	 * |                                 | RRRR    | -0043, 0000, 0001, 1900, 2017     | 5,7   |
    	 * |                                 | RRRRR   | ...                               | 3,5,7 |
    	 * | Extended year                   | u       | -43, 0, 1, 1900, 2017             | 5     |
    	 * |                                 | uu      | -43, 01, 1900, 2017               | 5     |
    	 * |                                 | uuu     | -043, 001, 1900, 2017             | 5     |
    	 * |                                 | uuuu    | -0043, 0001, 1900, 2017           | 5     |
    	 * |                                 | uuuuu   | ...                               | 3,5   |
    	 * | Quarter (formatting)            | Q       | 1, 2, 3, 4                        |       |
    	 * |                                 | Qo      | 1st, 2nd, 3rd, 4th                | 7     |
    	 * |                                 | QQ      | 01, 02, 03, 04                    |       |
    	 * |                                 | QQQ     | Q1, Q2, Q3, Q4                    |       |
    	 * |                                 | QQQQ    | 1st quarter, 2nd quarter, ...     | 2     |
    	 * |                                 | QQQQQ   | 1, 2, 3, 4                        | 4     |
    	 * | Quarter (stand-alone)           | q       | 1, 2, 3, 4                        |       |
    	 * |                                 | qo      | 1st, 2nd, 3rd, 4th                | 7     |
    	 * |                                 | qq      | 01, 02, 03, 04                    |       |
    	 * |                                 | qqq     | Q1, Q2, Q3, Q4                    |       |
    	 * |                                 | qqqq    | 1st quarter, 2nd quarter, ...     | 2     |
    	 * |                                 | qqqqq   | 1, 2, 3, 4                        | 4     |
    	 * | Month (formatting)              | M       | 1, 2, ..., 12                     |       |
    	 * |                                 | Mo      | 1st, 2nd, ..., 12th               | 7     |
    	 * |                                 | MM      | 01, 02, ..., 12                   |       |
    	 * |                                 | MMM     | Jan, Feb, ..., Dec                |       |
    	 * |                                 | MMMM    | January, February, ..., December  | 2     |
    	 * |                                 | MMMMM   | J, F, ..., D                      |       |
    	 * | Month (stand-alone)             | L       | 1, 2, ..., 12                     |       |
    	 * |                                 | Lo      | 1st, 2nd, ..., 12th               | 7     |
    	 * |                                 | LL      | 01, 02, ..., 12                   |       |
    	 * |                                 | LLL     | Jan, Feb, ..., Dec                |       |
    	 * |                                 | LLLL    | January, February, ..., December  | 2     |
    	 * |                                 | LLLLL   | J, F, ..., D                      |       |
    	 * | Local week of year              | w       | 1, 2, ..., 53                     |       |
    	 * |                                 | wo      | 1st, 2nd, ..., 53th               | 7     |
    	 * |                                 | ww      | 01, 02, ..., 53                   |       |
    	 * | ISO week of year                | I       | 1, 2, ..., 53                     | 7     |
    	 * |                                 | Io      | 1st, 2nd, ..., 53th               | 7     |
    	 * |                                 | II      | 01, 02, ..., 53                   | 7     |
    	 * | Day of month                    | d       | 1, 2, ..., 31                     |       |
    	 * |                                 | do      | 1st, 2nd, ..., 31st               | 7     |
    	 * |                                 | dd      | 01, 02, ..., 31                   |       |
    	 * | Day of year                     | D       | 1, 2, ..., 365, 366               | 8     |
    	 * |                                 | Do      | 1st, 2nd, ..., 365th, 366th       | 7     |
    	 * |                                 | DD      | 01, 02, ..., 365, 366             | 8     |
    	 * |                                 | DDD     | 001, 002, ..., 365, 366           |       |
    	 * |                                 | DDDD    | ...                               | 3     |
    	 * | Day of week (formatting)        | E..EEE  | Mon, Tue, Wed, ..., Su            |       |
    	 * |                                 | EEEE    | Monday, Tuesday, ..., Sunday      | 2     |
    	 * |                                 | EEEEE   | M, T, W, T, F, S, S               |       |
    	 * |                                 | EEEEEE  | Mo, Tu, We, Th, Fr, Su, Sa        |       |
    	 * | ISO day of week (formatting)    | i       | 1, 2, 3, ..., 7                   | 7     |
    	 * |                                 | io      | 1st, 2nd, ..., 7th                | 7     |
    	 * |                                 | ii      | 01, 02, ..., 07                   | 7     |
    	 * |                                 | iii     | Mon, Tue, Wed, ..., Su            | 7     |
    	 * |                                 | iiii    | Monday, Tuesday, ..., Sunday      | 2,7   |
    	 * |                                 | iiiii   | M, T, W, T, F, S, S               | 7     |
    	 * |                                 | iiiiii  | Mo, Tu, We, Th, Fr, Su, Sa        | 7     |
    	 * | Local day of week (formatting)  | e       | 2, 3, 4, ..., 1                   |       |
    	 * |                                 | eo      | 2nd, 3rd, ..., 1st                | 7     |
    	 * |                                 | ee      | 02, 03, ..., 01                   |       |
    	 * |                                 | eee     | Mon, Tue, Wed, ..., Su            |       |
    	 * |                                 | eeee    | Monday, Tuesday, ..., Sunday      | 2     |
    	 * |                                 | eeeee   | M, T, W, T, F, S, S               |       |
    	 * |                                 | eeeeee  | Mo, Tu, We, Th, Fr, Su, Sa        |       |
    	 * | Local day of week (stand-alone) | c       | 2, 3, 4, ..., 1                   |       |
    	 * |                                 | co      | 2nd, 3rd, ..., 1st                | 7     |
    	 * |                                 | cc      | 02, 03, ..., 01                   |       |
    	 * |                                 | ccc     | Mon, Tue, Wed, ..., Su            |       |
    	 * |                                 | cccc    | Monday, Tuesday, ..., Sunday      | 2     |
    	 * |                                 | ccccc   | M, T, W, T, F, S, S               |       |
    	 * |                                 | cccccc  | Mo, Tu, We, Th, Fr, Su, Sa        |       |
    	 * | AM, PM                          | a..aaa  | AM, PM                            |       |
    	 * |                                 | aaaa    | a.m., p.m.                        | 2     |
    	 * |                                 | aaaaa   | a, p                              |       |
    	 * | AM, PM, noon, midnight          | b..bbb  | AM, PM, noon, midnight            |       |
    	 * |                                 | bbbb    | a.m., p.m., noon, midnight        | 2     |
    	 * |                                 | bbbbb   | a, p, n, mi                       |       |
    	 * | Flexible day period             | B..BBB  | at night, in the morning, ...     |       |
    	 * |                                 | BBBB    | at night, in the morning, ...     | 2     |
    	 * |                                 | BBBBB   | at night, in the morning, ...     |       |
    	 * | Hour [1-12]                     | h       | 1, 2, ..., 11, 12                 |       |
    	 * |                                 | ho      | 1st, 2nd, ..., 11th, 12th         | 7     |
    	 * |                                 | hh      | 01, 02, ..., 11, 12               |       |
    	 * | Hour [0-23]                     | H       | 0, 1, 2, ..., 23                  |       |
    	 * |                                 | Ho      | 0th, 1st, 2nd, ..., 23rd          | 7     |
    	 * |                                 | HH      | 00, 01, 02, ..., 23               |       |
    	 * | Hour [0-11]                     | K       | 1, 2, ..., 11, 0                  |       |
    	 * |                                 | Ko      | 1st, 2nd, ..., 11th, 0th          | 7     |
    	 * |                                 | KK      | 1, 2, ..., 11, 0                  |       |
    	 * | Hour [1-24]                     | k       | 24, 1, 2, ..., 23                 |       |
    	 * |                                 | ko      | 24th, 1st, 2nd, ..., 23rd         | 7     |
    	 * |                                 | kk      | 24, 01, 02, ..., 23               |       |
    	 * | Minute                          | m       | 0, 1, ..., 59                     |       |
    	 * |                                 | mo      | 0th, 1st, ..., 59th               | 7     |
    	 * |                                 | mm      | 00, 01, ..., 59                   |       |
    	 * | Second                          | s       | 0, 1, ..., 59                     |       |
    	 * |                                 | so      | 0th, 1st, ..., 59th               | 7     |
    	 * |                                 | ss      | 00, 01, ..., 59                   |       |
    	 * | Fraction of second              | S       | 0, 1, ..., 9                      |       |
    	 * |                                 | SS      | 00, 01, ..., 99                   |       |
    	 * |                                 | SSS     | 000, 0001, ..., 999               |       |
    	 * |                                 | SSSS    | ...                               | 3     |
    	 * | Timezone (ISO-8601 w/ Z)        | X       | -08, +0530, Z                     |       |
    	 * |                                 | XX      | -0800, +0530, Z                   |       |
    	 * |                                 | XXX     | -08:00, +05:30, Z                 |       |
    	 * |                                 | XXXX    | -0800, +0530, Z, +123456          | 2     |
    	 * |                                 | XXXXX   | -08:00, +05:30, Z, +12:34:56      |       |
    	 * | Timezone (ISO-8601 w/o Z)       | x       | -08, +0530, +00                   |       |
    	 * |                                 | xx      | -0800, +0530, +0000               |       |
    	 * |                                 | xxx     | -08:00, +05:30, +00:00            | 2     |
    	 * |                                 | xxxx    | -0800, +0530, +0000, +123456      |       |
    	 * |                                 | xxxxx   | -08:00, +05:30, +00:00, +12:34:56 |       |
    	 * | Timezone (GMT)                  | O...OOO | GMT-8, GMT+5:30, GMT+0            |       |
    	 * |                                 | OOOO    | GMT-08:00, GMT+05:30, GMT+00:00   | 2     |
    	 * | Timezone (specific non-locat.)  | z...zzz | PDT, EST, CEST                    | 6     |
    	 * |                                 | zzzz    | Pacific Daylight Time             | 2,6   |
    	 * | Seconds timestamp               | t       | 512969520                         | 7     |
    	 * |                                 | tt      | ...                               | 3,7   |
    	 * | Milliseconds timestamp          | T       | 512969520900                      | 7     |
    	 * |                                 | TT      | ...                               | 3,7   |
    	 * | Long localized date             | P       | 05/29/1453                        | 7     |
    	 * |                                 | PP      | May 29, 1453                      | 7     |
    	 * |                                 | PPP     | May 29th, 1453                    | 7     |
    	 * |                                 | PPPP    | Sunday, May 29th, 1453            | 2,7   |
    	 * | Long localized time             | p       | 12:00 AM                          | 7     |
    	 * |                                 | pp      | 12:00:00 AM                       | 7     |
    	 * |                                 | ppp     | 12:00:00 AM GMT+2                 | 7     |
    	 * |                                 | pppp    | 12:00:00 AM GMT+02:00             | 2,7   |
    	 * | Combination of date and time    | Pp      | 05/29/1453, 12:00 AM              | 7     |
    	 * |                                 | PPpp    | May 29, 1453, 12:00:00 AM         | 7     |
    	 * |                                 | PPPppp  | May 29th, 1453 at ...             | 7     |
    	 * |                                 | PPPPpppp| Sunday, May 29th, 1453 at ...     | 2,7   |
    	 * Notes:
    	 * 1. "Formatting" units (e.g. formatting quarter) in the default en-US locale
    	 *    are the same as "stand-alone" units, but are different in some languages.
    	 *    "Formatting" units are declined according to the rules of the language
    	 *    in the context of a date. "Stand-alone" units are always nominative singular:
    	 *
    	 *    `format(new Date(2017, 10, 6), 'do LLLL', {locale: cs}) //=> '6. listopad'`
    	 *
    	 *    `format(new Date(2017, 10, 6), 'do MMMM', {locale: cs}) //=> '6. listopadu'`
    	 *
    	 * 2. Any sequence of the identical letters is a pattern, unless it is escaped by
    	 *    the single quote characters (see below).
    	 *    If the sequence is longer than listed in table (e.g. `EEEEEEEEEEE`)
    	 *    the output will be the same as default pattern for this unit, usually
    	 *    the longest one (in case of ISO weekdays, `EEEE`). Default patterns for units
    	 *    are marked with "2" in the last column of the table.
    	 *
    	 *    `format(new Date(2017, 10, 6), 'MMM') //=> 'Nov'`
    	 *
    	 *    `format(new Date(2017, 10, 6), 'MMMM') //=> 'November'`
    	 *
    	 *    `format(new Date(2017, 10, 6), 'MMMMM') //=> 'N'`
    	 *
    	 *    `format(new Date(2017, 10, 6), 'MMMMMM') //=> 'November'`
    	 *
    	 *    `format(new Date(2017, 10, 6), 'MMMMMMM') //=> 'November'`
    	 *
    	 * 3. Some patterns could be unlimited length (such as `yyyyyyyy`).
    	 *    The output will be padded with zeros to match the length of the pattern.
    	 *
    	 *    `format(new Date(2017, 10, 6), 'yyyyyyyy') //=> '00002017'`
    	 *
    	 * 4. `QQQQQ` and `qqqqq` could be not strictly numerical in some locales.
    	 *    These tokens represent the shortest form of the quarter.
    	 *
    	 * 5. The main difference between `y` and `u` patterns are B.C. years:
    	 *
    	 *    | Year | `y` | `u` |
    	 *    |------|-----|-----|
    	 *    | AC 1 |   1 |   1 |
    	 *    | BC 1 |   1 |   0 |
    	 *    | BC 2 |   2 |  -1 |
    	 *
    	 *    Also `yy` always returns the last two digits of a year,
    	 *    while `uu` pads single digit years to 2 characters and returns other years unchanged:
    	 *
    	 *    | Year | `yy` | `uu` |
    	 *    |------|------|------|
    	 *    | 1    |   01 |   01 |
    	 *    | 14   |   14 |   14 |
    	 *    | 376  |   76 |  376 |
    	 *    | 1453 |   53 | 1453 |
    	 *
    	 *    The same difference is true for local and ISO week-numbering years (`Y` and `R`),
    	 *    except local week-numbering years are dependent on `options.weekStartsOn`
    	 *    and `options.firstWeekContainsDate` (compare [getISOWeekYear]{@link https://date-fns.org/docs/getISOWeekYear}
    	 *    and [getWeekYear]{@link https://date-fns.org/docs/getWeekYear}).
    	 *
    	 * 6. Specific non-location timezones are created using the Intl browser API. The output is determined by the
    	 *    preferred standard of the current locale (en-US by default) which may not always give the expected result.
    	 *    For this reason it is recommended to supply a `locale` in the format options when formatting a time zone name.
    	 *
    	 * 7. These patterns are not in the Unicode Technical Standard #35:
    	 *    - `i`: ISO day of week
    	 *    - `I`: ISO week of year
    	 *    - `R`: ISO week-numbering year
    	 *    - `t`: seconds timestamp
    	 *    - `T`: milliseconds timestamp
    	 *    - `o`: ordinal number modifier
    	 *    - `P`: long localized date
    	 *    - `p`: long localized time
    	 *
    	 * 8. These tokens are often confused with others. See: https://git.io/fxCyr
    	 *
    	 *
    	 * ### v2.0.0 breaking changes:
    	 *
    	 * - [Changes that are common for the whole
    	 *   library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
    	 *
    	 * - The second argument is now required for the sake of explicitness.
    	 *
    	 *   ```javascript
    	 *   // Before v2.0.0
    	 *   format(new Date(2016, 0, 1))
    	 *
    	 *   // v2.0.0 onward
    	 *   format(new Date(2016, 0, 1), "yyyy-MM-dd'T'HH:mm:ss.SSSxxx")
    	 *   ```
    	 *
    	 * - New format string API for `format` function
    	 *   which is based on [Unicode Technical Standard
    	 *   #35](https://www.unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table). See [this
    	 *   post](https://blog.date-fns.org/post/unicode-tokens-in-date-fns-v2-sreatyki91jg) for more details.
    	 *
    	 * - Characters are now escaped using single quote symbols (`'`) instead of square brackets.
    	 *
    	 * @param {Date|String|Number} date - the original date
    	 * @param {String} format - the string of tokens
    	 * @param {OptionsWithTZ} [options] - the object with options. See [Options]{@link https://date-fns.org/docs/Options}
    	 * @param {0|1|2} [options.additionalDigits=2] - passed to `toDate`. See [toDate]{@link
    	 *   https://date-fns.org/docs/toDate}
    	 * @param {0|1|2|3|4|5|6} [options.weekStartsOn=0] - the index of the first day of the week (0 - Sunday)
    	 * @param {Number} [options.firstWeekContainsDate=1] - the day of January, which is
    	 * @param {Locale} [options.locale=defaultLocale] - the locale object. See
    	 *   [Locale]{@link https://date-fns.org/docs/Locale}
    	 * @param {Boolean} [options.awareOfUnicodeTokens=false] - if true, allows usage of Unicode tokens causes confusion:
    	 *   - Some of the day of year tokens (`D`, `DD`) that are confused with the day of month tokens (`d`, `dd`).
    	 *   - Some of the local week-numbering year tokens (`YY`, `YYYY`) that are confused with the calendar year tokens
    	 *   (`yy`, `yyyy`). See: https://git.io/fxCyr
    	 * @param {String} [options.timeZone=''] - used to specify the IANA time zone offset of a date String.
    	 * @returns {String} the formatted date string
    	 * @throws {TypeError} 2 arguments required
    	 * @throws {RangeError} `options.additionalDigits` must be 0, 1 or 2
    	 * @throws {RangeError} `options.locale` must contain `localize` property
    	 * @throws {RangeError} `options.locale` must contain `formatLong` property
    	 * @throws {RangeError} `options.weekStartsOn` must be between 0 and 6
    	 * @throws {RangeError} `options.firstWeekContainsDate` must be between 1 and 7
    	 * @throws {RangeError} `options.awareOfUnicodeTokens` must be set to `true` to use `XX` token; see:
    	 *   https://git.io/fxCyr
    	 *
    	 * @example
    	 * // Represent 11 February 2014 in middle-endian format:
    	 * var result = format(new Date(2014, 1, 11), 'MM/dd/yyyy')
    	 * //=> '02/11/2014'
    	 *
    	 * @example
    	 * // Represent 2 July 2014 in Esperanto:
    	 * import { eoLocale } from 'date-fns/locale/eo'
    	 * var result = format(new Date(2014, 6, 2), "do 'de' MMMM yyyy", {
    	 *   locale: eoLocale
    	 * })
    	 * //=> '2-a de julio 2014'
    	 *
    	 * @example
    	 * // Escape string by single quote characters:
    	 * var result = format(new Date(2014, 6, 2, 15), "h 'o''clock'")
    	 * //=> "3 o'clock"
    	 */

    	function format(dirtyDate, dirtyFormatStr, dirtyOptions) {
    	  var formatStr = String(dirtyFormatStr);
    	  var options = dirtyOptions || {};
    	  var matches = formatStr.match(tzFormattingTokensRegExp);

    	  if (matches) {
    	    var date = (0, _index3.default)(dirtyDate, options); // Work through each match and replace the tz token in the format string with the quoted
    	    // formatted time zone so the remaining tokens can be filled in by date-fns#format.

    	    formatStr = matches.reduce(function (result, token) {
    	      if (token[0] === "'") {
    	        return result; // This is a quoted portion, matched only to ensure we don't match inside it
    	      }

    	      var pos = result.indexOf(token);
    	      var precededByQuotedSection = result[pos - 1] === "'";
    	      var replaced = result.replace(token, "'" + _index2.default[token[0]](date, token, null, options) + "'"); // If the replacement results in two adjoining quoted strings, the back to back quotes
    	      // are removed, so it doesn't look like an escaped quote.

    	      return precededByQuotedSection ? replaced.substring(0, pos - 1) + replaced.substring(pos + 1) : replaced;
    	    }, formatStr);
    	  }

    	  return (0, _index.default)(dirtyDate, formatStr, options);
    	}

    	module.exports = exports.default;
    } (format$3, format$3.exports));

    var utcToZonedTime = {exports: {}};

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = utcToZonedTime;

    	var _index = _interopRequireDefault(tzParseTimezone.exports);

    	var _index2 = _interopRequireDefault(toDate.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}
    	/**
    	 * @name utcToZonedTime
    	 * @category Time Zone Helpers
    	 * @summary Get a date/time representing local time in a given time zone from the UTC date
    	 *
    	 * @description
    	 * Returns a date instance with values representing the local time in the time zone
    	 * specified of the UTC time from the date provided. In other words, when the new date
    	 * is formatted it will show the equivalent hours in the target time zone regardless
    	 * of the current system time zone.
    	 *
    	 * @param {Date|String|Number} date - the date with the relevant UTC time
    	 * @param {String} timeZone - the time zone to get local time for, can be an offset or IANA time zone
    	 * @param {OptionsWithTZ} [options] - the object with options. See [Options]{@link https://date-fns.org/docs/Options}
    	 * @param {0|1|2} [options.additionalDigits=2] - passed to `toDate`. See [toDate]{@link https://date-fns.org/docs/toDate}
    	 * @returns {Date} the new date with the equivalent time in the time zone
    	 * @throws {TypeError} 2 arguments required
    	 * @throws {RangeError} `options.additionalDigits` must be 0, 1 or 2
    	 *
    	 * @example
    	 * // In June 10am UTC is 6am in New York (-04:00)
    	 * const result = utcToZonedTime('2014-06-25T10:00:00.000Z', 'America/New_York')
    	 * //=> Jun 25 2014 06:00:00
    	 */


    	function utcToZonedTime(dirtyDate, timeZone, options) {
    	  var date = (0, _index2.default)(dirtyDate, options);
    	  var offsetMilliseconds = (0, _index.default)(timeZone, date, true);
    	  var d = new Date(date.getTime() - offsetMilliseconds);
    	  var resultDate = new Date(0);
    	  resultDate.setFullYear(d.getUTCFullYear(), d.getUTCMonth(), d.getUTCDate());
    	  resultDate.setHours(d.getUTCHours(), d.getUTCMinutes(), d.getUTCSeconds(), d.getUTCMilliseconds());
    	  return resultDate;
    	}

    	module.exports = exports.default;
    } (utcToZonedTime, utcToZonedTime.exports));

    (function (module, exports) {

    	Object.defineProperty(exports, "__esModule", {
    	  value: true
    	});
    	exports.default = formatInTimeZone;

    	var _index = _interopRequireDefault(cloneObject.exports);

    	var _index2 = _interopRequireDefault(format$3.exports);

    	var _index3 = _interopRequireDefault(utcToZonedTime.exports);

    	function _interopRequireDefault(obj) {
    	  return obj && obj.__esModule ? obj : {
    	    default: obj
    	  };
    	}
    	/**
    	 * @name formatInTimeZone
    	 * @category Time Zone Helpers
    	 * @summary Gets the offset in milliseconds between the time zone and Universal Coordinated Time (UTC)
    	 *
    	 * @param {Date|String|Number} date - the date representing the local time / real UTC time
    	 * @param {String} timeZone - the time zone this date should be formatted for; can be an offset or IANA time zone
    	 * @param {String} formatStr - the string of tokens
    	 * @param {OptionsWithTZ} [options] - the object with options. See [Options]{@link https://date-fns.org/docs/Options}
    	 * @param {0|1|2} [options.additionalDigits=2] - passed to `toDate`. See [toDate]{@link
    	 *   https://date-fns.org/docs/toDate}
    	 * @param {0|1|2|3|4|5|6} [options.weekStartsOn=0] - the index of the first day of the week (0 - Sunday)
    	 * @param {Number} [options.firstWeekContainsDate=1] - the day of January, which is
    	 * @param {Locale} [options.locale=defaultLocale] - the locale object. See
    	 *   [Locale]{@link https://date-fns.org/docs/Locale}
    	 * @param {Boolean} [options.awareOfUnicodeTokens=false] - if true, allows usage of Unicode tokens causes confusion:
    	 *   - Some of the day of year tokens (`D`, `DD`) that are confused with the day of month tokens (`d`, `dd`).
    	 *   - Some of the local week-numbering year tokens (`YY`, `YYYY`) that are confused with the calendar year tokens
    	 *   (`yy`, `yyyy`). See: https://git.io/fxCyr
    	 * @param {String} [options.timeZone=''] - used to specify the IANA time zone offset of a date String.
    	 * @returns {String} the formatted date string
    	 */


    	function formatInTimeZone(date, timeZone, formatStr, options) {
    	  var extendedOptions = (0, _index.default)(options);
    	  extendedOptions.timeZone = timeZone;
    	  return (0, _index2.default)((0, _index3.default)(date, timeZone), formatStr, extendedOptions);
    	}

    	module.exports = exports.default;
    } (formatInTimeZone$1, formatInTimeZone$1.exports));

    var formatInTimeZone = /*@__PURE__*/getDefaultExportFromCjs(formatInTimeZone$1.exports);

    const time = {
      amHours: ["00", "01", "02", "03", "04", "05", "06", "07", "08", "09", "10", "11"],
      pmHours: ["12", "01", "02", "03", "04", "05", "06", "07", "08", "09", "10", "11"],
      hours: ["00", "01", "02", "03", "04", "05", "06", "07", "08", "09", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22", "23"],
      minutes: ["00", "01", "02", "03", "04", "05", "06", "07", "08", "09", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27", "28", "29", "30", "31", "32", "33", "34", "35", "36", "37", "38", "39", "40", "41", "42", "43", "44", "45", "46", "47", "48", "49", "50", "51", "52", "53", "54", "55", "56", "57", "58", "59"],
      seconds: ["00", "01", "02", "03", "04", "05", "06", "07", "08", "09", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27", "28", "29", "30", "31", "32", "33", "34", "35", "36", "37", "38", "39", "40", "41", "42", "43", "44", "45", "46", "47", "48", "49", "50", "51", "52", "53", "54", "55", "56", "57", "58", "59"],
      period: ["AM", "PM"]
    };
    function getFixValue(value) {
      return `00${value}`.slice(-2);
    }
    function getTimeUnits(defaultValue, stepOrList, isHourWithAmPm) {
      if (Array.isArray(stepOrList)) {
        return (isHourWithAmPm === "am" ? stepOrList.filter(v => v < 12) : isHourWithAmPm === "pm" ? stepOrList.filter(v => v >= 12).map(v => v === 12 ? 12 : v - 12) : stepOrList).map(v => getFixValue(v));
      } else if (typeof stepOrList === "number") {
        if (isHourWithAmPm === "am") {
          return defaultValue.filter(hour => {
            const hourAsNumber = Number(hour);
            return hourAsNumber < 12 && hourAsNumber % stepOrList === 0;
          });
        } else if (isHourWithAmPm === "pm") {
          return defaultValue.filter(hour => {
            const hourAsNumber = Number(hour);
            return hourAsNumber >= 12 && hourAsNumber % stepOrList === 0;
          }).map(hour => {
            const hourAsNumber = Number(hour);
            return getFixValue(hourAsNumber === 12 ? 12 : hourAsNumber - 12);
          });
        }

        return defaultValue.filter(hour => {
          return Number(hour) % stepOrList === 0;
        });
      } else {
        return isHourWithAmPm === "am" ? defaultValue.filter(hour => Number(hour) < 12) : isHourWithAmPm === "pm" ? defaultValue.map(hour => Number(hour)).filter(hour => Number(hour) >= 12).map(v => getFixValue(v === 12 ? 12 : v - 12)) : defaultValue;
      }
    }
    function isTimeInStep(value, type, stepOrList) {
      if (!stepOrList) {
        return true;
      } else if (typeof stepOrList === "number") {
        return value % stepOrList === 0;
      } else {
        return stepOrList.includes(value);
      }
    }
    function findSimilarTime(value, type, stepOrList) {
      const list = getTimeUnits(time[type], stepOrList).map(Number);
      let lowerBound, upperBound;

      for (let i = 0; i < list.length; ++i) {
        const v = list[i];
        if (v === value) return v;else if (v > value) {
          upperBound = v;
          break;
        }
        lowerBound = v;
      }

      if (lowerBound === void 0) {
        if (!upperBound) {
          throwError("time-picker", "Please set 'hours' or 'minutes' or 'seconds' props");
        }

        return upperBound;
      }

      if (upperBound === void 0) {
        return lowerBound;
      }

      return upperBound - value > value - lowerBound ? lowerBound : upperBound;
    }
    function getAmPm(value) {
      return getHours(value) < 12 ? "am" : "pm";
    }

    const timePickerInjectionKey = createInjectionKey("n-time-picker");

    var PanelCol = vue.defineComponent({
      name: "TimePickerPanelCol",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        data: {
          type: Array,
          required: true
        },
        activeValue: {
          type: Number,
          default: null
        },
        onItemClick: Function
      },
      render() {
        const { activeValue, onItemClick, clsPrefix } = this;
        return this.data.map((item) => {
          const { label, disabled, value } = item;
          const active = activeValue === value;
          return /* @__PURE__ */ React.createElement("div", {
            key: label,
            "data-active": active ? "" : null,
            class: [
              `${clsPrefix}-time-picker-col__item`,
              active && `${clsPrefix}-time-picker-col__item--active`,
              disabled && `${clsPrefix}-time-picker-col__item--disabled`
            ],
            onClick: onItemClick && !disabled ? () => onItemClick(value) : void 0
          }, label);
        });
      }
    });

    const timePickerPanelProps = {
      actions: {
        type: Array,
        default: () => ["now", "confirm"]
      },
      showHour: {
        type: Boolean,
        default: true
      },
      showMinute: {
        type: Boolean,
        default: true
      },
      showSecond: {
        type: Boolean,
        default: true
      },
      showPeriod: {
        type: Boolean,
        default: true
      },
      isHourInvalid: Boolean,
      isMinuteInvalid: Boolean,
      isSecondInvalid: Boolean,
      isAmPmInvalid: Boolean,
      isValueInvalid: Boolean,
      hourValue: {
        type: Number,
        default: null
      },
      minuteValue: {
        type: Number,
        default: null
      },
      secondValue: {
        type: Number,
        default: null
      },
      amPmValue: {
        type: String,
        default: null
      },
      isHourDisabled: Function,
      isMinuteDisabled: Function,
      isSecondDisabled: Function,
      onHourClick: {
        type: Function,
        required: true
      },
      onMinuteClick: {
        type: Function,
        required: true
      },
      onSecondClick: {
        type: Function,
        required: true
      },
      onAmPmClick: {
        type: Function,
        required: true
      },
      onNowClick: Function,
      nowText: String,
      confirmText: String,
      transitionDisabled: Boolean,
      onConfirmClick: Function,
      onFocusin: Function,
      onFocusout: Function,
      onFocusDetectorFocus: Function,
      onKeydown: Function,
      hours: [Number, Array],
      minutes: [Number, Array],
      seconds: [Number, Array],
      use12Hours: Boolean
    };
    var Panel = vue.defineComponent({
      name: "TimePickerPanel",
      props: timePickerPanelProps,
      setup(props) {
        const {
          mergedThemeRef,
          mergedClsPrefixRef
        } = vue.inject(timePickerInjectionKey);
        const hoursRef = vue.computed(() => {
          const { isHourDisabled, hours, use12Hours, amPmValue } = props;
          if (!use12Hours) {
            return getTimeUnits(time.hours, hours).map((hour) => {
              return {
                label: hour,
                value: Number(hour),
                disabled: isHourDisabled ? isHourDisabled(Number(hour)) : false
              };
            });
          } else {
            const mergedAmPmValue = amPmValue ?? getAmPm(Date.now());
            return getTimeUnits(time.hours, hours, mergedAmPmValue).map((hour) => {
              const hourAs12FormattedNumber = Number(hour);
              const hourAs24FormattedNumber = mergedAmPmValue === "pm" && hourAs12FormattedNumber !== 12 ? hourAs12FormattedNumber + 12 : hourAs12FormattedNumber;
              return {
                label: hour,
                value: hourAs24FormattedNumber,
                disabled: isHourDisabled ? isHourDisabled(hourAs24FormattedNumber) : false
              };
            });
          }
        });
        const minutesRef = vue.computed(() => {
          const { isMinuteDisabled, minutes } = props;
          return getTimeUnits(time.minutes, minutes).map((minute) => {
            return {
              label: minute,
              value: Number(minute),
              disabled: isMinuteDisabled ? isMinuteDisabled(Number(minute), props.hourValue) : false
            };
          });
        });
        const secondsRef = vue.computed(() => {
          const { isSecondDisabled, seconds } = props;
          return getTimeUnits(time.seconds, seconds).map((second) => {
            return {
              label: second,
              value: Number(second),
              disabled: isSecondDisabled ? isSecondDisabled(
                Number(second),
                props.minuteValue,
                props.hourValue
              ) : false
            };
          });
        });
        const amPmRef = vue.computed(() => {
          const { isHourDisabled } = props;
          let amDisabled = true;
          let pmDisabled = true;
          for (let i = 0; i < 12; ++i) {
            if (!isHourDisabled?.(i)) {
              amDisabled = false;
              break;
            }
          }
          for (let i = 12; i < 24; ++i) {
            if (!isHourDisabled?.(i)) {
              pmDisabled = false;
              break;
            }
          }
          return [
            {
              label: "AM",
              value: "am",
              disabled: amDisabled
            },
            {
              label: "PM",
              value: "pm",
              disabled: pmDisabled
            }
          ];
        });
        return {
          mergedTheme: mergedThemeRef,
          mergedClsPrefix: mergedClsPrefixRef,
          hours: hoursRef,
          minutes: minutesRef,
          seconds: secondsRef,
          amPm: amPmRef,
          hourScrollRef: vue.ref(null),
          minuteScrollRef: vue.ref(null),
          secondScrollRef: vue.ref(null),
          amPmScrollRef: vue.ref(null)
        };
      },
      render() {
        const { mergedClsPrefix, mergedTheme } = this;
        return /* @__PURE__ */ React.createElement("div", {
          tabindex: 0,
          class: `${mergedClsPrefix}-time-picker-panel`,
          onFocusin: this.onFocusin,
          onFocusout: this.onFocusout,
          onKeydown: this.onKeydown
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-time-picker-cols`
        }, this.showHour ? /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-time-picker-col`,
            this.isHourInvalid && `${mergedClsPrefix}-time-picker-col--invalid`,
            this.transitionDisabled && `${mergedClsPrefix}-time-picker-col--transition-disabled`
          ]
        }, /* @__PURE__ */ React.createElement(NScrollbar, {
          ref: "hourScrollRef",
          theme: mergedTheme.peers.Scrollbar,
          themeOverrides: mergedTheme.peerOverrides.Scrollbar
        }, {
          default: () => [
            /* @__PURE__ */ React.createElement(PanelCol, {
              clsPrefix: mergedClsPrefix,
              data: this.hours,
              activeValue: this.hourValue,
              onItemClick: this.onHourClick
            }),
            /* @__PURE__ */ React.createElement("div", {
              class: `${mergedClsPrefix}-time-picker-col__padding`
            })
          ]
        })) : null, this.showMinute ? /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-time-picker-col`,
            this.transitionDisabled && `${mergedClsPrefix}-time-picker-col--transition-disabled`,
            this.isMinuteInvalid && `${mergedClsPrefix}-time-picker-col--invalid`
          ]
        }, /* @__PURE__ */ React.createElement(NScrollbar, {
          ref: "minuteScrollRef",
          theme: mergedTheme.peers.Scrollbar,
          themeOverrides: mergedTheme.peerOverrides.Scrollbar
        }, {
          default: () => [
            /* @__PURE__ */ React.createElement(PanelCol, {
              clsPrefix: mergedClsPrefix,
              data: this.minutes,
              activeValue: this.minuteValue,
              onItemClick: this.onMinuteClick
            }),
            /* @__PURE__ */ React.createElement("div", {
              class: `${mergedClsPrefix}-time-picker-col__padding`
            })
          ]
        })) : null, this.showSecond ? /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-time-picker-col`,
            this.isSecondInvalid && `${mergedClsPrefix}-time-picker-col--invalid`,
            this.transitionDisabled && `${mergedClsPrefix}-time-picker-col--transition-disabled`
          ]
        }, /* @__PURE__ */ React.createElement(NScrollbar, {
          ref: "secondScrollRef",
          theme: mergedTheme.peers.Scrollbar,
          themeOverrides: mergedTheme.peerOverrides.Scrollbar
        }, {
          default: () => [
            /* @__PURE__ */ React.createElement(PanelCol, {
              clsPrefix: mergedClsPrefix,
              data: this.seconds,
              activeValue: this.secondValue,
              onItemClick: this.onSecondClick
            }),
            /* @__PURE__ */ React.createElement("div", {
              class: `${mergedClsPrefix}-time-picker-col__padding`
            })
          ]
        })) : null, this.use12Hours ? /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-time-picker-col`,
            this.isAmPmInvalid && `${mergedClsPrefix}-time-picker-col--invalid`,
            this.transitionDisabled && `${mergedClsPrefix}-time-picker-col--transition-disabled`
          ]
        }, /* @__PURE__ */ React.createElement(NScrollbar, {
          ref: "amPmScrollRef",
          theme: mergedTheme.peers.Scrollbar,
          themeOverrides: mergedTheme.peerOverrides.Scrollbar
        }, {
          default: () => [
            /* @__PURE__ */ React.createElement(PanelCol, {
              clsPrefix: mergedClsPrefix,
              data: this.amPm,
              activeValue: this.amPmValue,
              onItemClick: this.onAmPmClick
            }),
            /* @__PURE__ */ React.createElement("div", {
              class: `${mergedClsPrefix}-time-picker-col__padding`
            })
          ]
        })) : null), this.actions?.length ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-time-picker-actions`
        }, this.actions?.includes("now") ? /* @__PURE__ */ React.createElement(NButton, {
          size: "tiny",
          theme: mergedTheme.peers.Button,
          themeOverrides: mergedTheme.peerOverrides.Button,
          onClick: this.onNowClick
        }, { default: () => this.nowText }) : null, this.actions?.includes("confirm") ? /* @__PURE__ */ React.createElement(NButton, {
          size: "tiny",
          type: "primary",
          class: `${mergedClsPrefix}-time-picker-actions__confirm`,
          theme: mergedTheme.peers.Button,
          themeOverrides: mergedTheme.peerOverrides.Button,
          disabled: this.isValueInvalid,
          onClick: this.onConfirmClick
        }, { default: () => this.confirmText }) : null) : null, /* @__PURE__ */ React.createElement(FocusDetector, {
          onFocus: this.onFocusDetectorFocus
        }));
      }
    });

    var style$S = c$1([cB("time-picker", `
    z-index: auto;
    position: relative;
  `, [cB("time-picker-icon", `
      color: var(--n-icon-color-override);
      transition: color .3s var(--n-bezier);
    `), cM("disabled", [cB("time-picker-icon", `
        color: var(--n-icon-color-disabled-override);
      `)])]), cB("time-picker-panel", `
    transition:
      box-shadow .3s var(--n-bezier),
      background-color .3s var(--n-bezier);
    outline: none;
    font-size: var(--n-item-font-size);
    border-radius: var(--n-border-radius);
    margin: 4px 0;
    min-width: 104px;
    overflow: hidden;
    background-color: var(--n-panel-color);
    box-shadow: var(--n-panel-box-shadow);
  `, [fadeInScaleUpTransition(), cB("time-picker-actions", `
      padding: var(--n-panel-action-padding);
      align-items: center;
      display: flex;
      justify-content: space-evenly;
    `), cB("time-picker-cols", `
      height: calc(var(--n-item-height) * 6);
      display: flex;
      position: relative;
      transition: border-color .3s var(--n-bezier);
      border-bottom: 1px solid var(--n-panel-divider-color);
    `), cB("time-picker-col", `
      flex-grow: 1;
      min-width: var(--n-item-width);
      height: calc(var(--n-item-height) * 6);
      flex-direction: column;
      transition: box-shadow .3s var(--n-bezier);
    `, [cM("transition-disabled", [cE("item", "transition: none;", [c$1("&::before", "transition: none;")])]), cE("padding", `
        height: calc(var(--n-item-height) * 5);
      `), c$1("&:first-child", "min-width: calc(var(--n-item-width) + 4px);", [cE("item", [c$1("&::before", "left: 4px;")])]), cE("item", `
        cursor: pointer;
        height: var(--n-item-height);
        display: flex;
        align-items: center;
        justify-content: center;
        transition: 
          color .3s var(--n-bezier),
          background-color .3s var(--n-bezier),
          opacity .3s var(--n-bezier),
          text-decoration-color .3s var(--n-bezier);
        background: #0000;
        text-decoration-color: #0000;
        color: var(--n-item-text-color);
        z-index: 0;
        box-sizing: border-box;
        padding-top: 4px;
        position: relative;
      `, [c$1("&::before", `
          content: "";
          transition: background-color .3s var(--n-bezier);
          z-index: -1;
          position: absolute;
          left: 0;
          right: 4px;
          top: 4px;
          bottom: 0;
          border-radius: var(--n-item-border-radius);
        `), cNotM("disabled", [c$1("&:hover::before", `
            background-color: var(--n-item-color-hover);
          `)]), cM("active", `
          color: var(--n-item-text-color-active);
        `, [c$1("&::before", `
            background-color: var(--n-item-color-hover);
          `)]), cM("disabled", `
          opacity: var(--n-item-opacity-disabled);
          cursor: not-allowed;
        `)]), cM("invalid", [cE("item", [cM("active", `
            text-decoration: line-through;
            text-decoration-color: var(--n-item-text-color-active);
          `)])])])])]);

    function validateUnits(value, max) {
      if (value === void 0) {
        return true;
      }
      if (Array.isArray(value)) {
        return value.every((v) => v >= 0 && v <= max);
      } else {
        return value >= 0 && value <= max;
      }
    }
    const timePickerProps = {
      ...useTheme.props,
      to: useAdjustedTo.propTo,
      bordered: {
        type: Boolean,
        default: void 0
      },
      actions: Array,
      defaultValue: {
        type: Number,
        default: null
      },
      defaultFormattedValue: String,
      placeholder: String,
      placement: {
        type: String,
        default: "bottom-start"
      },
      value: Number,
      format: {
        type: String,
        default: "HH:mm:ss"
      },
      valueFormat: String,
      formattedValue: String,
      isHourDisabled: Function,
      size: String,
      isMinuteDisabled: Function,
      isSecondDisabled: Function,
      inputReadonly: Boolean,
      clearable: Boolean,
      status: String,
      "onUpdate:value": [Function, Array],
      onUpdateValue: [Function, Array],
      "onUpdate:show": [Function, Array],
      onUpdateShow: [Function, Array],
      onUpdateFormattedValue: [Function, Array],
      "onUpdate:formattedValue": [Function, Array],
      onBlur: [Function, Array],
      onConfirm: [Function, Array],
      onClear: Function,
      onFocus: [Function, Array],
      timeZone: String,
      showIcon: {
        type: Boolean,
        default: true
      },
      disabled: {
        type: Boolean,
        default: void 0
      },
      show: {
        type: Boolean,
        default: void 0
      },
      hours: {
        type: [Number, Array],
        validator: (value) => validateUnits(value, 23)
      },
      minutes: {
        type: [Number, Array],
        validator: (value) => validateUnits(value, 59)
      },
      seconds: {
        type: [Number, Array],
        validator: (value) => validateUnits(value, 59)
      },
      use12Hours: Boolean,
      stateful: {
        type: Boolean,
        default: true
      },
      onChange: [Function, Array]
    };
    var NTimePicker = vue.defineComponent({
      name: "TimePicker",
      props: timePickerProps,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.onChange !== void 0) {
              warnOnce(
                "time-picker",
                "`on-change` is deprecated, please use `on-update:value` instead."
              );
            }
          });
        }
        const {
          mergedBorderedRef,
          mergedClsPrefixRef,
          namespaceRef,
          inlineThemeDisabled
        } = useConfig(props);
        const { localeRef, dateLocaleRef } = useLocale("TimePicker");
        const formItem = useFormItem(props);
        const { mergedSizeRef, mergedDisabledRef, mergedStatusRef } = formItem;
        const themeRef = useTheme(
          "TimePicker",
          "-time-picker",
          style$S,
          timePickerLight$1,
          props,
          mergedClsPrefixRef
        );
        const keyboardState = useKeyboard$1();
        const inputInstRef = vue.ref(null);
        const panelInstRef = vue.ref(null);
        const dateFnsOptionsRef = vue.computed(() => {
          return {
            locale: dateLocaleRef.value.locale
          };
        });
        function getTimestampFromFormattedValue(value) {
          if (value === null)
            return null;
          return strictParse(
            value,
            props.valueFormat || props.format,
            new Date(),
            dateFnsOptionsRef.value
          ).getTime();
        }
        const { defaultValue, defaultFormattedValue } = props;
        const uncontrolledValueRef = vue.ref(
          defaultFormattedValue !== void 0 ? getTimestampFromFormattedValue(defaultFormattedValue) : defaultValue
        );
        const mergedValueRef = vue.computed(() => {
          const { formattedValue } = props;
          if (formattedValue !== void 0) {
            return getTimestampFromFormattedValue(formattedValue);
          }
          const { value } = props;
          if (value !== void 0) {
            return value;
          }
          return uncontrolledValueRef.value;
        });
        const mergedFormatRef = vue.computed(() => {
          const { timeZone } = props;
          if (timeZone) {
            return (date, format2, options) => {
              return formatInTimeZone(date, timeZone, format2, options);
            };
          } else {
            return (date, _format, options) => {
              return format$4(date, _format, options);
            };
          }
        });
        const displayTimeStringRef = vue.ref("");
        vue.watch(
          () => props.timeZone,
          () => {
            const mergedValue = mergedValueRef.value;
            displayTimeStringRef.value = mergedValue === null ? "" : mergedFormatRef.value(
              mergedValue,
              props.format,
              dateFnsOptionsRef.value
            );
          },
          {
            immediate: true
          }
        );
        const uncontrolledShowRef = vue.ref(false);
        const controlledShowRef = vue.toRef(props, "show");
        const mergedShowRef = useMergedState(controlledShowRef, uncontrolledShowRef);
        const memorizedValueRef = vue.ref(mergedValueRef.value);
        const transitionDisabledRef = vue.ref(false);
        const localizedNowRef = vue.computed(() => {
          return localeRef.value.now;
        });
        const localizedPlaceholderRef = vue.computed(() => {
          if (props.placeholder !== void 0)
            return props.placeholder;
          return localeRef.value.placeholder;
        });
        const localizedNegativeTextRef = vue.computed(() => {
          return localeRef.value.negativeText;
        });
        const localizedPositiveTextRef = vue.computed(() => {
          return localeRef.value.positiveText;
        });
        const hourInFormatRef = vue.computed(() => {
          return /H|h|K|k/.test(props.format);
        });
        const minuteInFormatRef = vue.computed(() => {
          return props.format.includes("m");
        });
        const secondInFormatRef = vue.computed(() => {
          return props.format.includes("s");
        });
        const isHourInvalidRef = vue.computed(() => {
          const { isHourDisabled } = props;
          if (hourValueRef.value === null)
            return false;
          if (!isTimeInStep(hourValueRef.value, "hours", props.hours))
            return true;
          if (!isHourDisabled)
            return false;
          return isHourDisabled(hourValueRef.value);
        });
        const isMinuteInvalidRef = vue.computed(() => {
          const { value: minuteValue } = minuteValueRef;
          const { value: hourValue } = hourValueRef;
          if (minuteValue === null || hourValue === null)
            return false;
          if (!isTimeInStep(minuteValue, "minutes", props.minutes))
            return true;
          const { isMinuteDisabled } = props;
          if (!isMinuteDisabled)
            return false;
          return isMinuteDisabled(minuteValue, hourValue);
        });
        const isSecondInvalidRef = vue.computed(() => {
          const { value: minuteValue } = minuteValueRef;
          const { value: hourValue } = hourValueRef;
          const { value: secondValue } = secondValueRef;
          if (secondValue === null || minuteValue === null || hourValue === null) {
            return false;
          }
          if (!isTimeInStep(secondValue, "seconds", props.seconds))
            return true;
          const { isSecondDisabled } = props;
          if (!isSecondDisabled)
            return false;
          return isSecondDisabled(secondValue, minuteValue, hourValue);
        });
        const isValueInvalidRef = vue.computed(() => {
          return isHourInvalidRef.value || isMinuteInvalidRef.value || isSecondInvalidRef.value;
        });
        const mergedAttrSizeRef = vue.computed(() => {
          return props.format.length + 4;
        });
        const amPmValueRef = vue.computed(() => {
          const { value } = mergedValueRef;
          if (value === null)
            return null;
          return getHours(value) < 12 ? "am" : "pm";
        });
        const hourValueRef = vue.computed(() => {
          const { value } = mergedValueRef;
          if (value === null)
            return null;
          return Number(mergedFormatRef.value(value, "HH", dateFnsOptionsRef.value));
        });
        const minuteValueRef = vue.computed(() => {
          const { value } = mergedValueRef;
          if (value === null)
            return null;
          return Number(mergedFormatRef.value(value, "mm", dateFnsOptionsRef.value));
        });
        const secondValueRef = vue.computed(() => {
          const { value } = mergedValueRef;
          if (value === null)
            return null;
          return Number(mergedFormatRef.value(value, "ss", dateFnsOptionsRef.value));
        });
        function doUpdateFormattedValue(value, timestampValue) {
          const {
            onUpdateFormattedValue,
            "onUpdate:formattedValue": _onUpdateFormattedValue
          } = props;
          if (onUpdateFormattedValue) {
            call(
              onUpdateFormattedValue,
              value,
              timestampValue
            );
          }
          if (_onUpdateFormattedValue) {
            call(
              _onUpdateFormattedValue,
              value,
              timestampValue
            );
          }
        }
        function createFormattedValue(value) {
          return value === null ? null : mergedFormatRef.value(value, props.valueFormat || props.format);
        }
        function doUpdateValue(value) {
          const {
            onUpdateValue,
            "onUpdate:value": _onUpdateValue,
            onChange
          } = props;
          const { nTriggerFormChange, nTriggerFormInput } = formItem;
          const formattedValue = createFormattedValue(value);
          if (onUpdateValue) {
            call(onUpdateValue, value, formattedValue);
          }
          if (_onUpdateValue) {
            call(_onUpdateValue, value, formattedValue);
          }
          if (onChange)
            call(onChange, value, formattedValue);
          doUpdateFormattedValue(formattedValue, value);
          uncontrolledValueRef.value = value;
          nTriggerFormChange();
          nTriggerFormInput();
        }
        function doFocus(e) {
          const { onFocus } = props;
          const { nTriggerFormFocus } = formItem;
          if (onFocus)
            call(onFocus, e);
          nTriggerFormFocus();
        }
        function doBlur(e) {
          const { onBlur } = props;
          const { nTriggerFormBlur } = formItem;
          if (onBlur)
            call(onBlur, e);
          nTriggerFormBlur();
        }
        function doConfirm() {
          const { onConfirm } = props;
          if (onConfirm) {
            call(
              onConfirm,
              mergedValueRef.value,
              createFormattedValue(mergedValueRef.value)
            );
          }
        }
        function handleTimeInputClear(e) {
          e.stopPropagation();
          doUpdateValue(null);
          deriveInputValue(null);
          props.onClear?.();
        }
        function handleFocusDetectorFocus() {
          closePanel({
            returnFocus: true
          });
        }
        function handleInputKeydown(e) {
          if (e.key === "Escape" && mergedShowRef.value) {
            markEventEffectPerformed(e);
          }
        }
        function handleMenuKeydown(e) {
          switch (e.key) {
            case "Escape":
              if (mergedShowRef.value) {
                markEventEffectPerformed(e);
                closePanel({
                  returnFocus: true
                });
              }
              break;
            case "Tab":
              if (keyboardState.shift && e.target === panelInstRef.value?.$el) {
                e.preventDefault();
                closePanel({
                  returnFocus: true
                });
              }
              break;
          }
        }
        function disableTransitionOneTick() {
          transitionDisabledRef.value = true;
          void vue.nextTick(() => {
            transitionDisabledRef.value = false;
          });
        }
        function handleTriggerClick(e) {
          if (mergedDisabledRef.value || happensIn(e, "clear"))
            return;
          if (!mergedShowRef.value) {
            openPanel();
          }
        }
        function handleHourClick(hour) {
          if (typeof hour === "string")
            return;
          if (mergedValueRef.value === null) {
            doUpdateValue(getTime(setHours(startOfHour(new Date()), hour)));
          } else {
            doUpdateValue(getTime(setHours(mergedValueRef.value, hour)));
          }
        }
        function handleMinuteClick(minute) {
          if (typeof minute === "string")
            return;
          if (mergedValueRef.value === null) {
            doUpdateValue(getTime(setMinutes(startOfMinute(new Date()), minute)));
          } else {
            doUpdateValue(getTime(setMinutes(mergedValueRef.value, minute)));
          }
        }
        function handleSecondClick(second) {
          if (typeof second === "string")
            return;
          if (mergedValueRef.value === null) {
            doUpdateValue(getTime(setSeconds(startOfSecond(new Date()), second)));
          } else {
            doUpdateValue(getTime(setSeconds(mergedValueRef.value, second)));
          }
        }
        function handleAmPmClick(amPm) {
          const { value: mergedValue } = mergedValueRef;
          if (mergedValue === null) {
            const now = new Date();
            const hours = getHours(now);
            if (amPm === "pm" && hours < 12) {
              doUpdateValue(getTime(setHours(now, hours + 12)));
            } else if (amPm === "am" && hours >= 12) {
              doUpdateValue(getTime(setHours(now, hours - 12)));
            }
            doUpdateValue(getTime(now));
          } else {
            const hours = getHours(mergedValue);
            if (amPm === "pm" && hours < 12) {
              doUpdateValue(getTime(setHours(mergedValue, hours + 12)));
            } else if (amPm === "am" && hours >= 12) {
              doUpdateValue(getTime(setHours(mergedValue, hours - 12)));
            }
          }
        }
        function deriveInputValue(time) {
          if (time === void 0)
            time = mergedValueRef.value;
          if (time === null)
            displayTimeStringRef.value = "";
          else {
            displayTimeStringRef.value = mergedFormatRef.value(
              time,
              props.format,
              dateFnsOptionsRef.value
            );
          }
        }
        function handleTimeInputFocus(e) {
          if (isInternalFocusSwitch(e))
            return;
          doFocus(e);
        }
        function handleTimeInputBlur(e) {
          if (isInternalFocusSwitch(e))
            return;
          if (mergedShowRef.value) {
            const panelEl = panelInstRef.value?.$el;
            if (!panelEl?.contains(e.relatedTarget)) {
              deriveInputValue();
              doBlur(e);
              closePanel({
                returnFocus: false
              });
            }
          } else {
            deriveInputValue();
            doBlur(e);
          }
        }
        function handleTimeInputActivate() {
          if (mergedDisabledRef.value)
            return;
          if (!mergedShowRef.value) {
            openPanel();
          }
        }
        function handleTimeInputDeactivate() {
          if (mergedDisabledRef.value)
            return;
          deriveInputValue();
          closePanel({
            returnFocus: false
          });
        }
        function scrollTimer() {
          if (!panelInstRef.value)
            return;
          const { hourScrollRef, minuteScrollRef, secondScrollRef, amPmScrollRef } = panelInstRef.value;
          [hourScrollRef, minuteScrollRef, secondScrollRef, amPmScrollRef].forEach(
            (itemScrollRef) => {
              if (!itemScrollRef)
                return;
              const activeItemEl = itemScrollRef.contentRef?.querySelector("[data-active]");
              if (activeItemEl) {
                itemScrollRef.scrollTo({
                  top: activeItemEl.offsetTop
                });
              }
            }
          );
        }
        function doUpdateShow(value) {
          uncontrolledShowRef.value = value;
          const { onUpdateShow, "onUpdate:show": _onUpdateShow } = props;
          if (onUpdateShow)
            call(onUpdateShow, value);
          if (_onUpdateShow)
            call(_onUpdateShow, value);
        }
        function isInternalFocusSwitch(e) {
          return !!(inputInstRef.value?.wrapperElRef?.contains(e.relatedTarget) || panelInstRef.value?.$el.contains(e.relatedTarget));
        }
        function openPanel() {
          memorizedValueRef.value = mergedValueRef.value;
          doUpdateShow(true);
          void vue.nextTick(scrollTimer);
        }
        function handleClickOutside(e) {
          if (mergedShowRef.value && !inputInstRef.value?.wrapperElRef?.contains(
            getPreciseEventTarget(e)
          )) {
            closePanel({
              returnFocus: false
            });
          }
        }
        function closePanel({ returnFocus }) {
          if (mergedShowRef.value) {
            doUpdateShow(false);
            if (returnFocus) {
              inputInstRef.value?.focus();
            }
          }
        }
        function handleTimeInputUpdateValue(v) {
          if (v === "") {
            doUpdateValue(null);
            return;
          }
          const time = strictParse(
            v,
            props.format,
            new Date(),
            dateFnsOptionsRef.value
          );
          displayTimeStringRef.value = v;
          if (isValid$1(time)) {
            const { value: mergedValue } = mergedValueRef;
            if (mergedValue !== null) {
              const newTime = set(mergedValue, {
                hours: getHours(time),
                minutes: getMinutes(time),
                seconds: getSeconds(time)
              });
              doUpdateValue(getTime(newTime));
            } else {
              doUpdateValue(getTime(time));
            }
          }
        }
        function handleCancelClick() {
          doUpdateValue(memorizedValueRef.value);
          doUpdateShow(false);
        }
        function handleNowClick() {
          const now = new Date();
          const getNowTime = {
            hours: getHours,
            minutes: getMinutes,
            seconds: getSeconds
          };
          const [mergeHours, mergeMinutes, mergeSeconds] = ["hours", "minutes", "seconds"].map(
            (i) => !props[i] || isTimeInStep(getNowTime[i](now), i, props[i]) ? getNowTime[i](now) : findSimilarTime(getNowTime[i](now), i, props[i])
          );
          const newValue = setSeconds(
            setMinutes(
              setHours(
                mergedValueRef.value ? mergedValueRef.value : getTime(now),
                mergeHours
              ),
              mergeMinutes
            ),
            mergeSeconds
          );
          doUpdateValue(getTime(newValue));
        }
        function handleConfirmClick() {
          deriveInputValue();
          doConfirm();
          closePanel({
            returnFocus: true
          });
        }
        function handleMenuFocusOut(e) {
          if (isInternalFocusSwitch(e))
            return;
          deriveInputValue();
          doBlur(e);
          closePanel({
            returnFocus: false
          });
        }
        vue.watch(mergedValueRef, (value) => {
          deriveInputValue(value);
          disableTransitionOneTick();
          void vue.nextTick(scrollTimer);
        });
        vue.watch(mergedShowRef, () => {
          if (isValueInvalidRef.value) {
            doUpdateValue(memorizedValueRef.value);
          }
        });
        vue.provide(timePickerInjectionKey, {
          mergedThemeRef: themeRef,
          mergedClsPrefixRef
        });
        const exposedMethods = {
          focus: () => {
            inputInstRef.value?.focus();
          },
          blur: () => {
            inputInstRef.value?.blur();
          }
        };
        const triggerCssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self: { iconColor, iconColorDisabled }
          } = themeRef.value;
          return {
            "--n-icon-color-override": iconColor,
            "--n-icon-color-disabled-override": iconColorDisabled,
            "--n-bezier": cubicBezierEaseInOut
          };
        });
        const triggerThemeClassHandle = inlineThemeDisabled ? useThemeClass(
          "time-picker-trigger",
          void 0,
          triggerCssVarsRef,
          props
        ) : void 0;
        const cssVarsRef = vue.computed(() => {
          const {
            self: {
              panelColor,
              itemTextColor,
              itemTextColorActive,
              itemColorHover,
              panelDividerColor,
              panelBoxShadow,
              itemOpacityDisabled,
              borderRadius,
              itemFontSize,
              itemWidth,
              itemHeight,
              panelActionPadding,
              itemBorderRadius
            },
            common: { cubicBezierEaseInOut }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-border-radius": borderRadius,
            "--n-item-color-hover": itemColorHover,
            "--n-item-font-size": itemFontSize,
            "--n-item-height": itemHeight,
            "--n-item-opacity-disabled": itemOpacityDisabled,
            "--n-item-text-color": itemTextColor,
            "--n-item-text-color-active": itemTextColorActive,
            "--n-item-width": itemWidth,
            "--n-panel-action-padding": panelActionPadding,
            "--n-panel-box-shadow": panelBoxShadow,
            "--n-panel-color": panelColor,
            "--n-panel-divider-color": panelDividerColor,
            "--n-item-border-radius": itemBorderRadius
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("time-picker", void 0, cssVarsRef, props) : void 0;
        return {
          focus: exposedMethods.focus,
          blur: exposedMethods.blur,
          mergedStatus: mergedStatusRef,
          mergedBordered: mergedBorderedRef,
          mergedClsPrefix: mergedClsPrefixRef,
          namespace: namespaceRef,
          uncontrolledValue: uncontrolledValueRef,
          mergedValue: mergedValueRef,
          isMounted: isMounted(),
          inputInstRef,
          panelInstRef,
          adjustedTo: useAdjustedTo(props),
          mergedShow: mergedShowRef,
          localizedNow: localizedNowRef,
          localizedPlaceholder: localizedPlaceholderRef,
          localizedNegativeText: localizedNegativeTextRef,
          localizedPositiveText: localizedPositiveTextRef,
          hourInFormat: hourInFormatRef,
          minuteInFormat: minuteInFormatRef,
          secondInFormat: secondInFormatRef,
          mergedAttrSize: mergedAttrSizeRef,
          displayTimeString: displayTimeStringRef,
          mergedSize: mergedSizeRef,
          mergedDisabled: mergedDisabledRef,
          isValueInvalid: isValueInvalidRef,
          isHourInvalid: isHourInvalidRef,
          isMinuteInvalid: isMinuteInvalidRef,
          isSecondInvalid: isSecondInvalidRef,
          transitionDisabled: transitionDisabledRef,
          hourValue: hourValueRef,
          minuteValue: minuteValueRef,
          secondValue: secondValueRef,
          amPmValue: amPmValueRef,
          handleInputKeydown,
          handleTimeInputFocus,
          handleTimeInputBlur,
          handleNowClick,
          handleConfirmClick,
          handleTimeInputUpdateValue,
          handleMenuFocusOut,
          handleCancelClick,
          handleClickOutside,
          handleTimeInputActivate,
          handleTimeInputDeactivate,
          handleHourClick,
          handleMinuteClick,
          handleSecondClick,
          handleAmPmClick,
          handleTimeInputClear,
          handleFocusDetectorFocus,
          handleMenuKeydown,
          handleTriggerClick,
          mergedTheme: themeRef,
          triggerCssVars: inlineThemeDisabled ? void 0 : triggerCssVarsRef,
          triggerThemeClass: triggerThemeClassHandle?.themeClass,
          triggerOnRender: triggerThemeClassHandle?.onRender,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedClsPrefix, $slots, triggerOnRender } = this;
        triggerOnRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          class: [`${mergedClsPrefix}-time-picker`, this.triggerThemeClass],
          style: this.triggerCssVars
        }, /* @__PURE__ */ React.createElement(VBinder, null, {
          default: () => [
            /* @__PURE__ */ React.createElement(VTarget, null, {
              default: () => /* @__PURE__ */ React.createElement(NInput, {
                ref: "inputInstRef",
                status: this.mergedStatus,
                value: this.displayTimeString,
                bordered: this.mergedBordered,
                passivelyActivated: true,
                attrSize: this.mergedAttrSize,
                theme: this.mergedTheme.peers.Input,
                themeOverrides: this.mergedTheme.peerOverrides.Input,
                stateful: this.stateful,
                size: this.mergedSize,
                placeholder: this.localizedPlaceholder,
                clearable: this.clearable,
                disabled: this.mergedDisabled,
                textDecoration: this.isValueInvalid ? "line-through" : void 0,
                onFocus: this.handleTimeInputFocus,
                onBlur: this.handleTimeInputBlur,
                onActivate: this.handleTimeInputActivate,
                onDeactivate: this.handleTimeInputDeactivate,
                onUpdateValue: this.handleTimeInputUpdateValue,
                onClear: this.handleTimeInputClear,
                internalDeactivateOnEnter: true,
                internalForceFocus: this.mergedShow,
                readonly: this.inputReadonly || this.mergedDisabled,
                onClick: this.handleTriggerClick,
                onKeydown: this.handleInputKeydown
              }, this.showIcon ? {
                [this.clearable ? "clear-icon-placeholder" : "suffix"]: () => /* @__PURE__ */ React.createElement(NBaseIcon, {
                  clsPrefix: mergedClsPrefix,
                  class: `${mergedClsPrefix}-time-picker-icon`
                }, {
                  default: () => $slots.icon ? $slots.icon() : /* @__PURE__ */ React.createElement(TimeIcon, null)
                })
              } : null)
            }),
            /* @__PURE__ */ React.createElement(VFollower, {
              teleportDisabled: this.adjustedTo === useAdjustedTo.tdkey,
              show: this.mergedShow,
              to: this.adjustedTo,
              containerClass: this.namespace,
              placement: this.placement
            }, {
              default: () => /* @__PURE__ */ React.createElement(vue.Transition, {
                name: "fade-in-scale-up-transition",
                appear: this.isMounted
              }, {
                default: () => {
                  if (this.mergedShow) {
                    this.onRender?.();
                    return vue.withDirectives(
                      /* @__PURE__ */ React.createElement(Panel, {
                        ref: "panelInstRef",
                        actions: this.actions,
                        class: this.themeClass,
                        style: this.cssVars,
                        seconds: this.seconds,
                        minutes: this.minutes,
                        hours: this.hours,
                        transitionDisabled: this.transitionDisabled,
                        hourValue: this.hourValue,
                        showHour: this.hourInFormat,
                        isHourInvalid: this.isHourInvalid,
                        isHourDisabled: this.isHourDisabled,
                        minuteValue: this.minuteValue,
                        showMinute: this.minuteInFormat,
                        isMinuteInvalid: this.isMinuteInvalid,
                        isMinuteDisabled: this.isMinuteDisabled,
                        secondValue: this.secondValue,
                        amPmValue: this.amPmValue,
                        showSecond: this.secondInFormat,
                        isSecondInvalid: this.isSecondInvalid,
                        isSecondDisabled: this.isSecondDisabled,
                        isValueInvalid: this.isValueInvalid,
                        nowText: this.localizedNow,
                        confirmText: this.localizedPositiveText,
                        use12Hours: this.use12Hours,
                        onFocusout: this.handleMenuFocusOut,
                        onKeydown: this.handleMenuKeydown,
                        onHourClick: this.handleHourClick,
                        onMinuteClick: this.handleMinuteClick,
                        onSecondClick: this.handleSecondClick,
                        onAmPmClick: this.handleAmPmClick,
                        onNowClick: this.handleNowClick,
                        onConfirmClick: this.handleConfirmClick,
                        onFocusDetectorFocus: this.handleFocusDetectorFocus
                      }),
                      [
                        [
                          clickoutside$1,
                          this.handleClickOutside,
                          void 0,
                          { capture: true }
                        ]
                      ]
                    );
                  }
                  return null;
                }
              })
            })
          ]
        }));
      }
    });

    const TIME_FORMAT = "HH:mm:ss";
    const usePanelCommonProps = {
      active: Boolean,
      dateFormat: String,
      timeFormat: {
        type: String,
        value: TIME_FORMAT
      },
      value: {
        type: [Array, Number],
        default: null
      },
      shortcuts: Object,
      defaultTime: [Number, String, Array],
      onClear: Function,
      onConfirm: Function,
      onClose: Function,
      onTabOut: Function,
      onUpdateValue: {
        type: Function,
        required: true
      },
      themeClass: String,
      onRender: Function,
      panel: Boolean
    };

    function usePanelCommon(props) {
      const {
        dateLocaleRef,
        timePickerSizeRef,
        timePickerPropsRef,
        localeRef,
        mergedClsPrefixRef,
        mergedThemeRef
      } = vue.inject(datePickerInjectionKey);
      const dateFnsOptionsRef = vue.computed(() => {
        return {
          locale: dateLocaleRef.value.locale
        };
      });
      const selfRef = vue.ref(null);
      const keyboardState = useKeyboard$1();

      function doClear() {
        const {
          onClear
        } = props;
        if (onClear) onClear();
      }

      function doConfirm() {
        const {
          onConfirm,
          value
        } = props;
        if (onConfirm) onConfirm(value);
      }

      function doUpdateValue(value, doUpdate) {
        const {
          onUpdateValue
        } = props;
        onUpdateValue(value, doUpdate);
      }

      function doClose() {
        let disableUpdateOnClose = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
        const {
          onClose
        } = props;
        if (onClose) onClose(disableUpdateOnClose);
      }

      function doTabOut() {
        const {
          onTabOut
        } = props;
        if (onTabOut) onTabOut();
      }

      function handleClearClick() {
        doUpdateValue(null, true);
        doClose(true);
        doClear();
      }

      function handleFocusDetectorFocus() {
        doTabOut();
      }

      function disableTransitionOneTick() {
        if (props.active || props.panel) {
          void vue.nextTick(() => {
            const {
              value: selfEl
            } = selfRef;
            if (!selfEl) return;
            const dateEls = selfEl.querySelectorAll("[data-n-date]");
            dateEls.forEach(el => {
              el.classList.add("transition-disabled");
            });
            void selfEl.offsetWidth;
            dateEls.forEach(el => {
              el.classList.remove("transition-disabled");
            });
          });
        }
      }

      function handlePanelKeyDown(e) {
        if (e.key === "Tab" && e.target === selfRef.value && keyboardState.shift) {
          e.preventDefault();
          doTabOut();
        }
      }

      function handlePanelFocus(e) {
        const {
          value: el
        } = selfRef;

        if (keyboardState.tab && e.target === el && el !== null && el !== void 0 && el.contains(e.relatedTarget)) {
          doTabOut();
        }
      }

      let cachedValue = null;
      let cached = false;

      function cachePendingValue() {
        cachedValue = props.value;
        cached = true;
      }

      function clearPendingValue() {
        cached = false;
      }

      function restorePendingValue() {
        if (cached) {
          doUpdateValue(cachedValue, false);
          cached = false;
        }
      }

      function getShortcutValue(shortcut) {
        if (typeof shortcut === "function") {
          return shortcut();
        }

        return shortcut;
      }

      const showMonthYearPanel = vue.ref(false);

      function handleOpenQuickSelectMonthPanel() {
        showMonthYearPanel.value = !showMonthYearPanel.value;
      }

      return {
        mergedTheme: mergedThemeRef,
        mergedClsPrefix: mergedClsPrefixRef,
        dateFnsOptions: dateFnsOptionsRef,
        timePickerSize: timePickerSizeRef,
        timePickerProps: timePickerPropsRef,
        selfRef,
        locale: localeRef,
        doConfirm,
        doClose,
        doUpdateValue,
        doTabOut,
        handleClearClick,
        handleFocusDetectorFocus,
        disableTransitionOneTick,
        handlePanelKeyDown,
        handlePanelFocus,
        cachePendingValue,
        clearPendingValue,
        restorePendingValue,
        getShortcutValue,
        handleShortcutMouseleave: restorePendingValue,
        showMonthYearPanel,
        handleOpenQuickSelectMonthPanel
      };
    }

    const useCalendarProps = { ...usePanelCommonProps,
      actions: {
        type: Array,
        default: () => ["now", "clear", "confirm"]
      }
    };

    function useCalendar(props, type) {
      const panelCommon = usePanelCommon(props);
      const {
        isValueInvalidRef,
        isDateDisabledRef,
        isDateInvalidRef,
        isTimeInvalidRef,
        isDateTimeInvalidRef,
        isHourDisabledRef,
        isMinuteDisabledRef,
        isSecondDisabledRef,
        localeRef,
        firstDayOfWeekRef,
        datePickerSlots
      } = vue.inject(datePickerInjectionKey);
      const validation = {
        isValueInvalid: isValueInvalidRef,
        isDateDisabled: isDateDisabledRef,
        isDateInvalid: isDateInvalidRef,
        isTimeInvalid: isTimeInvalidRef,
        isDateTimeInvalid: isDateTimeInvalidRef,
        isHourDisabled: isHourDisabledRef,
        isMinuteDisabled: isMinuteDisabledRef,
        isSecondDisabled: isSecondDisabledRef
      };
      const mergedDateFormatRef = vue.computed(() => props.dateFormat || localeRef.value.dateFormat);
      const dateInputValueRef = vue.ref(props.value === null || Array.isArray(props.value) ? "" : format$4(props.value, mergedDateFormatRef.value));
      const calendarValueRef = vue.ref(props.value === null || Array.isArray(props.value) ? Date.now() : props.value);
      const yearVlRef = vue.ref(null);
      const yearScrollbarRef = vue.ref(null);
      const monthScrollbarRef = vue.ref(null);
      const nowRef = vue.ref(Date.now());
      const dateArrayRef = vue.computed(() => {
        return dateArray(calendarValueRef.value, props.value, nowRef.value, firstDayOfWeekRef.value ?? localeRef.value.firstDayOfWeek);
      });
      const monthArrayRef = vue.computed(() => {
        const {
          value
        } = props;
        return monthArray(calendarValueRef.value, Array.isArray(value) ? null : value, nowRef.value);
      });
      const yearArrayRef = vue.computed(() => {
        const {
          value
        } = props;
        return yearArray(Array.isArray(value) ? null : value, nowRef.value);
      });
      const quarterArrayRef = vue.computed(() => {
        const {
          value
        } = props;
        return quarterArray(calendarValueRef.value, Array.isArray(value) ? null : value, nowRef.value);
      });
      const weekdaysRef = vue.computed(() => {
        return dateArrayRef.value.slice(0, 7).map(dateItem => {
          const {
            ts
          } = dateItem;
          return format$4(ts, localeRef.value.dayFormat, panelCommon.dateFnsOptions.value);
        });
      });
      const calendarMonthRef = vue.computed(() => {
        return format$4(calendarValueRef.value, localeRef.value.monthFormat, panelCommon.dateFnsOptions.value);
      });
      const calendarYearRef = vue.computed(() => {
        return format$4(calendarValueRef.value, localeRef.value.yearFormat, panelCommon.dateFnsOptions.value);
      });
      vue.watch(calendarValueRef, (value, oldValue) => {
        if (type === "date" || type === "datetime") {
          if (!isSameMonth(value, oldValue)) {
            panelCommon.disableTransitionOneTick();
          }
        }
      });
      vue.watch(vue.computed(() => props.value), value => {
        if (value !== null && !Array.isArray(value)) {
          dateInputValueRef.value = format$4(value, mergedDateFormatRef.value, panelCommon.dateFnsOptions.value);
          calendarValueRef.value = value;
        } else {
          dateInputValueRef.value = "";
        }
      });

      function sanitizeValue(value) {
        if (type === "datetime") return getTime(startOfSecond(value));
        if (type === "month") return getTime(startOfMonth(value));
        if (type === "year") return getTime(startOfYear(value));
        if (type === "quarter") return getTime(startOfQuarter(value));
        return getTime(startOfDay(value));
      }

      function mergedIsDateDisabled(ts) {
        const {
          isDateDisabled: {
            value: isDateDisabled
          }
        } = validation;
        if (!isDateDisabled) return false;
        return isDateDisabled(ts);
      }

      function handleDateInput(value) {
        const date = strictParse(value, mergedDateFormatRef.value, new Date(), panelCommon.dateFnsOptions.value);

        if (isValid$1(date)) {
          if (props.value === null) {
            panelCommon.doUpdateValue(getTime(sanitizeValue(Date.now())), props.panel);
          } else if (!Array.isArray(props.value)) {
            const newDateTime = set(props.value, {
              year: getYear(date),
              month: getMonth(date),
              date: getDate(date)
            });
            panelCommon.doUpdateValue(getTime(sanitizeValue(getTime(newDateTime))), props.panel);
          }
        } else {
          dateInputValueRef.value = value;
        }
      }

      function handleDateInputBlur() {
        const date = strictParse(dateInputValueRef.value, mergedDateFormatRef.value, new Date(), panelCommon.dateFnsOptions.value);

        if (isValid$1(date)) {
          if (props.value === null) {
            panelCommon.doUpdateValue(getTime(sanitizeValue(Date.now())), false);
          } else if (!Array.isArray(props.value)) {
            const newDateTime = set(props.value, {
              year: getYear(date),
              month: getMonth(date),
              date: getDate(date)
            });
            panelCommon.doUpdateValue(getTime(sanitizeValue(getTime(newDateTime))), false);
          }
        } else {
          deriveDateInputValue();
        }
      }

      function clearSelectedDateTime() {
        panelCommon.doUpdateValue(null, true);
        dateInputValueRef.value = "";
        panelCommon.doClose(true);
        panelCommon.handleClearClick();
      }

      function handleNowClick() {
        panelCommon.doUpdateValue(getTime(sanitizeValue(Date.now())), true);
        const now = Date.now();
        calendarValueRef.value = now;
        panelCommon.doClose(true);

        if (props.panel && (type === "month" || type === "quarter" || type === "year")) {
          panelCommon.disableTransitionOneTick();
          justifyColumnsScrollState(now);
        }
      }

      function handleDateClick(dateItem) {
        if (mergedIsDateDisabled(dateItem.ts)) {
          return;
        }

        let newValue;

        if (props.value !== null && !Array.isArray(props.value)) {
          newValue = props.value;
        } else {
          newValue = Date.now();
        }

        if (type === "datetime" && props.defaultTime !== null && !Array.isArray(props.defaultTime)) {
          const time = getDefaultTime(props.defaultTime);

          if (time) {
            newValue = getTime(set(newValue, time));
          }
        }

        newValue = getTime(dateItem.type === "quarter" && dateItem.dateObject.quarter ? setQuarter(setYear(newValue, dateItem.dateObject.year), dateItem.dateObject.quarter) : set(newValue, dateItem.dateObject));
        panelCommon.doUpdateValue(sanitizeValue(newValue), props.panel || type === "date" || type === "year");

        switch (type) {
          case "date":
            panelCommon.doClose();
            break;

          case "year":
            if (props.panel) {
              panelCommon.disableTransitionOneTick();
            }

            panelCommon.doClose();
            break;

          case "month":
            panelCommon.disableTransitionOneTick();
            justifyColumnsScrollState(newValue);
            break;

          case "quarter":
            panelCommon.disableTransitionOneTick();
            justifyColumnsScrollState(newValue);
            break;
        }
      }

      function handleQuickMonthClick(dateItem, updatePanelValue) {
        let newValue;

        if (props.value !== null && !Array.isArray(props.value)) {
          newValue = props.value;
        } else {
          newValue = Date.now();
        }

        newValue = getTime(dateItem.type === "month" ? setMonth(newValue, dateItem.dateObject.month) : setYear(newValue, dateItem.dateObject.year));
        updatePanelValue(newValue);
        justifyColumnsScrollState(newValue);
      }

      function onUpdateCalendarValue(value) {
        calendarValueRef.value = value;
      }

      function deriveDateInputValue(time) {
        if (props.value === null || Array.isArray(props.value)) {
          dateInputValueRef.value = "";
          return;
        }

        if (time === void 0) {
          time = props.value;
        }

        dateInputValueRef.value = format$4(time, mergedDateFormatRef.value, panelCommon.dateFnsOptions.value);
      }

      function handleConfirmClick() {
        if (validation.isDateInvalid.value || validation.isTimeInvalid.value) {
          return;
        }

        panelCommon.doConfirm();
        closeCalendar();
      }

      function closeCalendar() {
        if (props.active) {
          panelCommon.doClose();
        }
      }

      function nextYear() {
        calendarValueRef.value = getTime(addYears(calendarValueRef.value, 1));
      }

      function prevYear() {
        calendarValueRef.value = getTime(addYears(calendarValueRef.value, -1));
      }

      function nextMonth() {
        calendarValueRef.value = getTime(addMonths(calendarValueRef.value, 1));
      }

      function prevMonth() {
        calendarValueRef.value = getTime(addMonths(calendarValueRef.value, -1));
      }

      function virtualListContainer() {
        const {
          value
        } = yearVlRef;
        return value === null || value === void 0 ? void 0 : value.listElRef;
      }

      function virtualListContent() {
        const {
          value
        } = yearVlRef;
        return value === null || value === void 0 ? void 0 : value.itemsElRef;
      }

      function handleVirtualListScroll(e) {
        var _yearScrollbarRef$val;

        (_yearScrollbarRef$val = yearScrollbarRef.value) === null || _yearScrollbarRef$val === void 0 ? void 0 : _yearScrollbarRef$val.sync();
      }

      function handleTimePickerChange(value) {
        if (value === null) return;
        panelCommon.doUpdateValue(value, props.panel);
      }

      function handleSingleShortcutMouseenter(shortcut) {
        panelCommon.cachePendingValue();
        const shortcutValue = panelCommon.getShortcutValue(shortcut);
        if (typeof shortcutValue !== "number") return;
        panelCommon.doUpdateValue(shortcutValue, false);
      }

      function handleSingleShortcutClick(shortcut) {
        const shortcutValue = panelCommon.getShortcutValue(shortcut);
        if (typeof shortcutValue !== "number") return;
        panelCommon.doUpdateValue(shortcutValue, props.panel);
        panelCommon.clearPendingValue();
        handleConfirmClick();
      }

      function justifyColumnsScrollState(value) {
        const {
          value: mergedValue
        } = props;

        if (monthScrollbarRef.value) {
          const monthIndex = value === void 0 ? mergedValue === null ? getMonth(Date.now()) : getMonth(mergedValue) : getMonth(value);
          monthScrollbarRef.value.scrollTo({
            top: monthIndex * MONTH_ITEM_HEIGHT
          });
        }

        if (yearVlRef.value) {
          const yearIndex = (value === void 0 ? mergedValue === null ? getYear(Date.now()) : getYear(mergedValue) : getYear(value)) - START_YEAR;
          yearVlRef.value.scrollTo({
            top: yearIndex * MONTH_ITEM_HEIGHT
          });
        }
      }

      const childComponentRefs = {
        monthScrollbarRef,
        yearScrollbarRef,
        yearVlRef
      };
      return {
        dateArray: dateArrayRef,
        monthArray: monthArrayRef,
        yearArray: yearArrayRef,
        quarterArray: quarterArrayRef,
        calendarYear: calendarYearRef,
        calendarMonth: calendarMonthRef,
        weekdays: weekdaysRef,
        mergedIsDateDisabled,
        nextYear,
        prevYear,
        nextMonth,
        prevMonth,
        handleNowClick,
        handleConfirmClick,
        handleSingleShortcutMouseenter,
        handleSingleShortcutClick,
        ...validation,
        ...panelCommon,
        ...childComponentRefs,
        handleDateClick,
        handleDateInputBlur,
        handleDateInput,
        handleTimePickerChange,
        clearSelectedDateTime,
        virtualListContainer,
        virtualListContent,
        handleVirtualListScroll,
        timePickerSize: panelCommon.timePickerSize,
        dateInputValue: dateInputValueRef,
        datePickerSlots,
        handleQuickMonthClick,
        justifyColumnsScrollState,
        calendarValue: calendarValueRef,
        onUpdateCalendarValue
      };
    }

    var MonthPanel = vue.defineComponent({
      name: "MonthPanel",
      props: {
        ...useCalendarProps,
        type: {
          type: String,
          required: true
        },
        useAsQuickJump: Boolean
      },
      setup(props) {
        const useCalendarRef = useCalendar(props, props.type);
        const getRenderContent = (item) => {
          switch (item.type) {
            case "year":
              return item.dateObject.year;
            case "month":
              return item.dateObject.month + 1;
            case "quarter":
              return `Q${item.dateObject.quarter}`;
          }
        };
        const { useAsQuickJump } = props;
        const renderItem = (item, i, mergedClsPrefix) => {
          const { mergedIsDateDisabled, handleDateClick, handleQuickMonthClick } = useCalendarRef;
          return /* @__PURE__ */ React.createElement("div", {
            "data-n-date": true,
            key: i,
            class: [
              `${mergedClsPrefix}-date-panel-month-calendar__picker-col-item`,
              {
                [`${mergedClsPrefix}-date-panel-month-calendar__picker-col-item--current`]: item.isCurrent,
                [`${mergedClsPrefix}-date-panel-month-calendar__picker-col-item--selected`]: item.selected,
                [`${mergedClsPrefix}-date-panel-month-calendar__picker-col-item--disabled`]: !useAsQuickJump && mergedIsDateDisabled(item.ts)
              }
            ],
            onClick: () => {
              useAsQuickJump ? handleQuickMonthClick(
                item,
                (value) => props.onUpdateValue(value, false)
              ) : handleDateClick(item);
            }
          }, getRenderContent(item));
        };
        vue.onMounted(() => {
          useCalendarRef.justifyColumnsScrollState();
        });
        return { ...useCalendarRef, renderItem };
      },
      render() {
        const {
          mergedClsPrefix,
          mergedTheme,
          shortcuts,
          actions,
          renderItem,
          type,
          onRender
        } = this;
        onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          ref: "selfRef",
          tabindex: 0,
          class: [
            `${mergedClsPrefix}-date-panel`,
            `${mergedClsPrefix}-date-panel--month`,
            !this.panel && `${mergedClsPrefix}-date-panel--shadow`,
            this.themeClass
          ],
          onFocus: this.handlePanelFocus,
          onKeydown: this.handlePanelKeyDown
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month-calendar`
        }, /* @__PURE__ */ React.createElement(NScrollbar, {
          ref: "yearScrollbarRef",
          class: `${mergedClsPrefix}-date-panel-month-calendar__picker-col`,
          theme: mergedTheme.peers.Scrollbar,
          themeOverrides: mergedTheme.peerOverrides.Scrollbar,
          container: this.virtualListContainer,
          content: this.virtualListContent,
          horizontalRailStyle: { zIndex: 1 },
          verticalRailStyle: { zIndex: 1 }
        }, {
          default: () => /* @__PURE__ */ React.createElement(VVirtualList, {
            ref: "yearVlRef",
            items: this.yearArray,
            itemSize: MONTH_ITEM_HEIGHT,
            showScrollbar: false,
            keyField: "ts",
            onScroll: this.handleVirtualListScroll,
            paddingBottom: 4
          }, {
            default: ({
              item,
              index
            }) => {
              return renderItem(item, index, mergedClsPrefix);
            }
          })
        }), type === "month" || type === "quarter" ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month-calendar__picker-col`
        }, /* @__PURE__ */ React.createElement(NScrollbar, {
          ref: "monthScrollbarRef",
          theme: mergedTheme.peers.Scrollbar,
          themeOverrides: mergedTheme.peerOverrides.Scrollbar
        }, {
          default: () => [
            (type === "month" ? this.monthArray : this.quarterArray).map((item, i) => renderItem(item, i, mergedClsPrefix)),
            /* @__PURE__ */ React.createElement("div", {
              class: `${mergedClsPrefix}-date-panel-${type}-calendar__padding`
            })
          ]
        })) : null), this.datePickerSlots.footer ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-footer`
        }, {
          default: this.datePickerSlots.footer
        }) : null, actions?.length || shortcuts ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-actions`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-actions__prefix`
        }, shortcuts && Object.keys(shortcuts).map((key) => {
          const shortcut = shortcuts[key];
          return Array.isArray(shortcut) ? null : /* @__PURE__ */ React.createElement(XButton, {
            size: "tiny",
            onMouseenter: () => {
              this.handleSingleShortcutMouseenter(shortcut);
            },
            onClick: () => {
              this.handleSingleShortcutClick(shortcut);
            },
            onMouseleave: () => {
              this.handleShortcutMouseleave();
            }
          }, { default: () => key });
        })), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-actions__suffix`
        }, actions?.includes("clear") ? /* @__PURE__ */ React.createElement(NButton, {
          theme: mergedTheme.peers.Button,
          themeOverrides: mergedTheme.peerOverrides.Button,
          size: "tiny",
          onClick: this.handleClearClick
        }, { default: () => this.locale.clear }) : null, actions?.includes("now") ? /* @__PURE__ */ React.createElement(NButton, {
          theme: mergedTheme.peers.Button,
          themeOverrides: mergedTheme.peerOverrides.Button,
          size: "tiny",
          onClick: this.handleNowClick
        }, { default: () => this.locale.now }) : null, actions?.includes("confirm") ? /* @__PURE__ */ React.createElement(NButton, {
          theme: mergedTheme.peers.Button,
          themeOverrides: mergedTheme.peerOverrides.Button,
          size: "tiny",
          type: "primary",
          disabled: this.isDateInvalid,
          onClick: this.handleConfirmClick
        }, { default: () => this.locale.confirm }) : null)) : null, /* @__PURE__ */ React.createElement(FocusDetector, {
          onFocus: this.handleFocusDetectorFocus
        }));
      }
    });

    var PanelHeader = vue.defineComponent({
      props: {
        mergedClsPrefix: {
          type: String,
          required: true
        },
        value: Number,
        monthBeforeYear: {
          type: Boolean,
          required: true
        },
        calendarMonth: {
          type: String,
          required: true
        },
        calendarYear: {
          type: String,
          required: true
        },
        onUpdateValue: {
          type: Function,
          required: true
        }
      },
      setup() {
        const triggerRef = vue.ref(null);
        const monthPanelRef = vue.ref(null);
        const showRef = vue.ref(false);
        function handleClickOutside(e) {
          if (showRef.value && !triggerRef.value?.contains(getPreciseEventTarget(e))) {
            showRef.value = false;
          }
        }
        function handleHeaderClick() {
          showRef.value = !showRef.value;
        }
        return {
          show: showRef,
          triggerRef,
          monthPanelRef,
          handleHeaderClick,
          handleClickOutside
        };
      },
      render() {
        const { handleClickOutside, mergedClsPrefix } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__month-year`,
          ref: "triggerRef"
        }, /* @__PURE__ */ React.createElement(VBinder, null, {
          default: () => [
            /* @__PURE__ */ React.createElement(VTarget, null, {
              default: () => /* @__PURE__ */ React.createElement("div", {
                class: [
                  `${mergedClsPrefix}-date-panel-month__text`,
                  this.show && `${mergedClsPrefix}-date-panel-month__text--active`
                ],
                onClick: this.handleHeaderClick
              }, this.monthBeforeYear ? [this.calendarMonth, " ", this.calendarYear] : [this.calendarYear, " ", this.calendarMonth])
            }),
            /* @__PURE__ */ React.createElement(VFollower, {
              show: this.show,
              teleportDisabled: true
            }, {
              default: () => /* @__PURE__ */ React.createElement(vue.Transition, {
                name: "fade-in-scale-up-transition",
                appear: true
              }, {
                default: () => this.show ? vue.withDirectives(
                  /* @__PURE__ */ React.createElement(MonthPanel, {
                    ref: "monthPanelRef",
                    onUpdateValue: this.onUpdateValue,
                    actions: [],
                    type: "month",
                    key: "month",
                    useAsQuickJump: true,
                    value: this.value
                  }),
                  [
                    [
                      clickoutside$1,
                      handleClickOutside,
                      void 0,
                      { capture: true }
                    ]
                  ]
                ) : null
              })
            })
          ]
        }));
      }
    });

    var DatetimePanel = vue.defineComponent({
      name: "DateTimePanel",
      props: useCalendarProps,
      setup(props) {
        return useCalendar(props, "datetime");
      },
      render() {
        const {
          mergedClsPrefix,
          mergedTheme,
          shortcuts,
          timePickerProps,
          onRender
        } = this;
        onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          ref: "selfRef",
          tabindex: 0,
          class: [
            `${mergedClsPrefix}-date-panel`,
            `${mergedClsPrefix}-date-panel--datetime`,
            !this.panel && `${mergedClsPrefix}-date-panel--shadow`,
            this.themeClass
          ],
          onKeydown: this.handlePanelKeyDown,
          onFocus: this.handlePanelFocus
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-header`
        }, /* @__PURE__ */ React.createElement(NInput, {
          value: this.dateInputValue,
          theme: mergedTheme.peers.Input,
          themeOverrides: mergedTheme.peerOverrides.Input,
          stateful: false,
          size: this.timePickerSize,
          class: `${mergedClsPrefix}-date-panel-date-input`,
          textDecoration: this.isDateInvalid ? "line-through" : "",
          placeholder: this.locale.selectDate,
          onBlur: this.handleDateInputBlur,
          onUpdateValue: this.handleDateInput
        }), /* @__PURE__ */ React.createElement(NTimePicker, {
          size: this.timePickerSize,
          placeholder: this.locale.selectTime,
          format: this.timeFormat,
          ...Array.isArray(timePickerProps) ? void 0 : timePickerProps,
          showIcon: false,
          to: false,
          theme: mergedTheme.peers.TimePicker,
          themeOverrides: mergedTheme.peerOverrides.TimePicker,
          value: Array.isArray(this.value) ? null : this.value,
          isHourDisabled: this.isHourDisabled,
          isMinuteDisabled: this.isMinuteDisabled,
          isSecondDisabled: this.isSecondDisabled,
          onUpdateValue: this.handleTimePickerChange,
          stateful: false
        })), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-calendar`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__fast-prev`,
          onClick: this.prevYear
        }, /* @__PURE__ */ React.createElement(FastBackwardIcon, null)), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__prev`,
          onClick: this.prevMonth
        }, /* @__PURE__ */ React.createElement(BackwardIcon, null)), /* @__PURE__ */ React.createElement(PanelHeader, {
          monthBeforeYear: this.locale.monthBeforeYear,
          value: this.calendarValue,
          onUpdateValue: this.onUpdateCalendarValue,
          mergedClsPrefix,
          calendarMonth: this.calendarMonth,
          calendarYear: this.calendarYear
        }), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__next`,
          onClick: this.nextMonth
        }, /* @__PURE__ */ React.createElement(ForwardIcon, null)), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__fast-next`,
          onClick: this.nextYear
        }, /* @__PURE__ */ React.createElement(FastForwardIcon, null))), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-weekdays`
        }, this.weekdays.map((weekday) => /* @__PURE__ */ React.createElement("div", {
          key: weekday,
          class: `${mergedClsPrefix}-date-panel-weekdays__day`
        }, weekday))), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-dates`
        }, this.dateArray.map((dateItem, i) => /* @__PURE__ */ React.createElement("div", {
          "data-n-date": true,
          key: i,
          class: [
            `${mergedClsPrefix}-date-panel-date`,
            {
              [`${mergedClsPrefix}-date-panel-date--current`]: dateItem.isCurrentDate,
              [`${mergedClsPrefix}-date-panel-date--selected`]: dateItem.selected,
              [`${mergedClsPrefix}-date-panel-date--excluded`]: !dateItem.inCurrentMonth,
              [`${mergedClsPrefix}-date-panel-date--disabled`]: this.mergedIsDateDisabled(dateItem.ts)
            }
          ],
          onClick: () => this.handleDateClick(dateItem)
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-date__trigger`
        }), dateItem.dateObject.date, dateItem.isCurrentDate ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-date__sup`
        }) : null)))), this.datePickerSlots.footer ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-footer`
        }, this.datePickerSlots.footer()) : null, this.actions?.length || shortcuts ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-actions`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-actions__prefix`
        }, shortcuts && Object.keys(shortcuts).map((key) => {
          const shortcut = shortcuts[key];
          return Array.isArray(shortcut) ? null : /* @__PURE__ */ React.createElement(XButton, {
            size: "tiny",
            onMouseenter: () => {
              this.handleSingleShortcutMouseenter(shortcut);
            },
            onClick: () => {
              this.handleSingleShortcutClick(shortcut);
            },
            onMouseleave: () => {
              this.handleShortcutMouseleave();
            }
          }, { default: () => key });
        })), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-actions__suffix`
        }, this.actions?.includes("clear") ? /* @__PURE__ */ React.createElement(NButton, {
          theme: mergedTheme.peers.Button,
          themeOverrides: mergedTheme.peerOverrides.Button,
          size: "tiny",
          onClick: this.clearSelectedDateTime
        }, { default: () => this.locale.clear }) : null, this.actions?.includes("now") ? /* @__PURE__ */ React.createElement(NButton, {
          theme: mergedTheme.peers.Button,
          themeOverrides: mergedTheme.peerOverrides.Button,
          size: "tiny",
          onClick: this.handleNowClick
        }, { default: () => this.locale.now }) : null, this.actions?.includes("confirm") ? /* @__PURE__ */ React.createElement(NButton, {
          theme: mergedTheme.peers.Button,
          themeOverrides: mergedTheme.peerOverrides.Button,
          size: "tiny",
          type: "primary",
          disabled: this.isDateInvalid,
          onClick: this.handleConfirmClick
        }, { default: () => this.locale.confirm }) : null)) : null, /* @__PURE__ */ React.createElement(FocusDetector, {
          onFocus: this.handleFocusDetectorFocus
        }));
      }
    });

    const useDualCalendarProps = { ...usePanelCommonProps,
      defaultCalendarStartTime: Number,
      defaultCalendarEndTime: Number,
      bindCalendarMonths: Boolean,
      actions: {
        type: Array,
        default: () => ["clear", "confirm"]
      }
    };

    function useDualCalendar(props, type) {
      const {
        isDateDisabledRef,
        isStartHourDisabledRef,
        isEndHourDisabledRef,
        isStartMinuteDisabledRef,
        isEndMinuteDisabledRef,
        isStartSecondDisabledRef,
        isEndSecondDisabledRef,
        isStartDateInvalidRef,
        isEndDateInvalidRef,
        isStartTimeInvalidRef,
        isEndTimeInvalidRef,
        isStartValueInvalidRef,
        isEndValueInvalidRef,
        isRangeInvalidRef,
        localeRef,
        rangesRef,
        closeOnSelectRef,
        updateValueOnCloseRef,
        firstDayOfWeekRef,
        datePickerSlots
      } = vue.inject(datePickerInjectionKey);
      const validation = {
        isDateDisabled: isDateDisabledRef,
        isStartHourDisabled: isStartHourDisabledRef,
        isEndHourDisabled: isEndHourDisabledRef,
        isStartMinuteDisabled: isStartMinuteDisabledRef,
        isEndMinuteDisabled: isEndMinuteDisabledRef,
        isStartSecondDisabled: isStartSecondDisabledRef,
        isEndSecondDisabled: isEndSecondDisabledRef,
        isStartDateInvalid: isStartDateInvalidRef,
        isEndDateInvalid: isEndDateInvalidRef,
        isStartTimeInvalid: isStartTimeInvalidRef,
        isEndTimeInvalid: isEndTimeInvalidRef,
        isStartValueInvalid: isStartValueInvalidRef,
        isEndValueInvalid: isEndValueInvalidRef,
        isRangeInvalid: isRangeInvalidRef
      };
      const panelCommon = usePanelCommon(props);
      const startDatesElRef = vue.ref(null);
      const endDatesElRef = vue.ref(null);
      const startYearScrollbarRef = vue.ref(null);
      const endYearScrollbarRef = vue.ref(null);
      const startYearVlRef = vue.ref(null);
      const endYearVlRef = vue.ref(null);
      const startMonthScrollbarRef = vue.ref(null);
      const endMonthScrollbarRef = vue.ref(null);
      const {
        value
      } = props;
      const defaultCalendarStartTime = props.defaultCalendarStartTime ?? (Array.isArray(value) && typeof value[0] === "number" ? value[0] : Date.now());
      const startCalendarDateTimeRef = vue.ref(defaultCalendarStartTime);
      const endCalendarDateTimeRef = vue.ref(props.defaultCalendarEndTime ?? (Array.isArray(value) && typeof value[1] === "number" ? value[1] : getTime(addMonths(defaultCalendarStartTime, 1))));
      adjustCalendarTimes(true);
      const nowRef = vue.ref(Date.now());
      const isSelectingRef = vue.ref(false);
      const memorizedStartDateTimeRef = vue.ref(0);
      const mergedDateFormatRef = vue.computed(() => props.dateFormat || localeRef.value.dateFormat);
      const startDateInput = vue.ref(Array.isArray(value) ? format$4(value[0], mergedDateFormatRef.value, panelCommon.dateFnsOptions.value) : "");
      const endDateInputRef = vue.ref(Array.isArray(value) ? format$4(value[1], mergedDateFormatRef.value, panelCommon.dateFnsOptions.value) : "");
      const selectingPhaseRef = vue.computed(() => {
        if (isSelectingRef.value) return "end";else return "start";
      });
      const startDateArrayRef = vue.computed(() => {
        return dateArray(startCalendarDateTimeRef.value, props.value, nowRef.value, firstDayOfWeekRef.value ?? localeRef.value.firstDayOfWeek);
      });
      const endDateArrayRef = vue.computed(() => {
        return dateArray(endCalendarDateTimeRef.value, props.value, nowRef.value, firstDayOfWeekRef.value ?? localeRef.value.firstDayOfWeek);
      });
      const weekdaysRef = vue.computed(() => {
        return startDateArrayRef.value.slice(0, 7).map(dateItem => {
          const {
            ts
          } = dateItem;
          return format$4(ts, localeRef.value.dayFormat, panelCommon.dateFnsOptions.value);
        });
      });
      const startCalendarMonthRef = vue.computed(() => {
        return format$4(startCalendarDateTimeRef.value, localeRef.value.monthFormat, panelCommon.dateFnsOptions.value);
      });
      const endCalendarMonthRef = vue.computed(() => {
        return format$4(endCalendarDateTimeRef.value, localeRef.value.monthFormat, panelCommon.dateFnsOptions.value);
      });
      const startCalendarYearRef = vue.computed(() => {
        return format$4(startCalendarDateTimeRef.value, localeRef.value.yearFormat, panelCommon.dateFnsOptions.value);
      });
      const endCalendarYearRef = vue.computed(() => {
        return format$4(endCalendarDateTimeRef.value, localeRef.value.yearFormat, panelCommon.dateFnsOptions.value);
      });
      const startTimeValueRef = vue.computed(() => {
        const {
          value: value2
        } = props;
        if (Array.isArray(value2)) return value2[0];
        return null;
      });
      const endTimeValueRef = vue.computed(() => {
        const {
          value: value2
        } = props;
        if (Array.isArray(value2)) return value2[1];
        return null;
      });
      const shortcutsRef = vue.computed(() => {
        const {
          shortcuts
        } = props;
        return shortcuts || rangesRef.value;
      });
      const startYearArrayRef = vue.computed(() => {
        return yearArray(pluckValueFromRange(props.value, "start"), nowRef.value);
      });
      const endYearArrayRef = vue.computed(() => {
        return yearArray(pluckValueFromRange(props.value, "end"), nowRef.value);
      });
      const startQuarterArrayRef = vue.computed(() => {
        const startValue = pluckValueFromRange(props.value, "start");
        return quarterArray(startValue ?? Date.now(), startValue, nowRef.value);
      });
      const endQuarterArrayRef = vue.computed(() => {
        const endValue = pluckValueFromRange(props.value, "end");
        return quarterArray(endValue ?? Date.now(), endValue, nowRef.value);
      });
      const startMonthArrayRef = vue.computed(() => {
        const startValue = pluckValueFromRange(props.value, "start");
        return monthArray(startValue ?? Date.now(), startValue, nowRef.value);
      });
      const endMonthArrayRef = vue.computed(() => {
        const endValue = pluckValueFromRange(props.value, "end");
        return monthArray(endValue ?? Date.now(), endValue, nowRef.value);
      });
      vue.watch(vue.computed(() => props.value), value2 => {
        if (value2 !== null && Array.isArray(value2)) {
          const [startMoment, endMoment] = value2;
          startDateInput.value = format$4(startMoment, mergedDateFormatRef.value, panelCommon.dateFnsOptions.value);
          endDateInputRef.value = format$4(endMoment, mergedDateFormatRef.value, panelCommon.dateFnsOptions.value);

          if (!isSelectingRef.value) {
            syncCalendarTimeWithValue(value2);
          }
        } else {
          startDateInput.value = "";
          endDateInputRef.value = "";
        }
      });

      function handleCalendarChange(value2, oldValue) {
        if (type === "daterange" || type === "datetimerange") {
          if (getYear(value2) !== getYear(oldValue) || getMonth(value2) !== getMonth(oldValue)) {
            panelCommon.disableTransitionOneTick();
          }
        }
      }

      vue.watch(startCalendarDateTimeRef, handleCalendarChange);
      vue.watch(endCalendarDateTimeRef, handleCalendarChange);

      function adjustCalendarTimes(byStartCalendarTime) {
        const startTime = startOfMonth(startCalendarDateTimeRef.value);
        const endTime = startOfMonth(endCalendarDateTimeRef.value);

        if (props.bindCalendarMonths || startTime >= endTime) {
          if (byStartCalendarTime) {
            endCalendarDateTimeRef.value = getTime(addMonths(startTime, 1));
          } else {
            startCalendarDateTimeRef.value = getTime(addMonths(endTime, -1));
          }
        }
      }

      function startCalendarNextYear() {
        startCalendarDateTimeRef.value = getTime(addMonths(startCalendarDateTimeRef.value, 12));
        adjustCalendarTimes(true);
      }

      function startCalendarPrevYear() {
        startCalendarDateTimeRef.value = getTime(addMonths(startCalendarDateTimeRef.value, -12));
        adjustCalendarTimes(true);
      }

      function startCalendarNextMonth() {
        startCalendarDateTimeRef.value = getTime(addMonths(startCalendarDateTimeRef.value, 1));
        adjustCalendarTimes(true);
      }

      function startCalendarPrevMonth() {
        startCalendarDateTimeRef.value = getTime(addMonths(startCalendarDateTimeRef.value, -1));
        adjustCalendarTimes(true);
      }

      function endCalendarNextYear() {
        endCalendarDateTimeRef.value = getTime(addMonths(endCalendarDateTimeRef.value, 12));
        adjustCalendarTimes(false);
      }

      function endCalendarPrevYear() {
        endCalendarDateTimeRef.value = getTime(addMonths(endCalendarDateTimeRef.value, -12));
        adjustCalendarTimes(false);
      }

      function endCalendarNextMonth() {
        endCalendarDateTimeRef.value = getTime(addMonths(endCalendarDateTimeRef.value, 1));
        adjustCalendarTimes(false);
      }

      function endCalendarPrevMonth() {
        endCalendarDateTimeRef.value = getTime(addMonths(endCalendarDateTimeRef.value, -1));
        adjustCalendarTimes(false);
      }

      function onUpdateStartCalendarValue(value2) {
        startCalendarDateTimeRef.value = value2;
        adjustCalendarTimes(true);
      }

      function onUpdateEndCalendarValue(value2) {
        endCalendarDateTimeRef.value = value2;
        adjustCalendarTimes(false);
      }

      function mergedIsDateDisabled(ts) {
        const isDateDisabled = isDateDisabledRef.value;
        if (!isDateDisabled) return false;
        if (!Array.isArray(props.value)) return isDateDisabled(ts, "start", null);

        if (selectingPhaseRef.value === "start") {
          return isDateDisabled(ts, "start", null);
        } else {
          const {
            value: memorizedStartDateTime
          } = memorizedStartDateTimeRef;

          if (ts < memorizedStartDateTimeRef.value) {
            return isDateDisabled(ts, "start", [memorizedStartDateTime, memorizedStartDateTime]);
          } else {
            return isDateDisabled(ts, "end", [memorizedStartDateTime, memorizedStartDateTime]);
          }
        }
      }

      function syncCalendarTimeWithValue(value2) {
        if (value2 === null) return;
        const [startMoment, endMoment] = value2;
        startCalendarDateTimeRef.value = startMoment;

        if (startOfMonth(endMoment) <= startOfMonth(startMoment)) {
          endCalendarDateTimeRef.value = getTime(startOfMonth(addMonths(startMoment, 1)));
        } else {
          endCalendarDateTimeRef.value = getTime(startOfMonth(endMoment));
        }
      }

      function handleDateClick(dateItem) {
        if (!isSelectingRef.value) {
          isSelectingRef.value = true;
          memorizedStartDateTimeRef.value = dateItem.ts;
          changeStartEndTime(dateItem.ts, dateItem.ts, "done");
        } else {
          isSelectingRef.value = false;
          const {
            value: value2
          } = props;

          if (props.panel && Array.isArray(value2)) {
            changeStartEndTime(value2[0], value2[1], "done");
          } else {
            if (closeOnSelectRef.value && type === "daterange") {
              if (updateValueOnCloseRef.value) {
                closeCalendar();
              } else {
                handleConfirmClick();
              }
            }
          }
        }
      }

      function handleDateMouseEnter(dateItem) {
        if (isSelectingRef.value) {
          if (mergedIsDateDisabled(dateItem.ts)) return;

          if (dateItem.ts >= memorizedStartDateTimeRef.value) {
            changeStartEndTime(memorizedStartDateTimeRef.value, dateItem.ts, "wipPreview");
          } else {
            changeStartEndTime(dateItem.ts, memorizedStartDateTimeRef.value, "wipPreview");
          }
        }
      }

      function handleConfirmClick() {
        if (isRangeInvalidRef.value) {
          return;
        }

        panelCommon.doConfirm();
        closeCalendar();
      }

      function closeCalendar() {
        isSelectingRef.value = false;

        if (props.active) {
          panelCommon.doClose();
        }
      }

      function changeStartDateTime(time) {
        if (typeof time !== "number") {
          time = getTime(time);
        }

        if (props.value === null) {
          panelCommon.doUpdateValue([time, time], props.panel);
        } else if (Array.isArray(props.value)) {
          panelCommon.doUpdateValue([time, Math.max(props.value[1], time)], props.panel);
        }
      }

      function changeEndDateTime(time) {
        if (typeof time !== "number") {
          time = getTime(time);
        }

        if (props.value === null) {
          panelCommon.doUpdateValue([time, time], props.panel);
        } else if (Array.isArray(props.value)) {
          panelCommon.doUpdateValue([Math.min(props.value[0], time), time], props.panel);
        }
      }

      function changeStartEndTime(startTime, endTime, source) {
        if (typeof startTime !== "number") {
          startTime = getTime(startTime);
        }

        if (source !== "shortcutPreview") {
          let startDefaultTime;
          let endDefaultTime;

          if (type === "datetimerange") {
            const {
              defaultTime
            } = props;

            if (Array.isArray(defaultTime)) {
              startDefaultTime = getDefaultTime(defaultTime[0]);
              endDefaultTime = getDefaultTime(defaultTime[1]);
            } else {
              startDefaultTime = getDefaultTime(defaultTime);
              endDefaultTime = startDefaultTime;
            }
          }

          if (startDefaultTime) {
            startTime = getTime(set(startTime, startDefaultTime));
          }

          if (endDefaultTime) {
            endTime = getTime(set(endTime, endDefaultTime));
          }
        }

        panelCommon.doUpdateValue([startTime, endTime], props.panel && source === "done");
      }

      function sanitizeValue(datetime) {
        if (type === "datetimerange") {
          return getTime(startOfSecond(datetime));
        } else if (type === "monthrange") {
          return getTime(startOfMonth(datetime));
        } else {
          return getTime(startOfDay(datetime));
        }
      }

      function handleStartDateInput(value2) {
        const date = strictParse(value2, mergedDateFormatRef.value, new Date(), panelCommon.dateFnsOptions.value);

        if (isValid$1(date)) {
          if (!props.value) {
            const newValue = set(new Date(), {
              year: getYear(date),
              month: getMonth(date),
              date: getDate(date)
            });
            changeStartDateTime(sanitizeValue(getTime(newValue)));
          } else if (Array.isArray(props.value)) {
            const newValue = set(props.value[0], {
              year: getYear(date),
              month: getMonth(date),
              date: getDate(date)
            });
            changeStartDateTime(sanitizeValue(getTime(newValue)));
          }
        } else {
          startDateInput.value = value2;
        }
      }

      function handleEndDateInput(value2) {
        const date = strictParse(value2, mergedDateFormatRef.value, new Date(), panelCommon.dateFnsOptions.value);

        if (isValid$1(date)) {
          if (props.value === null) {
            const newValue = set(new Date(), {
              year: getYear(date),
              month: getMonth(date),
              date: getDate(date)
            });
            changeEndDateTime(sanitizeValue(getTime(newValue)));
          } else if (Array.isArray(props.value)) {
            const newValue = set(props.value[1], {
              year: getYear(date),
              month: getMonth(date),
              date: getDate(date)
            });
            changeEndDateTime(sanitizeValue(getTime(newValue)));
          }
        } else {
          endDateInputRef.value = value2;
        }
      }

      function handleStartDateInputBlur() {
        const date = strictParse(startDateInput.value, mergedDateFormatRef.value, new Date(), panelCommon.dateFnsOptions.value);
        const {
          value: value2
        } = props;

        if (isValid$1(date)) {
          if (value2 === null) {
            const newValue = set(new Date(), {
              year: getYear(date),
              month: getMonth(date),
              date: getDate(date)
            });
            changeStartDateTime(sanitizeValue(getTime(newValue)));
          } else if (Array.isArray(value2)) {
            const newValue = set(value2[0], {
              year: getYear(date),
              month: getMonth(date),
              date: getDate(date)
            });
            changeStartDateTime(sanitizeValue(getTime(newValue)));
          }
        } else {
          refreshDisplayDateString();
        }
      }

      function handleEndDateInputBlur() {
        const date = strictParse(endDateInputRef.value, mergedDateFormatRef.value, new Date(), panelCommon.dateFnsOptions.value);
        const {
          value: value2
        } = props;

        if (isValid$1(date)) {
          if (value2 === null) {
            const newValue = set(new Date(), {
              year: getYear(date),
              month: getMonth(date),
              date: getDate(date)
            });
            changeEndDateTime(sanitizeValue(getTime(newValue)));
          } else if (Array.isArray(value2)) {
            const newValue = set(value2[1], {
              year: getYear(date),
              month: getMonth(date),
              date: getDate(date)
            });
            changeEndDateTime(sanitizeValue(getTime(newValue)));
          }
        } else {
          refreshDisplayDateString();
        }
      }

      function refreshDisplayDateString(times) {
        const {
          value: value2
        } = props;

        if (value2 === null || !Array.isArray(value2)) {
          startDateInput.value = "";
          endDateInputRef.value = "";
          return;
        }

        if (times === void 0) {
          times = value2;
        }

        startDateInput.value = format$4(times[0], mergedDateFormatRef.value, panelCommon.dateFnsOptions.value);
        endDateInputRef.value = format$4(times[1], mergedDateFormatRef.value, panelCommon.dateFnsOptions.value);
      }

      function handleStartTimePickerChange(value2) {
        if (value2 === null) return;
        changeStartDateTime(value2);
      }

      function handleEndTimePickerChange(value2) {
        if (value2 === null) return;
        changeEndDateTime(value2);
      }

      function handleRangeShortcutMouseenter(shortcut) {
        panelCommon.cachePendingValue();
        const shortcutValue = panelCommon.getShortcutValue(shortcut);
        if (!Array.isArray(shortcutValue)) return;
        changeStartEndTime(shortcutValue[0], shortcutValue[1], "shortcutPreview");
      }

      function handleRangeShortcutClick(shortcut) {
        const shortcutValue = panelCommon.getShortcutValue(shortcut);
        if (!Array.isArray(shortcutValue)) return;
        changeStartEndTime(shortcutValue[0], shortcutValue[1], "done");
        panelCommon.clearPendingValue();
        handleConfirmClick();
      }

      function justifyColumnsScrollState(value2, type2) {
        const mergedValue = value2 === void 0 ? props.value : value2;

        if (value2 === void 0 || type2 === "start") {
          if (startMonthScrollbarRef.value) {
            const monthIndex = !Array.isArray(mergedValue) ? getMonth(Date.now()) : getMonth(mergedValue[0]);
            startMonthScrollbarRef.value.scrollTo({
              debounce: false,
              index: monthIndex,
              elSize: MONTH_ITEM_HEIGHT
            });
          }

          if (startYearVlRef.value) {
            const yearIndex = (!Array.isArray(mergedValue) ? getYear(Date.now()) : getYear(mergedValue[0])) - START_YEAR;
            startYearVlRef.value.scrollTo({
              index: yearIndex,
              debounce: false
            });
          }
        }

        if (value2 === void 0 || type2 === "end") {
          if (endMonthScrollbarRef.value) {
            const monthIndex = !Array.isArray(mergedValue) ? getMonth(Date.now()) : getMonth(mergedValue[1]);
            endMonthScrollbarRef.value.scrollTo({
              debounce: false,
              index: monthIndex,
              elSize: MONTH_ITEM_HEIGHT
            });
          }

          if (endYearVlRef.value) {
            const yearIndex = (!Array.isArray(mergedValue) ? getYear(Date.now()) : getYear(mergedValue[1])) - START_YEAR;
            endYearVlRef.value.scrollTo({
              index: yearIndex,
              debounce: false
            });
          }
        }
      }

      function handleColItemClick(dateItem, clickType) {
        const {
          value: value2
        } = props;
        const noCurrentValue = !Array.isArray(value2);
        const itemTs = dateItem.type === "year" && type !== "yearrange" ? noCurrentValue ? set(dateItem.ts, {
          month: getMonth(type === "quarterrange" ? startOfQuarter(new Date()) : new Date())
        }).valueOf() : set(dateItem.ts, {
          month: getMonth(type === "quarterrange" ? startOfQuarter(value2[clickType === "start" ? 0 : 1]) : value2[clickType === "start" ? 0 : 1])
        }).valueOf() : dateItem.ts;

        if (noCurrentValue) {
          const partialValue = sanitizeValue(itemTs);
          const nextValue2 = [partialValue, partialValue];
          panelCommon.doUpdateValue(nextValue2, props.panel);
          justifyColumnsScrollState(nextValue2, "start");
          justifyColumnsScrollState(nextValue2, "end");
          panelCommon.disableTransitionOneTick();
          return;
        }

        const nextValue = [value2[0], value2[1]];
        let otherPartsChanged = false;

        if (clickType === "start") {
          nextValue[0] = sanitizeValue(itemTs);

          if (nextValue[0] > nextValue[1]) {
            nextValue[1] = nextValue[0];
            otherPartsChanged = true;
          }
        } else {
          nextValue[1] = sanitizeValue(itemTs);

          if (nextValue[0] > nextValue[1]) {
            nextValue[0] = nextValue[1];
            otherPartsChanged = true;
          }
        }

        panelCommon.doUpdateValue(nextValue, props.panel);

        switch (type) {
          case "monthrange":
          case "quarterrange":
            panelCommon.disableTransitionOneTick();

            if (otherPartsChanged) {
              justifyColumnsScrollState(nextValue, "start");
              justifyColumnsScrollState(nextValue, "end");
            } else {
              justifyColumnsScrollState(nextValue, clickType);
            }

            break;

          case "yearrange":
            panelCommon.disableTransitionOneTick();
            justifyColumnsScrollState(nextValue, "start");
            justifyColumnsScrollState(nextValue, "end");
        }
      }

      function handleStartYearVlScroll() {
        var _startYearScrollbarRe;

        (_startYearScrollbarRe = startYearScrollbarRef.value) === null || _startYearScrollbarRe === void 0 ? void 0 : _startYearScrollbarRe.sync();
      }

      function handleEndYearVlScroll() {
        var _endYearScrollbarRef$;

        (_endYearScrollbarRef$ = endYearScrollbarRef.value) === null || _endYearScrollbarRef$ === void 0 ? void 0 : _endYearScrollbarRef$.sync();
      }

      function virtualListContainer(type2) {
        if (type2 === "start") {
          var _startYearVlRef$value;

          return (_startYearVlRef$value = startYearVlRef.value) === null || _startYearVlRef$value === void 0 ? void 0 : _startYearVlRef$value.listElRef;
        } else {
          var _endYearVlRef$value;

          return (_endYearVlRef$value = endYearVlRef.value) === null || _endYearVlRef$value === void 0 ? void 0 : _endYearVlRef$value.listElRef;
        }
      }

      function virtualListContent(type2) {
        if (type2 === "start") {
          var _startYearVlRef$value2;

          return (_startYearVlRef$value2 = startYearVlRef.value) === null || _startYearVlRef$value2 === void 0 ? void 0 : _startYearVlRef$value2.itemsElRef;
        } else {
          var _endYearVlRef$value2;

          return (_endYearVlRef$value2 = endYearVlRef.value) === null || _endYearVlRef$value2 === void 0 ? void 0 : _endYearVlRef$value2.itemsElRef;
        }
      }

      const childComponentRefs = {
        startYearVlRef,
        endYearVlRef,
        startMonthScrollbarRef,
        endMonthScrollbarRef,
        startYearScrollbarRef,
        endYearScrollbarRef
      };
      return {
        startDatesElRef,
        endDatesElRef,
        handleDateClick,
        handleColItemClick,
        handleDateMouseEnter,
        handleConfirmClick,
        startCalendarPrevYear,
        startCalendarPrevMonth,
        startCalendarNextYear,
        startCalendarNextMonth,
        endCalendarPrevYear,
        endCalendarPrevMonth,
        endCalendarNextMonth,
        endCalendarNextYear,
        mergedIsDateDisabled,
        changeStartEndTime,
        ranges: rangesRef,
        startCalendarMonth: startCalendarMonthRef,
        startCalendarYear: startCalendarYearRef,
        endCalendarMonth: endCalendarMonthRef,
        endCalendarYear: endCalendarYearRef,
        weekdays: weekdaysRef,
        startDateArray: startDateArrayRef,
        endDateArray: endDateArrayRef,
        startYearArray: startYearArrayRef,
        startMonthArray: startMonthArrayRef,
        startQuarterArray: startQuarterArrayRef,
        endYearArray: endYearArrayRef,
        endMonthArray: endMonthArrayRef,
        endQuarterArray: endQuarterArrayRef,
        isSelecting: isSelectingRef,
        handleRangeShortcutMouseenter,
        handleRangeShortcutClick,
        ...panelCommon,
        ...validation,
        ...childComponentRefs,
        startDateDisplayString: startDateInput,
        endDateInput: endDateInputRef,
        timePickerSize: panelCommon.timePickerSize,
        startTimeValue: startTimeValueRef,
        endTimeValue: endTimeValueRef,
        datePickerSlots,
        shortcuts: shortcutsRef,
        startCalendarDateTime: startCalendarDateTimeRef,
        endCalendarDateTime: endCalendarDateTimeRef,
        justifyColumnsScrollState,
        handleFocusDetectorFocus: panelCommon.handleFocusDetectorFocus,
        handleStartTimePickerChange,
        handleEndTimePickerChange,
        handleStartDateInput,
        handleStartDateInputBlur,
        handleEndDateInput,
        handleEndDateInputBlur,
        handleStartYearVlScroll,
        handleEndYearVlScroll,
        virtualListContainer,
        virtualListContent,
        onUpdateStartCalendarValue,
        onUpdateEndCalendarValue
      };
    }

    var DatetimerangePanel = vue.defineComponent({
      name: "DateTimeRangePanel",
      props: useDualCalendarProps,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.actions?.includes("now")) {
              warnOnce(
                "date-picker",
                "The `now` action is not supported for n-date-picker of `datetimerange` type"
              );
            }
          });
        }
        return useDualCalendar(props, "datetimerange");
      },
      render() {
        const {
          mergedClsPrefix,
          mergedTheme,
          shortcuts,
          timePickerProps,
          onRender
        } = this;
        onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          ref: "selfRef",
          tabindex: 0,
          class: [
            `${mergedClsPrefix}-date-panel`,
            `${mergedClsPrefix}-date-panel--datetimerange`,
            !this.panel && `${mergedClsPrefix}-date-panel--shadow`,
            this.themeClass
          ],
          onKeydown: this.handlePanelKeyDown,
          onFocus: this.handlePanelFocus
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-header`
        }, /* @__PURE__ */ React.createElement(NInput, {
          value: this.startDateDisplayString,
          theme: mergedTheme.peers.Input,
          themeOverrides: mergedTheme.peerOverrides.Input,
          size: this.timePickerSize,
          stateful: false,
          class: `${mergedClsPrefix}-date-panel-date-input`,
          textDecoration: this.isStartValueInvalid ? "line-through" : "",
          placeholder: this.locale.selectDate,
          onBlur: this.handleStartDateInputBlur,
          onUpdateValue: this.handleStartDateInput
        }), /* @__PURE__ */ React.createElement(NTimePicker, {
          placeholder: this.locale.selectTime,
          format: this.timeFormat,
          size: this.timePickerSize,
          ...Array.isArray(timePickerProps) ? timePickerProps[0] : timePickerProps,
          value: this.startTimeValue,
          to: false,
          showIcon: false,
          disabled: this.isSelecting,
          theme: mergedTheme.peers.TimePicker,
          themeOverrides: mergedTheme.peerOverrides.TimePicker,
          stateful: false,
          isHourDisabled: this.isStartHourDisabled,
          isMinuteDisabled: this.isStartMinuteDisabled,
          isSecondDisabled: this.isStartSecondDisabled,
          onUpdateValue: this.handleStartTimePickerChange
        }), /* @__PURE__ */ React.createElement(NInput, {
          value: this.endDateInput,
          theme: mergedTheme.peers.Input,
          themeOverrides: mergedTheme.peerOverrides.Input,
          stateful: false,
          size: this.timePickerSize,
          class: `${mergedClsPrefix}-date-panel-date-input`,
          textDecoration: this.isEndValueInvalid ? "line-through" : "",
          placeholder: this.locale.selectDate,
          onBlur: this.handleEndDateInputBlur,
          onUpdateValue: this.handleEndDateInput
        }), /* @__PURE__ */ React.createElement(NTimePicker, {
          placeholder: this.locale.selectTime,
          format: this.timeFormat,
          size: this.timePickerSize,
          ...Array.isArray(timePickerProps) ? timePickerProps[1] : timePickerProps,
          disabled: this.isSelecting,
          showIcon: false,
          theme: mergedTheme.peers.TimePicker,
          themeOverrides: mergedTheme.peerOverrides.TimePicker,
          to: false,
          stateful: false,
          value: this.endTimeValue,
          isHourDisabled: this.isEndHourDisabled,
          isMinuteDisabled: this.isEndMinuteDisabled,
          isSecondDisabled: this.isEndSecondDisabled,
          onUpdateValue: this.handleEndTimePickerChange
        })), /* @__PURE__ */ React.createElement("div", {
          ref: "startDatesElRef",
          class: `${mergedClsPrefix}-date-panel-calendar ${mergedClsPrefix}-date-panel-calendar--start`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__fast-prev`,
          onClick: this.startCalendarPrevYear
        }, /* @__PURE__ */ React.createElement(FastBackwardIcon, null)), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__prev`,
          onClick: this.startCalendarPrevMonth
        }, /* @__PURE__ */ React.createElement(BackwardIcon, null)), /* @__PURE__ */ React.createElement(PanelHeader, {
          monthBeforeYear: this.locale.monthBeforeYear,
          value: this.startCalendarDateTime,
          onUpdateValue: this.onUpdateStartCalendarValue,
          mergedClsPrefix,
          calendarMonth: this.startCalendarMonth,
          calendarYear: this.startCalendarYear
        }), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__next`,
          onClick: this.startCalendarNextMonth
        }, /* @__PURE__ */ React.createElement(ForwardIcon, null)), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__fast-next`,
          onClick: this.startCalendarNextYear
        }, /* @__PURE__ */ React.createElement(FastForwardIcon, null))), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-weekdays`
        }, this.weekdays.map((weekday) => /* @__PURE__ */ React.createElement("div", {
          key: weekday,
          class: `${mergedClsPrefix}-date-panel-weekdays__day`
        }, weekday))), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel__divider`
        }), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-dates`
        }, this.startDateArray.map((dateItem, i) => {
          const disabled = this.mergedIsDateDisabled(dateItem.ts);
          return /* @__PURE__ */ React.createElement("div", {
            "data-n-date": true,
            key: i,
            class: [
              `${mergedClsPrefix}-date-panel-date`,
              {
                [`${mergedClsPrefix}-date-panel-date--excluded`]: !dateItem.inCurrentMonth,
                [`${mergedClsPrefix}-date-panel-date--current`]: dateItem.isCurrentDate,
                [`${mergedClsPrefix}-date-panel-date--selected`]: dateItem.selected,
                [`${mergedClsPrefix}-date-panel-date--covered`]: dateItem.inSpan,
                [`${mergedClsPrefix}-date-panel-date--start`]: dateItem.startOfSpan,
                [`${mergedClsPrefix}-date-panel-date--end`]: dateItem.endOfSpan,
                [`${mergedClsPrefix}-date-panel-date--disabled`]: disabled
              }
            ],
            onClick: disabled ? void 0 : () => this.handleDateClick(dateItem),
            onMouseenter: disabled ? void 0 : () => this.handleDateMouseEnter(dateItem)
          }, /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-date-panel-date__trigger`
          }), dateItem.dateObject.date, dateItem.isCurrentDate ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-date-panel-date__sup`
          }) : null);
        }))), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel__vertical-divider`
        }), /* @__PURE__ */ React.createElement("div", {
          ref: "endDatesElRef",
          class: `${mergedClsPrefix}-date-panel-calendar ${mergedClsPrefix}-date-panel-calendar--end`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__fast-prev`,
          onClick: this.endCalendarPrevYear
        }, /* @__PURE__ */ React.createElement(FastBackwardIcon, null)), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__prev`,
          onClick: this.endCalendarPrevMonth
        }, /* @__PURE__ */ React.createElement(BackwardIcon, null)), /* @__PURE__ */ React.createElement(PanelHeader, {
          monthBeforeYear: this.locale.monthBeforeYear,
          value: this.endCalendarDateTime,
          onUpdateValue: this.onUpdateEndCalendarValue,
          mergedClsPrefix,
          calendarMonth: this.endCalendarMonth,
          calendarYear: this.endCalendarYear
        }), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__next`,
          onClick: this.endCalendarNextMonth
        }, /* @__PURE__ */ React.createElement(ForwardIcon, null)), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__fast-next`,
          onClick: this.endCalendarNextYear
        }, /* @__PURE__ */ React.createElement(FastForwardIcon, null))), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-weekdays`
        }, this.weekdays.map((weekday) => /* @__PURE__ */ React.createElement("div", {
          key: weekday,
          class: `${mergedClsPrefix}-date-panel-weekdays__day`
        }, weekday))), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel__divider`
        }), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-dates`
        }, this.endDateArray.map((dateItem, i) => {
          const disabled = this.mergedIsDateDisabled(dateItem.ts);
          return /* @__PURE__ */ React.createElement("div", {
            "data-n-date": true,
            key: i,
            class: [
              `${mergedClsPrefix}-date-panel-date`,
              {
                [`${mergedClsPrefix}-date-panel-date--excluded`]: !dateItem.inCurrentMonth,
                [`${mergedClsPrefix}-date-panel-date--current`]: dateItem.isCurrentDate,
                [`${mergedClsPrefix}-date-panel-date--selected`]: dateItem.selected,
                [`${mergedClsPrefix}-date-panel-date--covered`]: dateItem.inSpan,
                [`${mergedClsPrefix}-date-panel-date--start`]: dateItem.startOfSpan,
                [`${mergedClsPrefix}-date-panel-date--end`]: dateItem.endOfSpan,
                [`${mergedClsPrefix}-date-panel-date--disabled`]: disabled
              }
            ],
            onClick: disabled ? void 0 : () => this.handleDateClick(dateItem),
            onMouseenter: disabled ? void 0 : () => this.handleDateMouseEnter(dateItem)
          }, /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-date-panel-date__trigger`
          }), dateItem.dateObject.date, dateItem.isCurrentDate ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-date-panel-date__sup`
          }) : null);
        }))), this.datePickerSlots.footer ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-footer`
        }, this.datePickerSlots.footer()) : null, this.actions?.length || shortcuts ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-actions`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-actions__prefix`
        }, shortcuts && Object.keys(shortcuts).map((key) => {
          const shortcut = shortcuts[key];
          return Array.isArray(shortcut) || typeof shortcut === "function" ? /* @__PURE__ */ React.createElement(XButton, {
            size: "tiny",
            onMouseenter: () => {
              this.handleRangeShortcutMouseenter(shortcut);
            },
            onClick: () => {
              this.handleRangeShortcutClick(shortcut);
            },
            onMouseleave: () => {
              this.handleShortcutMouseleave();
            }
          }, { default: () => key }) : null;
        })), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-actions__suffix`
        }, this.actions?.includes("clear") ? /* @__PURE__ */ React.createElement(NButton, {
          theme: mergedTheme.peers.Button,
          themeOverrides: mergedTheme.peerOverrides.Button,
          size: "tiny",
          onClick: this.handleClearClick
        }, { default: () => this.locale.clear }) : null, this.actions?.includes("confirm") ? /* @__PURE__ */ React.createElement(NButton, {
          theme: mergedTheme.peers.Button,
          themeOverrides: mergedTheme.peerOverrides.Button,
          size: "tiny",
          type: "primary",
          disabled: this.isRangeInvalid || this.isSelecting,
          onClick: this.handleConfirmClick
        }, { default: () => this.locale.confirm }) : null)) : null, /* @__PURE__ */ React.createElement(FocusDetector, {
          onFocus: this.handleFocusDetectorFocus
        }));
      }
    });

    var DatePanel = vue.defineComponent({
      name: "DatePanel",
      props: useCalendarProps,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.actions?.includes("confirm")) {
              warnOnce(
                "date-picker",
                "The `confirm` action is not supported for n-date-picker of `date` type"
              );
            }
          });
        }
        return useCalendar(props, "date");
      },
      render() {
        const { mergedClsPrefix, mergedTheme, shortcuts, onRender } = this;
        onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          ref: "selfRef",
          tabindex: 0,
          class: [
            `${mergedClsPrefix}-date-panel`,
            `${mergedClsPrefix}-date-panel--date`,
            !this.panel && `${mergedClsPrefix}-date-panel--shadow`,
            this.themeClass
          ],
          onFocus: this.handlePanelFocus,
          onKeydown: this.handlePanelKeyDown
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-calendar`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__fast-prev`,
          onClick: this.prevYear
        }, /* @__PURE__ */ React.createElement(FastBackwardIcon, null)), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__prev`,
          onClick: this.prevMonth
        }, /* @__PURE__ */ React.createElement(BackwardIcon, null)), /* @__PURE__ */ React.createElement(PanelHeader, {
          monthBeforeYear: this.locale.monthBeforeYear,
          value: this.calendarValue,
          onUpdateValue: this.onUpdateCalendarValue,
          mergedClsPrefix,
          calendarMonth: this.calendarMonth,
          calendarYear: this.calendarYear
        }), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__next`,
          onClick: this.nextMonth
        }, /* @__PURE__ */ React.createElement(ForwardIcon, null)), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__fast-next`,
          onClick: this.nextYear
        }, /* @__PURE__ */ React.createElement(FastForwardIcon, null))), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-weekdays`
        }, this.weekdays.map((weekday) => /* @__PURE__ */ React.createElement("div", {
          key: weekday,
          class: `${mergedClsPrefix}-date-panel-weekdays__day`
        }, weekday))), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-dates`
        }, this.dateArray.map((dateItem, i) => /* @__PURE__ */ React.createElement("div", {
          "data-n-date": true,
          key: i,
          class: [
            `${mergedClsPrefix}-date-panel-date`,
            {
              [`${mergedClsPrefix}-date-panel-date--current`]: dateItem.isCurrentDate,
              [`${mergedClsPrefix}-date-panel-date--selected`]: dateItem.selected,
              [`${mergedClsPrefix}-date-panel-date--excluded`]: !dateItem.inCurrentMonth,
              [`${mergedClsPrefix}-date-panel-date--disabled`]: this.mergedIsDateDisabled(dateItem.ts)
            }
          ],
          onClick: () => this.handleDateClick(dateItem)
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-date__trigger`
        }), dateItem.dateObject.date, dateItem.isCurrentDate ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-date__sup`
        }) : null)))), this.datePickerSlots.footer ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-footer`
        }, this.datePickerSlots.footer()) : null, this.actions?.length || shortcuts ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-actions`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-actions__prefix`
        }, shortcuts && Object.keys(shortcuts).map((key) => {
          const shortcut = shortcuts[key];
          return Array.isArray(shortcut) ? null : /* @__PURE__ */ React.createElement(XButton, {
            size: "tiny",
            onMouseenter: () => {
              this.handleSingleShortcutMouseenter(shortcut);
            },
            onClick: () => {
              this.handleSingleShortcutClick(shortcut);
            },
            onMouseleave: () => {
              this.handleShortcutMouseleave();
            }
          }, { default: () => key });
        })), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-actions__suffix`
        }, this.actions?.includes("clear") ? /* @__PURE__ */ React.createElement(NButton, {
          theme: mergedTheme.peers.Button,
          themeOverrides: mergedTheme.peerOverrides.Button,
          size: "tiny",
          onClick: this.handleClearClick
        }, { default: () => this.locale.clear }) : null, this.actions?.includes("now") ? /* @__PURE__ */ React.createElement(NButton, {
          theme: mergedTheme.peers.Button,
          themeOverrides: mergedTheme.peerOverrides.Button,
          size: "tiny",
          onClick: this.handleNowClick
        }, { default: () => this.locale.now }) : null)) : null, /* @__PURE__ */ React.createElement(FocusDetector, {
          onFocus: this.handleFocusDetectorFocus
        }));
      }
    });

    var DaterangePanel = vue.defineComponent({
      name: "DateRangePanel",
      props: useDualCalendarProps,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.actions?.includes("now")) {
              warnOnce(
                "date-picker",
                "The `now` action is not supported for n-date-picker of `daterange` type"
              );
            }
          });
        }
        return useDualCalendar(props, "daterange");
      },
      render() {
        const { mergedClsPrefix, mergedTheme, shortcuts, onRender } = this;
        onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          ref: "selfRef",
          tabindex: 0,
          class: [
            `${mergedClsPrefix}-date-panel`,
            `${mergedClsPrefix}-date-panel--daterange`,
            !this.panel && `${mergedClsPrefix}-date-panel--shadow`,
            this.themeClass
          ],
          onKeydown: this.handlePanelKeyDown,
          onFocus: this.handlePanelFocus
        }, /* @__PURE__ */ React.createElement("div", {
          ref: "startDatesElRef",
          class: `${mergedClsPrefix}-date-panel-calendar ${mergedClsPrefix}-date-panel-calendar--start`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__fast-prev`,
          onClick: this.startCalendarPrevYear
        }, /* @__PURE__ */ React.createElement(FastBackwardIcon, null)), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__prev`,
          onClick: this.startCalendarPrevMonth
        }, /* @__PURE__ */ React.createElement(BackwardIcon, null)), /* @__PURE__ */ React.createElement(PanelHeader, {
          monthBeforeYear: this.locale.monthBeforeYear,
          value: this.startCalendarDateTime,
          onUpdateValue: this.onUpdateStartCalendarValue,
          mergedClsPrefix,
          calendarMonth: this.startCalendarMonth,
          calendarYear: this.startCalendarYear
        }), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__next`,
          onClick: this.startCalendarNextMonth
        }, /* @__PURE__ */ React.createElement(ForwardIcon, null)), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__fast-next`,
          onClick: this.startCalendarNextYear
        }, /* @__PURE__ */ React.createElement(FastForwardIcon, null))), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-weekdays`
        }, this.weekdays.map((weekday) => /* @__PURE__ */ React.createElement("div", {
          key: weekday,
          class: `${mergedClsPrefix}-date-panel-weekdays__day`
        }, weekday))), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel__divider`
        }), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-dates`
        }, this.startDateArray.map((dateItem, i) => /* @__PURE__ */ React.createElement("div", {
          "data-n-date": true,
          key: i,
          class: [
            `${mergedClsPrefix}-date-panel-date`,
            {
              [`${mergedClsPrefix}-date-panel-date--excluded`]: !dateItem.inCurrentMonth,
              [`${mergedClsPrefix}-date-panel-date--current`]: dateItem.isCurrentDate,
              [`${mergedClsPrefix}-date-panel-date--selected`]: dateItem.selected,
              [`${mergedClsPrefix}-date-panel-date--covered`]: dateItem.inSpan,
              [`${mergedClsPrefix}-date-panel-date--start`]: dateItem.startOfSpan,
              [`${mergedClsPrefix}-date-panel-date--end`]: dateItem.endOfSpan,
              [`${mergedClsPrefix}-date-panel-date--disabled`]: this.mergedIsDateDisabled(dateItem.ts)
            }
          ],
          onClick: () => this.handleDateClick(dateItem),
          onMouseenter: () => this.handleDateMouseEnter(dateItem)
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-date__trigger`
        }), dateItem.dateObject.date, dateItem.isCurrentDate ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-date__sup`
        }) : null)))), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel__vertical-divider`
        }), /* @__PURE__ */ React.createElement("div", {
          ref: "endDatesElRef",
          class: `${mergedClsPrefix}-date-panel-calendar ${mergedClsPrefix}-date-panel-calendar--end`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__fast-prev`,
          onClick: this.endCalendarPrevYear
        }, /* @__PURE__ */ React.createElement(FastBackwardIcon, null)), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__prev`,
          onClick: this.endCalendarPrevMonth
        }, /* @__PURE__ */ React.createElement(BackwardIcon, null)), /* @__PURE__ */ React.createElement(PanelHeader, {
          monthBeforeYear: this.locale.monthBeforeYear,
          value: this.endCalendarDateTime,
          onUpdateValue: this.onUpdateEndCalendarValue,
          mergedClsPrefix,
          calendarMonth: this.endCalendarMonth,
          calendarYear: this.endCalendarYear
        }), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__next`,
          onClick: this.endCalendarNextMonth
        }, /* @__PURE__ */ React.createElement(ForwardIcon, null)), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month__fast-next`,
          onClick: this.endCalendarNextYear
        }, /* @__PURE__ */ React.createElement(FastForwardIcon, null))), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-weekdays`
        }, this.weekdays.map((weekday) => /* @__PURE__ */ React.createElement("div", {
          key: weekday,
          class: `${mergedClsPrefix}-date-panel-weekdays__day`
        }, weekday))), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel__divider`
        }), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-dates`
        }, this.endDateArray.map((dateItem, i) => /* @__PURE__ */ React.createElement("div", {
          "data-n-date": true,
          key: i,
          class: [
            `${mergedClsPrefix}-date-panel-date`,
            {
              [`${mergedClsPrefix}-date-panel-date--excluded`]: !dateItem.inCurrentMonth,
              [`${mergedClsPrefix}-date-panel-date--current`]: dateItem.isCurrentDate,
              [`${mergedClsPrefix}-date-panel-date--selected`]: dateItem.selected,
              [`${mergedClsPrefix}-date-panel-date--covered`]: dateItem.inSpan,
              [`${mergedClsPrefix}-date-panel-date--start`]: dateItem.startOfSpan,
              [`${mergedClsPrefix}-date-panel-date--end`]: dateItem.endOfSpan,
              [`${mergedClsPrefix}-date-panel-date--disabled`]: this.mergedIsDateDisabled(dateItem.ts)
            }
          ],
          onClick: () => this.handleDateClick(dateItem),
          onMouseenter: () => this.handleDateMouseEnter(dateItem)
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-date__trigger`
        }), dateItem.dateObject.date, dateItem.isCurrentDate ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-date__sup`
        }) : null)))), this.datePickerSlots.footer ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-footer`
        }, this.datePickerSlots.footer()) : null, this.actions?.length || shortcuts ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-actions`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-actions__prefix`
        }, shortcuts && Object.keys(shortcuts).map((key) => {
          const shortcut = shortcuts[key];
          return Array.isArray(shortcut) || typeof shortcut === "function" ? /* @__PURE__ */ React.createElement(XButton, {
            size: "tiny",
            onMouseenter: () => {
              this.handleRangeShortcutMouseenter(shortcut);
            },
            onClick: () => {
              this.handleRangeShortcutClick(shortcut);
            },
            onMouseleave: () => {
              this.handleShortcutMouseleave();
            }
          }, { default: () => key }) : null;
        })), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-actions__suffix`
        }, this.actions?.includes("clear") ? /* @__PURE__ */ React.createElement(NButton, {
          theme: mergedTheme.peers.Button,
          themeOverrides: mergedTheme.peerOverrides.Button,
          size: "tiny",
          onClick: this.handleClearClick
        }, { default: () => this.locale.clear }) : null, this.actions?.includes("confirm") ? /* @__PURE__ */ React.createElement(NButton, {
          theme: mergedTheme.peers.Button,
          themeOverrides: mergedTheme.peerOverrides.Button,
          size: "tiny",
          type: "primary",
          disabled: this.isRangeInvalid || this.isSelecting,
          onClick: this.handleConfirmClick
        }, { default: () => this.locale.confirm }) : null)) : null, /* @__PURE__ */ React.createElement(FocusDetector, {
          onFocus: this.handleFocusDetectorFocus
        }));
      }
    });

    var MonthRangePanel = vue.defineComponent({
      name: "MonthRangePanel",
      props: {
        ...useDualCalendarProps,
        type: {
          type: String,
          required: true
        }
      },
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.actions?.includes("now")) {
              warnOnce(
                "date-picker",
                `The \`now\` action is not supported for n-date-picker of ${props.type}type`
              );
            }
          });
        }
        const useCalendarRef = useDualCalendar(props, props.type);
        const renderItem = (item, i, mergedClsPrefix, type) => {
          const { handleColItemClick } = useCalendarRef;
          const disabled = false;
          return /* @__PURE__ */ React.createElement("div", {
            "data-n-date": true,
            key: i,
            class: [
              `${mergedClsPrefix}-date-panel-month-calendar__picker-col-item`,
              {
                [`${mergedClsPrefix}-date-panel-month-calendar__picker-col-item--current`]: item.isCurrent,
                [`${mergedClsPrefix}-date-panel-month-calendar__picker-col-item--selected`]: item.selected,
                [`${mergedClsPrefix}-date-panel-month-calendar__picker-col-item--disabled`]: disabled
              }
            ],
            onClick: () => {
              handleColItemClick(item, type);
            }
          }, item.type === "month" ? item.dateObject.month + 1 : item.type === "quarter" ? `Q${item.dateObject.quarter}` : item.dateObject.year);
        };
        vue.onMounted(() => {
          useCalendarRef.justifyColumnsScrollState();
        });
        return { ...useCalendarRef, renderItem };
      },
      render() {
        const { mergedClsPrefix, mergedTheme, shortcuts, type, renderItem } = this;
        return /* @__PURE__ */ React.createElement("div", {
          ref: "selfRef",
          tabindex: 0,
          class: [
            `${mergedClsPrefix}-date-panel`,
            `${mergedClsPrefix}-date-panel--daterange`,
            !this.panel && `${mergedClsPrefix}-date-panel--shadow`
          ],
          onKeydown: this.handlePanelKeyDown,
          onFocus: this.handlePanelFocus
        }, /* @__PURE__ */ React.createElement("div", {
          ref: "startDatesElRef",
          class: `${mergedClsPrefix}-date-panel-calendar ${mergedClsPrefix}-date-panel-calendar--start`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month-calendar`
        }, /* @__PURE__ */ React.createElement(NScrollbar, {
          ref: "startYearScrollbarRef",
          class: `${mergedClsPrefix}-date-panel-month-calendar__picker-col`,
          theme: mergedTheme.peers.Scrollbar,
          themeOverrides: mergedTheme.peerOverrides.Scrollbar,
          container: () => this.virtualListContainer("start"),
          content: () => this.virtualListContent("start"),
          horizontalRailStyle: { zIndex: 1 },
          verticalRailStyle: { zIndex: 1 }
        }, {
          default: () => /* @__PURE__ */ React.createElement(VVirtualList, {
            ref: "startYearVlRef",
            items: this.startYearArray,
            itemSize: MONTH_ITEM_HEIGHT,
            showScrollbar: false,
            keyField: "ts",
            onScroll: this.handleStartYearVlScroll,
            paddingBottom: 4
          }, {
            default: ({
              item,
              index
            }) => {
              return renderItem(item, index, mergedClsPrefix, "start");
            }
          })
        }), type === "monthrange" || type === "quarterrange" ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month-calendar__picker-col`
        }, /* @__PURE__ */ React.createElement(NScrollbar, {
          ref: "startMonthScrollbarRef",
          theme: mergedTheme.peers.Scrollbar,
          themeOverrides: mergedTheme.peerOverrides.Scrollbar
        }, {
          default: () => [
            (type === "monthrange" ? this.startMonthArray : this.startQuarterArray).map(
              (item, i) => renderItem(item, i, mergedClsPrefix, "start")
            ),
            type === "monthrange" && /* @__PURE__ */ React.createElement("div", {
              class: `${mergedClsPrefix}-date-panel-month-calendar__padding`
            })
          ]
        })) : null)), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel__vertical-divider`
        }), /* @__PURE__ */ React.createElement("div", {
          ref: "endDatesElRef",
          class: `${mergedClsPrefix}-date-panel-calendar ${mergedClsPrefix}-date-panel-calendar--end`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month-calendar`
        }, /* @__PURE__ */ React.createElement(NScrollbar, {
          ref: "endYearScrollbarRef",
          class: `${mergedClsPrefix}-date-panel-month-calendar__picker-col`,
          theme: mergedTheme.peers.Scrollbar,
          themeOverrides: mergedTheme.peerOverrides.Scrollbar,
          container: () => this.virtualListContainer("end"),
          content: () => this.virtualListContent("end"),
          horizontalRailStyle: { zIndex: 1 },
          verticalRailStyle: { zIndex: 1 }
        }, {
          default: () => /* @__PURE__ */ React.createElement(VVirtualList, {
            ref: "endYearVlRef",
            items: this.endYearArray,
            itemSize: MONTH_ITEM_HEIGHT,
            showScrollbar: false,
            keyField: "ts",
            onScroll: this.handleEndYearVlScroll,
            paddingBottom: 4
          }, {
            default: ({
              item,
              index
            }) => {
              return renderItem(item, index, mergedClsPrefix, "end");
            }
          })
        }), type === "monthrange" || type === "quarterrange" ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-month-calendar__picker-col`
        }, /* @__PURE__ */ React.createElement(NScrollbar, {
          ref: "endMonthScrollbarRef",
          theme: mergedTheme.peers.Scrollbar,
          themeOverrides: mergedTheme.peerOverrides.Scrollbar
        }, {
          default: () => [
            (type === "monthrange" ? this.endMonthArray : this.endQuarterArray).map(
              (item, i) => renderItem(item, i, mergedClsPrefix, "end")
            ),
            type === "monthrange" && /* @__PURE__ */ React.createElement("div", {
              class: `${mergedClsPrefix}-date-panel-month-calendar__padding`
            })
          ]
        })) : null)), this.datePickerSlots.footer ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-footer`
        }, vue.renderSlot(this.datePickerSlots, "footer")) : null, this.actions?.length || shortcuts ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-actions`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-actions__prefix`
        }, shortcuts && Object.keys(shortcuts).map((key) => {
          const shortcut = shortcuts[key];
          return Array.isArray(shortcut) || typeof shortcut === "function" ? /* @__PURE__ */ React.createElement(XButton, {
            size: "tiny",
            onMouseenter: () => {
              this.handleRangeShortcutMouseenter(shortcut);
            },
            onClick: () => {
              this.handleRangeShortcutClick(shortcut);
            },
            onMouseleave: () => {
              this.handleShortcutMouseleave();
            }
          }, { default: () => key }) : null;
        })), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-date-panel-actions__suffix`
        }, this.actions?.includes("clear") ? /* @__PURE__ */ React.createElement(XButton, {
          theme: mergedTheme.peers.Button,
          themeOverrides: mergedTheme.peerOverrides.Button,
          size: "tiny",
          onClick: this.handleClearClick
        }, { default: () => this.locale.clear }) : null, this.actions?.includes("confirm") ? /* @__PURE__ */ React.createElement(XButton, {
          theme: mergedTheme.peers.Button,
          themeOverrides: mergedTheme.peerOverrides.Button,
          size: "tiny",
          type: "primary",
          disabled: this.isRangeInvalid,
          onClick: this.handleConfirmClick
        }, { default: () => this.locale.confirm }) : null)) : null, /* @__PURE__ */ React.createElement(FocusDetector, {
          onFocus: this.handleFocusDetectorFocus
        }));
      }
    });

    var style$R = c$1([cB("date-picker", `
    position: relative;
    z-index: auto;
  `, [cB("date-picker-icon", `
      color: var(--n-icon-color-override);
      transition: color .3s var(--n-bezier);
    `), cB("icon", `
      color: var(--n-icon-color-override);
      transition: color .3s var(--n-bezier);
    `), cM("disabled", [cB("date-picker-icon", `
        color: var(--n-icon-color-disabled-override);
      `), cB("icon", `
        color: var(--n-icon-color-disabled-override);
      `)])]), cB("date-panel", `
    width: fit-content;
    outline: none;
    margin: 4px 0;
    display: grid;
    grid-template-columns: 0fr;
    border-radius: var(--n-panel-border-radius);
    background-color: var(--n-panel-color);
    color: var(--n-panel-text-color);
  `, [fadeInScaleUpTransition(), cM("shadow", `
      box-shadow: var(--n-panel-box-shadow);
    `), cB("date-panel-calendar", {
      padding: "var(--n-calendar-left-padding)",
      display: "grid",
      gridTemplateColumns: "1fr",
      gridArea: "left-calendar"
    }, [cM("end", {
      padding: "var(--n-calendar-right-padding)",
      gridArea: "right-calendar"
    })]), cB("date-panel-month-calendar", {
      display: "flex",
      gridArea: "left-calendar"
    }, [cE("picker-col", `
        min-width: var(--n-scroll-item-width);
        height: calc(var(--n-scroll-item-height) * 6);
        user-select: none;
        -webkit-user-select: none;
      `, [c$1("&:first-child", `
          min-width: calc(var(--n-scroll-item-width) + 4px);
        `, [cE("picker-col-item", [c$1("&::before", "left: 4px;")])]), cE("padding", `
          height: calc(var(--n-scroll-item-height) * 5)
        `)]), cE("picker-col-item", `
        z-index: 0;
        cursor: pointer;
        height: var(--n-scroll-item-height);
        box-sizing: border-box;
        padding-top: 4px;
        display: flex;
        align-items: center;
        justify-content: center;
        position: relative;
        transition: 
          color .3s var(--n-bezier),
          background-color .3s var(--n-bezier);
        background: #0000;
        color: var(--n-item-text-color);
      `, [c$1("&::before", `
          z-index: -1;
          content: "";
          position: absolute;
          left: 0;
          right: 4px;
          top: 4px;
          bottom: 0;
          border-radius: var(--n-scroll-item-border-radius);
          transition: 
            background-color .3s var(--n-bezier);
        `), cNotM("disabled", [c$1("&:hover::before", `
            background-color: var(--n-item-color-hover);
          `), cM("selected", `
            color: var(--n-item-color-active);
          `, [c$1("&::before", "background-color: var(--n-item-color-hover);")])]), cM("disabled", `
          color: var(--n-item-text-color-disabled);
          cursor: not-allowed;
        `, [cM("selected", [c$1("&::before", `
              background-color: var(--n-item-color-disabled);
            `)])])])]), cM("date", {
      gridTemplateAreas: `
        "left-calendar"
        "footer"
        "action"
      `
    }), cM("daterange", {
      gridTemplateAreas: `
        "left-calendar divider right-calendar"
        "footer footer footer"
        "action action action"
      `
    }), cM("datetime", {
      gridTemplateAreas: `
        "header"
        "left-calendar"
        "footer"
        "action"
      `
    }), cM("datetimerange", {
      gridTemplateAreas: `
        "header header header"
        "left-calendar divider right-calendar"
        "footer footer footer"
        "action action action"
      `
    }), cM("month", {
      gridTemplateAreas: `
        "left-calendar"
        "footer"
        "action"
      `
    }), cB("date-panel-footer", {
      gridArea: "footer"
    }), cB("date-panel-actions", {
      gridArea: "action"
    }), cB("date-panel-header", {
      gridArea: "header"
    }), cB("date-panel-header", `
      box-sizing: border-box;
      width: 100%;
      align-items: center;
      padding: var(--n-panel-header-padding);
      display: flex;
      justify-content: space-between;
      border-bottom: 1px solid var(--n-panel-header-divider-color);
    `, [c$1(">", [c$1("*:not(:last-child)", {
      marginRight: "10px"
    }), c$1("*", {
      flex: 1,
      width: 0
    }), cB("time-picker", {
      zIndex: 1
    })])]), cB("date-panel-month", `
      box-sizing: border-box;
      display: grid;
      grid-template-columns: var(--n-calendar-title-grid-template-columns);
      align-items: center;
      justify-items: center;
      padding: var(--n-calendar-title-padding);
      height: var(--n-calendar-title-height);
    `, [cE("prev, next, fast-prev, fast-next", `
        line-height: 0;
        cursor: pointer;
        width: var(--n-arrow-size);
        height: var(--n-arrow-size);
        color: var(--n-arrow-color);
      `), cE("month-year", `
        user-select: none;
        -webkit-user-select: none;
        flex-grow: 1;
        position: relative;
      `, [cE("text", `
          font-size: var(--n-calendar-title-font-size);
          line-height: var(--n-calendar-title-font-size);
          font-weight: var(--n-calendar-title-font-weight);
          padding: 6px 8px;
          text-align: center;
          color: var(--n-calendar-title-text-color);
          cursor: pointer;
          transition: background-color .3s var(--n-bezier);
          border-radius: var(--n-panel-border-radius);
        `, [cM("active", `
            background-color: var(--n-calendar-title-color-hover);
          `), c$1("&:hover", `
            background-color: var(--n-calendar-title-color-hover);
          `)])])]), cB("date-panel-weekdays", `
      display: grid;
      margin: auto;
      grid-template-columns: repeat(7, var(--n-item-cell-width));
      grid-template-rows: repeat(1, var(--n-item-cell-height));
      align-items: center;
      justify-items: center;
      margin-bottom: 4px;
      border-bottom: 1px solid var(--n-calendar-days-divider-color);
    `, [cE("day", `
        user-select: none;
        -webkit-user-select: none;
        line-height: 15px;
        width: var(--n-item-size);
        text-align: center;
        font-size: var(--n-calendar-days-font-size);
        color: var(--n-item-text-color);
      `)]), cB("date-panel-dates", `
      margin: auto;
      display: grid;
      grid-template-columns: repeat(7, var(--n-item-cell-width));
      grid-template-rows: repeat(6, var(--n-item-cell-height));
      align-items: center;
      justify-items: center;
      flex-wrap: wrap;
    `, [cB("date-panel-date", `
        user-select: none;
        -webkit-user-select: none;
        position: relative;
        width: var(--n-item-size);
        height: var(--n-item-size);
        line-height: var(--n-item-size);
        text-align: center;
        font-size: var(--n-item-font-size);
        border-radius: var(--n-item-border-radius);
        z-index: 0;
        cursor: pointer;
        transition:
          background-color .2s var(--n-bezier),
          color .2s var(--n-bezier);
      `, [cE("trigger", `
          position: absolute;
          left: calc(var(--n-item-size) / 2 - var(--n-item-cell-width) / 2);
          top: calc(var(--n-item-size) / 2 - var(--n-item-cell-height) / 2);
          width:  var(--n-item-cell-width);
          height:  var(--n-item-cell-height);
        `), cNotM("disabled", [cNotM("selected", [c$1("&:hover", {
      backgroundColor: "var(--n-item-color-hover)"
    })])]), cM("current", [cE("sup", `
            position: absolute;
            top: 2px;
            right: 2px;
            content: "";
            height: 4px;
            width: 4px;
            border-radius: 2px;
            background-color: var(--n-item-color-active);
            transition:
              background-color .2s var(--n-bezier);
          `)]), c$1("&::after", `
          content: "";
          z-index: -1;
          position: absolute;
          left: 0;
          right: 0;
          top: 0;
          bottom: 0;
          border-radius: inherit;
          transition: background-color .3s var(--n-bezier);
        `), cM("covered, start, end", [cNotM("excluded", [c$1("&::before", `
              content: "";
              z-index: -2;
              position: absolute;
              left: calc((var(--n-item-size) - var(--n-item-cell-width)) / 2);
              right: calc((var(--n-item-size) - var(--n-item-cell-width)) / 2);
              top: 0;
              bottom: 0;
              background-color: var(--n-item-color-included);
            `), c$1("&:nth-child(7n + 1)::before", {
      borderTopLeftRadius: "var(--n-item-border-radius)",
      borderBottomLeftRadius: "var(--n-item-border-radius)"
    }), c$1("&:nth-child(7n + 7)::before", {
      borderTopRightRadius: "var(--n-item-border-radius)",
      borderBottomRightRadius: "var(--n-item-border-radius)"
    })])]), cM("selected", {
      color: "var(--n-item-text-color-active)"
    }, [c$1("&::after", {
      backgroundColor: "var(--n-item-color-active)"
    }), cM("start", [c$1("&::before", {
      left: "50%"
    })]), cM("end", [c$1("&::before", {
      right: "50%"
    })]), cE("sup", {
      backgroundColor: "var(--n-panel-color)"
    })]), cM("excluded", {
      color: "var(--n-item-text-color-disabled)"
    }, [cM("selected", [c$1("&::after", {
      backgroundColor: "var(--n-item-color-disabled)"
    })])]), cM("disabled", {
      cursor: "not-allowed",
      color: "var(--n-item-text-color-disabled)"
    }, [cM("covered", [c$1("&::before", {
      backgroundColor: "var(--n-item-color-disabled)"
    })]), cM("selected", [c$1("&::before", {
      backgroundColor: "var(--n-item-color-disabled)"
    }), c$1("&::after", {
      backgroundColor: "var(--n-item-color-disabled)"
    })])])])]), cE("vertical-divider", `
      grid-area: divider;
      height: 100%;
      width: 1px;
      background-color: var(--n-calendar-divider-color);
    `), cB("date-panel-footer", {
      borderTop: "1px solid var(--n-panel-action-divider-color)",
      padding: "var(--n-panel-extra-footer-padding)"
    }), cB("date-panel-actions", `
      flex: 1;
      padding: var(--n-panel-action-padding);
      display: flex;
      align-items: center;
      justify-content: space-between;
      border-top: 1px solid var(--n-panel-action-divider-color);
    `, [cE("prefix, suffix", `
        display: flex;
        margin-bottom: -8px;
      `), cE("suffix", `
        align-self: flex-end;
      `), cE("prefix", `
        flex-wrap: wrap;
      `), cB("button", `
        margin-bottom: 8px;
      `, [c$1("&:not(:last-child)", `
          margin-right: 8px;
        `)])])]), c$1("[data-n-date].transition-disabled", {
      transition: "none !important"
    }, [c$1("&::before, &::after", {
      transition: "none !important"
    })])]);

    const datePickerProps = {
      ...useTheme.props,
      to: useAdjustedTo.propTo,
      bordered: {
        type: Boolean,
        default: void 0
      },
      clearable: Boolean,
      updateValueOnClose: Boolean,
      defaultValue: [Number, Array],
      defaultFormattedValue: [String, Array],
      defaultTime: [Number, String, Array],
      disabled: {
        type: Boolean,
        default: void 0
      },
      placement: {
        type: String,
        default: "bottom-start"
      },
      value: [Number, Array],
      formattedValue: [String, Array],
      size: String,
      type: {
        type: String,
        default: "date"
      },
      valueFormat: String,
      separator: String,
      placeholder: String,
      startPlaceholder: String,
      endPlaceholder: String,
      format: String,
      dateFormat: String,
      timeFormat: String,
      actions: Array,
      shortcuts: Object,
      isDateDisabled: Function,
      isTimeDisabled: Function,
      show: {
        type: Boolean,
        default: void 0
      },
      panel: Boolean,
      ranges: Object,
      firstDayOfWeek: Number,
      inputReadonly: Boolean,
      closeOnSelect: Boolean,
      status: String,
      timePickerProps: [Object, Array],
      onClear: Function,
      onConfirm: Function,
      defaultCalendarStartTime: Number,
      defaultCalendarEndTime: Number,
      bindCalendarMonths: Boolean,
      "onUpdate:show": [Function, Array],
      onUpdateShow: [Function, Array],
      "onUpdate:formattedValue": [Function, Array],
      onUpdateFormattedValue: [Function, Array],
      "onUpdate:value": [Function, Array],
      onUpdateValue: [Function, Array],
      onFocus: [Function, Array],
      onBlur: [Function, Array],
      onChange: [Function, Array]
    };
    var DatePicker = vue.defineComponent({
      name: "DatePicker",
      props: datePickerProps,
      setup(props, { slots }) {
        {
          vue.watchEffect(() => {
            if (props.onChange !== void 0) {
              warnOnce(
                "data-picker",
                "`on-change` is deprecated, please use `on-update:value` instead."
              );
            }
          });
        }
        const { localeRef, dateLocaleRef } = useLocale("DatePicker");
        const formItem = useFormItem(props);
        const { mergedSizeRef, mergedDisabledRef, mergedStatusRef } = formItem;
        const {
          mergedComponentPropsRef,
          mergedClsPrefixRef,
          mergedBorderedRef,
          namespaceRef,
          inlineThemeDisabled
        } = useConfig(props);
        const panelInstRef = vue.ref(null);
        const triggerElRef = vue.ref(null);
        const inputInstRef = vue.ref(null);
        const uncontrolledShowRef = vue.ref(false);
        const controlledShowRef = vue.toRef(props, "show");
        const mergedShowRef = useMergedState(controlledShowRef, uncontrolledShowRef);
        const dateFnsOptionsRef = vue.computed(() => {
          return {
            locale: dateLocaleRef.value.locale
          };
        });
        const mergedFormatRef = vue.computed(() => {
          const { format: format2 } = props;
          if (format2)
            return format2;
          switch (props.type) {
            case "date":
            case "daterange":
              return localeRef.value.dateFormat;
            case "datetime":
            case "datetimerange":
              return localeRef.value.dateTimeFormat;
            case "year":
            case "yearrange":
              return localeRef.value.yearTypeFormat;
            case "month":
            case "monthrange":
              return localeRef.value.monthTypeFormat;
            case "quarter":
            case "quarterrange":
              return localeRef.value.quarterFormat;
          }
        });
        const mergedValueFormatRef = vue.computed(() => {
          return props.valueFormat ?? mergedFormatRef.value;
        });
        function getTimestampValue(value) {
          if (value === null)
            return null;
          const { value: mergedValueFormat } = mergedValueFormatRef;
          const { value: dateFnsOptions } = dateFnsOptionsRef;
          if (Array.isArray(value)) {
            return [
              strictParse(
                value[0],
                mergedValueFormat,
                new Date(),
                dateFnsOptions
              ).getTime(),
              strictParse(
                value[1],
                mergedValueFormat,
                new Date(),
                dateFnsOptions
              ).getTime()
            ];
          }
          return strictParse(
            value,
            mergedValueFormat,
            new Date(),
            dateFnsOptions
          ).getTime();
        }
        const { defaultFormattedValue, defaultValue } = props;
        const uncontrolledValueRef = vue.ref(
          (defaultFormattedValue !== void 0 ? getTimestampValue(defaultFormattedValue) : defaultValue) ?? null
        );
        const controlledValueRef = vue.computed(() => {
          const { formattedValue } = props;
          if (formattedValue !== void 0) {
            return getTimestampValue(formattedValue);
          }
          return props.value;
        });
        const mergedValueRef = useMergedState(
          controlledValueRef,
          uncontrolledValueRef
        );
        const pendingValueRef = vue.ref(null);
        vue.watchEffect(() => {
          pendingValueRef.value = mergedValueRef.value;
        });
        const singleInputValueRef = vue.ref("");
        const rangeStartInputValueRef = vue.ref("");
        const rangeEndInputValueRef = vue.ref("");
        const themeRef = useTheme(
          "DatePicker",
          "-date-picker",
          style$R,
          datePickerLight$1,
          props,
          mergedClsPrefixRef
        );
        const timePickerSizeRef = vue.computed(() => {
          return mergedComponentPropsRef?.value?.DatePicker?.timePickerSize || "small";
        });
        const isRangeRef = vue.computed(() => {
          return [
            "daterange",
            "datetimerange",
            "monthrange",
            "quarterrange",
            "yearrange"
          ].includes(props.type);
        });
        const localizedPlacehoderRef = vue.computed(() => {
          const { placeholder } = props;
          if (placeholder === void 0) {
            const { type } = props;
            switch (type) {
              case "date":
                return localeRef.value.datePlaceholder;
              case "datetime":
                return localeRef.value.datetimePlaceholder;
              case "month":
                return localeRef.value.monthPlaceholder;
              case "year":
                return localeRef.value.yearPlaceholder;
              case "quarter":
                return localeRef.value.quarterPlaceholder;
              default:
                return "";
            }
          } else {
            return placeholder;
          }
        });
        const localizedStartPlaceholderRef = vue.computed(() => {
          if (props.startPlaceholder === void 0) {
            if (props.type === "daterange") {
              return localeRef.value.startDatePlaceholder;
            } else if (props.type === "datetimerange") {
              return localeRef.value.startDatetimePlaceholder;
            } else if (props.type === "monthrange") {
              return localeRef.value.startMonthPlaceholder;
            }
            return "";
          } else {
            return props.startPlaceholder;
          }
        });
        const localizedEndPlaceholderRef = vue.computed(() => {
          if (props.endPlaceholder === void 0) {
            if (props.type === "daterange") {
              return localeRef.value.endDatePlaceholder;
            } else if (props.type === "datetimerange") {
              return localeRef.value.endDatetimePlaceholder;
            } else if (props.type === "monthrange") {
              return localeRef.value.endMonthPlaceholder;
            }
            return "";
          } else {
            return props.endPlaceholder;
          }
        });
        const mergedActionsRef = vue.computed(() => {
          const { actions, type, clearable } = props;
          if (actions === null)
            return [];
          if (actions !== void 0)
            return actions;
          const result = clearable ? ["clear"] : [];
          switch (type) {
            case "date": {
              result.push("now");
              return result;
            }
            case "datetime": {
              result.push("now", "confirm");
              return result;
            }
            case "daterange": {
              result.push("confirm");
              return result;
            }
            case "datetimerange": {
              result.push("confirm");
              return result;
            }
            case "month": {
              result.push("now", "confirm");
              return result;
            }
            case "year": {
              result.push("now");
              return result;
            }
            case "quarter": {
              result.push("now", "confirm");
              return result;
            }
            case "monthrange":
            case "yearrange":
            case "quarterrange": {
              result.push("confirm");
              return result;
            }
            default: {
              warn$2(
                "data-picker",
                "The type is wrong, n-date-picker's type only supports `date`, `datetime`, `daterange` and `datetimerange`."
              );
              break;
            }
          }
        });
        function getFormattedValue(value) {
          if (value === null)
            return null;
          if (Array.isArray(value)) {
            const { value: mergedValueFormat } = mergedValueFormatRef;
            const { value: dateFnsOptions } = dateFnsOptionsRef;
            return [
              format$4(value[0], mergedValueFormat, dateFnsOptions),
              format$4(value[1], mergedValueFormat, dateFnsOptionsRef.value)
            ];
          } else {
            return format$4(
              value,
              mergedValueFormatRef.value,
              dateFnsOptionsRef.value
            );
          }
        }
        function doUpdatePendingValue(value) {
          pendingValueRef.value = value;
        }
        function doUpdateFormattedValue(value, timestampValue) {
          const {
            "onUpdate:formattedValue": _onUpdateFormattedValue,
            onUpdateFormattedValue
          } = props;
          if (_onUpdateFormattedValue) {
            call(
              _onUpdateFormattedValue,
              value,
              timestampValue
            );
          }
          if (onUpdateFormattedValue) {
            call(
              onUpdateFormattedValue,
              value,
              timestampValue
            );
          }
        }
        function doUpdateValue(value, options) {
          const {
            "onUpdate:value": _onUpdateValue,
            onUpdateValue,
            onChange
          } = props;
          const { nTriggerFormChange, nTriggerFormInput } = formItem;
          const formattedValue = getFormattedValue(value);
          if (options.doConfirm) {
            doConfirm(value, formattedValue);
          }
          if (onUpdateValue) {
            call(onUpdateValue, value, formattedValue);
          }
          if (_onUpdateValue) {
            call(_onUpdateValue, value, formattedValue);
          }
          if (onChange)
            call(onChange, value, formattedValue);
          uncontrolledValueRef.value = value;
          doUpdateFormattedValue(formattedValue, value);
          nTriggerFormChange();
          nTriggerFormInput();
        }
        function doClear() {
          const { onClear } = props;
          onClear?.();
        }
        function doConfirm(value, formattedValue) {
          const { onConfirm } = props;
          if (onConfirm)
            onConfirm(value, formattedValue);
        }
        function doFocus(e) {
          const { onFocus } = props;
          const { nTriggerFormFocus } = formItem;
          if (onFocus)
            call(onFocus, e);
          nTriggerFormFocus();
        }
        function doBlur(e) {
          const { onBlur } = props;
          const { nTriggerFormBlur } = formItem;
          if (onBlur)
            call(onBlur, e);
          nTriggerFormBlur();
        }
        function doUpdateShow(show) {
          const { "onUpdate:show": _onUpdateShow, onUpdateShow } = props;
          if (_onUpdateShow)
            call(_onUpdateShow, show);
          if (onUpdateShow)
            call(onUpdateShow, show);
          uncontrolledShowRef.value = show;
        }
        function handleKeydown(e) {
          if (e.key === "Escape") {
            if (mergedShowRef.value) {
              markEventEffectPerformed(e);
              closeCalendar({
                returnFocus: true
              });
            }
          }
        }
        function handleInputKeydown(e) {
          if (e.key === "Escape" && mergedShowRef.value) {
            markEventEffectPerformed(e);
          }
        }
        function handleClear() {
          doUpdateShow(false);
          inputInstRef.value?.deactivate();
          doClear();
        }
        function handlePanelClear() {
          inputInstRef.value?.deactivate();
          doClear();
        }
        function handlePanelTabOut() {
          closeCalendar({
            returnFocus: true
          });
        }
        function handleClickOutside(e) {
          if (mergedShowRef.value && !triggerElRef.value?.contains(getPreciseEventTarget(e))) {
            closeCalendar({
              returnFocus: false
            });
          }
        }
        function handlePanelClose(disableUpdateOnClose) {
          closeCalendar({
            returnFocus: true,
            disableUpdateOnClose
          });
        }
        function handlePanelUpdateValue(value, doUpdate) {
          if (doUpdate) {
            doUpdateValue(value, { doConfirm: false });
          } else {
            doUpdatePendingValue(value);
          }
        }
        function handlePanelConfirm() {
          const pendingValue = pendingValueRef.value;
          doUpdateValue(
            Array.isArray(pendingValue) ? [pendingValue[0], pendingValue[1]] : pendingValue,
            { doConfirm: true }
          );
        }
        function deriveInputState() {
          const { value } = pendingValueRef;
          if (isRangeRef.value) {
            if (Array.isArray(value) || value === null) {
              deriveRangeInputState(value);
            }
          } else {
            if (!Array.isArray(value)) {
              deriveSingleInputState(value);
            }
          }
        }
        function deriveSingleInputState(value) {
          if (value === null) {
            singleInputValueRef.value = "";
          } else {
            singleInputValueRef.value = format$4(
              value,
              mergedFormatRef.value,
              dateFnsOptionsRef.value
            );
          }
        }
        function deriveRangeInputState(values) {
          if (values === null) {
            rangeStartInputValueRef.value = "";
            rangeEndInputValueRef.value = "";
          } else {
            const dateFnsOptions = dateFnsOptionsRef.value;
            rangeStartInputValueRef.value = format$4(
              values[0],
              mergedFormatRef.value,
              dateFnsOptions
            );
            rangeEndInputValueRef.value = format$4(
              values[1],
              mergedFormatRef.value,
              dateFnsOptions
            );
          }
        }
        function handleInputActivate() {
          if (!mergedShowRef.value) {
            openCalendar();
          }
        }
        function handleInputBlur(e) {
          if (!panelInstRef.value?.$el.contains(e.relatedTarget)) {
            doBlur(e);
            deriveInputState();
            closeCalendar({
              returnFocus: false
            });
          }
        }
        function handleInputDeactivate() {
          if (mergedDisabledRef.value)
            return;
          deriveInputState();
          closeCalendar({
            returnFocus: false
          });
        }
        function handleSingleUpdateValue(v) {
          if (v === "") {
            doUpdateValue(null, { doConfirm: false });
            return;
          }
          const newSelectedDateTime = strictParse(
            v,
            mergedFormatRef.value,
            new Date(),
            dateFnsOptionsRef.value
          );
          if (isValid$1(newSelectedDateTime)) {
            doUpdateValue(getTime(newSelectedDateTime), { doConfirm: false });
            deriveInputState();
          } else {
            singleInputValueRef.value = v;
          }
        }
        function handleRangeUpdateValue(v) {
          if (v[0] === "" && v[1] === "") {
            doUpdateValue(null, { doConfirm: false });
            return;
          }
          const [startTime, endTime] = v;
          const newStartTime = strictParse(
            startTime,
            mergedFormatRef.value,
            new Date(),
            dateFnsOptionsRef.value
          );
          const newEndTime = strictParse(
            endTime,
            mergedFormatRef.value,
            new Date(),
            dateFnsOptionsRef.value
          );
          if (isValid$1(newStartTime) && isValid$1(newEndTime)) {
            doUpdateValue([getTime(newStartTime), getTime(newEndTime)], {
              doConfirm: false
            });
            deriveInputState();
          } else {
            [rangeStartInputValueRef.value, rangeEndInputValueRef.value] = v;
          }
        }
        function handleTriggerClick(e) {
          if (mergedDisabledRef.value)
            return;
          if (happensIn(e, "clear"))
            return;
          if (!mergedShowRef.value) {
            openCalendar();
          }
        }
        function handleInputFocus(e) {
          if (mergedDisabledRef.value)
            return;
          doFocus(e);
        }
        function openCalendar() {
          if (mergedDisabledRef.value || mergedShowRef.value)
            return;
          doUpdateShow(true);
        }
        function closeCalendar({
          returnFocus,
          disableUpdateOnClose
        }) {
          if (mergedShowRef.value) {
            doUpdateShow(false);
            if (props.type !== "date" && props.updateValueOnClose && !disableUpdateOnClose) {
              handlePanelConfirm();
            }
            if (returnFocus) {
              inputInstRef.value?.focus();
            }
          }
        }
        vue.watch(pendingValueRef, () => {
          deriveInputState();
        });
        deriveInputState();
        vue.watch(mergedShowRef, (value) => {
          if (!value) {
            pendingValueRef.value = mergedValueRef.value;
          }
        });
        const uniVaidation = uniCalendarValidation(props, pendingValueRef);
        const dualValidation = dualCalendarValidation(props, pendingValueRef);
        vue.provide(datePickerInjectionKey, {
          mergedClsPrefixRef,
          mergedThemeRef: themeRef,
          timePickerSizeRef,
          localeRef,
          dateLocaleRef,
          firstDayOfWeekRef: vue.toRef(props, "firstDayOfWeek"),
          isDateDisabledRef: vue.toRef(props, "isDateDisabled"),
          rangesRef: vue.toRef(props, "ranges"),
          timePickerPropsRef: vue.toRef(props, "timePickerProps"),
          closeOnSelectRef: vue.toRef(props, "closeOnSelect"),
          updateValueOnCloseRef: vue.toRef(props, "updateValueOnClose"),
          ...uniVaidation,
          ...dualValidation,
          datePickerSlots: slots
        });
        const exposedMethods = {
          focus: () => {
            inputInstRef.value?.focus();
          },
          blur: () => {
            inputInstRef.value?.blur();
          }
        };
        const triggerCssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self: { iconColor, iconColorDisabled }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-icon-color-override": iconColor,
            "--n-icon-color-disabled-override": iconColorDisabled
          };
        });
        const triggerThemeClassHandle = inlineThemeDisabled ? useThemeClass(
          "date-picker-trigger",
          void 0,
          triggerCssVarsRef,
          props
        ) : void 0;
        const cssVarsRef = vue.computed(() => {
          const { type } = props;
          const {
            common: { cubicBezierEaseInOut },
            self: {
              calendarTitleFontSize,
              calendarDaysFontSize,
              itemFontSize,
              itemTextColor,
              itemColorDisabled,
              itemColorIncluded,
              itemColorHover,
              itemColorActive,
              itemBorderRadius,
              itemTextColorDisabled,
              itemTextColorActive,
              panelColor,
              panelTextColor,
              arrowColor,
              calendarTitleTextColor,
              panelActionDividerColor,
              panelHeaderDividerColor,
              calendarDaysDividerColor,
              panelBoxShadow,
              panelBorderRadius,
              calendarTitleFontWeight,
              panelExtraFooterPadding,
              panelActionPadding,
              itemSize,
              itemCellWidth,
              itemCellHeight,
              scrollItemWidth,
              scrollItemHeight,
              calendarTitlePadding,
              calendarTitleHeight,
              calendarDaysHeight,
              calendarDaysTextColor,
              arrowSize,
              panelHeaderPadding,
              calendarDividerColor,
              calendarTitleGridTempateColumns,
              iconColor,
              iconColorDisabled,
              scrollItemBorderRadius,
              calendarTitleColorHover,
              [createKey("calendarLeftPadding", type)]: calendarLeftPadding,
              [createKey("calendarRightPadding", type)]: calendarRightPadding
            }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-panel-border-radius": panelBorderRadius,
            "--n-panel-color": panelColor,
            "--n-panel-box-shadow": panelBoxShadow,
            "--n-panel-text-color": panelTextColor,
            "--n-panel-header-padding": panelHeaderPadding,
            "--n-panel-header-divider-color": panelHeaderDividerColor,
            "--n-calendar-left-padding": calendarLeftPadding,
            "--n-calendar-right-padding": calendarRightPadding,
            "--n-calendar-title-color-hover": calendarTitleColorHover,
            "--n-calendar-title-height": calendarTitleHeight,
            "--n-calendar-title-padding": calendarTitlePadding,
            "--n-calendar-title-font-size": calendarTitleFontSize,
            "--n-calendar-title-font-weight": calendarTitleFontWeight,
            "--n-calendar-title-text-color": calendarTitleTextColor,
            "--n-calendar-title-grid-template-columns": calendarTitleGridTempateColumns,
            "--n-calendar-days-height": calendarDaysHeight,
            "--n-calendar-days-divider-color": calendarDaysDividerColor,
            "--n-calendar-days-font-size": calendarDaysFontSize,
            "--n-calendar-days-text-color": calendarDaysTextColor,
            "--n-calendar-divider-color": calendarDividerColor,
            "--n-panel-action-padding": panelActionPadding,
            "--n-panel-extra-footer-padding": panelExtraFooterPadding,
            "--n-panel-action-divider-color": panelActionDividerColor,
            "--n-item-font-size": itemFontSize,
            "--n-item-border-radius": itemBorderRadius,
            "--n-item-size": itemSize,
            "--n-item-cell-width": itemCellWidth,
            "--n-item-cell-height": itemCellHeight,
            "--n-item-text-color": itemTextColor,
            "--n-item-color-included": itemColorIncluded,
            "--n-item-color-disabled": itemColorDisabled,
            "--n-item-color-hover": itemColorHover,
            "--n-item-color-active": itemColorActive,
            "--n-item-text-color-disabled": itemTextColorDisabled,
            "--n-item-text-color-active": itemTextColorActive,
            "--n-scroll-item-width": scrollItemWidth,
            "--n-scroll-item-height": scrollItemHeight,
            "--n-scroll-item-border-radius": scrollItemBorderRadius,
            "--n-arrow-size": arrowSize,
            "--n-arrow-color": arrowColor,
            "--n-icon-color": iconColor,
            "--n-icon-color-disabled": iconColorDisabled
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("date-picker", void 0, cssVarsRef, props) : void 0;
        return {
          ...exposedMethods,
          mergedStatus: mergedStatusRef,
          mergedClsPrefix: mergedClsPrefixRef,
          mergedBordered: mergedBorderedRef,
          namespace: namespaceRef,
          uncontrolledValue: uncontrolledValueRef,
          pendingValue: pendingValueRef,
          panelInstRef,
          triggerElRef,
          inputInstRef,
          isMounted: isMounted(),
          displayTime: singleInputValueRef,
          displayStartTime: rangeStartInputValueRef,
          displayEndTime: rangeEndInputValueRef,
          mergedShow: mergedShowRef,
          adjustedTo: useAdjustedTo(props),
          isRange: isRangeRef,
          localizedStartPlaceholder: localizedStartPlaceholderRef,
          localizedEndPlaceholder: localizedEndPlaceholderRef,
          mergedSize: mergedSizeRef,
          mergedDisabled: mergedDisabledRef,
          localizedPlacehoder: localizedPlacehoderRef,
          isValueInvalid: uniVaidation.isValueInvalidRef,
          isStartValueInvalid: dualValidation.isStartValueInvalidRef,
          isEndValueInvalid: dualValidation.isEndValueInvalidRef,
          handleInputKeydown,
          handleClickOutside,
          handleKeydown,
          handleClear,
          handlePanelClear,
          handleTriggerClick,
          handleInputActivate,
          handleInputDeactivate,
          handleInputFocus,
          handleInputBlur,
          handlePanelTabOut,
          handlePanelClose,
          handleRangeUpdateValue,
          handleSingleUpdateValue,
          handlePanelUpdateValue,
          handlePanelConfirm,
          mergedTheme: themeRef,
          actions: mergedActionsRef,
          triggerCssVars: inlineThemeDisabled ? void 0 : triggerCssVarsRef,
          triggerThemeClass: triggerThemeClassHandle?.themeClass,
          triggerOnRender: triggerThemeClassHandle?.onRender,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { clearable, triggerOnRender, mergedClsPrefix, $slots } = this;
        const commonPanelProps = {
          onUpdateValue: this.handlePanelUpdateValue,
          onTabOut: this.handlePanelTabOut,
          onClose: this.handlePanelClose,
          onClear: this.handlePanelClear,
          onKeydown: this.handleKeydown,
          onConfirm: this.handlePanelConfirm,
          ref: "panelInstRef",
          value: this.pendingValue,
          active: this.mergedShow,
          actions: this.actions,
          shortcuts: this.shortcuts,
          style: this.cssVars,
          defaultTime: this.defaultTime,
          themeClass: this.themeClass,
          panel: this.panel,
          onRender: this.onRender
        };
        const renderPanel = () => {
          const { type } = this;
          return type === "datetime" ? /* @__PURE__ */ React.createElement(DatetimePanel, {
            ...commonPanelProps
          }) : type === "daterange" ? /* @__PURE__ */ React.createElement(DaterangePanel, {
            ...commonPanelProps,
            defaultCalendarStartTime: this.defaultCalendarStartTime,
            defaultCalendarEndTime: this.defaultCalendarEndTime,
            bindCalendarMonths: this.bindCalendarMonths
          }) : type === "datetimerange" ? /* @__PURE__ */ React.createElement(DatetimerangePanel, {
            ...commonPanelProps,
            defaultCalendarStartTime: this.defaultCalendarStartTime,
            defaultCalendarEndTime: this.defaultCalendarEndTime,
            bindCalendarMonths: this.bindCalendarMonths
          }) : type === "month" || type === "year" || type === "quarter" ? /* @__PURE__ */ React.createElement(MonthPanel, {
            ...commonPanelProps,
            type,
            key: type
          }) : type === "monthrange" || type === "yearrange" || type === "quarterrange" ? /* @__PURE__ */ React.createElement(MonthRangePanel, {
            ...commonPanelProps,
            type
          }) : /* @__PURE__ */ React.createElement(DatePanel, {
            ...commonPanelProps
          });
        };
        if (this.panel) {
          return renderPanel();
        }
        triggerOnRender?.();
        const commonInputProps = {
          bordered: this.mergedBordered,
          size: this.mergedSize,
          passivelyActivated: true,
          disabled: this.mergedDisabled,
          readonly: this.inputReadonly || this.mergedDisabled,
          clearable,
          onClear: this.handleClear,
          onClick: this.handleTriggerClick,
          onKeydown: this.handleInputKeydown,
          onActivate: this.handleInputActivate,
          onDeactivate: this.handleInputDeactivate,
          onFocus: this.handleInputFocus,
          onBlur: this.handleInputBlur
        };
        return /* @__PURE__ */ React.createElement("div", {
          ref: "triggerElRef",
          class: [
            `${mergedClsPrefix}-date-picker`,
            this.mergedDisabled && `${mergedClsPrefix}-date-picker--disabled`,
            this.isRange && `${mergedClsPrefix}-date-picker--range`,
            this.triggerThemeClass
          ],
          style: this.triggerCssVars,
          onKeydown: this.handleKeydown
        }, /* @__PURE__ */ React.createElement(VBinder, null, {
          default: () => [
            /* @__PURE__ */ React.createElement(VTarget, null, {
              default: () => this.isRange ? /* @__PURE__ */ React.createElement(NInput, {
                ref: "inputInstRef",
                status: this.mergedStatus,
                value: [this.displayStartTime, this.displayEndTime],
                placeholder: [
                  this.localizedStartPlaceholder,
                  this.localizedEndPlaceholder
                ],
                textDecoration: [
                  this.isStartValueInvalid ? "line-through" : "",
                  this.isEndValueInvalid ? "line-through" : ""
                ],
                pair: true,
                onUpdateValue: this.handleRangeUpdateValue,
                theme: this.mergedTheme.peers.Input,
                themeOverrides: this.mergedTheme.peerOverrides.Input,
                internalForceFocus: this.mergedShow,
                internalDeactivateOnEnter: true,
                ...commonInputProps
              }, {
                separator: () => this.separator === void 0 ? resolveSlot($slots.separator, () => [
                  /* @__PURE__ */ React.createElement(NBaseIcon, {
                    clsPrefix: mergedClsPrefix,
                    class: `${mergedClsPrefix}-date-picker-icon`
                  }, {
                    default: () => /* @__PURE__ */ React.createElement(ToIcon, null)
                  })
                ]) : this.separator,
                [clearable ? "clear-icon-placeholder" : "suffix"]: () => resolveSlot($slots["date-icon"], () => [
                  /* @__PURE__ */ React.createElement(NBaseIcon, {
                    clsPrefix: mergedClsPrefix,
                    class: `${mergedClsPrefix}-date-picker-icon`
                  }, {
                    default: () => /* @__PURE__ */ React.createElement(DateIcon, null)
                  })
                ])
              }) : /* @__PURE__ */ React.createElement(NInput, {
                ref: "inputInstRef",
                status: this.mergedStatus,
                value: this.displayTime,
                placeholder: this.localizedPlacehoder,
                textDecoration: this.isValueInvalid && !this.isRange ? "line-through" : "",
                onUpdateValue: this.handleSingleUpdateValue,
                theme: this.mergedTheme.peers.Input,
                themeOverrides: this.mergedTheme.peerOverrides.Input,
                internalForceFocus: this.mergedShow,
                internalDeactivateOnEnter: true,
                ...commonInputProps
              }, {
                [clearable ? "clear-icon-placeholder" : "suffix"]: () => /* @__PURE__ */ React.createElement(NBaseIcon, {
                  clsPrefix: mergedClsPrefix,
                  class: `${mergedClsPrefix}-date-picker-icon`
                }, {
                  default: () => resolveSlot($slots["date-icon"], () => [
                    /* @__PURE__ */ React.createElement(DateIcon, null)
                  ])
                })
              })
            }),
            /* @__PURE__ */ React.createElement(VFollower, {
              show: this.mergedShow,
              containerClass: this.namespace,
              to: this.adjustedTo,
              teleportDisabled: this.adjustedTo === useAdjustedTo.tdkey,
              placement: this.placement
            }, {
              default: () => /* @__PURE__ */ React.createElement(vue.Transition, {
                name: "fade-in-scale-up-transition",
                appear: this.isMounted
              }, {
                default: () => {
                  if (!this.mergedShow)
                    return null;
                  return vue.withDirectives(renderPanel(), [
                    [
                      clickoutside$1,
                      this.handleClickOutside,
                      void 0,
                      { capture: true }
                    ]
                  ]);
                }
              })
            })
          ]
        }));
      }
    });

    var commonVariables$7 = {
      thPaddingBorderedSmall: "8px 12px",
      thPaddingBorderedMedium: "12px 16px",
      thPaddingBorderedLarge: "16px 24px",
      thPaddingSmall: "0",
      thPaddingMedium: "0",
      thPaddingLarge: "0",
      tdPaddingBorderedSmall: "8px 12px",
      tdPaddingBorderedMedium: "12px 16px",
      tdPaddingBorderedLarge: "16px 24px",
      tdPaddingSmall: "0 0 8px 0",
      tdPaddingMedium: "0 0 12px 0",
      tdPaddingLarge: "0 0 16px 0"
    };

    const self$F = vars => {
      const {
        tableHeaderColor,
        textColor2,
        textColor1,
        cardColor,
        modalColor,
        popoverColor,
        dividerColor,
        borderRadius,
        fontWeightStrong,
        lineHeight,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge
      } = vars;
      return { ...commonVariables$7,
        lineHeight,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge,
        titleTextColor: textColor1,
        thColor: composite(cardColor, tableHeaderColor),
        thColorModal: composite(modalColor, tableHeaderColor),
        thColorPopover: composite(popoverColor, tableHeaderColor),
        thTextColor: textColor1,
        thFontWeight: fontWeightStrong,
        tdTextColor: textColor2,
        tdColor: cardColor,
        tdColorModal: modalColor,
        tdColorPopover: popoverColor,
        borderColor: composite(cardColor, dividerColor),
        borderColorModal: composite(modalColor, dividerColor),
        borderColorPopover: composite(popoverColor, dividerColor),
        borderRadius
      };
    };
    const descriptionsLight = {
      name: "Descriptions",
      common: commonLight,
      self: self$F
    };
    var descriptionsLight$1 = descriptionsLight;

    const descriptionsDark = {
      name: "Descriptions",
      common: commonDark,
      self: self$F
    };
    var descriptionsDark$1 = descriptionsDark;

    const DESCRIPTION_ITEM_FLAG = Symbol("DESCRIPTION_ITEM_FLAG");
    function isDescriptionsItem(vNode) {
      if (typeof vNode === "object" && vNode && !Array.isArray(vNode)) {
        return vNode.type && vNode.type[DESCRIPTION_ITEM_FLAG];
      }

      return false;
    }

    var style$Q = c$1([cB("descriptions", {
      fontSize: "var(--n-font-size)"
    }, [cB("descriptions-separator", `
      display: inline-block;
      margin: 0 8px 0 2px;
    `), cB("descriptions-table-wrapper", [cB("descriptions-table", [cB("descriptions-table-row", [cB("descriptions-table-header", {
      padding: "var(--n-th-padding)"
    }), cB("descriptions-table-content", {
      padding: "var(--n-td-padding)"
    })])])]), cNotM("bordered", [cB("descriptions-table-wrapper", [cB("descriptions-table", [cB("descriptions-table-row", [c$1("&:last-child", [cB("descriptions-table-content", {
      paddingBottom: 0
    })])])])])]), cM("left-label-placement", [cB("descriptions-table-content", [c$1("> *", {
      verticalAlign: "top"
    })])]), cM("left-label-align", [c$1("th", {
      textAlign: "left"
    })]), cM("center-label-align", [c$1("th", {
      textAlign: "center"
    })]), cM("right-label-align", [c$1("th", {
      textAlign: "right"
    })]), cM("bordered", [cB("descriptions-table-wrapper", `
        border-radius: var(--n-border-radius);
        overflow: hidden;
        background: var(--n-merged-td-color);
        border: 1px solid var(--n-merged-border-color);
      `, [cB("descriptions-table", [cB("descriptions-table-row", [c$1("&:not(:last-child)", [cB("descriptions-table-content", {
      borderBottom: "1px solid var(--n-merged-border-color)"
    }), cB("descriptions-table-header", {
      borderBottom: "1px solid var(--n-merged-border-color)"
    })]), cB("descriptions-table-header", `
              font-weight: 400;
              background-clip: padding-box;
              background-color: var(--n-merged-th-color);
            `, [c$1("&:not(:last-child)", {
      borderRight: "1px solid var(--n-merged-border-color)"
    })]), cB("descriptions-table-content", [c$1("&:not(:last-child)", {
      borderRight: "1px solid var(--n-merged-border-color)"
    })])])])])]), cB("descriptions-header", `
      font-weight: var(--n-th-font-weight);
      font-size: 18px;
      transition: color .3s var(--n-bezier);
      line-height: var(--n-line-height);
      margin-bottom: 16px;
      color: var(--n-title-text-color);
    `), cB("descriptions-table-wrapper", `
      transition:
        background-color .3s var(--n-bezier),
        border-color .3s var(--n-bezier);
    `, [cB("descriptions-table", `
        width: 100%;
        border-collapse: separate;
        border-spacing: 0;
        box-sizing: border-box;
      `, [cB("descriptions-table-row", `
          box-sizing: border-box;
          transition: border-color .3s var(--n-bezier);
        `, [cB("descriptions-table-header", `
            font-weight: var(--n-th-font-weight);
            line-height: var(--n-line-height);
            display: table-cell;
            box-sizing: border-box;
            color: var(--n-th-text-color);
            transition:
              color .3s var(--n-bezier),
              background-color .3s var(--n-bezier),
              border-color .3s var(--n-bezier);
          `), cB("descriptions-table-content", `
            vertical-align: top;
            line-height: var(--n-line-height);
            display: table-cell;
            box-sizing: border-box;
            color: var(--n-td-text-color);
            transition:
              color .3s var(--n-bezier),
              background-color .3s var(--n-bezier),
              border-color .3s var(--n-bezier);
          `, [cE("content", `
              transition: color .3s var(--n-bezier);
              display: inline-block;
              color: var(--n-td-text-color);
            `)]), cE("label", `
            font-weight: var(--n-th-font-weight);
            transition: color .3s var(--n-bezier);
            display: inline-block;
            margin-right: 14px;
            color: var(--n-th-text-color);
          `)])])])]), cB("descriptions-table-wrapper", `
    --n-merged-th-color: var(--n-th-color);
    --n-merged-td-color: var(--n-td-color);
    --n-merged-border-color: var(--n-border-color);
  `), insideModal(cB("descriptions-table-wrapper", `
      --n-merged-th-color: var(--n-th-color-modal);
      --n-merged-td-color: var(--n-td-color-modal);
      --n-merged-border-color: var(--n-border-color-modal);
    `)), insidePopover(cB("descriptions-table-wrapper", `
      --n-merged-th-color: var(--n-th-color-popover);
      --n-merged-td-color: var(--n-td-color-popover);
      --n-merged-border-color: var(--n-border-color-popover);
    `))]);

    const descriptionsProps = {
      ...useTheme.props,
      title: String,
      column: {
        type: Number,
        default: 3
      },
      columns: Number,
      labelPlacement: {
        type: String,
        default: "top"
      },
      labelAlign: {
        type: String,
        default: "left"
      },
      separator: {
        type: String,
        default: ":"
      },
      size: {
        type: String,
        default: "medium"
      },
      bordered: Boolean,
      labelStyle: [Object, String],
      contentStyle: [Object, String]
    };
    var Descriptions = vue.defineComponent({
      name: "Descriptions",
      props: descriptionsProps,
      setup(props) {
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Descriptions",
          "-descriptions",
          style$Q,
          descriptionsLight$1,
          props,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const { size, bordered } = props;
          const {
            common: { cubicBezierEaseInOut },
            self: {
              titleTextColor,
              thColor,
              thColorModal,
              thColorPopover,
              thTextColor,
              thFontWeight,
              tdTextColor,
              tdColor,
              tdColorModal,
              tdColorPopover,
              borderColor,
              borderColorModal,
              borderColorPopover,
              borderRadius,
              lineHeight,
              [createKey("fontSize", size)]: fontSize,
              [createKey(bordered ? "thPaddingBordered" : "thPadding", size)]: thPadding,
              [createKey(bordered ? "tdPaddingBordered" : "tdPadding", size)]: tdPadding
            }
          } = themeRef.value;
          return {
            "--n-title-text-color": titleTextColor,
            "--n-th-padding": thPadding,
            "--n-td-padding": tdPadding,
            "--n-font-size": fontSize,
            "--n-bezier": cubicBezierEaseInOut,
            "--n-th-font-weight": thFontWeight,
            "--n-line-height": lineHeight,
            "--n-th-text-color": thTextColor,
            "--n-td-text-color": tdTextColor,
            "--n-th-color": thColor,
            "--n-th-color-modal": thColorModal,
            "--n-th-color-popover": thColorPopover,
            "--n-td-color": tdColor,
            "--n-td-color-modal": tdColorModal,
            "--n-td-color-popover": tdColorPopover,
            "--n-border-radius": borderRadius,
            "--n-border-color": borderColor,
            "--n-border-color-modal": borderColorModal,
            "--n-border-color-popover": borderColorPopover
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "descriptions",
          vue.computed(() => {
            let hash = "";
            const { size, bordered } = props;
            if (bordered)
              hash += "a";
            hash += size[0];
            return hash;
          }),
          cssVarsRef,
          props
        ) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender,
          compitableColumn: useCompitable(props, ["columns", "column"]),
          inlineThemeDisabled
        };
      },
      render() {
        const defaultSlots = this.$slots.default;
        const children = defaultSlots ? flatten$3(defaultSlots()) : [];
        const memorizedLength = children.length;
        const {
          compitableColumn,
          labelPlacement,
          labelAlign,
          size,
          bordered,
          title,
          cssVars,
          mergedClsPrefix,
          separator,
          onRender
        } = this;
        onRender?.();
        const filteredChildren = children.filter(
          (child) => isDescriptionsItem(child)
        );
        if (memorizedLength !== filteredChildren.length) {
          warn$2(
            "descriptions",
            "`n-descriptions` only takes `n-descriptions-item` as children."
          );
        }
        const defaultState = {
          span: 0,
          row: [],
          secondRow: [],
          rows: []
        };
        const itemState = filteredChildren.reduce((state, vNode, index) => {
          const props = vNode.props || {};
          const isLastIteration = filteredChildren.length - 1 === index;
          const itemLabel = [
            "label" in props ? props.label : getVNodeChildren(vNode, "label")
          ];
          const itemChildren = [getVNodeChildren(vNode)];
          const itemSpan = props.span || 1;
          const memorizedSpan = state.span;
          state.span += itemSpan;
          const labelStyle = props.labelStyle || props["label-style"] || this.labelStyle;
          const contentStyle = props.contentStyle || props["content-style"] || this.contentStyle;
          if (labelPlacement === "left") {
            if (bordered) {
              state.row.push(
                /* @__PURE__ */ React.createElement("th", {
                  class: `${mergedClsPrefix}-descriptions-table-header`,
                  colspan: 1,
                  style: labelStyle
                }, itemLabel),
                /* @__PURE__ */ React.createElement("td", {
                  class: `${mergedClsPrefix}-descriptions-table-content`,
                  colspan: isLastIteration ? (compitableColumn - memorizedSpan) * 2 + 1 : itemSpan * 2 - 1,
                  style: contentStyle
                }, itemChildren)
              );
            } else {
              state.row.push(
                /* @__PURE__ */ React.createElement("td", {
                  class: `${mergedClsPrefix}-descriptions-table-content`,
                  colspan: isLastIteration ? (compitableColumn - memorizedSpan) * 2 : itemSpan * 2
                }, /* @__PURE__ */ React.createElement("span", {
                  class: `${mergedClsPrefix}-descriptions-table-content__label`,
                  style: labelStyle
                }, [
                  ...itemLabel,
                  separator && /* @__PURE__ */ React.createElement("span", {
                    class: `${mergedClsPrefix}-descriptions-separator`
                  }, separator)
                ]), /* @__PURE__ */ React.createElement("span", {
                  class: `${mergedClsPrefix}-descriptions-table-content__content`,
                  style: contentStyle
                }, itemChildren))
              );
            }
          } else {
            const colspan = isLastIteration ? (compitableColumn - memorizedSpan) * 2 : itemSpan * 2;
            state.row.push(
              /* @__PURE__ */ React.createElement("th", {
                class: `${mergedClsPrefix}-descriptions-table-header`,
                colspan,
                style: labelStyle
              }, itemLabel)
            );
            state.secondRow.push(
              /* @__PURE__ */ React.createElement("td", {
                class: `${mergedClsPrefix}-descriptions-table-content`,
                colspan,
                style: contentStyle
              }, itemChildren)
            );
          }
          if (state.span >= compitableColumn || isLastIteration) {
            state.span = 0;
            if (state.row.length) {
              state.rows.push(state.row);
              state.row = [];
            }
            if (labelPlacement !== "left") {
              if (state.secondRow.length) {
                state.rows.push(state.secondRow);
                state.secondRow = [];
              }
            }
          }
          return state;
        }, defaultState);
        const rows = itemState.rows.map((row) => /* @__PURE__ */ React.createElement("tr", {
          class: `${mergedClsPrefix}-descriptions-table-row`
        }, row));
        return /* @__PURE__ */ React.createElement("div", {
          style: cssVars,
          class: [
            `${mergedClsPrefix}-descriptions`,
            this.themeClass,
            `${mergedClsPrefix}-descriptions--${labelPlacement}-label-placement`,
            `${mergedClsPrefix}-descriptions--${labelAlign}-label-align`,
            `${mergedClsPrefix}-descriptions--${size}-size`,
            bordered && `${mergedClsPrefix}-descriptions--bordered`
          ]
        }, title || this.$slots.header ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-descriptions-header`
        }, title || getSlot$1(this, "header")) : null, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-descriptions-table-wrapper`
        }, /* @__PURE__ */ React.createElement("table", {
          class: `${mergedClsPrefix}-descriptions-table`
        }, /* @__PURE__ */ React.createElement("tbody", null, rows))));
      }
    });

    const descriptionsItemProps = {
      label: String,
      span: {
        type: Number,
        default: 1
      },
      labelStyle: [Object, String],
      contentStyle: [Object, String]
    };
    var DescriptionsItem = vue.defineComponent({
      name: "DescriptionsItem",
      [DESCRIPTION_ITEM_FLAG]: true,
      props: descriptionsItemProps,

      render() {
        return null;
      }

    });

    var commonVars$5 = {
      titleFontSize: "18px",
      padding: "16px 28px 20px 28px",
      iconSize: "28px",
      actionSpace: "12px",
      contentMargin: "8px 0 16px 0",
      iconMargin: "0 4px 0 0",
      iconMarginIconTop: "4px 0 8px 0",
      closeSize: "22px",
      closeIconSize: "18px",
      closeMargin: "20px 26px 0 0",
      closeMarginIconTop: "10px 16px 0 0"
    };

    const self$E = vars => {
      const {
        textColor1,
        textColor2,
        modalColor,
        closeIconColor,
        closeIconColorHover,
        closeIconColorPressed,
        closeColorHover,
        closeColorPressed,
        infoColor,
        successColor,
        warningColor,
        errorColor,
        primaryColor,
        dividerColor,
        borderRadius,
        fontWeightStrong,
        lineHeight,
        fontSize
      } = vars;
      return { ...commonVars$5,
        fontSize,
        lineHeight,
        border: `1px solid ${dividerColor}`,
        titleTextColor: textColor1,
        textColor: textColor2,
        color: modalColor,
        closeColorHover,
        closeColorPressed,
        closeIconColor,
        closeIconColorHover,
        closeIconColorPressed,
        closeBorderRadius: borderRadius,
        iconColor: primaryColor,
        iconColorInfo: infoColor,
        iconColorSuccess: successColor,
        iconColorWarning: warningColor,
        iconColorError: errorColor,
        borderRadius,
        titleFontWeight: fontWeightStrong
      };
    };
    const dialogLight = createTheme$1({
      name: "Dialog",
      common: commonLight,
      peers: {
        Button: buttonLight$1
      },
      self: self$E
    });
    var dialogLight$1 = dialogLight;

    const dialogDark = {
      name: "Dialog",
      common: commonDark,
      peers: {
        Button: buttonDark$1
      },
      self: self$E
    };
    var dialogDark$1 = dialogDark;

    const dialogProps = {
      icon: Function,
      type: {
        type: String,
        default: "default"
      },
      title: [String, Function],
      closable: {
        type: Boolean,
        default: true
      },
      negativeText: String,
      positiveText: String,
      positiveButtonProps: Object,
      negativeButtonProps: Object,
      content: [String, Function],
      action: Function,
      showIcon: {
        type: Boolean,
        default: true
      },
      loading: Boolean,
      bordered: Boolean,
      iconPlacement: String,
      onPositiveClick: Function,
      onNegativeClick: Function,
      onClose: Function
    };
    const dialogPropKeys = keysOf(dialogProps);

    var style$P = c$1([cB("dialog", `
    word-break: break-word;
    line-height: var(--n-line-height);
    position: relative;
    background: var(--n-color);
    color: var(--n-text-color);
    box-sizing: border-box;
    margin: auto;
    border-radius: var(--n-border-radius);
    padding: var(--n-padding);
    transition: 
      border-color .3s var(--n-bezier),
      background-color .3s var(--n-bezier),
      color .3s var(--n-bezier);
  `, [cE("icon", {
      color: "var(--n-icon-color)"
    }), cM("bordered", {
      border: "var(--n-border)"
    }), cM("icon-top", [cE("close", {
      margin: "var(--n-close-margin)"
    }), cE("icon", {
      margin: "var(--n-icon-margin)"
    }), cE("content", {
      textAlign: "center"
    }), cE("title", {
      justifyContent: "center"
    }), cE("action", {
      justifyContent: "center"
    })]), cM("icon-left", [cE("icon", {
      margin: "var(--n-icon-margin)"
    }), cM("closable", [cE("title", `
          padding-right: calc(var(--n-close-size) + 6px);
        `)])]), cE("close", `
      position: absolute;
      right: 0;
      top: 0;
      margin: var(--n-close-margin);
      transition:
        background-color .3s var(--n-bezier),
        color .3s var(--n-bezier);
      z-index: 1;
    `), cE("content", `
      font-size: var(--n-font-size);
      margin: var(--n-content-margin);
      position: relative;
      word-break: break-word;
    `, [cM("last", "margin-bottom: 0;")]), cE("action", `
      display: flex;
      justify-content: flex-end;
    `, [c$1("> *:not(:last-child)", {
      marginRight: "var(--n-action-space)"
    })]), cE("icon", {
      fontSize: "var(--n-icon-size)",
      transition: "color .3s var(--n-bezier)"
    }), cE("title", `
      transition: color .3s var(--n-bezier);
      display: flex;
      align-items: center;
      font-size: var(--n-title-font-size);
      font-weight: var(--n-title-font-weight);
      color: var(--n-title-text-color);
    `), cB("dialog-icon-container", {
      display: "flex",
      justifyContent: "center"
    })]), insideModal(cB("dialog", `
      width: 446px;
      max-width: calc(100vw - 32px);
    `)), cB("dialog", [asModal(`
      width: 446px;
      max-width: calc(100vw - 32px);
    `)])]);

    const iconRenderMap$2 = {
      default: () => /* @__PURE__ */ React.createElement(InfoIcon, null),
      info: () => /* @__PURE__ */ React.createElement(InfoIcon, null),
      success: () => /* @__PURE__ */ React.createElement(SuccessIcon, null),
      warning: () => /* @__PURE__ */ React.createElement(WarningIcon, null),
      error: () => /* @__PURE__ */ React.createElement(ErrorIcon, null)
    };
    const NDialog = vue.defineComponent({
      name: "Dialog",
      alias: [
        "NimbusConfirmCard",
        "Confirm"
      ],
      props: {
        ...useTheme.props,
        ...dialogProps
      },
      setup(props) {
        const { mergedComponentPropsRef, mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const mergedIconPlacementRef = vue.computed(() => {
          const { iconPlacement } = props;
          return iconPlacement || mergedComponentPropsRef?.value?.Dialog?.iconPlacement || "left";
        });
        function handlePositiveClick(e) {
          const { onPositiveClick } = props;
          if (onPositiveClick)
            onPositiveClick(e);
        }
        function handleNegativeClick(e) {
          const { onNegativeClick } = props;
          if (onNegativeClick)
            onNegativeClick(e);
        }
        function handleCloseClick() {
          const { onClose } = props;
          if (onClose)
            onClose();
        }
        const themeRef = useTheme(
          "Dialog",
          "-dialog",
          style$P,
          dialogLight$1,
          props,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const { type } = props;
          const iconPlacement = mergedIconPlacementRef.value;
          const {
            common: { cubicBezierEaseInOut },
            self: {
              fontSize,
              lineHeight,
              border,
              titleTextColor,
              textColor,
              color,
              closeBorderRadius,
              closeColorHover,
              closeColorPressed,
              closeIconColor,
              closeIconColorHover,
              closeIconColorPressed,
              closeIconSize,
              borderRadius,
              titleFontWeight,
              titleFontSize,
              padding,
              iconSize,
              actionSpace,
              contentMargin,
              closeSize,
              [iconPlacement === "top" ? "iconMarginIconTop" : "iconMargin"]: iconMargin,
              [iconPlacement === "top" ? "closeMarginIconTop" : "closeMargin"]: closeMargin,
              [createKey("iconColor", type)]: iconColor
            }
          } = themeRef.value;
          return {
            "--n-font-size": fontSize,
            "--n-icon-color": iconColor,
            "--n-bezier": cubicBezierEaseInOut,
            "--n-close-margin": closeMargin,
            "--n-icon-margin": iconMargin,
            "--n-icon-size": iconSize,
            "--n-close-size": closeSize,
            "--n-close-icon-size": closeIconSize,
            "--n-close-border-radius": closeBorderRadius,
            "--n-close-color-hover": closeColorHover,
            "--n-close-color-pressed": closeColorPressed,
            "--n-close-icon-color": closeIconColor,
            "--n-close-icon-color-hover": closeIconColorHover,
            "--n-close-icon-color-pressed": closeIconColorPressed,
            "--n-color": color,
            "--n-text-color": textColor,
            "--n-border-radius": borderRadius,
            "--n-padding": padding,
            "--n-line-height": lineHeight,
            "--n-border": border,
            "--n-content-margin": contentMargin,
            "--n-title-font-size": titleFontSize,
            "--n-title-font-weight": titleFontWeight,
            "--n-title-text-color": titleTextColor,
            "--n-action-space": actionSpace
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "dialog",
          vue.computed(() => `${props.type[0]}${mergedIconPlacementRef.value[0]}`),
          cssVarsRef,
          props
        ) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          mergedIconPlacement: mergedIconPlacementRef,
          mergedTheme: themeRef,
          handlePositiveClick,
          handleNegativeClick,
          handleCloseClick,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const {
          bordered,
          mergedIconPlacement,
          cssVars,
          closable,
          showIcon,
          title,
          content,
          action,
          negativeText,
          positiveText,
          positiveButtonProps,
          negativeButtonProps,
          handlePositiveClick,
          handleNegativeClick,
          mergedTheme,
          loading,
          type,
          mergedClsPrefix
        } = this;
        this.onRender?.();
        const icon = showIcon ? /* @__PURE__ */ React.createElement(NBaseIcon, {
          clsPrefix: mergedClsPrefix,
          class: `${mergedClsPrefix}-dialog__icon`
        }, {
          default: () => resolveWrappedSlot(
            this.$slots.icon,
            (children) => children || (this.icon ? render$1(this.icon) : iconRenderMap$2[this.type]())
          )
        }) : null;
        const actionNode = resolveWrappedSlot(
          this.$slots.action,
          (children) => children || positiveText || negativeText || action ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-dialog__action`
          }, children || (action ? [render$1(action)] : [
            this.negativeText && /* @__PURE__ */ React.createElement(NButton, {
              theme: mergedTheme.peers.Button,
              themeOverrides: mergedTheme.peerOverrides.Button,
              ghost: true,
              size: "small",
              onClick: handleNegativeClick,
              ...negativeButtonProps
            }, {
              default: () => render$1(this.negativeText)
            }),
            this.positiveText && /* @__PURE__ */ React.createElement(NButton, {
              theme: mergedTheme.peers.Button,
              themeOverrides: mergedTheme.peerOverrides.Button,
              size: "small",
              type: type === "default" ? "primary" : type,
              disabled: loading,
              loading,
              onClick: handlePositiveClick,
              ...positiveButtonProps
            }, {
              default: () => render$1(this.positiveText)
            })
          ])) : null
        );
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-dialog`,
            this.themeClass,
            this.closable && `${mergedClsPrefix}-dialog--closable`,
            `${mergedClsPrefix}-dialog--icon-${mergedIconPlacement}`,
            bordered && `${mergedClsPrefix}-dialog--bordered`
          ],
          style: cssVars,
          role: "dialog"
        }, closable ? /* @__PURE__ */ React.createElement(NBaseClose, {
          clsPrefix: mergedClsPrefix,
          class: `${mergedClsPrefix}-dialog__close`,
          onClick: this.handleCloseClick
        }) : null, showIcon && mergedIconPlacement === "top" ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-dialog-icon-container`
        }, icon) : null, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-dialog__title`
        }, showIcon && mergedIconPlacement === "left" ? icon : null, resolveSlot(this.$slots.header, () => [render$1(title)])), /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-dialog__content`,
            actionNode ? "" : `${mergedClsPrefix}-dialog__content--last`
          ]
        }, resolveSlot(this.$slots.default, () => [render$1(content)])), actionNode);
      }
    });

    const dialogProviderInjectionKey = createInjectionKey("n-dialog-provider");
    const dialogApiInjectionKey = createInjectionKey("n-dialog-api");
    const dialogReactiveListInjectionKey = createInjectionKey("n-dialog-reactive-list");

    const self$D = vars => {
      const {
        modalColor,
        textColor2,
        boxShadow3
      } = vars;
      return {
        color: modalColor,
        textColor: textColor2,
        boxShadow: boxShadow3
      };
    };
    const modalLight = createTheme$1({
      name: "Modal",
      common: commonLight,
      peers: {
        Scrollbar: scrollbarLight$1,
        Dialog: dialogLight$1,
        Card: cardLight$1
      },
      self: self$D
    });
    var modalLight$1 = modalLight;

    const modalDark = {
      name: "Modal",
      common: commonDark,
      peers: {
        Scrollbar: scrollbarDark$1,
        Dialog: dialogDark$1,
        Card: cardDark$1
      },
      self: self$D
    };
    var modalDark$1 = modalDark;

    const presetProps = { ...cardBaseProps,
      ...dialogProps
    };
    const presetPropsKeys = keysOf(presetProps);

    var NModalBodyWrapper = vue.defineComponent({
      name: "ModalBody",
      inheritAttrs: false,
      props: {
        show: {
          type: Boolean,
          required: true
        },
        preset: String,
        displayDirective: {
          type: String,
          required: true
        },
        trapFocus: {
          type: Boolean,
          default: true
        },
        autoFocus: {
          type: Boolean,
          default: true
        },
        blockScroll: Boolean,
        ...presetProps,
        renderMask: Function,
        onClickoutside: Function,
        onBeforeLeave: {
          type: Function,
          required: true
        },
        onAfterLeave: {
          type: Function,
          required: true
        },
        onPositiveClick: {
          type: Function,
          required: true
        },
        onNegativeClick: {
          type: Function,
          required: true
        },
        onClose: {
          type: Function,
          required: true
        },
        onAfterEnter: Function,
        onEsc: Function
      },
      setup(props) {
        const bodyRef = vue.ref(null);
        const scrollbarRef = vue.ref(null);
        const displayedRef = vue.ref(props.show);
        const transformOriginXRef = vue.ref(null);
        const transformOriginYRef = vue.ref(null);
        vue.watch(vue.toRef(props, "show"), (value) => {
          if (value)
            displayedRef.value = true;
        });
        useLockHtmlScroll(vue.computed(() => props.blockScroll && displayedRef.value));
        const NModal = vue.inject(modalInjectionKey);
        function styleTransformOrigin() {
          if (NModal.transformOriginRef.value === "center") {
            return "";
          }
          const { value: transformOriginX } = transformOriginXRef;
          const { value: transformOriginY } = transformOriginYRef;
          if (transformOriginX === null || transformOriginY === null) {
            return "";
          } else if (scrollbarRef.value) {
            const scrollTop = scrollbarRef.value.containerScrollTop;
            return `${transformOriginX}px ${transformOriginY + scrollTop}px`;
          }
          return "";
        }
        function syncTransformOrigin(el) {
          if (NModal.transformOriginRef.value === "center") {
            return;
          }
          const mousePosition = NModal.getMousePosition();
          if (!mousePosition) {
            return;
          }
          if (!scrollbarRef.value)
            return;
          const scrollTop = scrollbarRef.value.containerScrollTop;
          const { offsetLeft, offsetTop } = el;
          if (mousePosition) {
            const top = mousePosition.y;
            const left = mousePosition.x;
            transformOriginXRef.value = -(offsetLeft - left);
            transformOriginYRef.value = -(offsetTop - top - scrollTop);
          }
          el.style.transformOrigin = styleTransformOrigin();
        }
        function handleEnter(el) {
          void vue.nextTick(() => {
            syncTransformOrigin(el);
          });
        }
        function handleBeforeLeave(el) {
          el.style.transformOrigin = styleTransformOrigin();
          props.onBeforeLeave();
        }
        function handleAfterLeave() {
          displayedRef.value = false;
          transformOriginXRef.value = null;
          transformOriginYRef.value = null;
          props.onAfterLeave();
        }
        function handleCloseClick() {
          const { onClose } = props;
          if (onClose) {
            onClose();
          }
        }
        function handleNegativeClick() {
          props.onNegativeClick();
        }
        function handlePositiveClick() {
          props.onPositiveClick();
        }
        const childNodeRef = vue.ref(null);
        vue.watch(childNodeRef, (node) => {
          if (node) {
            void vue.nextTick(() => {
              const el = node.el;
              if (el && bodyRef.value !== el) {
                bodyRef.value = el;
              }
            });
          }
        });
        vue.provide(modalBodyInjectionKey, bodyRef);
        vue.provide(drawerBodyInjectionKey, null);
        vue.provide(popoverBodyInjectionKey, null);
        return {
          mergedTheme: NModal.mergedThemeRef,
          appear: NModal.appearRef,
          isMounted: NModal.isMountedRef,
          mergedClsPrefix: NModal.mergedClsPrefixRef,
          bodyRef,
          scrollbarRef,
          displayed: displayedRef,
          childNodeRef,
          handlePositiveClick,
          handleNegativeClick,
          handleCloseClick,
          handleAfterLeave,
          handleBeforeLeave,
          handleEnter
        };
      },
      render() {
        const {
          $slots,
          $attrs,
          handleEnter,
          handleAfterLeave,
          handleBeforeLeave,
          preset,
          mergedClsPrefix
        } = this;
        let childNode = null;
        if (!preset) {
          childNode = getFirstSlotVNode($slots);
          if (!childNode) {
            warn$2("modal", "default slot is empty");
            return;
          }
          childNode = vue.cloneVNode(childNode);
          childNode.props = vue.mergeProps(
            {
              class: `${mergedClsPrefix}-modal`
            },
            $attrs,
            childNode.props || {}
          );
        }
        return this.displayDirective === "show" || this.displayed || this.show ? vue.withDirectives(
          /* @__PURE__ */ React.createElement("div", {
            role: "none",
            class: `${mergedClsPrefix}-modal-body-wrapper`
          }, /* @__PURE__ */ React.createElement(NScrollbar, {
            ref: "scrollbarRef",
            theme: this.mergedTheme.peers.Scrollbar,
            themeOverrides: this.mergedTheme.peerOverrides.Scrollbar,
            contentClass: `${mergedClsPrefix}-modal-scroll-content`
          }, {
            default: () => [
              this.renderMask?.(),
              /* @__PURE__ */ React.createElement(FocusTrap, {
                disabled: !this.trapFocus,
                active: this.show,
                onEsc: this.onEsc,
                autoFocus: this.autoFocus
              }, {
                default: () => /* @__PURE__ */ React.createElement(vue.Transition, {
                  name: "fade-in-scale-up-transition",
                  appear: this.appear ?? this.isMounted,
                  onEnter: handleEnter,
                  onAfterEnter: this.onAfterEnter,
                  onAfterLeave: handleAfterLeave,
                  onBeforeLeave: handleBeforeLeave
                }, {
                  default: () => {
                    const dirs = [
                      [vue.vShow, this.show]
                    ];
                    const { onClickoutside } = this;
                    if (onClickoutside) {
                      dirs.push([
                        clickoutside$1,
                        this.onClickoutside,
                        void 0,
                        { capture: true }
                      ]);
                    }
                    return vue.withDirectives(
                      this.preset === "confirm" || this.preset === "dialog" ? /* @__PURE__ */ React.createElement(NDialog, {
                        ...this.$attrs,
                        class: [
                          `${mergedClsPrefix}-modal`,
                          this.$attrs.class
                        ],
                        ref: "bodyRef",
                        theme: this.mergedTheme.peers.Dialog,
                        themeOverrides: this.mergedTheme.peerOverrides.Dialog,
                        ...keep(this.$props, dialogPropKeys),
                        "aria-modal": "true"
                      }, $slots) : this.preset === "card" ? /* @__PURE__ */ React.createElement(NCard, {
                        ...this.$attrs,
                        ref: "bodyRef",
                        class: [
                          `${mergedClsPrefix}-modal`,
                          this.$attrs.class
                        ],
                        theme: this.mergedTheme.peers.Card,
                        themeOverrides: this.mergedTheme.peerOverrides.Card,
                        ...keep(this.$props, cardBasePropKeys),
                        "aria-modal": "true",
                        role: "dialog"
                      }, $slots) : this.childNodeRef = childNode,
                      dirs
                    );
                  }
                })
              })
            ]
          })),
          [
            [
              vue.vShow,
              this.displayDirective === "if" || this.displayed || this.show
            ]
          ]
        ) : null;
      }
    });

    var style$O = c$1([cB("modal-container", `
    position: fixed;
    left: 0;
    top: 0;
    height: 0;
    width: 0;
    display: flex;
  `), cB("modal-mask", `
    position: fixed;
    left: 0;
    right: 0;
    top: 0;
    bottom: 0;
    background-color: rgba(0, 0, 0, .4);
  `, [fadeInTransition({
      enterDuration: ".25s",
      leaveDuration: ".25s",
      enterCubicBezier: "var(--n-bezier-ease-out)",
      leaveCubicBezier: "var(--n-bezier-ease-out)"
    })]), cB("modal-body-wrapper", `
    position: fixed;
    left: 0;
    right: 0;
    top: 0;
    bottom: 0;
    overflow: visible;
  `, [cB("modal-scroll-content", `
      min-height: 100%;
      display: flex;
      position: relative;
    `)]), cB("modal", `
    position: relative;
    align-self: center;
    color: var(--n-text-color);
    margin: auto;
    box-shadow: var(--n-box-shadow);
  `, [fadeInScaleUpTransition({
      duration: ".25s",
      enterScale: ".5"
    })])]);

    const modalProps = {
      ...useTheme.props,
      show: Boolean,
      unstableShowMask: {
        type: Boolean,
        default: true
      },
      maskClosable: {
        type: Boolean,
        default: true
      },
      preset: String,
      to: [String, Object],
      displayDirective: {
        type: String,
        default: "if"
      },
      transformOrigin: {
        type: String,
        default: "mouse"
      },
      zIndex: Number,
      autoFocus: {
        type: Boolean,
        default: true
      },
      trapFocus: {
        type: Boolean,
        default: true
      },
      closeOnEsc: {
        type: Boolean,
        default: true
      },
      blockScroll: { type: Boolean, default: true },
      ...presetProps,
      onEsc: Function,
      "onUpdate:show": [Function, Array],
      onUpdateShow: [Function, Array],
      onAfterEnter: Function,
      onBeforeLeave: Function,
      onAfterLeave: Function,
      onClose: Function,
      onPositiveClick: Function,
      onNegativeClick: Function,
      onMaskClick: Function,
      internalDialog: Boolean,
      internalAppear: {
        type: Boolean,
        default: void 0
      },
      overlayStyle: [String, Object],
      onBeforeHide: Function,
      onAfterHide: Function,
      onHide: Function
    };
    var NModal = vue.defineComponent({
      name: "Modal",
      inheritAttrs: false,
      props: modalProps,
      setup(props) {
        {
          if (props.onHide) {
            warnOnce("modal", "`on-hide` is deprecated.");
          }
          if (props.onAfterHide) {
            warnOnce(
              "modal",
              "`on-after-hide` is deprecated, please use `on-after-leave` instead."
            );
          }
          if (props.onBeforeHide) {
            warnOnce(
              "modal",
              "`on-before-hide` is deprecated, please use `on-before-leave` instead."
            );
          }
          if (props.overlayStyle) {
            warnOnce(
              "modal",
              "`overlay-style` is deprecated, please use `style` instead."
            );
          }
        }
        const containerRef = vue.ref(null);
        const { mergedClsPrefixRef, namespaceRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Modal",
          "-modal",
          style$O,
          modalLight$1,
          props,
          mergedClsPrefixRef
        );
        const clickedRef = useClicked(64);
        const clickedPositionRef = useClickPosition();
        const isMountedRef = isMounted();
        const NDialogProvider = props.internalDialog ? vue.inject(dialogProviderInjectionKey, null) : null;
        const isComposingRef = useIsComposing();
        function doUpdateShow(show) {
          const { onUpdateShow, "onUpdate:show": _onUpdateShow, onHide } = props;
          if (onUpdateShow)
            call(onUpdateShow, show);
          if (_onUpdateShow)
            call(_onUpdateShow, show);
          if (onHide && !show)
            onHide(show);
        }
        function handleCloseClick() {
          const { onClose } = props;
          if (onClose) {
            void Promise.resolve(onClose()).then((value) => {
              if (value === false)
                return;
              doUpdateShow(false);
            });
          } else {
            doUpdateShow(false);
          }
        }
        function handlePositiveClick() {
          const { onPositiveClick } = props;
          if (onPositiveClick) {
            void Promise.resolve(onPositiveClick()).then((value) => {
              if (value === false)
                return;
              doUpdateShow(false);
            });
          } else {
            doUpdateShow(false);
          }
        }
        function handleNegativeClick() {
          const { onNegativeClick } = props;
          if (onNegativeClick) {
            void Promise.resolve(onNegativeClick()).then((value) => {
              if (value === false)
                return;
              doUpdateShow(false);
            });
          } else {
            doUpdateShow(false);
          }
        }
        function handleBeforeLeave() {
          const { onBeforeLeave, onBeforeHide } = props;
          if (onBeforeLeave)
            call(onBeforeLeave);
          if (onBeforeHide)
            onBeforeHide();
        }
        function handleAfterLeave() {
          const { onAfterLeave, onAfterHide } = props;
          if (onAfterLeave)
            call(onAfterLeave);
          if (onAfterHide)
            onAfterHide();
        }
        function handleClickoutside(e) {
          const { onMaskClick } = props;
          if (onMaskClick) {
            onMaskClick(e);
          }
          if (props.maskClosable) {
            if (containerRef.value?.contains(getPreciseEventTarget(e))) {
              doUpdateShow(false);
            }
          }
        }
        function handleEsc(e) {
          props.onEsc?.();
          if (props.show && props.closeOnEsc && eventEffectNotPerformed(e)) {
            !isComposingRef.value && doUpdateShow(false);
          }
        }
        vue.provide(modalInjectionKey, {
          getMousePosition: () => {
            if (NDialogProvider) {
              const { clickedRef: clickedRef2, clickPositionRef } = NDialogProvider;
              if (clickedRef2.value && clickPositionRef.value) {
                return clickPositionRef.value;
              }
            }
            if (clickedRef.value) {
              return clickedPositionRef.value;
            }
            return null;
          },
          mergedClsPrefixRef,
          mergedThemeRef: themeRef,
          isMountedRef,
          appearRef: vue.toRef(props, "internalAppear"),
          transformOriginRef: vue.toRef(props, "transformOrigin")
        });
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseOut },
            self: { boxShadow, color, textColor }
          } = themeRef.value;
          return {
            "--n-bezier-ease-out": cubicBezierEaseOut,
            "--n-box-shadow": boxShadow,
            "--n-color": color,
            "--n-text-color": textColor
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("theme-class", void 0, cssVarsRef, props) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          namespace: namespaceRef,
          isMounted: isMountedRef,
          containerRef,
          presetProps: vue.computed(() => {
            const pickedProps = keep(props, presetPropsKeys);
            return pickedProps;
          }),
          handleEsc,
          handleAfterLeave,
          handleClickoutside,
          handleBeforeLeave,
          doUpdateShow,
          handleNegativeClick,
          handlePositiveClick,
          handleCloseClick,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedClsPrefix } = this;
        return /* @__PURE__ */ React.createElement(LazyTeleport, {
          to: this.to,
          show: this.show
        }, {
          default: () => {
            this.onRender?.();
            const { unstableShowMask } = this;
            return vue.withDirectives(
              /* @__PURE__ */ React.createElement("div", {
                role: "none",
                ref: "containerRef",
                class: [
                  `${mergedClsPrefix}-modal-container`,
                  this.themeClass,
                  this.namespace
                ],
                style: this.cssVars
              }, /* @__PURE__ */ React.createElement(NModalBodyWrapper, {
                style: this.overlayStyle,
                ...this.$attrs,
                ref: "bodyWrapper",
                displayDirective: this.displayDirective,
                show: this.show,
                preset: this.preset,
                autoFocus: this.autoFocus,
                trapFocus: this.trapFocus,
                blockScroll: this.blockScroll,
                ...this.presetProps,
                onEsc: this.handleEsc,
                onClose: this.handleCloseClick,
                onNegativeClick: this.handleNegativeClick,
                onPositiveClick: this.handlePositiveClick,
                onBeforeLeave: this.handleBeforeLeave,
                onAfterEnter: this.onAfterEnter,
                onAfterLeave: this.handleAfterLeave,
                onClickoutside: unstableShowMask ? void 0 : this.handleClickoutside,
                renderMask: unstableShowMask ? () => /* @__PURE__ */ React.createElement(vue.Transition, {
                  name: "fade-in-transition",
                  key: "mask",
                  appear: this.internalAppear ?? this.isMounted
                }, {
                  default: () => {
                    return this.show ? /* @__PURE__ */ React.createElement("div", {
                      "aria-hidden": true,
                      ref: "containerRef",
                      class: `${mergedClsPrefix}-modal-mask`,
                      onClick: this.handleClickoutside
                    }) : null;
                  }
                }) : void 0
              }, this.$slots)),
              [
                [
                  zindexable$1,
                  {
                    zIndex: this.zIndex,
                    enabled: this.show
                  }
                ]
              ]
            );
          }
        });
      }
    });

    const exposedDialogEnvProps = {
      ...dialogProps,
      onAfterEnter: Function,
      blockScroll: { type: Boolean, default: true },
      closeOnEsc: { type: Boolean, default: true },
      onEsc: Function,
      autoFocus: {
        type: Boolean,
        default: true
      },
      internalStyle: [String, Object],
      maskClosable: {
        type: Boolean,
        default: true
      },
      onPositiveClick: Function,
      onNegativeClick: Function,
      onClose: Function,
      onMaskClick: Function
    };
    const NDialogEnvironment = vue.defineComponent({
      name: "DialogEnvironment",
      props: {
        ...exposedDialogEnvProps,
        internalKey: {
          type: String,
          required: true
        },
        to: [String, Object],
        onInternalAfterLeave: {
          type: Function,
          required: true
        }
      },
      setup(props) {
        const showRef = vue.ref(true);
        function handleAfterLeave() {
          props.onInternalAfterLeave(props.internalKey);
        }
        function handlePositiveClick(e) {
          const { onPositiveClick } = props;
          if (onPositiveClick) {
            void Promise.resolve(onPositiveClick(e)).then((result) => {
              if (result === false)
                return;
              hide();
            });
          } else {
            hide();
          }
        }
        function handleNegativeClick(e) {
          const { onNegativeClick } = props;
          if (onNegativeClick) {
            void Promise.resolve(onNegativeClick(e)).then((result) => {
              if (result === false)
                return;
              hide();
            });
          } else {
            hide();
          }
        }
        function handleCloseClick() {
          const { onClose } = props;
          if (onClose) {
            void Promise.resolve(onClose()).then((result) => {
              if (result === false)
                return;
              hide();
            });
          } else {
            hide();
          }
        }
        function handleMaskClick(e) {
          const { onMaskClick, maskClosable } = props;
          if (onMaskClick) {
            onMaskClick(e);
            maskClosable && hide();
          }
        }
        function handleEsc() {
          const { onEsc } = props;
          if (onEsc) {
            onEsc();
          }
        }
        function hide() {
          showRef.value = false;
        }
        function handleUpdateShow(value) {
          showRef.value = value;
        }
        return {
          show: showRef,
          hide,
          handleUpdateShow,
          handleAfterLeave,
          handleCloseClick,
          handleNegativeClick,
          handlePositiveClick,
          handleMaskClick,
          handleEsc
        };
      },
      render() {
        const {
          handlePositiveClick,
          handleUpdateShow,
          handleNegativeClick,
          handleCloseClick,
          handleAfterLeave,
          handleMaskClick,
          handleEsc,
          to,
          maskClosable,
          show
        } = this;
        return /* @__PURE__ */ React.createElement(NModal, {
          show,
          onUpdateShow: handleUpdateShow,
          onMaskClick: handleMaskClick,
          onEsc: handleEsc,
          to,
          maskClosable,
          onAfterEnter: this.onAfterEnter,
          onAfterLeave: handleAfterLeave,
          closeOnEsc: this.closeOnEsc,
          blockScroll: this.blockScroll,
          autoFocus: this.autoFocus,
          internalAppear: true,
          internalDialog: true
        }, {
          default: () => /* @__PURE__ */ React.createElement(NDialog, {
            ...keep(this.$props, dialogPropKeys),
            style: this.internalStyle,
            onClose: handleCloseClick,
            onNegativeClick: handleNegativeClick,
            onPositiveClick: handlePositiveClick
          })
        });
      }
    });

    const dialogProviderProps = {
      injectionKey: String,
      to: [String, Object]
    };
    const NDialogProvider = vue.defineComponent({
      name: "DialogProvider",
      props: dialogProviderProps,

      setup() {
        const dialogListRef = vue.ref([]);
        const dialogInstRefs = {};

        function create() {
          let options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
          const key = createId();
          const dialogReactive = vue.reactive({ ...options,
            key,
            destroy: () => {
              dialogInstRefs[`n-dialog-${key}`].hide();
            }
          });
          dialogListRef.value.push(dialogReactive);
          return dialogReactive;
        }

        const typedApi = ["info", "success", "warning", "error"].map(type => options => {
          return create({ ...options,
            type
          });
        });

        function handleAfterLeave(key) {
          const {
            value: dialogList
          } = dialogListRef;
          dialogList.splice(dialogList.findIndex(dialog => dialog.key === key), 1);
        }

        function destroyAll() {
          Object.values(dialogInstRefs).forEach(dialogInstRef => dialogInstRef.hide());
        }

        const api = {
          create,
          destroyAll,
          info: typedApi[0],
          success: typedApi[1],
          warning: typedApi[2],
          error: typedApi[3]
        };
        vue.provide(dialogApiInjectionKey, api);
        vue.provide(dialogProviderInjectionKey, {
          clickedRef: useClicked(64),
          clickPositionRef: useClickPosition()
        });
        vue.provide(dialogReactiveListInjectionKey, dialogListRef);
        return { ...api,
          dialogList: dialogListRef,
          dialogInstRefs,
          handleAfterLeave
        };
      },

      render() {
        var _this$$slots$default, _this$$slots;

        return vue.h(vue.Fragment, null, [this.dialogList.map(dialog => vue.h(NDialogEnvironment, omit(dialog, ["destroy", "style"], {
          internalStyle: dialog.style,
          to: this.to,
          ref: inst => {
            if (inst === null) {
              delete this.dialogInstRefs[`n-dialog-${dialog.key}`];
            } else {
              this.dialogInstRefs[`n-dialog-${dialog.key}`] = inst;
            }
          },
          internalKey: dialog.key,
          onInternalAfterLeave: this.handleAfterLeave
        }))), (_this$$slots$default = (_this$$slots = this.$slots).default) === null || _this$$slots$default === void 0 ? void 0 : _this$$slots$default.call(_this$$slots)]);
      }

    });

    function useDialog() {
      const dialog = vue.inject(dialogApiInjectionKey, null);

      if (dialog === null) {
        throwError("use-dialog", "No outer <n-dialog-provider /> founded.");
      }

      return dialog;
    }
    function useDialogReactiveList() {
      const dialogReactiveList = vue.inject(dialogReactiveListInjectionKey, null);

      if (dialogReactiveList === null) {
        throwError("use-dialog-reactive-list", "No outer <n-dialog-provider /> founded.");
      }

      return dialogReactiveList;
    }

    const self$C = vars => {
      const {
        textColor1,
        dividerColor,
        fontWeightStrong
      } = vars;
      return {
        textColor: textColor1,
        color: dividerColor,
        fontWeight: fontWeightStrong
      };
    };
    const dividerLight = {
      name: "Divider",
      common: commonLight,
      self: self$C
    };
    var dividerLight$1 = dividerLight;

    const dividerDark = {
      name: "Divider",
      common: commonDark,
      self: self$C
    };
    var dividerDark$1 = dividerDark;

    var style$N = cB("divider", `
  position: relative;
  display: flex;
  width: 100%;
  box-sizing: border-box;
  font-size: 16px;
  color: var(--n-text-color);
  transition:
    color .3s var(--n-bezier),
    background-color .3s var(--n-bezier);
`, [cNotM("vertical", `
    margin-top: 24px;
    margin-bottom: 24px;
  `, [cNotM("no-title", `
      display: flex;
      align-items: center;
    `)]), cE("title", `
    display: flex;
    align-items: center;
    margin-left: 12px;
    margin-right: 12px;
    white-space: nowrap;
    font-weight: var(--n-font-weight);
  `), cM("title-position-left", [cE("line", [cM("left", {
      width: "28px"
    })])]), cM("title-position-right", [cE("line", [cM("right", {
      width: "28px"
    })])]), cM("dashed", [cE("line", `
      background-color: #0000;
      height: 0px;
      width: 100%;
      border-style: dashed;
      border-width: 1px 0 0;
    `)]), cM("vertical", `
    display: inline-block;
    height: 1em;
    margin: 0 8px;
    vertical-align: middle;
    width: 1px;
  `), cE("line", `
    border: none;
    transition: background-color .3s var(--n-bezier), border-color .3s var(--n-bezier);
    height: 1px;
    width: 100%;
    margin: 0;
  `), cNotM("dashed", [cE("line", {
      backgroundColor: "var(--n-color)"
    })]), cM("dashed", [cE("line", {
      borderColor: "var(--n-color)"
    })]), cM("vertical", {
      backgroundColor: "var(--n-color)"
    })]);

    const dividerProps = {
      ...useTheme.props,
      titlePlacement: {
        type: String,
        default: "center"
      },
      dashed: Boolean,
      vertical: Boolean
    };
    var NDivider = vue.defineComponent({
      name: "Divider",
      props: dividerProps,
      setup(props) {
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Divider",
          "-divider",
          style$N,
          dividerLight$1,
          props,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self: { color, textColor, fontWeight }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-color": color,
            "--n-text-color": textColor,
            "--n-font-weight": fontWeight
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("divider", void 0, cssVarsRef, props) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const {
          $slots,
          titlePlacement,
          vertical,
          dashed,
          cssVars,
          mergedClsPrefix
        } = this;
        this.onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          role: "separator",
          class: [
            `${mergedClsPrefix}-divider`,
            this.themeClass,
            {
              [`${mergedClsPrefix}-divider--vertical`]: vertical,
              [`${mergedClsPrefix}-divider--no-title`]: !$slots.default,
              [`${mergedClsPrefix}-divider--dashed`]: dashed,
              [`${mergedClsPrefix}-divider--title-position-${titlePlacement}`]: $slots.default && titlePlacement
            }
          ],
          style: cssVars
        }, !vertical ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-divider__line ${mergedClsPrefix}-divider__line--left`
        }) : null, !vertical && $slots.default ? /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-divider__title`
        }, this.$slots), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-divider__line ${mergedClsPrefix}-divider__line--right`
        })) : null);
      }
    });

    const self$B = vars => {
      const {
        modalColor,
        textColor1,
        textColor2,
        boxShadow3,
        lineHeight,
        fontWeightStrong,
        dividerColor,
        closeColorHover,
        closeColorPressed,
        closeIconColor,
        closeIconColorHover,
        closeIconColorPressed,
        borderRadius,
        primaryColorHover
      } = vars;
      return {
        bodyPadding: "16px 24px",
        headerPadding: "16px 24px",
        footerPadding: "16px 24px",
        color: modalColor,
        textColor: textColor2,
        titleTextColor: textColor1,
        titleFontSize: "18px",
        titleFontWeight: fontWeightStrong,
        boxShadow: boxShadow3,
        lineHeight,
        headerBorderBottom: `1px solid ${dividerColor}`,
        footerBorderTop: `1px solid ${dividerColor}`,
        closeIconColor,
        closeIconColorHover,
        closeIconColorPressed,
        closeSize: "22px",
        closeIconSize: "18px",
        closeColorHover,
        closeColorPressed,
        closeBorderRadius: borderRadius,
        resizableTriggerColorHover: primaryColorHover
      };
    };
    const drawerLight = createTheme$1({
      name: "Drawer",
      common: commonLight,
      peers: {
        Scrollbar: scrollbarLight$1
      },
      self: self$B
    });
    var drawerLight$1 = drawerLight;

    const drawerDark = {
      name: "Drawer",
      common: commonDark,
      peers: {
        Scrollbar: scrollbarDark$1
      },
      self: self$B
    };
    var drawerDark$1 = drawerDark;

    var rtlStyle$e = cB("drawer", [cM("rtl", `
    direction: rtl;
    text-align: right;
  `, [cB("drawer-content", [cB("drawer-header", [cE("close", `
          margin-left: 0;
          margin-right: 6px;
        `)])])])]);

    const drawerRtl = {
      name: "Drawer",
      style: rtlStyle$e,
      peers: [scrollbarRtl]
    };
    var drawerRtl$1 = drawerRtl;

    var NDrawerBodyWrapper = vue.defineComponent({
      name: "NDrawerContent",
      inheritAttrs: false,
      props: {
        blockScroll: Boolean,
        show: {
          type: Boolean,
          default: void 0
        },
        displayDirective: {
          type: String,
          required: true
        },
        placement: {
          type: String,
          required: true
        },
        contentStyle: [Object, String],
        nativeScrollbar: {
          type: Boolean,
          required: true
        },
        scrollbarProps: Object,
        trapFocus: {
          type: Boolean,
          default: true
        },
        autoFocus: {
          type: Boolean,
          default: true
        },
        showMask: {
          type: [Boolean, String],
          required: true
        },
        resizable: Boolean,
        onClickoutside: Function,
        onAfterLeave: Function,
        onAfterEnter: Function,
        onEsc: Function
      },
      setup(props) {
        const displayedRef = vue.ref(!!props.show);
        const bodyRef = vue.ref(null);
        const NDrawer = vue.inject(drawerInjectionKey);
        let startPosition = 0;
        let memoizedBodyStyleCursor = "";
        let hoverTimerId = null;
        const isHoverOnResizeTriggerRef = vue.ref(false);
        const isDraggingRef = vue.ref(false);
        const isVertical = vue.computed(() => {
          return props.placement === "top" || props.placement === "bottom";
        });
        const { mergedClsPrefixRef, mergedRtlRef } = useConfig(props);
        const rtlEnabledRef = useRtl("Drawer", mergedRtlRef, mergedClsPrefixRef);
        const handleMousedownResizeTrigger = (e) => {
          isDraggingRef.value = true;
          startPosition = isVertical.value ? e.clientY : e.clientX;
          memoizedBodyStyleCursor = document.body.style.cursor;
          document.body.style.cursor = isVertical.value ? "ns-resize" : "ew-resize";
          document.body.addEventListener("mousemove", handleBodyMousemove);
          document.body.addEventListener("mouseleave", handleBodyMouseleave);
          document.body.addEventListener("mouseup", handleBodyMouseup);
        };
        const handleMouseenterResizeTrigger = () => {
          if (hoverTimerId !== null) {
            window.clearTimeout(hoverTimerId);
            hoverTimerId = null;
          }
          if (isDraggingRef.value) {
            isHoverOnResizeTriggerRef.value = true;
          } else {
            hoverTimerId = window.setTimeout(() => {
              isHoverOnResizeTriggerRef.value = true;
            }, 300);
          }
        };
        const handleMouseleaveResizeTrigger = () => {
          if (hoverTimerId !== null) {
            window.clearTimeout(hoverTimerId);
            hoverTimerId = null;
          }
          isHoverOnResizeTriggerRef.value = false;
        };
        const { doUpdateHeight, doUpdateWidth } = NDrawer;
        const handleBodyMousemove = (e) => {
          if (isDraggingRef.value) {
            if (isVertical.value) {
              let height = bodyRef.value?.offsetHeight || 0;
              const increment = startPosition - e.clientY;
              height += props.placement === "bottom" ? increment : -increment;
              doUpdateHeight(height);
              startPosition = e.clientY;
            } else {
              let width = bodyRef.value?.offsetWidth || 0;
              const increment = startPosition - e.clientX;
              width += props.placement === "right" ? increment : -increment;
              doUpdateWidth(width);
              startPosition = e.clientX;
            }
          }
        };
        const handleBodyMouseup = () => {
          if (isDraggingRef.value) {
            startPosition = 0;
            isDraggingRef.value = false;
            document.body.style.cursor = memoizedBodyStyleCursor;
            document.body.removeEventListener("mousemove", handleBodyMousemove);
            document.body.removeEventListener("mouseup", handleBodyMouseup);
            document.body.removeEventListener("mouseleave", handleBodyMouseleave);
          }
        };
        const handleBodyMouseleave = handleBodyMouseup;
        vue.watchEffect(() => {
          if (props.show)
            displayedRef.value = true;
        });
        vue.watch(
          () => props.show,
          (value) => {
            if (!value) {
              handleBodyMouseup();
            }
          }
        );
        vue.onBeforeUnmount(() => {
          handleBodyMouseup();
        });
        const bodyDirectivesRef = vue.computed(() => {
          const { show } = props;
          const directives = [[vue.vShow, show]];
          if (!props.showMask) {
            directives.push([
              clickoutside$1,
              props.onClickoutside,
              void 0,
              { capture: true }
            ]);
          }
          return directives;
        });
        function handleAfterLeave() {
          displayedRef.value = false;
          props.onAfterLeave?.();
        }
        useLockHtmlScroll(vue.computed(() => props.blockScroll && displayedRef.value));
        vue.provide(drawerBodyInjectionKey, bodyRef);
        vue.provide(popoverBodyInjectionKey, null);
        vue.provide(modalBodyInjectionKey, null);
        return {
          bodyRef,
          rtlEnabled: rtlEnabledRef,
          mergedClsPrefix: NDrawer.mergedClsPrefixRef,
          isMounted: NDrawer.isMountedRef,
          mergedTheme: NDrawer.mergedThemeRef,
          displayed: displayedRef,
          transitionName: vue.computed(() => {
            return {
              right: "slide-in-from-right-transition",
              left: "slide-in-from-left-transition",
              top: "slide-in-from-top-transition",
              bottom: "slide-in-from-bottom-transition"
            }[props.placement];
          }),
          handleAfterLeave,
          bodyDirectives: bodyDirectivesRef,
          handleMousedownResizeTrigger,
          handleMouseenterResizeTrigger,
          handleMouseleaveResizeTrigger,
          isDragging: isDraggingRef,
          isHoverOnResizeTrigger: isHoverOnResizeTriggerRef
        };
      },
      render() {
        const { $slots, mergedClsPrefix } = this;
        return this.displayDirective === "show" || this.displayed || this.show ? vue.withDirectives(
          /* @__PURE__ */ React.createElement("div", {
            role: "none"
          }, /* @__PURE__ */ React.createElement(FocusTrap, {
            disabled: !this.showMask || !this.trapFocus,
            active: this.show,
            autoFocus: this.autoFocus,
            onEsc: this.onEsc
          }, {
            default: () => /* @__PURE__ */ React.createElement(vue.Transition, {
              name: this.transitionName,
              appear: this.isMounted,
              onAfterEnter: this.onAfterEnter,
              onAfterLeave: this.handleAfterLeave
            }, {
              default: () => vue.withDirectives(
                vue.h(
                  "div",
                  vue.mergeProps(this.$attrs, {
                    role: "dialog",
                    ref: "bodyRef",
                    "aria-modal": "true",
                    class: [
                      `${mergedClsPrefix}-drawer`,
                      this.rtlEnabled && `${mergedClsPrefix}-drawer--rtl`,
                      `${mergedClsPrefix}-drawer--${this.placement}-placement`,
                      this.isDragging && `${mergedClsPrefix}-drawer--unselectable`,
                      this.nativeScrollbar && `${mergedClsPrefix}-drawer--native-scrollbar`
                    ]
                  }),
                  [
                    this.resizable ? /* @__PURE__ */ React.createElement("div", {
                      class: [
                        `${mergedClsPrefix}-drawer__resize-trigger`,
                        (this.isDragging || this.isHoverOnResizeTrigger) && `${mergedClsPrefix}-drawer__resize-trigger--hover`
                      ],
                      onMouseenter: this.handleMouseenterResizeTrigger,
                      onMouseleave: this.handleMouseleaveResizeTrigger,
                      onMousedown: this.handleMousedownResizeTrigger
                    }) : null,
                    this.nativeScrollbar ? /* @__PURE__ */ React.createElement("div", {
                      class: `${mergedClsPrefix}-drawer-content-wrapper`,
                      style: this.contentStyle,
                      role: "none"
                    }, $slots) : /* @__PURE__ */ React.createElement(NScrollbar, {
                      ...this.scrollbarProps,
                      contentStyle: this.contentStyle,
                      contentClass: `${mergedClsPrefix}-drawer-content-wrapper`,
                      theme: this.mergedTheme.peers.Scrollbar,
                      themeOverrides: this.mergedTheme.peerOverrides.Scrollbar
                    }, $slots)
                  ]
                ),
                this.bodyDirectives
              )
            })
          })),
          [
            [
              vue.vShow,
              this.displayDirective === "if" || this.displayed || this.show
            ]
          ]
        ) : null;
      }
    });

    const {
      cubicBezierEaseIn: cubicBezierEaseIn$3,
      cubicBezierEaseOut: cubicBezierEaseOut$3
    } = commonVariables$m;
    function slideInFromRightTransition() {
      let {
        duration = "0.3s",
        leaveDuration = "0.2s",
        name = "slide-in-from-right"
      } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      return [c$1(`&.${name}-transition-leave-active`, {
        transition: `transform ${leaveDuration} ${cubicBezierEaseIn$3}`
      }), c$1(`&.${name}-transition-enter-active`, {
        transition: `transform ${duration} ${cubicBezierEaseOut$3}`
      }), c$1(`&.${name}-transition-enter-to`, {
        transform: "translateX(0)"
      }), c$1(`&.${name}-transition-enter-from`, {
        transform: "translateX(100%)"
      }), c$1(`&.${name}-transition-leave-from`, {
        transform: "translateX(0)"
      }), c$1(`&.${name}-transition-leave-to`, {
        transform: "translateX(100%)"
      })];
    }

    const {
      cubicBezierEaseIn: cubicBezierEaseIn$2,
      cubicBezierEaseOut: cubicBezierEaseOut$2
    } = commonVariables$m;
    function slideInFromLeftTransition() {
      let {
        duration = "0.3s",
        leaveDuration = "0.2s",
        name = "slide-in-from-left"
      } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      return [c$1(`&.${name}-transition-leave-active`, {
        transition: `transform ${leaveDuration} ${cubicBezierEaseIn$2}`
      }), c$1(`&.${name}-transition-enter-active`, {
        transition: `transform ${duration} ${cubicBezierEaseOut$2}`
      }), c$1(`&.${name}-transition-enter-to`, {
        transform: "translateX(0)"
      }), c$1(`&.${name}-transition-enter-from`, {
        transform: "translateX(-100%)"
      }), c$1(`&.${name}-transition-leave-from`, {
        transform: "translateX(0)"
      }), c$1(`&.${name}-transition-leave-to`, {
        transform: "translateX(-100%)"
      })];
    }

    const {
      cubicBezierEaseIn: cubicBezierEaseIn$1,
      cubicBezierEaseOut: cubicBezierEaseOut$1
    } = commonVariables$m;
    function slideInFromTopTransition() {
      let {
        duration = "0.3s",
        leaveDuration = "0.2s",
        name = "slide-in-from-top"
      } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      return [c$1(`&.${name}-transition-leave-active`, {
        transition: `transform ${leaveDuration} ${cubicBezierEaseIn$1}`
      }), c$1(`&.${name}-transition-enter-active`, {
        transition: `transform ${duration} ${cubicBezierEaseOut$1}`
      }), c$1(`&.${name}-transition-enter-to`, {
        transform: "translateY(0)"
      }), c$1(`&.${name}-transition-enter-from`, {
        transform: "translateY(-100%)"
      }), c$1(`&.${name}-transition-leave-from`, {
        transform: "translateY(0)"
      }), c$1(`&.${name}-transition-leave-to`, {
        transform: "translateY(-100%)"
      })];
    }

    const {
      cubicBezierEaseIn,
      cubicBezierEaseOut
    } = commonVariables$m;
    function slideInFromBottomTransition() {
      let {
        duration = "0.3s",
        leaveDuration = "0.2s",
        name = "slide-in-from-bottom"
      } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      return [c$1(`&.${name}-transition-leave-active`, {
        transition: `transform ${leaveDuration} ${cubicBezierEaseIn}`
      }), c$1(`&.${name}-transition-enter-active`, {
        transition: `transform ${duration} ${cubicBezierEaseOut}`
      }), c$1(`&.${name}-transition-enter-to`, {
        transform: "translateY(0)"
      }), c$1(`&.${name}-transition-enter-from`, {
        transform: "translateY(100%)"
      }), c$1(`&.${name}-transition-leave-from`, {
        transform: "translateY(0)"
      }), c$1(`&.${name}-transition-leave-to`, {
        transform: "translateY(100%)"
      })];
    }

    var style$M = c$1([cB("drawer", `
    word-break: break-word;
    line-height: var(--n-line-height);
    position: absolute;
    pointer-events: all;
    box-shadow: var(--n-box-shadow);
    transition:
      background-color .3s var(--n-bezier),
      color .3s var(--n-bezier);
    background-color: var(--n-color);
    color: var(--n-text-color);
    box-sizing: border-box;
  `, [slideInFromRightTransition(), slideInFromLeftTransition(), slideInFromTopTransition(), slideInFromBottomTransition(), cM("unselectable", `
      user-select: none; 
      -webkit-user-select: none;
    `), cM("native-scrollbar", [cB("drawer-content-wrapper", `
        overflow: auto;
        height: 100%;
      `)]), cE("resize-trigger", `
      position: absolute;
      background-color: #0000;
      transition: background-color .3s var(--n-bezier);
    `, [cM("hover", `
        background-color: var(--n-resize-trigger-color-hover);
      `)]), cB("drawer-content-wrapper", `
      box-sizing: border-box;
    `), cB("drawer-content", `
      height: 100%;
      display: flex;
      flex-direction: column;
    `, [cM("native-scrollbar", [cB("drawer-body-content-wrapper", `
          height: 100%;
          overflow: auto;
        `)]), cB("drawer-body", `
        flex: 1 0 0;
        overflow: hidden;
      `), cB("drawer-body-content-wrapper", `
        box-sizing: border-box;
        padding: var(--n-body-padding);
      `), cB("drawer-header", `
        font-weight: var(--n-title-font-weight);
        line-height: 1;
        font-size: var(--n-title-font-size);
        color: var(--n-title-text-color);
        padding: var(--n-header-padding);
        transition: border .3s var(--n-bezier);
        border-bottom: 1px solid var(--n-divider-color);
        border-bottom: var(--n-header-border-bottom);
        display: flex;
        justify-content: space-between;
        align-items: center;
      `, [cE("close", `
          margin-left: 6px;
          transition:
            background-color .3s var(--n-bezier),
            color .3s var(--n-bezier);
        `)]), cB("drawer-footer", `
        display: flex;
        justify-content: flex-end;
        border-top: var(--n-footer-border-top);
        transition: border .3s var(--n-bezier);
        padding: var(--n-footer-padding);
      `)]), cM("right-placement", `
      top: 0;
      bottom: 0;
      right: 0;
    `, [cE("resize-trigger", `
        width: 3px;
        height: 100%;
        top: 0;
        left: 0;
        transform: translateX(-1.5px);
        cursor: ew-resize;
      `)]), cM("left-placement", `
      top: 0;
      bottom: 0;
      left: 0;
    `, [cE("resize-trigger", `
        width: 3px;
        height: 100%;
        top: 0;
        right: 0;
        transform: translateX(1.5px);
        cursor: ew-resize;
      `)]), cM("top-placement", `
      top: 0;
      left: 0;
      right: 0;
    `, [cE("resize-trigger", `
        width: 100%;
        height: 3px;
        bottom: 0;
        left: 0;
        transform: translateY(1.5px);
        cursor: ns-resize;
      `)]), cM("bottom-placement", `
      left: 0;
      bottom: 0;
      right: 0;
    `, [cE("resize-trigger", `
        width: 100%;
        height: 3px;
        top: 0;
        left: 0;
        transform: translateY(-1.5px);
        cursor: ns-resize;
      `)])]), c$1("body", [c$1(">", [cB("drawer-container", {
      position: "fixed"
    })])]), cB("drawer-container", `
    position: relative;
    position: absolute;
    left: 0;
    right: 0;
    top: 0;
    bottom: 0;
    pointer-events: none;
  `, [c$1("> *", {
      pointerEvents: "all"
    })]), cB("drawer-mask", `
    background-color: rgba(0, 0, 0, .3);
    position: absolute;
    left: 0;
    right: 0;
    top: 0;
    bottom: 0;
  `, [cM("invisible", `
      background-color: rgba(0, 0, 0, 0)
    `), fadeInTransition({
      enterDuration: "0.2s",
      leaveDuration: "0.2s",
      enterCubicBezier: "var(--n-bezier-in)",
      leaveCubicBezier: "var(--n-bezier-out)"
    })])]);

    const drawerProps = {
      ...useTheme.props,
      show: Boolean,
      width: [Number, String],
      height: [Number, String],
      placement: {
        type: String,
        default: "right"
      },
      maskClosable: {
        type: Boolean,
        default: true
      },
      showMask: {
        type: [Boolean, String],
        default: true
      },
      to: [String, Object],
      displayDirective: {
        type: String,
        default: "if"
      },
      nativeScrollbar: {
        type: Boolean,
        default: true
      },
      zIndex: Number,
      onMaskClick: Function,
      scrollbarProps: Object,
      contentStyle: [Object, String],
      trapFocus: {
        type: Boolean,
        default: true
      },
      onEsc: Function,
      autoFocus: {
        type: Boolean,
        default: true
      },
      closeOnEsc: {
        type: Boolean,
        default: true
      },
      blockScroll: {
        type: Boolean,
        default: true
      },
      resizable: Boolean,
      defaultWidth: {
        type: [Number, String],
        default: 251
      },
      defaultHeight: {
        type: [Number, String],
        default: 251
      },
      onUpdateWidth: [Function, Array],
      onUpdateHeight: [Function, Array],
      "onUpdate:width": [Function, Array],
      "onUpdate:height": [Function, Array],
      "onUpdate:show": [Function, Array],
      onUpdateShow: [Function, Array],
      onAfterEnter: Function,
      onAfterLeave: Function,
      drawerStyle: [String, Object],
      drawerClass: String,
      target: null,
      onShow: Function,
      onHide: Function
    };
    var Drawer = vue.defineComponent({
      name: "Drawer",
      inheritAttrs: false,
      props: drawerProps,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.drawerStyle !== void 0) {
              warnOnce(
                "drawer",
                "`drawer-style` is deprecated, please use `style` instead."
              );
            }
            if (props.drawerClass !== void 0) {
              warnOnce(
                "drawer",
                "`drawer-class` is deprecated, please use `class` instead."
              );
            }
            if (props.target !== void 0) {
              warnOnce("drawer", "`target` is deprecated, please use `to` instead.");
            }
            if (props.onShow !== void 0) {
              warnOnce(
                "drawer",
                "`on-show` is deprecated, please use `on-update:show` instead."
              );
            }
            if (props.onHide !== void 0) {
              warnOnce(
                "drawer",
                "`on-hide` is deprecated, please use `on-update:show` instead."
              );
            }
          });
        }
        const { mergedClsPrefixRef, namespaceRef, inlineThemeDisabled } = useConfig(props);
        const isMountedRef = isMounted();
        const themeRef = useTheme(
          "Drawer",
          "-drawer",
          style$M,
          drawerLight$1,
          props,
          mergedClsPrefixRef
        );
        const uncontrolledWidthRef = vue.ref(props.defaultWidth);
        const uncontrolledHeightRef = vue.ref(props.defaultHeight);
        const mergedWidthRef = useMergedState(
          vue.toRef(props, "width"),
          uncontrolledWidthRef
        );
        const mergedHeightRef = useMergedState(
          vue.toRef(props, "height"),
          uncontrolledHeightRef
        );
        const styleWidthRef = vue.computed(() => {
          const { placement } = props;
          if (placement === "top" || placement === "bottom")
            return "";
          return formatLength(mergedWidthRef.value);
        });
        const styleHeightRef = vue.computed(() => {
          const { placement } = props;
          if (placement === "left" || placement === "right")
            return "";
          return formatLength(mergedHeightRef.value);
        });
        const doUpdateWidth = (value) => {
          const { onUpdateWidth, "onUpdate:width": _onUpdateWidth } = props;
          if (onUpdateWidth)
            call(onUpdateWidth, value);
          if (_onUpdateWidth)
            call(_onUpdateWidth, value);
          uncontrolledWidthRef.value = value;
        };
        const doUpdateHeight = (value) => {
          const { onUpdateHeight, "onUpdate:width": _onUpdateHeight } = props;
          if (onUpdateHeight)
            call(onUpdateHeight, value);
          if (_onUpdateHeight)
            call(_onUpdateHeight, value);
          uncontrolledHeightRef.value = value;
        };
        const mergedBodyStyleRef = vue.computed(() => {
          return [
            {
              width: styleWidthRef.value,
              height: styleHeightRef.value
            },
            props.drawerStyle || ""
          ];
        });
        function handleMaskClick(e) {
          const { onMaskClick, maskClosable } = props;
          if (maskClosable) {
            doUpdateShow(false);
          }
          if (onMaskClick)
            onMaskClick(e);
        }
        const isComposingRef = useIsComposing();
        function handleEsc(e) {
          props.onEsc?.();
          if (props.show && props.closeOnEsc && eventEffectNotPerformed(e)) {
            !isComposingRef.value && doUpdateShow(false);
          }
        }
        function doUpdateShow(show) {
          const { onHide, onUpdateShow, "onUpdate:show": _onUpdateShow } = props;
          if (onUpdateShow)
            call(onUpdateShow, show);
          if (_onUpdateShow)
            call(_onUpdateShow, show);
          if (onHide && !show)
            call(onHide, show);
        }
        vue.provide(drawerInjectionKey, {
          isMountedRef,
          mergedThemeRef: themeRef,
          mergedClsPrefixRef,
          doUpdateShow,
          doUpdateHeight,
          doUpdateWidth
        });
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut, cubicBezierEaseIn, cubicBezierEaseOut },
            self: {
              color,
              textColor,
              boxShadow,
              lineHeight,
              headerPadding,
              footerPadding,
              bodyPadding,
              titleFontSize,
              titleTextColor,
              titleFontWeight,
              headerBorderBottom,
              footerBorderTop,
              closeIconColor,
              closeIconColorHover,
              closeIconColorPressed,
              closeColorHover,
              closeColorPressed,
              closeIconSize,
              closeSize,
              closeBorderRadius,
              resizableTriggerColorHover
            }
          } = themeRef.value;
          return {
            "--n-line-height": lineHeight,
            "--n-color": color,
            "--n-text-color": textColor,
            "--n-box-shadow": boxShadow,
            "--n-bezier": cubicBezierEaseInOut,
            "--n-bezier-out": cubicBezierEaseOut,
            "--n-bezier-in": cubicBezierEaseIn,
            "--n-header-padding": headerPadding,
            "--n-body-padding": bodyPadding,
            "--n-footer-padding": footerPadding,
            "--n-title-text-color": titleTextColor,
            "--n-title-font-size": titleFontSize,
            "--n-title-font-weight": titleFontWeight,
            "--n-header-border-bottom": headerBorderBottom,
            "--n-footer-border-top": footerBorderTop,
            "--n-close-icon-color": closeIconColor,
            "--n-close-icon-color-hover": closeIconColorHover,
            "--n-close-icon-color-pressed": closeIconColorPressed,
            "--n-close-size": closeSize,
            "--n-close-color-hover": closeColorHover,
            "--n-close-color-pressed": closeColorPressed,
            "--n-close-icon-size": closeIconSize,
            "--n-close-border-radius": closeBorderRadius,
            "--n-resize-trigger-color-hover": resizableTriggerColorHover
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("drawer", void 0, cssVarsRef, props) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          namespace: namespaceRef,
          mergedBodyStyle: mergedBodyStyleRef,
          handleMaskClick,
          handleEsc,
          mergedTheme: themeRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender,
          isMounted: isMountedRef
        };
      },
      render() {
        const { mergedClsPrefix } = this;
        return /* @__PURE__ */ React.createElement(LazyTeleport, {
          to: this.to,
          show: this.show
        }, {
          default: () => {
            this.onRender?.();
            return vue.withDirectives(
              /* @__PURE__ */ React.createElement("div", {
                class: [
                  `${mergedClsPrefix}-drawer-container`,
                  this.namespace,
                  this.themeClass
                ],
                style: this.cssVars,
                role: "none"
              }, this.showMask ? /* @__PURE__ */ React.createElement(vue.Transition, {
                name: "fade-in-transition",
                appear: this.isMounted
              }, {
                default: () => this.show ? /* @__PURE__ */ React.createElement("div", {
                  "aria-hidden": true,
                  class: [
                    `${mergedClsPrefix}-drawer-mask`,
                    this.showMask === "transparent" && `${mergedClsPrefix}-drawer-mask--invisible`
                  ],
                  onClick: this.handleMaskClick
                }) : null
              }) : null, /* @__PURE__ */ React.createElement(NDrawerBodyWrapper, {
                ...this.$attrs,
                class: [this.drawerClass, this.$attrs.class],
                style: [this.mergedBodyStyle, this.$attrs.style],
                blockScroll: this.blockScroll,
                contentStyle: this.contentStyle,
                placement: this.placement,
                scrollbarProps: this.scrollbarProps,
                show: this.show,
                displayDirective: this.displayDirective,
                nativeScrollbar: this.nativeScrollbar,
                onAfterEnter: this.onAfterEnter,
                onAfterLeave: this.onAfterLeave,
                trapFocus: this.trapFocus,
                autoFocus: this.autoFocus,
                resizable: this.resizable,
                showMask: this.showMask,
                onEsc: this.handleEsc,
                onClickoutside: this.handleMaskClick
              }, this.$slots)),
              [[zindexable$1, { zIndex: this.zIndex, enabled: this.show }]]
            );
          }
        });
      }
    });

    const drawerContentProps = {
      title: {
        type: String
      },
      headerStyle: [Object, String],
      footerStyle: [Object, String],
      bodyStyle: [Object, String],
      bodyContentStyle: [Object, String],
      nativeScrollbar: { type: Boolean, default: true },
      scrollbarProps: Object,
      closable: Boolean
    };
    var DrawerContent = vue.defineComponent({
      name: "DrawerContent",
      props: drawerContentProps,
      setup() {
        const NDrawer = vue.inject(drawerInjectionKey, null);
        if (!NDrawer) {
          throwError(
            "drawer-content",
            "`n-drawer-content` must be placed inside `n-drawer`."
          );
        }
        const { doUpdateShow } = NDrawer;
        function handleCloseClick() {
          doUpdateShow(false);
        }
        return {
          handleCloseClick,
          mergedTheme: NDrawer.mergedThemeRef,
          mergedClsPrefix: NDrawer.mergedClsPrefixRef
        };
      },
      render() {
        const {
          title,
          mergedClsPrefix,
          nativeScrollbar,
          mergedTheme,
          bodyStyle,
          bodyContentStyle,
          headerStyle,
          footerStyle,
          scrollbarProps,
          closable,
          $slots
        } = this;
        return /* @__PURE__ */ React.createElement("div", {
          role: "none",
          class: [
            `${mergedClsPrefix}-drawer-content`,
            nativeScrollbar && `${mergedClsPrefix}-drawer-content--native-scrollbar`
          ]
        }, $slots.header || title || closable ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-drawer-header`,
          style: headerStyle,
          role: "none"
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-drawer-header__main`,
          role: "heading",
          "aria-level": "1"
        }, $slots.header !== void 0 ? $slots.header() : title), closable && /* @__PURE__ */ React.createElement(NBaseClose, {
          onClick: this.handleCloseClick,
          clsPrefix: mergedClsPrefix,
          class: `${mergedClsPrefix}-drawer-header__close`,
          absolute: true
        })) : null, nativeScrollbar ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-drawer-body`,
          style: bodyStyle,
          role: "none"
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-drawer-body-content-wrapper`,
          style: bodyContentStyle,
          role: "none"
        }, $slots)) : /* @__PURE__ */ React.createElement(NScrollbar, {
          themeOverrides: mergedTheme.peerOverrides.Scrollbar,
          theme: mergedTheme.peers.Scrollbar,
          ...scrollbarProps,
          class: `${mergedClsPrefix}-drawer-body`,
          contentClass: `${mergedClsPrefix}-drawer-body-content-wrapper`,
          contentStyle: bodyContentStyle
        }, $slots), $slots.footer ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-drawer-footer`,
          style: footerStyle,
          role: "none"
        }, $slots.footer()) : null);
      }
    });

    var commonVariables$6 = {
      actionMargin: "0 0 0 20px",
      actionMarginRtl: "0 20px 0 0"
    };

    const dynamicInputDark = {
      name: "DynamicInput",
      common: commonDark,
      peers: {
        Input: inputDark$1,
        Button: buttonDark$1
      },

      self() {
        return commonVariables$6;
      }

    };
    var dynamicInputDark$1 = dynamicInputDark;

    const self$A = () => {
      return commonVariables$6;
    };

    const dynamicInputLight = createTheme$1({
      name: "DynamicInput",
      common: commonLight,
      peers: {
        Input: inputLight$1,
        Button: buttonLight$1
      },
      self: self$A
    });
    var dynamicInputLight$1 = dynamicInputLight;

    var rtlStyle$d = cB("dynamic-input", [cM("rtl", `
    direction: rtl;
  `, [cB("dynamic-input-preset-pair", [cB("dynamic-input-pair-input", [c$1("&:first-child", {
      "margin-left": "12px",
      "margin-right": "0"
    })])]), cB("dynamic-input-item", [cE("action", `
        margin: var(--action-margin-rtl);
      `)])])]);

    function createRightBorderStyle(type) {
      return cM(type + "-type", [c$1("& +", [cB("button", {}, [cM(type + "-type", [cE("border", {
        borderRightWidth: zero
      }), cE("state-border", {
        left: n1
      })])])])]);
    }

    var rtlStyle$c = cB("button-group", [cNotM("vertical", [cM("rtl", `
      direction: rtl;
    `, [cB("button", [c$1("&:last-child:not(:first-child)", `
          margin-right: ${zero};
          border-top-right-radius: ${zero};
          border-bottom-right-radius: ${zero};
        `), c$1("&:first-child:not(:last-child)", `
          margin-left: ${zero};
          border-top-left-radius: ${zero};
          border-bottom-left-radius: ${zero};
        `), c$1("&:not(:last-child):not(:first-child)", `
          margin-left: ${zero};
          margin-right: ${zero};
          border-radius: ${zero};
        `), createRightBorderStyle("default"), cM("ghost", [createRightBorderStyle("primary"), createRightBorderStyle("info"), createRightBorderStyle("success"), createRightBorderStyle("warning"), createRightBorderStyle("error")])])])])]);

    const buttonGroupRtl = {
      name: "ButtonGroup",
      style: rtlStyle$c
    };

    var rtlStyle$b = cB("input-number", [cM("rtl", `
    direction: rtl;
  `)]);

    const inputNumberRtl = {
      name: "InputNumber",
      style: rtlStyle$b,
      peers: [inputRtl, buttonRtl]
    };

    const dynamicInputRtl = {
      name: "DynamicInput",
      style: rtlStyle$d,
      peers: [inputRtl, buttonRtl, buttonGroupRtl, checkboxRtl, inputNumberRtl]
    };

    const dynamicInputInjectionKey = createInjectionKey("n-dynamic-input");

    var NDynamicInputInputPreset = vue.defineComponent({
      name: "DynamicInputInputPreset",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        value: {
          type: String,
          default: ""
        },
        parentPath: String,
        path: String,
        onUpdateValue: {
          type: Function,
          required: true
        }
      },
      setup() {
        const {
          mergedThemeRef,
          placeholderRef
        } = vue.inject(dynamicInputInjectionKey);
        return {
          mergedTheme: mergedThemeRef,
          placeholder: placeholderRef
        };
      },
      render() {
        const { mergedTheme, placeholder, value, clsPrefix, onUpdateValue } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-dynamic-input-preset-input`
        }, /* @__PURE__ */ React.createElement(NInput, {
          theme: mergedTheme.peers.Input,
          "theme-overrides": mergedTheme.peerOverrides.Input,
          value,
          placeholder,
          onUpdateValue
        }));
      }
    });

    var NDynamicInputPairPreset = vue.defineComponent({
      name: "DynamicInputPairPreset",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        value: {
          type: Object,
          default: () => ({
            key: "",
            value: ""
          })
        },
        parentPath: String,
        path: String,
        onUpdateValue: {
          type: Function,
          required: true
        }
      },
      setup(props) {
        const { mergedThemeRef, keyPlaceholderRef, valuePlaceholderRef } = vue.inject(
          dynamicInputInjectionKey
        );
        return {
          mergedTheme: mergedThemeRef,
          keyPlaceholder: keyPlaceholderRef,
          valuePlaceholder: valuePlaceholderRef,
          handleKeyInput(key) {
            props.onUpdateValue({
              key,
              value: props.value.value
            });
          },
          handleValueInput(value) {
            props.onUpdateValue({
              key: props.value.key,
              value
            });
          }
        };
      },
      render() {
        const {
          mergedTheme,
          keyPlaceholder,
          valuePlaceholder,
          value,
          clsPrefix
        } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-dynamic-input-preset-pair`
        }, /* @__PURE__ */ React.createElement(NInput, {
          theme: mergedTheme.peers.Input,
          "theme-overrides": mergedTheme.peerOverrides.Input,
          value: value.key,
          class: `${clsPrefix}-dynamic-input-pair-input`,
          placeholder: keyPlaceholder,
          onUpdateValue: this.handleKeyInput
        }), /* @__PURE__ */ React.createElement(NInput, {
          theme: mergedTheme.peers.Input,
          "theme-overrides": mergedTheme.peerOverrides.Input,
          value: value.value,
          class: `${clsPrefix}-dynamic-input-pair-input`,
          placeholder: valuePlaceholder,
          onUpdateValue: this.handleValueInput
        }));
      }
    });

    var style$L = cB("dynamic-input", {
      width: "100%"
    }, [cB("dynamic-input-item", `
    margin-bottom: 10px;
    display: flex;
    flex-wrap: nowrap;
  `, [cB("dynamic-input-preset-input", {
      flex: 1,
      alignItems: "center"
    }), cB("dynamic-input-preset-pair", `
      flex: 1;
      display: flex;
      align-items: center;
    `, [cB("dynamic-input-pair-input", [c$1("&:first-child", {
      "margin-right": "12px"
    })])]), cE("action", `
      align-self: flex-start;
      display: flex;
      justify-content: flex-end;
      flex-shrink: 0;
      flex-grow: 0;
      margin: var(--action-margin);
    `, [cM("icon", {
      cursor: "pointer"
    })]), c$1("&:last-child", {
      marginBottom: 0
    })]), cB("form-item", `
    padding-top: 0 !important;
    margin-right: 0 !important;
  `, [cB("form-item-blank", {
      paddingTop: "0 !important"
    })])]);

    const globalDataKeyMap = /* @__PURE__ */ new WeakMap();
    const dynamicInputProps = {
      ...useTheme.props,
      max: Number,
      min: {
        type: Number,
        default: 0
      },
      value: Array,
      defaultValue: {
        type: Array,
        default: () => []
      },
      preset: {
        type: String,
        default: "input"
      },
      keyField: String,
      itemStyle: [String, Object],
      keyPlaceholder: {
        type: String,
        default: ""
      },
      valuePlaceholder: {
        type: String,
        default: ""
      },
      placeholder: {
        type: String,
        default: ""
      },
      showSortButton: Boolean,
      createButtonProps: Object,
      onCreate: Function,
      onRemove: Function,
      "onUpdate:value": [Function, Array],
      onUpdateValue: [Function, Array],
      onClear: Function,
      onInput: [Function, Array]
    };
    var DynamicInput = vue.defineComponent({
      name: "DynamicInput",
      props: dynamicInputProps,
      setup(props, { slots }) {
        {
          vue.watchEffect(() => {
            if (props.onClear !== void 0) {
              warnOnce(
                "dynamic-input",
                "`on-clear` is deprecated, it is out of usage anymore."
              );
            }
            if (props.onInput !== void 0) {
              warnOnce(
                "dynamic-input",
                "`on-input` is deprecated, please use `on-update:value` instead."
              );
            }
          });
        }
        const {
          mergedComponentPropsRef,
          mergedClsPrefixRef,
          mergedRtlRef,
          inlineThemeDisabled
        } = useConfig();
        const NFormItem = vue.inject(formItemInjectionKey, null);
        const uncontrolledValueRef = vue.ref(props.defaultValue);
        const controlledValueRef = vue.toRef(props, "value");
        const mergedValueRef = useMergedState(
          controlledValueRef,
          uncontrolledValueRef
        );
        const themeRef = useTheme(
          "DynamicInput",
          "-dynamic-input",
          style$L,
          dynamicInputLight$1,
          props,
          mergedClsPrefixRef
        );
        const insertionDisabledRef = vue.computed(() => {
          const { value: mergedValue } = mergedValueRef;
          if (Array.isArray(mergedValue)) {
            const { max } = props;
            return max !== void 0 && mergedValue.length >= max;
          }
          return false;
        });
        const removeDisabledRef = vue.computed(() => {
          const { value: mergedValue } = mergedValueRef;
          if (Array.isArray(mergedValue))
            return mergedValue.length <= props.min;
          return true;
        });
        const buttonSizeRef = vue.computed(() => {
          return mergedComponentPropsRef?.value?.DynamicInput?.buttonSize;
        });
        function doUpdateValue(value) {
          const { onInput, "onUpdate:value": _onUpdateValue, onUpdateValue } = props;
          if (onInput)
            call(onInput, value);
          if (_onUpdateValue)
            call(_onUpdateValue, value);
          if (onUpdateValue)
            call(onUpdateValue, value);
          uncontrolledValueRef.value = value;
        }
        function ensureKey(value, index) {
          if (value === void 0 || value === null)
            return index;
          if (typeof value !== "object")
            return index;
          const rawValue = vue.isProxy(value) ? vue.toRaw(value) : value;
          let key = globalDataKeyMap.get(rawValue);
          if (key === void 0) {
            globalDataKeyMap.set(rawValue, key = createId());
          }
          return key;
        }
        function handleValueChange(index, value) {
          const { value: mergedValue } = mergedValueRef;
          const newValue = Array.from(mergedValue ?? []);
          const originalItem = newValue[index];
          newValue[index] = value;
          if (originalItem && value && typeof originalItem === "object" && typeof value === "object") {
            const rawOriginal = vue.isProxy(originalItem) ? vue.toRaw(originalItem) : originalItem;
            const rawNew = vue.isProxy(value) ? vue.toRaw(value) : value;
            const originalKey = globalDataKeyMap.get(rawOriginal);
            if (originalKey !== void 0) {
              globalDataKeyMap.set(rawNew, originalKey);
            }
          }
          doUpdateValue(newValue);
        }
        function handleCreateClick() {
          createItem(0);
        }
        function createItem(index) {
          const { value: mergedValue } = mergedValueRef;
          const { onCreate } = props;
          const newValue = Array.from(mergedValue ?? []);
          if (onCreate) {
            newValue.splice(index + 1, 0, onCreate(index + 1));
            doUpdateValue(newValue);
          } else if (slots.default) {
            newValue.splice(index + 1, 0, null);
            doUpdateValue(newValue);
          } else {
            switch (props.preset) {
              case "input":
                newValue.splice(index + 1, 0, "");
                doUpdateValue(newValue);
                break;
              case "pair":
                newValue.splice(index + 1, 0, { key: "", value: "" });
                doUpdateValue(newValue);
                break;
            }
          }
        }
        function remove(index) {
          const { value: mergedValue } = mergedValueRef;
          if (!Array.isArray(mergedValue))
            return;
          const { min } = props;
          if (mergedValue.length <= min)
            return;
          const newValue = Array.from(mergedValue);
          newValue.splice(index, 1);
          doUpdateValue(newValue);
          const { onRemove } = props;
          if (onRemove)
            onRemove(index);
        }
        function swap(array, currentIndex, targetIndex) {
          if (currentIndex < 0 || targetIndex < 0 || currentIndex >= array.length || targetIndex >= array.length) {
            return;
          }
          if (currentIndex === targetIndex)
            return;
          const currentItem = array[currentIndex];
          array[currentIndex] = array[targetIndex];
          array[targetIndex] = currentItem;
        }
        function move(type, index) {
          const { value: mergedValue } = mergedValueRef;
          if (!Array.isArray(mergedValue))
            return;
          const newValue = Array.from(mergedValue);
          if (type === "up") {
            swap(newValue, index, index - 1);
          }
          if (type === "down") {
            swap(newValue, index, index + 1);
          }
          doUpdateValue(newValue);
        }
        vue.provide(dynamicInputInjectionKey, {
          mergedThemeRef: themeRef,
          keyPlaceholderRef: vue.toRef(props, "keyPlaceholder"),
          valuePlaceholderRef: vue.toRef(props, "valuePlaceholder"),
          placeholderRef: vue.toRef(props, "placeholder")
        });
        const rtlEnabledRef = useRtl(
          "DynamicInput",
          mergedRtlRef,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const {
            self: { actionMargin, actionMarginRtl }
          } = themeRef.value;
          return {
            "--action-margin": actionMargin,
            "--action-margin-rtl": actionMarginRtl
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("dynamic-input", void 0, cssVarsRef, props) : void 0;
        return {
          locale: useLocale("DynamicInput").localeRef,
          rtlEnabled: rtlEnabledRef,
          buttonSize: buttonSizeRef,
          mergedClsPrefix: mergedClsPrefixRef,
          NFormItem,
          uncontrolledValue: uncontrolledValueRef,
          mergedValue: mergedValueRef,
          insertionDisabled: insertionDisabledRef,
          removeDisabled: removeDisabledRef,
          handleCreateClick,
          ensureKey,
          handleValueChange,
          remove,
          move,
          createItem,
          mergedTheme: themeRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const {
          $slots,
          buttonSize,
          mergedClsPrefix,
          mergedValue,
          locale,
          mergedTheme,
          keyField,
          itemStyle,
          preset,
          showSortButton,
          NFormItem,
          ensureKey,
          handleValueChange,
          remove,
          createItem,
          move,
          onRender
        } = this;
        onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-dynamic-input`,
            this.rtlEnabled && `${mergedClsPrefix}-dynamic-input--rtl`,
            this.themeClass
          ],
          style: this.cssVars
        }, !Array.isArray(mergedValue) || mergedValue.length === 0 ? /* @__PURE__ */ React.createElement(NButton, {
          block: true,
          ghost: true,
          dashed: true,
          size: buttonSize,
          ...this.createButtonProps,
          disabled: this.insertionDisabled,
          theme: mergedTheme.peers.Button,
          themeOverrides: mergedTheme.peerOverrides.Button,
          onClick: this.handleCreateClick
        }, {
          default: () => resolveSlot($slots["create-button-default"], () => [
            locale.create
          ]),
          icon: () => resolveSlot($slots["create-button-icon"], () => [
            /* @__PURE__ */ React.createElement(NBaseIcon, {
              clsPrefix: mergedClsPrefix
            }, { default: () => /* @__PURE__ */ React.createElement(AddIcon, null) })
          ])
        }) : mergedValue.map((_, index) => /* @__PURE__ */ React.createElement("div", {
          key: keyField ? _[keyField] : ensureKey(_, index),
          "data-key": keyField ? _[keyField] : ensureKey(_, index),
          class: `${mergedClsPrefix}-dynamic-input-item`,
          style: itemStyle
        }, resolveSlotWithProps(
          $slots.default,
          {
            value: mergedValue[index],
            index
          },
          () => {
            return [
              preset === "input" ? /* @__PURE__ */ React.createElement(NDynamicInputInputPreset, {
                clsPrefix: mergedClsPrefix,
                value: mergedValue[index],
                parentPath: NFormItem ? NFormItem.path.value : void 0,
                path: NFormItem?.path.value ? `${NFormItem.path.value}[${index}]` : void 0,
                onUpdateValue: (v) => handleValueChange(index, v)
              }) : preset === "pair" ? /* @__PURE__ */ React.createElement(NDynamicInputPairPreset, {
                clsPrefix: mergedClsPrefix,
                value: mergedValue[index],
                parentPath: NFormItem ? NFormItem.path.value : void 0,
                path: NFormItem?.path.value ? `${NFormItem.path.value}[${index}]` : void 0,
                onUpdateValue: (v) => handleValueChange(index, v)
              }) : null
            ];
          }
        ), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-dynamic-input-item__action`
        }, /* @__PURE__ */ React.createElement(NButtonGroup, {
          size: buttonSize
        }, {
          default: () => [
            /* @__PURE__ */ React.createElement(NButton, {
              disabled: this.removeDisabled,
              theme: mergedTheme.peers.Button,
              themeOverrides: mergedTheme.peerOverrides.Button,
              circle: true,
              onClick: () => remove(index)
            }, {
              icon: () => /* @__PURE__ */ React.createElement(NBaseIcon, {
                clsPrefix: mergedClsPrefix
              }, { default: () => /* @__PURE__ */ React.createElement(RemoveIcon, null) })
            }),
            /* @__PURE__ */ React.createElement(NButton, {
              disabled: this.insertionDisabled,
              circle: true,
              theme: mergedTheme.peers.Button,
              themeOverrides: mergedTheme.peerOverrides.Button,
              onClick: () => createItem(index)
            }, {
              icon: () => /* @__PURE__ */ React.createElement(NBaseIcon, {
                clsPrefix: mergedClsPrefix
              }, { default: () => /* @__PURE__ */ React.createElement(AddIcon, null) })
            }),
            showSortButton ? /* @__PURE__ */ React.createElement(NButton, {
              disabled: index === 0,
              circle: true,
              theme: mergedTheme.peers.Button,
              themeOverrides: mergedTheme.peerOverrides.Button,
              onClick: () => move("up", index)
            }, {
              icon: () => /* @__PURE__ */ React.createElement(NBaseIcon, {
                clsPrefix: mergedClsPrefix
              }, {
                default: () => /* @__PURE__ */ React.createElement(ArrowUpIcon, null)
              })
            }) : null,
            showSortButton ? /* @__PURE__ */ React.createElement(NButton, {
              disabled: index === mergedValue.length - 1,
              circle: true,
              theme: mergedTheme.peers.Button,
              themeOverrides: mergedTheme.peerOverrides.Button,
              onClick: () => move("down", index)
            }, {
              icon: () => /* @__PURE__ */ React.createElement(NBaseIcon, {
                clsPrefix: mergedClsPrefix
              }, { default: () => /* @__PURE__ */ React.createElement(ArrowDownIcon, null) })
            }) : null
          ]
        })))));
      }
    });

    var commonVars$4 = {
      gapSmall: "4px 8px",
      gapMedium: "8px 12px",
      gapLarge: "12px 16px"
    };

    const spaceDark = {
      name: "Space",

      self() {
        return commonVars$4;
      }

    };
    var spaceDark$1 = spaceDark;

    const self$z = () => {
      return commonVars$4;
    };

    const spaceLight = {
      name: "Space",
      self: self$z
    };
    var spaceLight$1 = spaceLight;

    var rtlStyle$a = cB("space", [cM("rtl", `
    direction: rtl;
  `)]);

    const spaceRtl = {
      name: "Space",
      style: rtlStyle$a
    };

    let supportFlexGap;
    const ensureSupportFlexGap = () => {
      if (!isBrowser$2) return true;

      if (supportFlexGap === void 0) {
        const flex = document.createElement("div");
        flex.style.display = "flex";
        flex.style.flexDirection = "column";
        flex.style.rowGap = "1px";
        flex.appendChild(document.createElement("div"));
        flex.appendChild(document.createElement("div"));
        document.body.appendChild(flex);
        const isSupported = flex.scrollHeight === 1;
        document.body.removeChild(flex);
        return supportFlexGap = isSupported;
      }

      return supportFlexGap;
    };

    const spaceProps = {
      ...useTheme.props,
      align: String,
      justify: {
        type: String,
        default: "start"
      },
      inline: Boolean,
      vertical: Boolean,
      size: {
        type: [String, Number, Array],
        default: "medium"
      },
      wrapItem: {
        type: Boolean,
        default: true
      },
      itemStyle: [String, Object],
      wrap: {
        type: Boolean,
        default: true
      },
      internalUseGap: {
        type: Boolean,
        default: void 0
      }
    };
    var NSpace = vue.defineComponent({
      name: "Space",
      props: spaceProps,
      setup(props) {
        const { mergedClsPrefixRef, mergedRtlRef } = useConfig(props);
        const themeRef = useTheme(
          "Space",
          "-space",
          void 0,
          spaceLight$1,
          props,
          mergedClsPrefixRef
        );
        const rtlEnabledRef = useRtl("Space", mergedRtlRef, mergedClsPrefixRef);
        return {
          useGap: ensureSupportFlexGap(),
          rtlEnabled: rtlEnabledRef,
          mergedClsPrefix: mergedClsPrefixRef,
          margin: vue.computed(() => {
            const { size } = props;
            if (Array.isArray(size)) {
              return {
                horizontal: size[0],
                vertical: size[1]
              };
            }
            if (typeof size === "number") {
              return {
                horizontal: size,
                vertical: size
              };
            }
            const {
              self: { [createKey("gap", size)]: gap }
            } = themeRef.value;
            const { row, col } = getGap(gap);
            return {
              horizontal: depx(col),
              vertical: depx(row)
            };
          })
        };
      },
      render() {
        const {
          vertical,
          align,
          inline,
          justify,
          itemStyle,
          margin,
          wrap,
          mergedClsPrefix,
          rtlEnabled,
          useGap,
          wrapItem,
          internalUseGap
        } = this;
        const children = flatten$3(getSlot$1(this));
        if (!children.length)
          return null;
        const horizontalMargin = `${margin.horizontal}px`;
        const semiHorizontalMargin = `${margin.horizontal / 2}px`;
        const verticalMargin = `${margin.vertical}px`;
        const semiVerticalMargin = `${margin.vertical / 2}px`;
        const lastIndex = children.length - 1;
        const isJustifySpace = justify.startsWith("space-");
        return /* @__PURE__ */ React.createElement("div", {
          role: "none",
          class: [
            `${mergedClsPrefix}-space`,
            rtlEnabled && `${mergedClsPrefix}-space--rtl`
          ],
          style: {
            display: inline ? "inline-flex" : "flex",
            flexDirection: vertical ? "column" : "row",
            justifyContent: ["start", "end"].includes(justify) ? "flex-" + justify : justify,
            flexWrap: !wrap || vertical ? "nowrap" : "wrap",
            marginTop: useGap || vertical ? "" : `-${semiVerticalMargin}`,
            marginBottom: useGap || vertical ? "" : `-${semiVerticalMargin}`,
            alignItems: align,
            gap: useGap ? `${margin.vertical}px ${margin.horizontal}px` : ""
          }
        }, !wrapItem && (useGap || internalUseGap) ? children : children.map((child, index) => /* @__PURE__ */ React.createElement("div", {
          role: "none",
          style: [
            itemStyle,
            {
              maxWidth: "100%"
            },
            useGap ? "" : vertical ? {
              marginBottom: index !== lastIndex ? verticalMargin : ""
            } : rtlEnabled ? {
              marginLeft: isJustifySpace ? justify === "space-between" && index === lastIndex ? "" : semiHorizontalMargin : index !== lastIndex ? horizontalMargin : "",
              marginRight: isJustifySpace ? justify === "space-between" && index === 0 ? "" : semiHorizontalMargin : "",
              paddingTop: semiVerticalMargin,
              paddingBottom: semiVerticalMargin
            } : {
              marginRight: isJustifySpace ? justify === "space-between" && index === lastIndex ? "" : semiHorizontalMargin : index !== lastIndex ? horizontalMargin : "",
              marginLeft: isJustifySpace ? justify === "space-between" && index === 0 ? "" : semiHorizontalMargin : "",
              paddingTop: semiVerticalMargin,
              paddingBottom: semiVerticalMargin
            }
          ]
        }, child)));
      }
    });

    const dynamicTagsDark = {
      name: "DynamicTags",
      common: commonDark,
      peers: {
        Input: inputDark$1,
        Button: buttonDark$1,
        Tag: tagDark$1,
        Space: spaceDark$1
      },

      self() {
        return {
          inputWidth: "64px"
        };
      }

    };
    var dynamicTagsDark$1 = dynamicTagsDark;

    const dynamicTagsLight = createTheme$1({
      name: "DynamicTags",
      common: commonLight,
      peers: {
        Input: inputLight$1,
        Button: buttonLight$1,
        Tag: tagLight$1,
        Space: spaceLight$1
      },

      self() {
        return {
          inputWidth: "64px"
        };
      }

    });
    var dynamicTagsLight$1 = dynamicTagsLight;

    var style$K = cB("dynamic-tags", [cB("input", {
      minWidth: "var(--n-input-width)"
    })]);

    const dynamicTagsProps = {
      ...useTheme.props,
      ...commonProps,
      size: {
        type: String,
        default: "medium"
      },
      closable: {
        type: Boolean,
        default: true
      },
      defaultValue: {
        type: Array,
        default: () => []
      },
      value: Array,
      inputStyle: [String, Object],
      inputProps: Object,
      max: Number,
      tagStyle: [String, Object],
      renderTag: Function,
      onCreate: {
        type: Function,
        default: (label) => label
      },
      "onUpdate:value": [Function, Array],
      onUpdateValue: [Function, Array],
      onChange: [Function, Array]
    };
    var DynamicTags = vue.defineComponent({
      name: "DynamicTags",
      props: dynamicTagsProps,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.onChange !== void 0) {
              warnOnce(
                "dynamic-tags",
                "`on-change` is deprecated, please use `on-update:value` instead."
              );
            }
          });
        }
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const { localeRef } = useLocale("DynamicTags");
        const formItem = useFormItem(props);
        const { mergedDisabledRef } = formItem;
        const inputValueRef = vue.ref("");
        const showInputRef = vue.ref(false);
        const inputForceFocusedRef = vue.ref(true);
        const inputInstRef = vue.ref(null);
        const themeRef = useTheme(
          "DynamicTags",
          "-dynamic-tags",
          style$K,
          dynamicTagsLight$1,
          props,
          mergedClsPrefixRef
        );
        const uncontrolledValueRef = vue.ref(props.defaultValue);
        const controlledValueRef = vue.toRef(props, "value");
        const mergedValueRef = useMergedState(
          controlledValueRef,
          uncontrolledValueRef
        );
        const localizedAddRef = vue.computed(() => {
          return localeRef.value.add;
        });
        const inputSizeRef = vue.computed(() => {
          return smallerSize(props.size);
        });
        const triggerDisabledRef = vue.computed(() => {
          return mergedDisabledRef.value || !!props.max && mergedValueRef.value.length >= props.max;
        });
        function doChange(value) {
          const {
            onChange,
            "onUpdate:value": _onUpdateValue,
            onUpdateValue
          } = props;
          const { nTriggerFormInput, nTriggerFormChange } = formItem;
          if (onChange)
            call(onChange, value);
          if (onUpdateValue)
            call(onUpdateValue, value);
          if (_onUpdateValue)
            call(_onUpdateValue, value);
          uncontrolledValueRef.value = value;
          nTriggerFormInput();
          nTriggerFormChange();
        }
        function handleCloseClick(index) {
          const tags = mergedValueRef.value.slice(0);
          tags.splice(index, 1);
          doChange(tags);
        }
        function handleInputKeyUp(e) {
          switch (e.key) {
            case "Enter":
              handleInputConfirm();
          }
        }
        function handleInputConfirm(externalValue) {
          const nextValue = externalValue ?? inputValueRef.value;
          if (nextValue) {
            const tags = mergedValueRef.value.slice(0);
            tags.push(props.onCreate(nextValue));
            doChange(tags);
          }
          showInputRef.value = false;
          inputForceFocusedRef.value = true;
          inputValueRef.value = "";
        }
        function handleInputBlur() {
          handleInputConfirm();
        }
        function handleAddClick() {
          showInputRef.value = true;
          void vue.nextTick(() => {
            inputInstRef.value?.focus();
            inputForceFocusedRef.value = false;
          });
        }
        const cssVarsRef = vue.computed(() => {
          const {
            self: { inputWidth }
          } = themeRef.value;
          return {
            "--n-input-width": inputWidth
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("dynamic-tags", void 0, cssVarsRef, props) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          inputInstRef,
          localizedAdd: localizedAddRef,
          inputSize: inputSizeRef,
          inputValue: inputValueRef,
          showInput: showInputRef,
          inputForceFocused: inputForceFocusedRef,
          mergedValue: mergedValueRef,
          mergedDisabled: mergedDisabledRef,
          triggerDisabled: triggerDisabledRef,
          handleInputKeyUp,
          handleAddClick,
          handleInputBlur,
          handleCloseClick,
          handleInputConfirm,
          mergedTheme: themeRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedTheme, cssVars, mergedClsPrefix, onRender, renderTag } = this;
        onRender?.();
        return /* @__PURE__ */ React.createElement(NSpace, {
          class: [`${mergedClsPrefix}-dynamic-tags`, this.themeClass],
          size: "small",
          style: cssVars,
          theme: mergedTheme.peers.Space,
          themeOverrides: mergedTheme.peerOverrides.Space,
          itemStyle: "display: flex;"
        }, {
          default: () => {
            const {
              mergedTheme: mergedTheme2,
              tagStyle,
              type,
              round,
              size,
              color,
              closable,
              mergedDisabled,
              showInput,
              inputValue,
              inputStyle,
              inputSize,
              inputForceFocused,
              triggerDisabled,
              handleInputKeyUp,
              handleInputBlur,
              handleAddClick,
              handleCloseClick,
              handleInputConfirm,
              $slots
            } = this;
            return this.mergedValue.map(
              (tag, index) => renderTag ? renderTag(tag, index) : /* @__PURE__ */ React.createElement(NTag, {
                key: index,
                theme: mergedTheme2.peers.Tag,
                themeOverrides: mergedTheme2.peerOverrides.Tag,
                style: tagStyle,
                type,
                round,
                size,
                color,
                closable,
                disabled: mergedDisabled,
                onClose: () => handleCloseClick(index)
              }, {
                default: () => typeof tag === "string" ? tag : tag.label
              })
            ).concat(
              showInput ? $slots.input ? $slots.input({
                submit: handleInputConfirm,
                deactivate: handleInputBlur
              }) : /* @__PURE__ */ React.createElement(NInput, {
                placeholder: "",
                size: inputSize,
                style: inputStyle,
                autosize: true,
                ...this.inputProps,
                ref: "inputInstRef",
                value: inputValue,
                onUpdateValue: (v) => {
                  this.inputValue = v;
                },
                theme: mergedTheme2.peers.Input,
                themeOverrides: mergedTheme2.peerOverrides.Input,
                onKeyup: handleInputKeyUp,
                onBlur: handleInputBlur,
                internalForceFocus: inputForceFocused
              }) : $slots.trigger ? $slots.trigger({
                activate: handleAddClick,
                disabled: triggerDisabled
              }) : /* @__PURE__ */ React.createElement(NButton, {
                dashed: true,
                disabled: triggerDisabled,
                theme: mergedTheme2.peers.Button,
                themeOverrides: mergedTheme2.peerOverrides.Button,
                size: inputSize,
                onClick: handleAddClick
              }, {
                icon: () => /* @__PURE__ */ React.createElement(NBaseIcon, {
                  clsPrefix: mergedClsPrefix
                }, { default: () => /* @__PURE__ */ React.createElement(AddIcon, null) })
              })
            );
          }
        });
      }
    });

    const elementDark = {
      name: "Element",
      common: commonDark
    };
    var elementDark$1 = elementDark;

    const elementLight = {
      name: "Element",
      common: commonLight
    };
    var elementLight$1 = elementLight;

    const elementProps = { ...useTheme.props,
      tag: {
        type: String,
        default: "div"
      }
    };
    var NElement = vue.defineComponent({
      name: "Element",
      alias: ["El"],
      props: elementProps,

      setup(props) {
        const {
          mergedClsPrefixRef,
          inlineThemeDisabled
        } = useConfig(props);
        const themeRef = useTheme("Element", "-element", void 0, elementLight$1, props, mergedClsPrefixRef);
        const cssVarsRef = vue.computed(() => {
          const {
            common
          } = themeRef.value;
          return Object.keys(common).reduce((prevValue, key) => {
            prevValue[`--${lodash.exports.kebabCase(key)}`] = common[key];
            return prevValue;
          }, {});
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("element", void 0, cssVarsRef, props) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle === null || themeClassHandle === void 0 ? void 0 : themeClassHandle.themeClass,
          onRender: themeClassHandle === null || themeClassHandle === void 0 ? void 0 : themeClassHandle.onRender
        };
      },

      render() {
        var _$slots$default;

        const {
          tag,
          mergedClsPrefix,
          cssVars,
          themeClass,
          onRender,
          $slots
        } = this;
        onRender === null || onRender === void 0 ? void 0 : onRender();
        return vue.h(tag, {
          role: "none",
          class: [`${mergedClsPrefix}-element`, themeClass],
          style: cssVars
        }, (_$slots$default = $slots.default) === null || _$slots$default === void 0 ? void 0 : _$slots$default.call($slots));
      }

    });

    var commonVariables$5 = {
      feedbackPadding: "4px 0 0 2px",
      feedbackHeightSmall: "24px",
      feedbackHeightMedium: "24px",
      feedbackHeightLarge: "26px",
      feedbackFontSizeSmall: "13px",
      feedbackFontSizeMedium: "14px",
      feedbackFontSizeLarge: "14px",
      labelFontSizeLeftSmall: "14px",
      labelFontSizeLeftMedium: "14px",
      labelFontSizeLeftLarge: "15px",
      labelFontSizeTopSmall: "13px",
      labelFontSizeTopMedium: "14px",
      labelFontSizeTopLarge: "14px",
      labelHeightSmall: "24px",
      labelHeightMedium: "26px",
      labelHeightLarge: "28px",
      labelPaddingVertical: "0 0 6px 2px",
      labelPaddingHorizontal: "0 12px 0 0",
      labelTextAlignVertical: "left",
      labelTextAlignHorizontal: "right"
    };

    const self$y = vars => {
      const {
        heightSmall,
        heightMedium,
        heightLarge,
        textColor1,
        errorColor,
        warningColor,
        lineHeight,
        textColor3
      } = vars;
      return { ...commonVariables$5,
        blankHeightSmall: heightSmall,
        blankHeightMedium: heightMedium,
        blankHeightLarge: heightLarge,
        lineHeight,
        labelTextColor: textColor1,
        asteriskColor: errorColor,
        feedbackTextColorError: errorColor,
        feedbackTextColorWarning: warningColor,
        feedbackTextColor: textColor3
      };
    };
    const formLight = {
      name: "Form",
      common: commonLight,
      self: self$y
    };
    var formLight$1 = formLight;

    const formItemDark = {
      name: "Form",
      common: commonDark,
      self: self$y
    };
    var formDark = formItemDark;

    var style$J = cB("form", [cM("inline", `
    width: 100%;
    display: inline-flex;
    align-items: flex-start;
    align-content: space-around;
  `, [cB("form-item", {
      width: "auto",
      marginRight: "18px"
    }, [c$1("&:last-child", {
      marginRight: 0
    })])])]);

    const formInjectionKey = createInjectionKey("n-form");
    const formItemInstsInjectionKey = createInjectionKey("n-form-item-insts");

    const formProps = {
      ...useTheme.props,
      inline: Boolean,
      labelWidth: [Number, String],
      labelAlign: String,
      labelPlacement: {
        type: String,
        default: "top"
      },
      model: {
        type: Object,
        default: () => {
        }
      },
      rules: Object,
      disabled: Boolean,
      size: String,
      showRequireMark: {
        type: Boolean,
        default: void 0
      },
      requireMarkPlacement: String,
      showFeedback: {
        type: Boolean,
        default: true
      },
      onSubmit: {
        type: Function,
        default: (e) => e.preventDefault()
      },
      showLabel: {
        type: Boolean,
        default: void 0
      },
      validateMessages: Object
    };
    var Form = vue.defineComponent({
      name: "Form",
      props: formProps,
      setup(props) {
        const { mergedClsPrefixRef } = useConfig(props);
        useTheme("Form", "-form", style$J, formLight$1, props, mergedClsPrefixRef);
        const formItems = {};
        const maxChildLabelWidthRef = vue.ref(void 0);
        const deriveMaxChildLabelWidth = (currentWidth) => {
          const currentMaxChildLabelWidth = maxChildLabelWidthRef.value;
          if (currentMaxChildLabelWidth === void 0 || currentWidth >= currentMaxChildLabelWidth) {
            maxChildLabelWidthRef.value = currentWidth;
          }
        };
        async function validate(validateCallback, shouldRuleBeApplied = () => true) {
          return await new Promise((resolve, reject) => {
            const formItemValidationPromises = [];
            for (const key of keysOf(formItems)) {
              const formItemInstances = formItems[key];
              for (const formItemInstance of formItemInstances) {
                if (formItemInstance.path) {
                  formItemValidationPromises.push(
                    formItemInstance.internalValidate(null, shouldRuleBeApplied)
                  );
                }
              }
            }
            void Promise.all(formItemValidationPromises).then((results) => {
              if (results.some((result) => !result.valid)) {
                const errors = results.filter((result) => result.errors).map((result) => result.errors);
                if (validateCallback) {
                  validateCallback(errors);
                }
                reject(errors);
              } else {
                if (validateCallback)
                  validateCallback();
                resolve();
              }
            });
          });
        }
        function restoreValidation() {
          for (const key of keysOf(formItems)) {
            const formItemInstances = formItems[key];
            for (const formItemInstance of formItemInstances) {
              formItemInstance.restoreValidation();
            }
          }
        }
        vue.provide(formInjectionKey, {
          props,
          maxChildLabelWidthRef,
          deriveMaxChildLabelWidth
        });
        vue.provide(formItemInstsInjectionKey, { formItems });
        const formExposedMethod = {
          validate,
          restoreValidation
        };
        return Object.assign(formExposedMethod, {
          mergedClsPrefix: mergedClsPrefixRef
        });
      },
      render() {
        const { mergedClsPrefix } = this;
        return /* @__PURE__ */ React.createElement("form", {
          class: [
            `${mergedClsPrefix}-form`,
            this.inline && `${mergedClsPrefix}-form--inline`
          ],
          onSubmit: this.onSubmit
        }, this.$slots);
      }
    });

    function _extends() {
      _extends = Object.assign ? Object.assign.bind() : function (target) {
        for (var i = 1; i < arguments.length; i++) {
          var source = arguments[i];

          for (var key in source) {
            if (Object.prototype.hasOwnProperty.call(source, key)) {
              target[key] = source[key];
            }
          }
        }

        return target;
      };
      return _extends.apply(this, arguments);
    }

    function _inheritsLoose(subClass, superClass) {
      subClass.prototype = Object.create(superClass.prototype);
      subClass.prototype.constructor = subClass;

      _setPrototypeOf(subClass, superClass);
    }

    function _getPrototypeOf(o) {
      _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function _getPrototypeOf(o) {
        return o.__proto__ || Object.getPrototypeOf(o);
      };
      return _getPrototypeOf(o);
    }

    function _setPrototypeOf(o, p) {
      _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function _setPrototypeOf(o, p) {
        o.__proto__ = p;
        return o;
      };
      return _setPrototypeOf(o, p);
    }

    function _isNativeReflectConstruct() {
      if (typeof Reflect === "undefined" || !Reflect.construct) return false;
      if (Reflect.construct.sham) return false;
      if (typeof Proxy === "function") return true;

      try {
        Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {}));
        return true;
      } catch (e) {
        return false;
      }
    }

    function _construct(Parent, args, Class) {
      if (_isNativeReflectConstruct()) {
        _construct = Reflect.construct.bind();
      } else {
        _construct = function _construct(Parent, args, Class) {
          var a = [null];
          a.push.apply(a, args);
          var Constructor = Function.bind.apply(Parent, a);
          var instance = new Constructor();
          if (Class) _setPrototypeOf(instance, Class.prototype);
          return instance;
        };
      }

      return _construct.apply(null, arguments);
    }

    function _isNativeFunction(fn) {
      return Function.toString.call(fn).indexOf("[native code]") !== -1;
    }

    function _wrapNativeSuper(Class) {
      var _cache = typeof Map === "function" ? new Map() : undefined;

      _wrapNativeSuper = function _wrapNativeSuper(Class) {
        if (Class === null || !_isNativeFunction(Class)) return Class;

        if (typeof Class !== "function") {
          throw new TypeError("Super expression must either be null or a function");
        }

        if (typeof _cache !== "undefined") {
          if (_cache.has(Class)) return _cache.get(Class);

          _cache.set(Class, Wrapper);
        }

        function Wrapper() {
          return _construct(Class, arguments, _getPrototypeOf(this).constructor);
        }

        Wrapper.prototype = Object.create(Class.prototype, {
          constructor: {
            value: Wrapper,
            enumerable: false,
            writable: true,
            configurable: true
          }
        });
        return _setPrototypeOf(Wrapper, Class);
      };

      return _wrapNativeSuper(Class);
    }
    /* eslint no-console:0 */


    var formatRegExp = /%[sdj%]/g;

    var warning = function warning() {}; // don't print warning message when in production env or node runtime


    if (typeof process !== 'undefined' && process.env && "development" !== 'production' && typeof window !== 'undefined' && typeof document !== 'undefined') {
      warning = function warning(type, errors) {
        if (typeof console !== 'undefined' && console.warn && typeof ASYNC_VALIDATOR_NO_WARNING === 'undefined') {
          if (errors.every(function (e) {
            return typeof e === 'string';
          })) {
            console.warn(type, errors);
          }
        }
      };
    }

    function convertFieldsError(errors) {
      if (!errors || !errors.length) return null;
      var fields = {};
      errors.forEach(function (error) {
        var field = error.field;
        fields[field] = fields[field] || [];
        fields[field].push(error);
      });
      return fields;
    }

    function format$1(template) {
      for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
        args[_key - 1] = arguments[_key];
      }

      var i = 0;
      var len = args.length;

      if (typeof template === 'function') {
        return template.apply(null, args);
      }

      if (typeof template === 'string') {
        var str = template.replace(formatRegExp, function (x) {
          if (x === '%%') {
            return '%';
          }

          if (i >= len) {
            return x;
          }

          switch (x) {
            case '%s':
              return String(args[i++]);

            case '%d':
              return Number(args[i++]);

            case '%j':
              try {
                return JSON.stringify(args[i++]);
              } catch (_) {
                return '[Circular]';
              }

              break;

            default:
              return x;
          }
        });
        return str;
      }

      return template;
    }

    function isNativeStringType(type) {
      return type === 'string' || type === 'url' || type === 'hex' || type === 'email' || type === 'date' || type === 'pattern';
    }

    function isEmptyValue(value, type) {
      if (value === undefined || value === null) {
        return true;
      }

      if (type === 'array' && Array.isArray(value) && !value.length) {
        return true;
      }

      if (isNativeStringType(type) && typeof value === 'string' && !value) {
        return true;
      }

      return false;
    }

    function asyncParallelArray(arr, func, callback) {
      var results = [];
      var total = 0;
      var arrLength = arr.length;

      function count(errors) {
        results.push.apply(results, errors || []);
        total++;

        if (total === arrLength) {
          callback(results);
        }
      }

      arr.forEach(function (a) {
        func(a, count);
      });
    }

    function asyncSerialArray(arr, func, callback) {
      var index = 0;
      var arrLength = arr.length;

      function next(errors) {
        if (errors && errors.length) {
          callback(errors);
          return;
        }

        var original = index;
        index = index + 1;

        if (original < arrLength) {
          func(arr[original], next);
        } else {
          callback([]);
        }
      }

      next([]);
    }

    function flattenObjArr(objArr) {
      var ret = [];
      Object.keys(objArr).forEach(function (k) {
        ret.push.apply(ret, objArr[k] || []);
      });
      return ret;
    }

    var AsyncValidationError = /*#__PURE__*/function (_Error) {
      _inheritsLoose(AsyncValidationError, _Error);

      function AsyncValidationError(errors, fields) {
        var _this;

        _this = _Error.call(this, 'Async Validation Error') || this;
        _this.errors = errors;
        _this.fields = fields;
        return _this;
      }

      return AsyncValidationError;
    }( /*#__PURE__*/_wrapNativeSuper(Error));

    function asyncMap(objArr, option, func, callback, source) {
      if (option.first) {
        var _pending = new Promise(function (resolve, reject) {
          var next = function next(errors) {
            callback(errors);
            return errors.length ? reject(new AsyncValidationError(errors, convertFieldsError(errors))) : resolve(source);
          };

          var flattenArr = flattenObjArr(objArr);
          asyncSerialArray(flattenArr, func, next);
        });

        _pending["catch"](function (e) {
          return e;
        });

        return _pending;
      }

      var firstFields = option.firstFields === true ? Object.keys(objArr) : option.firstFields || [];
      var objArrKeys = Object.keys(objArr);
      var objArrLength = objArrKeys.length;
      var total = 0;
      var results = [];
      var pending = new Promise(function (resolve, reject) {
        var next = function next(errors) {
          results.push.apply(results, errors);
          total++;

          if (total === objArrLength) {
            callback(results);
            return results.length ? reject(new AsyncValidationError(results, convertFieldsError(results))) : resolve(source);
          }
        };

        if (!objArrKeys.length) {
          callback(results);
          resolve(source);
        }

        objArrKeys.forEach(function (key) {
          var arr = objArr[key];

          if (firstFields.indexOf(key) !== -1) {
            asyncSerialArray(arr, func, next);
          } else {
            asyncParallelArray(arr, func, next);
          }
        });
      });
      pending["catch"](function (e) {
        return e;
      });
      return pending;
    }

    function isErrorObj(obj) {
      return !!(obj && obj.message !== undefined);
    }

    function getValue(value, path) {
      var v = value;

      for (var i = 0; i < path.length; i++) {
        if (v == undefined) {
          return v;
        }

        v = v[path[i]];
      }

      return v;
    }

    function complementError(rule, source) {
      return function (oe) {
        var fieldValue;

        if (rule.fullFields) {
          fieldValue = getValue(source, rule.fullFields);
        } else {
          fieldValue = source[oe.field || rule.fullField];
        }

        if (isErrorObj(oe)) {
          oe.field = oe.field || rule.fullField;
          oe.fieldValue = fieldValue;
          return oe;
        }

        return {
          message: typeof oe === 'function' ? oe() : oe,
          fieldValue: fieldValue,
          field: oe.field || rule.fullField
        };
      };
    }

    function deepMerge(target, source) {
      if (source) {
        for (var s in source) {
          if (source.hasOwnProperty(s)) {
            var value = source[s];

            if (typeof value === 'object' && typeof target[s] === 'object') {
              target[s] = _extends({}, target[s], value);
            } else {
              target[s] = value;
            }
          }
        }
      }

      return target;
    }

    var required$1 = function required(rule, value, source, errors, options, type) {
      if (rule.required && (!source.hasOwnProperty(rule.field) || isEmptyValue(value, type || rule.type))) {
        errors.push(format$1(options.messages.required, rule.fullField));
      }
    };
    /**
     *  Rule for validating whitespace.
     *
     *  @param rule The validation rule.
     *  @param value The value of the field on the source object.
     *  @param source The source object being validated.
     *  @param errors An array of errors that this rule may add
     *  validation errors to.
     *  @param options The validation options.
     *  @param options.messages The validation messages.
     */


    var whitespace = function whitespace(rule, value, source, errors, options) {
      if (/^\s+$/.test(value) || value === '') {
        errors.push(format$1(options.messages.whitespace, rule.fullField));
      }
    }; // https://github.com/kevva/url-regex/blob/master/index.js


    var urlReg;

    var getUrlRegex = function () {
      if (urlReg) {
        return urlReg;
      }

      var word = '[a-fA-F\\d:]';

      var b = function b(options) {
        return options && options.includeBoundaries ? "(?:(?<=\\s|^)(?=" + word + ")|(?<=" + word + ")(?=\\s|$))" : '';
      };

      var v4 = '(?:25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]\\d|\\d)(?:\\.(?:25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]\\d|\\d)){3}';
      var v6seg = '[a-fA-F\\d]{1,4}';
      var v6 = ("\n(?:\n(?:" + v6seg + ":){7}(?:" + v6seg + "|:)|                                    // 1:2:3:4:5:6:7::  1:2:3:4:5:6:7:8\n(?:" + v6seg + ":){6}(?:" + v4 + "|:" + v6seg + "|:)|                             // 1:2:3:4:5:6::    1:2:3:4:5:6::8   1:2:3:4:5:6::8  1:2:3:4:5:6::1.2.3.4\n(?:" + v6seg + ":){5}(?::" + v4 + "|(?::" + v6seg + "){1,2}|:)|                   // 1:2:3:4:5::      1:2:3:4:5::7:8   1:2:3:4:5::8    1:2:3:4:5::7:1.2.3.4\n(?:" + v6seg + ":){4}(?:(?::" + v6seg + "){0,1}:" + v4 + "|(?::" + v6seg + "){1,3}|:)| // 1:2:3:4::        1:2:3:4::6:7:8   1:2:3:4::8      1:2:3:4::6:7:1.2.3.4\n(?:" + v6seg + ":){3}(?:(?::" + v6seg + "){0,2}:" + v4 + "|(?::" + v6seg + "){1,4}|:)| // 1:2:3::          1:2:3::5:6:7:8   1:2:3::8        1:2:3::5:6:7:1.2.3.4\n(?:" + v6seg + ":){2}(?:(?::" + v6seg + "){0,3}:" + v4 + "|(?::" + v6seg + "){1,5}|:)| // 1:2::            1:2::4:5:6:7:8   1:2::8          1:2::4:5:6:7:1.2.3.4\n(?:" + v6seg + ":){1}(?:(?::" + v6seg + "){0,4}:" + v4 + "|(?::" + v6seg + "){1,6}|:)| // 1::              1::3:4:5:6:7:8   1::8            1::3:4:5:6:7:1.2.3.4\n(?::(?:(?::" + v6seg + "){0,5}:" + v4 + "|(?::" + v6seg + "){1,7}|:))             // ::2:3:4:5:6:7:8  ::2:3:4:5:6:7:8  ::8             ::1.2.3.4\n)(?:%[0-9a-zA-Z]{1,})?                                             // %eth0            %1\n").replace(/\s*\/\/.*$/gm, '').replace(/\n/g, '').trim(); // Pre-compile only the exact regexes because adding a global flag make regexes stateful

      var v46Exact = new RegExp("(?:^" + v4 + "$)|(?:^" + v6 + "$)");
      var v4exact = new RegExp("^" + v4 + "$");
      var v6exact = new RegExp("^" + v6 + "$");

      var ip = function ip(options) {
        return options && options.exact ? v46Exact : new RegExp("(?:" + b(options) + v4 + b(options) + ")|(?:" + b(options) + v6 + b(options) + ")", 'g');
      };

      ip.v4 = function (options) {
        return options && options.exact ? v4exact : new RegExp("" + b(options) + v4 + b(options), 'g');
      };

      ip.v6 = function (options) {
        return options && options.exact ? v6exact : new RegExp("" + b(options) + v6 + b(options), 'g');
      };

      var protocol = "(?:(?:[a-z]+:)?//)";
      var auth = '(?:\\S+(?::\\S*)?@)?';
      var ipv4 = ip.v4().source;
      var ipv6 = ip.v6().source;
      var host = "(?:(?:[a-z\\u00a1-\\uffff0-9][-_]*)*[a-z\\u00a1-\\uffff0-9]+)";
      var domain = "(?:\\.(?:[a-z\\u00a1-\\uffff0-9]-*)*[a-z\\u00a1-\\uffff0-9]+)*";
      var tld = "(?:\\.(?:[a-z\\u00a1-\\uffff]{2,}))";
      var port = '(?::\\d{2,5})?';
      var path = '(?:[/?#][^\\s"]*)?';
      var regex = "(?:" + protocol + "|www\\.)" + auth + "(?:localhost|" + ipv4 + "|" + ipv6 + "|" + host + domain + tld + ")" + port + path;
      urlReg = new RegExp("(?:^" + regex + "$)", 'i');
      return urlReg;
    };
    /* eslint max-len:0 */


    var pattern$2 = {
      // http://emailregex.com/
      email: /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]+\.)+[a-zA-Z\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]{2,}))$/,
      // url: new RegExp(
      //   '^(?!mailto:)(?:(?:http|https|ftp)://|//)(?:\\S+(?::\\S*)?@)?(?:(?:(?:[1-9]\\d?|1\\d\\d|2[01]\\d|22[0-3])(?:\\.(?:1?\\d{1,2}|2[0-4]\\d|25[0-5])){2}(?:\\.(?:[0-9]\\d?|1\\d\\d|2[0-4]\\d|25[0-4]))|(?:(?:[a-z\\u00a1-\\uffff0-9]+-*)*[a-z\\u00a1-\\uffff0-9]+)(?:\\.(?:[a-z\\u00a1-\\uffff0-9]+-*)*[a-z\\u00a1-\\uffff0-9]+)*(?:\\.(?:[a-z\\u00a1-\\uffff]{2,})))|localhost)(?::\\d{2,5})?(?:(/|\\?|#)[^\\s]*)?$',
      //   'i',
      // ),
      hex: /^#?([a-f0-9]{6}|[a-f0-9]{3})$/i
    };
    var types = {
      integer: function integer(value) {
        return types.number(value) && parseInt(value, 10) === value;
      },
      "float": function float(value) {
        return types.number(value) && !types.integer(value);
      },
      array: function array(value) {
        return Array.isArray(value);
      },
      regexp: function regexp(value) {
        if (value instanceof RegExp) {
          return true;
        }

        try {
          return !!new RegExp(value);
        } catch (e) {
          return false;
        }
      },
      date: function date(value) {
        return typeof value.getTime === 'function' && typeof value.getMonth === 'function' && typeof value.getYear === 'function' && !isNaN(value.getTime());
      },
      number: function number(value) {
        if (isNaN(value)) {
          return false;
        }

        return typeof value === 'number';
      },
      object: function object(value) {
        return typeof value === 'object' && !types.array(value);
      },
      method: function method(value) {
        return typeof value === 'function';
      },
      email: function email(value) {
        return typeof value === 'string' && value.length <= 320 && !!value.match(pattern$2.email);
      },
      url: function url(value) {
        return typeof value === 'string' && value.length <= 2048 && !!value.match(getUrlRegex());
      },
      hex: function hex(value) {
        return typeof value === 'string' && !!value.match(pattern$2.hex);
      }
    };

    var type$1 = function type(rule, value, source, errors, options) {
      if (rule.required && value === undefined) {
        required$1(rule, value, source, errors, options);
        return;
      }

      var custom = ['integer', 'float', 'array', 'regexp', 'object', 'method', 'email', 'number', 'date', 'url', 'hex'];
      var ruleType = rule.type;

      if (custom.indexOf(ruleType) > -1) {
        if (!types[ruleType](value)) {
          errors.push(format$1(options.messages.types[ruleType], rule.fullField, rule.type));
        } // straight typeof check

      } else if (ruleType && typeof value !== rule.type) {
        errors.push(format$1(options.messages.types[ruleType], rule.fullField, rule.type));
      }
    };

    var range = function range(rule, value, source, errors, options) {
      var len = typeof rule.len === 'number';
      var min = typeof rule.min === 'number';
      var max = typeof rule.max === 'number'; // 正则匹配码点范围从U+010000一直到U+10FFFF的文字（补充平面Supplementary Plane）

      var spRegexp = /[\uD800-\uDBFF][\uDC00-\uDFFF]/g;
      var val = value;
      var key = null;
      var num = typeof value === 'number';
      var str = typeof value === 'string';
      var arr = Array.isArray(value);

      if (num) {
        key = 'number';
      } else if (str) {
        key = 'string';
      } else if (arr) {
        key = 'array';
      } // if the value is not of a supported type for range validation
      // the validation rule rule should use the
      // type property to also test for a particular type


      if (!key) {
        return false;
      }

      if (arr) {
        val = value.length;
      }

      if (str) {
        // 处理码点大于U+010000的文字length属性不准确的bug，如"𠮷𠮷𠮷".lenght !== 3
        val = value.replace(spRegexp, '_').length;
      }

      if (len) {
        if (val !== rule.len) {
          errors.push(format$1(options.messages[key].len, rule.fullField, rule.len));
        }
      } else if (min && !max && val < rule.min) {
        errors.push(format$1(options.messages[key].min, rule.fullField, rule.min));
      } else if (max && !min && val > rule.max) {
        errors.push(format$1(options.messages[key].max, rule.fullField, rule.max));
      } else if (min && max && (val < rule.min || val > rule.max)) {
        errors.push(format$1(options.messages[key].range, rule.fullField, rule.min, rule.max));
      }
    };

    var ENUM$1 = 'enum';

    var enumerable$1 = function enumerable(rule, value, source, errors, options) {
      rule[ENUM$1] = Array.isArray(rule[ENUM$1]) ? rule[ENUM$1] : [];

      if (rule[ENUM$1].indexOf(value) === -1) {
        errors.push(format$1(options.messages[ENUM$1], rule.fullField, rule[ENUM$1].join(', ')));
      }
    };

    var pattern$1 = function pattern(rule, value, source, errors, options) {
      if (rule.pattern) {
        if (rule.pattern instanceof RegExp) {
          // if a RegExp instance is passed, reset `lastIndex` in case its `global`
          // flag is accidentally set to `true`, which in a validation scenario
          // is not necessary and the result might be misleading
          rule.pattern.lastIndex = 0;

          if (!rule.pattern.test(value)) {
            errors.push(format$1(options.messages.pattern.mismatch, rule.fullField, value, rule.pattern));
          }
        } else if (typeof rule.pattern === 'string') {
          var _pattern = new RegExp(rule.pattern);

          if (!_pattern.test(value)) {
            errors.push(format$1(options.messages.pattern.mismatch, rule.fullField, value, rule.pattern));
          }
        }
      }
    };

    var rules = {
      required: required$1,
      whitespace: whitespace,
      type: type$1,
      range: range,
      "enum": enumerable$1,
      pattern: pattern$1
    };

    var string = function string(rule, value, callback, source, options) {
      var errors = [];
      var validate = rule.required || !rule.required && source.hasOwnProperty(rule.field);

      if (validate) {
        if (isEmptyValue(value, 'string') && !rule.required) {
          return callback();
        }

        rules.required(rule, value, source, errors, options, 'string');

        if (!isEmptyValue(value, 'string')) {
          rules.type(rule, value, source, errors, options);
          rules.range(rule, value, source, errors, options);
          rules.pattern(rule, value, source, errors, options);

          if (rule.whitespace === true) {
            rules.whitespace(rule, value, source, errors, options);
          }
        }
      }

      callback(errors);
    };

    var method = function method(rule, value, callback, source, options) {
      var errors = [];
      var validate = rule.required || !rule.required && source.hasOwnProperty(rule.field);

      if (validate) {
        if (isEmptyValue(value) && !rule.required) {
          return callback();
        }

        rules.required(rule, value, source, errors, options);

        if (value !== undefined) {
          rules.type(rule, value, source, errors, options);
        }
      }

      callback(errors);
    };

    var number = function number(rule, value, callback, source, options) {
      var errors = [];
      var validate = rule.required || !rule.required && source.hasOwnProperty(rule.field);

      if (validate) {
        if (value === '') {
          value = undefined;
        }

        if (isEmptyValue(value) && !rule.required) {
          return callback();
        }

        rules.required(rule, value, source, errors, options);

        if (value !== undefined) {
          rules.type(rule, value, source, errors, options);
          rules.range(rule, value, source, errors, options);
        }
      }

      callback(errors);
    };

    var _boolean = function _boolean(rule, value, callback, source, options) {
      var errors = [];
      var validate = rule.required || !rule.required && source.hasOwnProperty(rule.field);

      if (validate) {
        if (isEmptyValue(value) && !rule.required) {
          return callback();
        }

        rules.required(rule, value, source, errors, options);

        if (value !== undefined) {
          rules.type(rule, value, source, errors, options);
        }
      }

      callback(errors);
    };

    var regexp = function regexp(rule, value, callback, source, options) {
      var errors = [];
      var validate = rule.required || !rule.required && source.hasOwnProperty(rule.field);

      if (validate) {
        if (isEmptyValue(value) && !rule.required) {
          return callback();
        }

        rules.required(rule, value, source, errors, options);

        if (!isEmptyValue(value)) {
          rules.type(rule, value, source, errors, options);
        }
      }

      callback(errors);
    };

    var integer = function integer(rule, value, callback, source, options) {
      var errors = [];
      var validate = rule.required || !rule.required && source.hasOwnProperty(rule.field);

      if (validate) {
        if (isEmptyValue(value) && !rule.required) {
          return callback();
        }

        rules.required(rule, value, source, errors, options);

        if (value !== undefined) {
          rules.type(rule, value, source, errors, options);
          rules.range(rule, value, source, errors, options);
        }
      }

      callback(errors);
    };

    var floatFn = function floatFn(rule, value, callback, source, options) {
      var errors = [];
      var validate = rule.required || !rule.required && source.hasOwnProperty(rule.field);

      if (validate) {
        if (isEmptyValue(value) && !rule.required) {
          return callback();
        }

        rules.required(rule, value, source, errors, options);

        if (value !== undefined) {
          rules.type(rule, value, source, errors, options);
          rules.range(rule, value, source, errors, options);
        }
      }

      callback(errors);
    };

    var array = function array(rule, value, callback, source, options) {
      var errors = [];
      var validate = rule.required || !rule.required && source.hasOwnProperty(rule.field);

      if (validate) {
        if ((value === undefined || value === null) && !rule.required) {
          return callback();
        }

        rules.required(rule, value, source, errors, options, 'array');

        if (value !== undefined && value !== null) {
          rules.type(rule, value, source, errors, options);
          rules.range(rule, value, source, errors, options);
        }
      }

      callback(errors);
    };

    var object = function object(rule, value, callback, source, options) {
      var errors = [];
      var validate = rule.required || !rule.required && source.hasOwnProperty(rule.field);

      if (validate) {
        if (isEmptyValue(value) && !rule.required) {
          return callback();
        }

        rules.required(rule, value, source, errors, options);

        if (value !== undefined) {
          rules.type(rule, value, source, errors, options);
        }
      }

      callback(errors);
    };

    var ENUM = 'enum';

    var enumerable = function enumerable(rule, value, callback, source, options) {
      var errors = [];
      var validate = rule.required || !rule.required && source.hasOwnProperty(rule.field);

      if (validate) {
        if (isEmptyValue(value) && !rule.required) {
          return callback();
        }

        rules.required(rule, value, source, errors, options);

        if (value !== undefined) {
          rules[ENUM](rule, value, source, errors, options);
        }
      }

      callback(errors);
    };

    var pattern = function pattern(rule, value, callback, source, options) {
      var errors = [];
      var validate = rule.required || !rule.required && source.hasOwnProperty(rule.field);

      if (validate) {
        if (isEmptyValue(value, 'string') && !rule.required) {
          return callback();
        }

        rules.required(rule, value, source, errors, options);

        if (!isEmptyValue(value, 'string')) {
          rules.pattern(rule, value, source, errors, options);
        }
      }

      callback(errors);
    };

    var date = function date(rule, value, callback, source, options) {
      // console.log('integer rule called %j', rule);
      var errors = [];
      var validate = rule.required || !rule.required && source.hasOwnProperty(rule.field); // console.log('validate on %s value', value);

      if (validate) {
        if (isEmptyValue(value, 'date') && !rule.required) {
          return callback();
        }

        rules.required(rule, value, source, errors, options);

        if (!isEmptyValue(value, 'date')) {
          var dateObject;

          if (value instanceof Date) {
            dateObject = value;
          } else {
            dateObject = new Date(value);
          }

          rules.type(rule, dateObject, source, errors, options);

          if (dateObject) {
            rules.range(rule, dateObject.getTime(), source, errors, options);
          }
        }
      }

      callback(errors);
    };

    var required = function required(rule, value, callback, source, options) {
      var errors = [];
      var type = Array.isArray(value) ? 'array' : typeof value;
      rules.required(rule, value, source, errors, options, type);
      callback(errors);
    };

    var type = function type(rule, value, callback, source, options) {
      var ruleType = rule.type;
      var errors = [];
      var validate = rule.required || !rule.required && source.hasOwnProperty(rule.field);

      if (validate) {
        if (isEmptyValue(value, ruleType) && !rule.required) {
          return callback();
        }

        rules.required(rule, value, source, errors, options, ruleType);

        if (!isEmptyValue(value, ruleType)) {
          rules.type(rule, value, source, errors, options);
        }
      }

      callback(errors);
    };

    var any = function any(rule, value, callback, source, options) {
      var errors = [];
      var validate = rule.required || !rule.required && source.hasOwnProperty(rule.field);

      if (validate) {
        if (isEmptyValue(value) && !rule.required) {
          return callback();
        }

        rules.required(rule, value, source, errors, options);
      }

      callback(errors);
    };

    var validators = {
      string: string,
      method: method,
      number: number,
      "boolean": _boolean,
      regexp: regexp,
      integer: integer,
      "float": floatFn,
      array: array,
      object: object,
      "enum": enumerable,
      pattern: pattern,
      date: date,
      url: type,
      hex: type,
      email: type,
      required: required,
      any: any
    };

    function newMessages() {
      return {
        "default": 'Validation error on field %s',
        required: '%s is required',
        "enum": '%s must be one of %s',
        whitespace: '%s cannot be empty',
        date: {
          format: '%s date %s is invalid for format %s',
          parse: '%s date could not be parsed, %s is invalid ',
          invalid: '%s date %s is invalid'
        },
        types: {
          string: '%s is not a %s',
          method: '%s is not a %s (function)',
          array: '%s is not an %s',
          object: '%s is not an %s',
          number: '%s is not a %s',
          date: '%s is not a %s',
          "boolean": '%s is not a %s',
          integer: '%s is not an %s',
          "float": '%s is not a %s',
          regexp: '%s is not a valid %s',
          email: '%s is not a valid %s',
          url: '%s is not a valid %s',
          hex: '%s is not a valid %s'
        },
        string: {
          len: '%s must be exactly %s characters',
          min: '%s must be at least %s characters',
          max: '%s cannot be longer than %s characters',
          range: '%s must be between %s and %s characters'
        },
        number: {
          len: '%s must equal %s',
          min: '%s cannot be less than %s',
          max: '%s cannot be greater than %s',
          range: '%s must be between %s and %s'
        },
        array: {
          len: '%s must be exactly %s in length',
          min: '%s cannot be less than %s in length',
          max: '%s cannot be greater than %s in length',
          range: '%s must be between %s and %s in length'
        },
        pattern: {
          mismatch: '%s value %s does not match pattern %s'
        },
        clone: function clone() {
          var cloned = JSON.parse(JSON.stringify(this));
          cloned.clone = this.clone;
          return cloned;
        }
      };
    }

    var messages = newMessages();
    /**
     *  Encapsulates a validation schema.
     *
     *  @param descriptor An object declaring validation rules
     *  for this schema.
     */

    var Schema = /*#__PURE__*/function () {
      // ========================= Static =========================
      // ======================== Instance ========================
      function Schema(descriptor) {
        this.rules = null;
        this._messages = messages;
        this.define(descriptor);
      }

      var _proto = Schema.prototype;

      _proto.define = function define(rules) {
        var _this = this;

        if (!rules) {
          throw new Error('Cannot configure a schema with no rules');
        }

        if (typeof rules !== 'object' || Array.isArray(rules)) {
          throw new Error('Rules must be an object');
        }

        this.rules = {};
        Object.keys(rules).forEach(function (name) {
          var item = rules[name];
          _this.rules[name] = Array.isArray(item) ? item : [item];
        });
      };

      _proto.messages = function messages(_messages) {
        if (_messages) {
          this._messages = deepMerge(newMessages(), _messages);
        }

        return this._messages;
      };

      _proto.validate = function validate(source_, o, oc) {
        var _this2 = this;

        if (o === void 0) {
          o = {};
        }

        if (oc === void 0) {
          oc = function oc() {};
        }

        var source = source_;
        var options = o;
        var callback = oc;

        if (typeof options === 'function') {
          callback = options;
          options = {};
        }

        if (!this.rules || Object.keys(this.rules).length === 0) {
          if (callback) {
            callback(null, source);
          }

          return Promise.resolve(source);
        }

        function complete(results) {
          var errors = [];
          var fields = {};

          function add(e) {
            if (Array.isArray(e)) {
              var _errors;

              errors = (_errors = errors).concat.apply(_errors, e);
            } else {
              errors.push(e);
            }
          }

          for (var i = 0; i < results.length; i++) {
            add(results[i]);
          }

          if (!errors.length) {
            callback(null, source);
          } else {
            fields = convertFieldsError(errors);
            callback(errors, fields);
          }
        }

        if (options.messages) {
          var messages$1 = this.messages();

          if (messages$1 === messages) {
            messages$1 = newMessages();
          }

          deepMerge(messages$1, options.messages);
          options.messages = messages$1;
        } else {
          options.messages = this.messages();
        }

        var series = {};
        var keys = options.keys || Object.keys(this.rules);
        keys.forEach(function (z) {
          var arr = _this2.rules[z];
          var value = source[z];
          arr.forEach(function (r) {
            var rule = r;

            if (typeof rule.transform === 'function') {
              if (source === source_) {
                source = _extends({}, source);
              }

              value = source[z] = rule.transform(value);
            }

            if (typeof rule === 'function') {
              rule = {
                validator: rule
              };
            } else {
              rule = _extends({}, rule);
            } // Fill validator. Skip if nothing need to validate


            rule.validator = _this2.getValidationMethod(rule);

            if (!rule.validator) {
              return;
            }

            rule.field = z;
            rule.fullField = rule.fullField || z;
            rule.type = _this2.getType(rule);
            series[z] = series[z] || [];
            series[z].push({
              rule: rule,
              value: value,
              source: source,
              field: z
            });
          });
        });
        var errorFields = {};
        return asyncMap(series, options, function (data, doIt) {
          var rule = data.rule;
          var deep = (rule.type === 'object' || rule.type === 'array') && (typeof rule.fields === 'object' || typeof rule.defaultField === 'object');
          deep = deep && (rule.required || !rule.required && data.value);
          rule.field = data.field;

          function addFullField(key, schema) {
            return _extends({}, schema, {
              fullField: rule.fullField + "." + key,
              fullFields: rule.fullFields ? [].concat(rule.fullFields, [key]) : [key]
            });
          }

          function cb(e) {
            if (e === void 0) {
              e = [];
            }

            var errorList = Array.isArray(e) ? e : [e];

            if (!options.suppressWarning && errorList.length) {
              Schema.warning('async-validator:', errorList);
            }

            if (errorList.length && rule.message !== undefined) {
              errorList = [].concat(rule.message);
            } // Fill error info


            var filledErrors = errorList.map(complementError(rule, source));

            if (options.first && filledErrors.length) {
              errorFields[rule.field] = 1;
              return doIt(filledErrors);
            }

            if (!deep) {
              doIt(filledErrors);
            } else {
              // if rule is required but the target object
              // does not exist fail at the rule level and don't
              // go deeper
              if (rule.required && !data.value) {
                if (rule.message !== undefined) {
                  filledErrors = [].concat(rule.message).map(complementError(rule, source));
                } else if (options.error) {
                  filledErrors = [options.error(rule, format$1(options.messages.required, rule.field))];
                }

                return doIt(filledErrors);
              }

              var fieldsSchema = {};

              if (rule.defaultField) {
                Object.keys(data.value).map(function (key) {
                  fieldsSchema[key] = rule.defaultField;
                });
              }

              fieldsSchema = _extends({}, fieldsSchema, data.rule.fields);
              var paredFieldsSchema = {};
              Object.keys(fieldsSchema).forEach(function (field) {
                var fieldSchema = fieldsSchema[field];
                var fieldSchemaList = Array.isArray(fieldSchema) ? fieldSchema : [fieldSchema];
                paredFieldsSchema[field] = fieldSchemaList.map(addFullField.bind(null, field));
              });
              var schema = new Schema(paredFieldsSchema);
              schema.messages(options.messages);

              if (data.rule.options) {
                data.rule.options.messages = options.messages;
                data.rule.options.error = options.error;
              }

              schema.validate(data.value, data.rule.options || options, function (errs) {
                var finalErrors = [];

                if (filledErrors && filledErrors.length) {
                  finalErrors.push.apply(finalErrors, filledErrors);
                }

                if (errs && errs.length) {
                  finalErrors.push.apply(finalErrors, errs);
                }

                doIt(finalErrors.length ? finalErrors : null);
              });
            }
          }

          var res;

          if (rule.asyncValidator) {
            res = rule.asyncValidator(rule, data.value, cb, data.source, options);
          } else if (rule.validator) {
            try {
              res = rule.validator(rule, data.value, cb, data.source, options);
            } catch (error) {
              console.error == null ? void 0 : console.error(error); // rethrow to report error

              if (!options.suppressValidatorError) {
                setTimeout(function () {
                  throw error;
                }, 0);
              }

              cb(error.message);
            }

            if (res === true) {
              cb();
            } else if (res === false) {
              cb(typeof rule.message === 'function' ? rule.message(rule.fullField || rule.field) : rule.message || (rule.fullField || rule.field) + " fails");
            } else if (res instanceof Array) {
              cb(res);
            } else if (res instanceof Error) {
              cb(res.message);
            }
          }

          if (res && res.then) {
            res.then(function () {
              return cb();
            }, function (e) {
              return cb(e);
            });
          }
        }, function (results) {
          complete(results);
        }, source);
      };

      _proto.getType = function getType(rule) {
        if (rule.type === undefined && rule.pattern instanceof RegExp) {
          rule.type = 'pattern';
        }

        if (typeof rule.validator !== 'function' && rule.type && !validators.hasOwnProperty(rule.type)) {
          throw new Error(format$1('Unknown rule type %s', rule.type));
        }

        return rule.type || 'string';
      };

      _proto.getValidationMethod = function getValidationMethod(rule) {
        if (typeof rule.validator === 'function') {
          return rule.validator;
        }

        var keys = Object.keys(rule);
        var messageIndex = keys.indexOf('message');

        if (messageIndex !== -1) {
          keys.splice(messageIndex, 1);
        }

        if (keys.length === 1 && keys[0] === 'required') {
          return validators.required;
        }

        return validators[this.getType(rule)] || undefined;
      };

      return Schema;
    }();

    Schema.register = function register(type, validator) {
      if (typeof validator !== 'function') {
        throw new Error('Cannot register a validator by type, validator is not a function');
      }

      validators[type] = validator;
    };

    Schema.warning = warning;
    Schema.messages = messages;
    Schema.validators = validators;

    function formItemSize(props) {
      const NForm = vue.inject(formInjectionKey, null);
      return {
        mergedSize: vue.computed(() => {
          if (props.size !== void 0) return props.size;
          if ((NForm === null || NForm === void 0 ? void 0 : NForm.props.size) !== void 0) return NForm.props.size;
          return "medium";
        })
      };
    }
    function formItemMisc(props) {
      const NForm = vue.inject(formInjectionKey, null);
      const mergedLabelPlacementRef = vue.computed(() => {
        const {
          labelPlacement
        } = props;
        if (labelPlacement !== void 0) return labelPlacement;
        if (NForm !== null && NForm !== void 0 && NForm.props.labelPlacement) return NForm.props.labelPlacement;
        return "top";
      });
      const isAutoLabelWidthRef = vue.computed(() => {
        return mergedLabelPlacementRef.value === "left" && (props.labelWidth === "auto" || (NForm === null || NForm === void 0 ? void 0 : NForm.props.labelWidth) === "auto");
      });
      const mergedLabelWidthRef = vue.computed(() => {
        if (mergedLabelPlacementRef.value === "top") return;
        const {
          labelWidth
        } = props;

        if (labelWidth !== void 0 && labelWidth !== "auto") {
          return formatLength(labelWidth);
        }

        if (isAutoLabelWidthRef.value) {
          const autoComputedWidth = NForm === null || NForm === void 0 ? void 0 : NForm.maxChildLabelWidthRef.value;

          if (autoComputedWidth !== void 0) {
            return formatLength(autoComputedWidth);
          } else {
            return void 0;
          }
        }

        if ((NForm === null || NForm === void 0 ? void 0 : NForm.props.labelWidth) !== void 0) {
          return formatLength(NForm.props.labelWidth);
        }

        return void 0;
      });
      const mergedLabelAlignRef = vue.computed(() => {
        const {
          labelAlign
        } = props;
        if (labelAlign) return labelAlign;
        if (NForm !== null && NForm !== void 0 && NForm.props.labelAlign) return NForm.props.labelAlign;
        return void 0;
      });
      const mergedLabelStyleRef = vue.computed(() => {
        var _props$labelProps;

        return [(_props$labelProps = props.labelProps) === null || _props$labelProps === void 0 ? void 0 : _props$labelProps.style, props.labelStyle, {
          width: mergedLabelWidthRef.value
        }];
      });
      const mergedShowRequireMarkRef = vue.computed(() => {
        const {
          showRequireMark
        } = props;
        if (showRequireMark !== void 0) return showRequireMark;
        return NForm === null || NForm === void 0 ? void 0 : NForm.props.showRequireMark;
      });
      const mergedRequireMarkPlacementRef = vue.computed(() => {
        const {
          requireMarkPlacement
        } = props;
        if (requireMarkPlacement !== void 0) return requireMarkPlacement;
        return (NForm === null || NForm === void 0 ? void 0 : NForm.props.requireMarkPlacement) || "right";
      });
      const validationErroredRef = vue.ref(false);
      const mergedValidationStatusRef = vue.computed(() => {
        const {
          validationStatus
        } = props;
        if (validationStatus !== void 0) return validationStatus;
        if (validationErroredRef.value) return "error";
        return void 0;
      });
      const mergedShowFeedbackRef = vue.computed(() => {
        const {
          showFeedback
        } = props;
        if (showFeedback !== void 0) return showFeedback;
        if ((NForm === null || NForm === void 0 ? void 0 : NForm.props.showFeedback) !== void 0) return NForm.props.showFeedback;
        return true;
      });
      const mergedShowLabelRef = vue.computed(() => {
        const {
          showLabel
        } = props;
        if (showLabel !== void 0) return showLabel;
        if ((NForm === null || NForm === void 0 ? void 0 : NForm.props.showLabel) !== void 0) return NForm.props.showLabel;
        return true;
      });
      return {
        validationErrored: validationErroredRef,
        mergedLabelStyle: mergedLabelStyleRef,
        mergedLabelPlacement: mergedLabelPlacementRef,
        mergedLabelAlign: mergedLabelAlignRef,
        mergedShowRequireMark: mergedShowRequireMarkRef,
        mergedRequireMarkPlacement: mergedRequireMarkPlacementRef,
        mergedValidationStatus: mergedValidationStatusRef,
        mergedShowFeedback: mergedShowFeedbackRef,
        mergedShowLabel: mergedShowLabelRef,
        isAutoLabelWidth: isAutoLabelWidthRef
      };
    }
    function formItemRule(props) {
      const NForm = vue.inject(formInjectionKey, null);
      const compatibleRulePathRef = vue.computed(() => {
        const {
          rulePath
        } = props;
        if (rulePath !== void 0) return rulePath;
        const {
          path
        } = props;
        if (path !== void 0) return path;
        return void 0;
      });
      const mergedRulesRef = vue.computed(() => {
        const rules = [];
        const {
          rule
        } = props;

        if (rule !== void 0) {
          if (Array.isArray(rule)) rules.push(...rule);else rules.push(rule);
        }

        if (NForm) {
          const {
            rules: formRules
          } = NForm.props;
          const {
            value: rulePath
          } = compatibleRulePathRef;

          if (formRules !== void 0 && rulePath !== void 0) {
            const formRule = lodash.exports.get(formRules, rulePath);

            if (formRule !== void 0) {
              if (Array.isArray(formRule)) {
                rules.push(...formRule);
              } else {
                rules.push(formRule);
              }
            }
          }
        }

        return rules;
      });
      const hasRequiredRuleRef = vue.computed(() => {
        return mergedRulesRef.value.some(rule => rule.required);
      });
      const mergedRequiredRef = vue.computed(() => {
        return hasRequiredRuleRef.value || props.required;
      });
      return {
        mergedRules: mergedRulesRef,
        mergedRequired: mergedRequiredRef
      };
    }

    const {
      cubicBezierEaseInOut
    } = commonVariables$m;
    function fadeDownTransition() {
      let {
        name = "fade-down",
        fromOffset = "-4px",
        enterDuration = ".3s",
        leaveDuration = ".3s",
        enterCubicBezier = cubicBezierEaseInOut,
        leaveCubicBezier = cubicBezierEaseInOut
      } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      return [c$1(`&.${name}-transition-enter-from, &.${name}-transition-leave-to`, {
        opacity: 0,
        transform: `translateY(${fromOffset})`
      }), c$1(`&.${name}-transition-enter-to, &.${name}-transition-leave-from`, {
        opacity: 1,
        transform: "translateY(0)"
      }), c$1(`&.${name}-transition-leave-active`, {
        transition: `opacity ${leaveDuration} ${leaveCubicBezier}, transform ${leaveDuration} ${leaveCubicBezier}`
      }), c$1(`&.${name}-transition-enter-active`, {
        transition: `opacity ${enterDuration} ${enterCubicBezier}, transform ${enterDuration} ${enterCubicBezier}`
      })];
    }

    var style$I = cB("form-item", `
  display: grid;
  line-height: var(--n-line-height);
`, [cB("form-item-label", `
    grid-area: label;
    align-items: center;
    line-height: 1.25;
    text-align: var(--n-label-text-align);
    font-size: var(--n-label-font-size);
    min-height: var(--n-label-height);
    padding: var(--n-label-padding);
    color: var(--n-label-text-color);
    transition: color .3s var(--n-bezier);
    box-sizing: border-box;
  `, [cE("asterisk", `
      white-space: nowrap;
      user-select: none;
      -webkit-user-select: none;
      color: var(--n-asterisk-color);
      transition: color .3s var(--n-bezier);
    `), cE("asterisk-placeholder", `
      user-select: none;
      -webkit-user-select: none;
      visibility: hidden;      
    `)]), cB("form-item-blank", `
    grid-area: blank;
    min-height: var(--n-blank-height);
  `), cM("auto-label-width", [cB("form-item-label", "white-space: nowrap;")]), cM("left-labelled", `
    grid-template-areas:
      "label blank"
      "label feedback";
    grid-template-columns: auto minmax(0, 1fr);
    grid-template-rows: auto 1fr;
    align-items: start;
  `, [cB("form-item-label", `
      display: grid;
      grid-template-areas:
        "text star"
        "text .";
      grid-template-columns: 1fr auto;
      min-height: var(--n-blank-height);
      height: auto;
      box-sizing: border-box;
      flex-shrink: 0;
      flex-grow: 0;
    `, [cE("text", `
        grid-area: text;      
      `), cE("asterisk", `
        grid-area: star;      
        align-self: end;
      `)])]), cM("top-labelled", `
    grid-template-areas:
      "label"
      "blank"
      "feedback";
    grid-template-rows: minmax(var(--n-label-height), auto) 1fr;
    grid-template-columns: minmax(0, 100%);
  `, [cM("no-label", `
      grid-template-areas:
        "blank"
        "feedback";
        grid-template-rows: 1fr;
    `), cB("form-item-label", `
      display: flex;
      align-items: flex-start;
      justify-content: var(--n-label-text-align);
    `)]), cB("form-item-blank", `
    box-sizing: border-box;
    display: flex;
    align-items: center;
    position: relative;
  `), cB("form-item-feedback-wrapper", `
    grid-area: feedback;
    box-sizing: border-box;
    min-height: var(--n-feedback-height);
    font-size: var(--n-feedback-font-size);
    line-height: 1.25;
    transform-origin: top left;
  `, [c$1("&:not(:empty)", `
      padding: var(--n-feedback-padding);
    `), cB("form-item-feedback", {
      transition: "color .3s var(--n-bezier)",
      color: "var(--n-feedback-text-color)"
    }, [cM("warning", {
      color: "var(--n-feedback-text-color-warning)"
    }), cM("error", {
      color: "var(--n-feedback-text-color-error)"
    }), fadeDownTransition({
      fromOffset: "-3px",
      enterDuration: ".3s",
      leaveDuration: ".2s"
    })])])]);

    const formItemProps = {
      ...useTheme.props,
      label: String,
      labelWidth: [Number, String],
      labelStyle: [String, Object],
      labelAlign: String,
      labelPlacement: String,
      path: String,
      first: Boolean,
      rulePath: String,
      required: Boolean,
      showRequireMark: {
        type: Boolean,
        default: void 0
      },
      requireMarkPlacement: String,
      showFeedback: {
        type: Boolean,
        default: void 0
      },
      rule: [Object, Array],
      size: String,
      ignorePathChange: Boolean,
      validationStatus: String,
      feedback: String,
      showLabel: {
        type: Boolean,
        default: void 0
      },
      labelProps: Object
    };
    const formItemPropKeys = keysOf(formItemProps);
    function wrapValidator(validator, async) {
      return (...args) => {
        try {
          const validateResult = validator(...args);
          if (!async && (typeof validateResult === "boolean" || validateResult instanceof Error || Array.isArray(validateResult)) || validateResult?.then) {
            return validateResult;
          } else if (validateResult === void 0) {
            return true;
          } else {
            warn$2(
              "form-item/validate",
              `You return a ${typeof validateResult} typed value in the validator method, which is not recommended. Please use ` + (async ? "`Promise`" : "`boolean`, `Error` or `Promise`") + " typed value instead."
            );
            return true;
          }
        } catch (err) {
          warn$2(
            "form-item/validate",
            "An error is catched in the validation, so the validation won't be done. Your callback in `validate` method of `n-form` or `n-form-item` won't be called in this validation."
          );
          console.error(err);
          return void 0;
        }
      };
    }
    var NFormItem = vue.defineComponent({
      name: "FormItem",
      props: formItemProps,
      setup(props) {
        useInjectionInstanceCollection(
          formItemInstsInjectionKey,
          "formItems",
          vue.toRef(props, "path")
        );
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const NForm = vue.inject(formInjectionKey, null);
        const formItemSizeRefs = formItemSize(props);
        const formItemMiscRefs = formItemMisc(props);
        const { validationErrored: validationErroredRef } = formItemMiscRefs;
        const { mergedRequired: mergedRequiredRef, mergedRules: mergedRulesRef } = formItemRule(props);
        const { mergedSize: mergedSizeRef } = formItemSizeRefs;
        const {
          mergedLabelPlacement: labelPlacementRef,
          mergedLabelAlign: labelTextAlignRef
        } = formItemMiscRefs;
        const renderExplainsRef = vue.ref([]);
        const feedbackIdRef = vue.ref(createId());
        const mergedDisabledRef = NForm ? vue.toRef(NForm.props, "disabled") : vue.ref(false);
        const themeRef = useTheme(
          "Form",
          "-form-item",
          style$I,
          formLight$1,
          props,
          mergedClsPrefixRef
        );
        vue.watch(vue.toRef(props, "path"), () => {
          if (props.ignorePathChange)
            return;
          restoreValidation();
        });
        function restoreValidation() {
          renderExplainsRef.value = [];
          validationErroredRef.value = false;
          if (props.feedback) {
            feedbackIdRef.value = createId();
          }
        }
        function handleContentBlur() {
          void internalValidate("blur");
        }
        function handleContentChange() {
          void internalValidate("change");
        }
        function handleContentFocus() {
          void internalValidate("focus");
        }
        function handleContentInput() {
          void internalValidate("input");
        }
        async function validate(options, callback) {
          let trigger;
          let validateCallback;
          let shouldRuleBeApplied;
          let asyncValidatorOptions;
          if (typeof options === "string") {
            trigger = options;
            validateCallback = callback;
          } else if (options !== null && typeof options === "object") {
            trigger = options.trigger;
            validateCallback = options.callback;
            shouldRuleBeApplied = options.shouldRuleBeApplied;
            asyncValidatorOptions = options.options;
          }
          return await new Promise((resolve, reject) => {
            void internalValidate(
              trigger,
              shouldRuleBeApplied,
              asyncValidatorOptions
            ).then(({ valid, errors }) => {
              if (valid) {
                if (validateCallback) {
                  validateCallback();
                }
                resolve();
              } else {
                if (validateCallback) {
                  validateCallback(errors);
                }
                reject(errors);
              }
            });
          });
        }
        const internalValidate = async (trigger = null, shouldRuleBeApplied = () => true, options = {
          suppressWarning: true
        }) => {
          const { path } = props;
          if (!options) {
            options = {};
          } else {
            if (!options.first)
              options.first = props.first;
          }
          const { value: rules } = mergedRulesRef;
          const value = NForm ? lodash.exports.get(NForm.props.model, path || "") : void 0;
          const messageRenderers = {};
          const originalMessageRendersMessage = {};
          const activeRules = (!trigger ? rules : rules.filter((rule) => {
            if (Array.isArray(rule.trigger)) {
              return rule.trigger.includes(trigger);
            } else {
              return rule.trigger === trigger;
            }
          })).filter(shouldRuleBeApplied).map((rule, i) => {
            const shallowClonedRule = Object.assign({}, rule);
            if (shallowClonedRule.validator) {
              shallowClonedRule.validator = wrapValidator(
                shallowClonedRule.validator,
                false
              );
            }
            if (shallowClonedRule.asyncValidator) {
              shallowClonedRule.asyncValidator = wrapValidator(
                shallowClonedRule.asyncValidator,
                true
              );
            }
            if (shallowClonedRule.renderMessage) {
              const rendererKey = `__renderMessage__${i}`;
              originalMessageRendersMessage[rendererKey] = shallowClonedRule.message;
              shallowClonedRule.message = rendererKey;
              messageRenderers[rendererKey] = shallowClonedRule.renderMessage;
            }
            return shallowClonedRule;
          });
          if (!activeRules.length) {
            return {
              valid: true
            };
          }
          const mergedPath = path ?? "__n_no_path__";
          const validator = new Schema({ [mergedPath]: activeRules });
          const { validateMessages } = NForm?.props || {};
          if (validateMessages) {
            validator.messages(validateMessages);
          }
          return await new Promise((resolve) => {
            void validator.validate({ [mergedPath]: value }, options, (errors) => {
              if (errors?.length) {
                renderExplainsRef.value = errors.map((error) => {
                  const transformedMessage = error?.message || "";
                  return {
                    key: transformedMessage,
                    render: () => {
                      if (transformedMessage.startsWith("__renderMessage__")) {
                        return messageRenderers[transformedMessage]();
                      }
                      return transformedMessage;
                    }
                  };
                });
                errors.forEach((error) => {
                  if (error.message?.startsWith("__renderMessage__")) {
                    error.message = originalMessageRendersMessage[error.message];
                  }
                });
                validationErroredRef.value = true;
                resolve({
                  valid: false,
                  errors
                });
              } else {
                restoreValidation();
                resolve({
                  valid: true
                });
              }
            });
          });
        };
        vue.provide(formItemInjectionKey, {
          path: vue.toRef(props, "path"),
          disabled: mergedDisabledRef,
          mergedSize: formItemSizeRefs.mergedSize,
          mergedValidationStatus: formItemMiscRefs.mergedValidationStatus,
          restoreValidation,
          handleContentBlur,
          handleContentChange,
          handleContentFocus,
          handleContentInput
        });
        const exposedRef = {
          validate,
          restoreValidation,
          internalValidate
        };
        const labelElementRef = vue.ref(null);
        vue.onMounted(() => {
          if (!formItemMiscRefs.isAutoLabelWidth.value)
            return;
          const labelElement = labelElementRef.value;
          if (labelElement !== null) {
            const memoizedWhitespace = labelElement.style.whiteSpace;
            labelElement.style.whiteSpace = "nowrap";
            labelElement.style.width = "";
            NForm?.deriveMaxChildLabelWidth(
              Number(getComputedStyle(labelElement).width.slice(0, -2))
            );
            labelElement.style.whiteSpace = memoizedWhitespace;
          }
        });
        const cssVarsRef = vue.computed(() => {
          const { value: size } = mergedSizeRef;
          const { value: labelPlacement } = labelPlacementRef;
          const direction = labelPlacement === "top" ? "vertical" : "horizontal";
          const {
            common: { cubicBezierEaseInOut },
            self: {
              labelTextColor,
              asteriskColor,
              lineHeight,
              feedbackTextColor,
              feedbackTextColorWarning,
              feedbackTextColorError,
              feedbackPadding,
              [createKey("labelHeight", size)]: labelHeight,
              [createKey("blankHeight", size)]: blankHeight,
              [createKey("feedbackFontSize", size)]: feedbackFontSize,
              [createKey("feedbackHeight", size)]: feedbackHeight,
              [createKey("labelPadding", direction)]: labelPadding,
              [createKey("labelTextAlign", direction)]: labelTextAlign,
              [createKey(createKey("labelFontSize", labelPlacement), size)]: labelFontSize
            }
          } = themeRef.value;
          let mergedLabelTextAlign = labelTextAlignRef.value ?? labelTextAlign;
          if (labelPlacement === "top") {
            mergedLabelTextAlign = mergedLabelTextAlign === "right" ? "flex-end" : "flex-start";
          }
          const cssVars = {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-line-height": lineHeight,
            "--n-blank-height": blankHeight,
            "--n-label-font-size": labelFontSize,
            "--n-label-text-align": mergedLabelTextAlign,
            "--n-label-height": labelHeight,
            "--n-label-padding": labelPadding,
            "--n-asterisk-color": asteriskColor,
            "--n-label-text-color": labelTextColor,
            "--n-feedback-padding": feedbackPadding,
            "--n-feedback-font-size": feedbackFontSize,
            "--n-feedback-height": feedbackHeight,
            "--n-feedback-text-color": feedbackTextColor,
            "--n-feedback-text-color-warning": feedbackTextColorWarning,
            "--n-feedback-text-color-error": feedbackTextColorError
          };
          return cssVars;
        });
        const themeClassHandle = useThemeClass(
          "form-item",
          vue.computed(() => {
            return `${mergedSizeRef.value[0]}${labelPlacementRef.value[0]}${labelTextAlignRef.value?.[0] || ""}`;
          }),
          cssVarsRef,
          props
        );
        return {
          labelElementRef,
          mergedClsPrefix: mergedClsPrefixRef,
          mergedRequired: mergedRequiredRef,
          feedbackId: feedbackIdRef,
          renderExplains: renderExplainsRef,
          ...formItemMiscRefs,
          ...formItemSizeRefs,
          ...exposedRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const {
          $slots,
          mergedClsPrefix,
          mergedShowLabel,
          mergedShowRequireMark,
          mergedRequireMarkPlacement,
          onRender
        } = this;
        const renderedShowRequireMark = mergedShowRequireMark !== void 0 ? mergedShowRequireMark : this.mergedRequired;
        onRender?.();
        const renderLabel = () => {
          const labelText = this.$slots.label ? this.$slots.label() : this.label;
          if (!labelText)
            return null;
          const textNode = /* @__PURE__ */ React.createElement("span", {
            class: `${mergedClsPrefix}-form-item-label__text`
          }, labelText);
          const markNode = renderedShowRequireMark ? /* @__PURE__ */ React.createElement("span", {
            class: `${mergedClsPrefix}-form-item-label__asterisk`
          }, mergedRequireMarkPlacement !== "left" ? "\xA0*" : "*\xA0") : mergedRequireMarkPlacement === "right-hanging" && /* @__PURE__ */ React.createElement("span", {
            class: `${mergedClsPrefix}-form-item-label__asterisk-placeholder`
          }, "\xA0*");
          let labelContent;
          if (mergedRequireMarkPlacement === "left") {
            labelContent = [markNode, textNode];
          } else {
            labelContent = [textNode, markNode];
          }
          const { labelProps } = this;
          return /* @__PURE__ */ React.createElement("label", {
            ...labelProps,
            class: [labelProps?.class, `${mergedClsPrefix}-form-item-label`],
            style: this.mergedLabelStyle,
            ref: "labelElementRef"
          }, labelContent);
        };
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-form-item`,
            this.themeClass,
            `${mergedClsPrefix}-form-item--${this.mergedSize}-size`,
            `${mergedClsPrefix}-form-item--${this.mergedLabelPlacement}-labelled`,
            this.isAutoLabelWidth && `${mergedClsPrefix}-form-item--auto-label-width`,
            !mergedShowLabel && `${mergedClsPrefix}-form-item--no-label`
          ],
          style: this.cssVars
        }, mergedShowLabel && renderLabel(), /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-form-item-blank`,
            this.mergedValidationStatus && `${mergedClsPrefix}-form-item-blank--${this.mergedValidationStatus}`
          ]
        }, $slots), this.mergedShowFeedback ? /* @__PURE__ */ React.createElement("div", {
          key: this.feedbackId,
          class: `${mergedClsPrefix}-form-item-feedback-wrapper`
        }, /* @__PURE__ */ React.createElement(vue.Transition, {
          name: "fade-down-transition",
          mode: "out-in"
        }, {
          default: () => {
            const { mergedValidationStatus } = this;
            return resolveWrappedSlot($slots.feedback, (children) => {
              const { feedback } = this;
              const feedbackNodes = children || feedback ? /* @__PURE__ */ React.createElement("div", {
                key: "__feedback__",
                class: `${mergedClsPrefix}-form-item-feedback__line`
              }, children || feedback) : this.renderExplains.length ? this.renderExplains?.map(({ key, render }) => /* @__PURE__ */ React.createElement("div", {
                key,
                class: `${mergedClsPrefix}-form-item-feedback__line`
              }, render())) : null;
              return feedbackNodes ? mergedValidationStatus === "warning" ? /* @__PURE__ */ React.createElement("div", {
                key: "controlled-warning",
                class: `${mergedClsPrefix}-form-item-feedback ${mergedClsPrefix}-form-item-feedback--warning`
              }, feedbackNodes) : mergedValidationStatus === "error" ? /* @__PURE__ */ React.createElement("div", {
                key: "controlled-error",
                class: `${mergedClsPrefix}-form-item-feedback ${mergedClsPrefix}-form-item-feedback--error`
              }, feedbackNodes) : mergedValidationStatus === "success" ? /* @__PURE__ */ React.createElement("div", {
                key: "controlled-success",
                class: `${mergedClsPrefix}-form-item-feedback ${mergedClsPrefix}-form-item-feedback--success`
              }, feedbackNodes) : /* @__PURE__ */ React.createElement("div", {
                key: "controlled-default",
                class: `${mergedClsPrefix}-form-item-feedback`
              }, feedbackNodes) : null;
            });
          }
        })) : null);
      }
    });

    const defaultSpan$1 = 1;
    const gridInjectionKey = createInjectionKey("n-grid");

    const defaultSpan = 1;
    const gridItemProps = {
      span: {
        type: [Number, String],
        default: defaultSpan
      },
      offset: {
        type: [Number, String],
        default: 0
      },
      suffix: Boolean,
      privateOffset: Number,
      privateSpan: Number,
      privateColStart: Number,
      privateShow: {
        type: Boolean,
        default: true
      }
    };
    const gridItemPropKeys = keysOf(gridItemProps);
    var NGridItem = vue.defineComponent({
      __GRID_ITEM__: true,
      name: "GridItem",
      alias: ["Gi"],
      props: gridItemProps,
      setup() {
        const {
          isSsrRef,
          xGapRef,
          itemStyleRef,
          overflowRef,
          layoutShiftDisabledRef
        } = vue.inject(gridInjectionKey);
        const self = vue.getCurrentInstance();
        return {
          overflow: overflowRef,
          itemStyle: itemStyleRef,
          layoutShiftDisabled: layoutShiftDisabledRef,
          mergedXGap: vue.computed(() => {
            return pxfy(xGapRef.value || 0);
          }),
          deriveStyle: () => {
            void isSsrRef.value;
            const {
              privateSpan = defaultSpan,
              privateShow = true,
              privateColStart = void 0,
              privateOffset = 0
            } = self.vnode.props;
            const { value: xGap } = xGapRef;
            const mergedXGap = pxfy(xGap || 0);
            return {
              display: !privateShow ? "none" : "",
              gridColumn: `${privateColStart ?? `span ${privateSpan}`} / span ${privateSpan}`,
              marginLeft: privateOffset ? `calc((100% - (${privateSpan} - 1) * ${mergedXGap}) / ${privateSpan} * ${privateOffset} + ${mergedXGap} * ${privateOffset})` : ""
            };
          }
        };
      },
      render() {
        if (this.layoutShiftDisabled) {
          const { span, offset, mergedXGap } = this;
          return /* @__PURE__ */ React.createElement("div", {
            style: {
              gridColumn: `span ${span} / span ${span}`,
              marginLeft: offset ? `calc((100% - (${span} - 1) * ${mergedXGap}) / ${span} * ${offset} + ${mergedXGap} * ${offset})` : ""
            }
          }, this.$slots);
        }
        return /* @__PURE__ */ React.createElement("div", {
          style: [this.itemStyle, this.deriveStyle()]
        }, this.$slots.default?.({ overflow: this.overflow }));
      }
    });

    const formItemGiProps = { ...gridItemProps,
      ...formItemProps
    };
    var FormItemGridItem = vue.defineComponent({
      __GRID_ITEM__: true,
      name: "FormItemGridItem",
      alias: ["FormItemGi"],
      props: formItemGiProps,

      setup() {
        const formItemInstRef = vue.ref(null);

        const validate = function () {
          const {
            value
          } = formItemInstRef;

          if (value) {
            return value.validate(...arguments);
          }
        };

        const restoreValidation = () => {
          const {
            value
          } = formItemInstRef;

          if (value) {
            return value.restoreValidation();
          }
        };

        return {
          formItemInstRef,
          validate,
          restoreValidation
        };
      },

      render() {
        return vue.h(NGridItem, keep(this.$.vnode.props || {}, gridItemPropKeys), {
          default: () => {
            const itemProps = keep(this.$props, formItemPropKeys);
            return vue.h(NFormItem, {
              ref: "formItemInstRef",
              ...itemProps
            }, this.$slots);
          }
        });
      }

    });

    const positionStyles$1 = Array.apply(null, {
      length: 24
    }).map((_, index) => {
      const prefixIndex = index + 1;
      const percent = `calc(100% / 24 * ${prefixIndex})`;
      return [cM(`${prefixIndex}-span`, {
        width: percent
      }), cM(`${prefixIndex}-offset`, {
        marginLeft: percent
      }), cM(`${prefixIndex}-push`, {
        left: percent
      }), cM(`${prefixIndex}-pull`, {
        right: percent
      })];
    });
    var style$H = c$1([cB("row", {
      width: "100%",
      display: "flex",
      flexWrap: "wrap"
    }), cB("col", {
      verticalAlign: "top",
      boxSizing: "border-box",
      display: "inline-block",
      position: "relative",
      zIndex: "auto"
    }, [cE("box", {
      position: "relative",
      zIndex: "auto",
      width: "100%",
      height: "100%"
    }), positionStyles$1])]);

    const rowInjectionKey = createInjectionKey("n-row");
    const rowProps = {
      gutter: {
        type: [Array, Number, String],
        default: 0
      },
      alignItems: String,
      justifyContent: String
    };
    const rowPropKeys = keysOf(rowProps);
    var NRow = vue.defineComponent({
      name: "Row",
      props: rowProps,
      setup(props) {
        const { mergedClsPrefixRef, mergedRtlRef } = useConfig(props);
        useStyle("-legacy-grid", style$H, mergedClsPrefixRef);
        const rtlEnabledRef = useRtl("Row", mergedRtlRef, mergedClsPrefixRef);
        const verticalGutterRef = useMemo(() => {
          const { gutter } = props;
          if (Array.isArray(gutter)) {
            return gutter[1] || 0;
          }
          return 0;
        });
        const horizontalGutterRef = useMemo(() => {
          const { gutter } = props;
          if (Array.isArray(gutter)) {
            return gutter[0];
          }
          return Number(gutter);
        });
        vue.provide(rowInjectionKey, {
          mergedClsPrefixRef,
          gutterRef: vue.toRef(props, "gutter"),
          verticalGutterRef,
          horizontalGutterRef
        });
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          rtlEnabled: rtlEnabledRef,
          styleMargin: useMemo(
            () => `-${formatLength(verticalGutterRef.value, {
          c: 0.5
        })} -${formatLength(horizontalGutterRef.value, { c: 0.5 })}`
          ),
          styleWidth: useMemo(
            () => `calc(100% + ${formatLength(horizontalGutterRef.value)})`
          )
        };
      },
      render() {
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${this.mergedClsPrefix}-row`,
            this.rtlEnabled && `${this.mergedClsPrefix}-row--rtl`
          ],
          style: {
            margin: this.styleMargin,
            width: this.styleWidth,
            alignItems: this.alignItems,
            justifyContent: this.justifyContent
          }
        }, this.$slots);
      }
    });

    const colProps = {
      span: {
        type: [String, Number],
        default: 1
      },
      push: {
        type: [String, Number],
        default: 0
      },
      pull: {
        type: [String, Number],
        default: 0
      },
      offset: {
        type: [String, Number],
        default: 0
      }
    };
    const colPropKeys = keysOf(colProps);
    var NCol = vue.defineComponent({
      name: "Col",
      props: colProps,
      setup(props) {
        const NRow = vue.inject(rowInjectionKey, null);
        if (!NRow)
          throwError("col", "`n-col` must be placed inside `n-row`.");
        return {
          mergedClsPrefix: NRow.mergedClsPrefixRef,
          gutter: NRow.gutterRef,
          stylePadding: vue.computed(
            () => `${formatLength(NRow.verticalGutterRef.value, {
          c: 0.5
        })} ${formatLength(NRow.horizontalGutterRef.value, { c: 0.5 })}`
          ),
          mergedPush: vue.computed(() => Number(props.push) - Number(props.pull))
        };
      },
      render() {
        const {
          $slots,
          span,
          mergedPush,
          offset,
          stylePadding,
          gutter,
          mergedClsPrefix
        } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-col`,
            {
              [`${mergedClsPrefix}-col--${span}-span`]: true,
              [`${mergedClsPrefix}-col--${mergedPush}-push`]: mergedPush > 0,
              [`${mergedClsPrefix}-col--${-mergedPush}-pull`]: mergedPush < 0,
              [`${mergedClsPrefix}-col--${offset}-offset`]: offset
            }
          ],
          style: {
            padding: stylePadding
          }
        }, gutter ? /* @__PURE__ */ React.createElement("div", null, $slots) : $slots);
      }
    });

    const formItemColProps = { ...colProps,
      ...formItemProps
    };
    const formItemColPropKeys = keysOf(formItemColProps);
    var NFormItemCol = vue.defineComponent({
      name: "FormItemCol",
      props: formItemColProps,

      setup() {
        const formItemInstRef = vue.ref(null);

        const validate = function () {
          const {
            value
          } = formItemInstRef;

          if (value) {
            return value.validate(...arguments);
          }
        };

        const restoreValidation = () => {
          const {
            value
          } = formItemInstRef;

          if (value) {
            return value.restoreValidation();
          }
        };

        return {
          formItemInstRef,
          validate,
          restoreValidation
        };
      },

      render() {
        return vue.h(NCol, keep(this.$props, colPropKeys), {
          default: () => {
            const itemProps = keep(this.$props, formItemPropKeys);
            return vue.h(NFormItem, {
              ref: "formItemInstRef",
              ...itemProps
            }, this.$slots);
          }
        });
      }

    });

    const formItemRowProps = { ...rowProps,
      ...formItemColProps
    };
    var FormItemRow = vue.defineComponent({
      name: "FormItemRow",
      props: formItemRowProps,

      setup() {
        const formItemColInstRef = vue.ref(null);

        const validate = function () {
          const {
            value
          } = formItemColInstRef;

          if (value) {
            return value.validate(...arguments);
          }
        };

        const restoreValidation = () => {
          const {
            value
          } = formItemColInstRef;

          if (value) {
            return value.restoreValidation();
          }
        };

        return {
          formItemColInstRef,
          validate,
          restoreValidation
        };
      },

      render() {
        return vue.h(NRow, keep(this.$props, rowPropKeys), {
          default: () => {
            const colProps = keep(this.$props, formItemColPropKeys);
            return vue.h(NFormItemCol, {
              ref: "formItemColInstRef",
              ...colProps,
              span: 24
            }, this.$slots);
          }
        });
      }

    });

    var GlobalStyle = vue.defineComponent({
      name: "GlobalStyle",

      setup() {
        if (typeof document === "undefined") return;
        const NConfigProvider = vue.inject(configProviderInjectionKey, null);
        const {
          body
        } = document;
        const {
          style
        } = body;
        let styleApplied = false;
        let firstApply = true;
        vue.onBeforeMount(() => {
          vue.watchEffect(() => {
            var _NConfigProvider$merg, _NConfigProvider$merg2;

            const {
              textColor2,
              fontSize,
              fontFamily,
              bodyColor,
              cubicBezierEaseInOut,
              lineHeight
            } = NConfigProvider ? lodash.exports.merge({}, ((_NConfigProvider$merg = NConfigProvider.mergedThemeRef.value) === null || _NConfigProvider$merg === void 0 ? void 0 : _NConfigProvider$merg.common) || commonLight, (_NConfigProvider$merg2 = NConfigProvider.mergedThemeOverridesRef.value) === null || _NConfigProvider$merg2 === void 0 ? void 0 : _NConfigProvider$merg2.common) : commonLight;

            if (styleApplied || !body.hasAttribute("n-styled")) {
              style.setProperty("-webkit-text-size-adjust", "100%");
              style.setProperty("-webkit-tap-highlight-color", "transparent");
              style.padding = "0";
              style.margin = "0";
              style.backgroundColor = bodyColor;
              style.color = textColor2;
              style.fontSize = fontSize;
              style.fontFamily = fontFamily;
              style.lineHeight = lineHeight;
              const transition = `color .3s ${cubicBezierEaseInOut}, background-color .3s ${cubicBezierEaseInOut}`;

              if (firstApply) {
                setTimeout(() => {
                  style.transition = transition;
                }, 0);
              } else {
                style.transition = transition;
              }

              body.setAttribute("n-styled", "");
              styleApplied = true;
              firstApply = false;
            } else {
              warn$2("global-style", "More than one n-global-style exist in the document.body. Only the first mounted one will work.");
            }
          });
        });
        vue.onUnmounted(() => {
          if (styleApplied) {
            body.removeAttribute("n-styled");
          }
        });
      },

      render() {
        return null;
      }

    });

    const gradientTextDark = {
      name: "GradientText",
      common: commonDark,

      self(vars) {
        const {
          primaryColor,
          successColor,
          warningColor,
          errorColor,
          infoColor,
          primaryColorSuppl,
          successColorSuppl,
          warningColorSuppl,
          errorColorSuppl,
          infoColorSuppl,
          fontWeightStrong
        } = vars;
        return {
          fontWeight: fontWeightStrong,
          rotate: "252deg",
          colorStartPrimary: primaryColor,
          colorEndPrimary: primaryColorSuppl,
          colorStartInfo: infoColor,
          colorEndInfo: infoColorSuppl,
          colorStartWarning: warningColor,
          colorEndWarning: warningColorSuppl,
          colorStartError: errorColor,
          colorEndError: errorColorSuppl,
          colorStartSuccess: successColor,
          colorEndSuccess: successColorSuppl
        };
      }

    };
    var gradientTextDark$1 = gradientTextDark;

    const self$x = vars => {
      const {
        primaryColor,
        successColor,
        warningColor,
        errorColor,
        infoColor,
        fontWeightStrong
      } = vars;
      return {
        fontWeight: fontWeightStrong,
        rotate: "252deg",
        colorStartPrimary: changeColor(primaryColor, {
          alpha: 0.6
        }),
        colorEndPrimary: primaryColor,
        colorStartInfo: changeColor(infoColor, {
          alpha: 0.6
        }),
        colorEndInfo: infoColor,
        colorStartWarning: changeColor(warningColor, {
          alpha: 0.6
        }),
        colorEndWarning: warningColor,
        colorStartError: changeColor(errorColor, {
          alpha: 0.6
        }),
        colorEndError: errorColor,
        colorStartSuccess: changeColor(successColor, {
          alpha: 0.6
        }),
        colorEndSuccess: successColor
      };
    };

    const gradientTextLight = {
      name: "GradientText",
      common: commonLight,
      self: self$x
    };
    var gradientTextLight$1 = gradientTextLight;

    var style$G = cB("gradient-text", `
  display: inline-block;
  font-weight: var(--n-font-weight);
  -webkit-background-clip: text;
  background-clip: text;
  color: #0000;
  white-space: nowrap;
  background-image: linear-gradient(var(--n-rotate), var(--n-color-start) 0%, var(--n-color-end) 100%);
  transition:
    --n-color-start .3s var(--n-bezier),
    --n-color-end .3s var(--n-bezier);
`);

    const gradientTextProps = {
      ...useTheme.props,
      size: [String, Number],
      fontSize: [String, Number],
      type: {
        type: String,
        default: "primary"
      },
      color: [Object, String],
      gradient: [Object, String]
    };
    var GradientText = vue.defineComponent({
      name: "GradientText",
      props: gradientTextProps,
      setup(props) {
        useHoudini();
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const compatibleTypeRef = vue.computed(() => {
          const { type } = props;
          if (type === "danger")
            return "error";
          return type;
        });
        const styleFontSizeRef = vue.computed(() => {
          let fontSize = props.size || props.fontSize;
          if (fontSize)
            fontSize = formatLength(fontSize);
          return fontSize || void 0;
        });
        const styleBgImageRef = vue.computed(() => {
          const gradient = props.color || props.gradient;
          if (typeof gradient === "string") {
            return gradient;
          } else if (gradient) {
            const deg = gradient.deg || 0;
            const from = gradient.from;
            const to = gradient.to;
            return `linear-gradient(${deg}deg, ${from} 0%, ${to} 100%)`;
          }
          return void 0;
        });
        const themeRef = useTheme(
          "GradientText",
          "-gradient-text",
          style$G,
          gradientTextLight$1,
          props,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const { value: type } = compatibleTypeRef;
          const {
            common: { cubicBezierEaseInOut },
            self: {
              rotate,
              [createKey("colorStart", type)]: colorStart,
              [createKey("colorEnd", type)]: colorEnd,
              fontWeight
            }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-rotate": rotate,
            "--n-color-start": colorStart,
            "--n-color-end": colorEnd,
            "--n-font-weight": fontWeight
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "gradient-text",
          vue.computed(() => compatibleTypeRef.value[0]),
          cssVarsRef,
          props
        ) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          compatibleType: compatibleTypeRef,
          styleFontSize: styleFontSizeRef,
          styleBgImage: styleBgImageRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedClsPrefix, onRender } = this;
        onRender?.();
        return /* @__PURE__ */ React.createElement("span", {
          class: [
            `${mergedClsPrefix}-gradient-text`,
            `${mergedClsPrefix}-gradient-text--${this.compatibleType}-type`,
            this.themeClass
          ],
          style: [
            {
              fontSize: this.styleFontSize,
              backgroundImage: this.styleBgImage
            },
            this.cssVars
          ]
        }, this.$slots);
      }
    });

    const defaultBreakpoints = {
      xs: 0,
      s: 640,
      m: 1024,
      l: 1280,
      xl: 1536,
      xxl: 1920
    };

    const defaultCols = 24;
    const SSR_ATTR_NAME = "__ssr__";
    const gridProps = {
      layoutShiftDisabled: Boolean,
      responsive: {
        type: [String, Boolean],
        default: "self"
      },
      cols: {
        type: [Number, String],
        default: defaultCols
      },
      itemResponsive: Boolean,
      collapsed: Boolean,
      collapsedRows: {
        type: Number,
        default: 1
      },
      itemStyle: [Object, String],
      xGap: {
        type: [Number, String],
        default: 0
      },
      yGap: {
        type: [Number, String],
        default: 0
      }
    };
    var Grid = vue.defineComponent({
      name: "Grid",
      inheritAttrs: false,
      props: gridProps,
      setup(props) {
        const { mergedClsPrefixRef, mergedBreakpointsRef } = useConfig(props);
        const numRegex = /^\d+$/;
        const widthRef = vue.ref(void 0);
        const breakpointsRef = useBreakpoints(
          mergedBreakpointsRef?.value || defaultBreakpoints
        );
        const isResponsiveRef = useMemo(() => {
          if (props.itemResponsive)
            return true;
          if (!numRegex.test(props.cols.toString()))
            return true;
          if (!numRegex.test(props.xGap.toString()))
            return true;
          if (!numRegex.test(props.yGap.toString()))
            return true;
          return false;
        });
        const responsiveQueryRef = vue.computed(() => {
          if (!isResponsiveRef.value)
            return void 0;
          return props.responsive === "self" ? widthRef.value : breakpointsRef.value;
        });
        const responsiveColsRef = useMemo(() => {
          return Number(
            parseResponsivePropValue(
              props.cols.toString(),
              responsiveQueryRef.value
            )
          ) ?? defaultCols;
        });
        const responsiveXGapRef = useMemo(
          () => parseResponsivePropValue(props.xGap.toString(), responsiveQueryRef.value)
        );
        const responsiveYGapRef = useMemo(
          () => parseResponsivePropValue(props.yGap.toString(), responsiveQueryRef.value)
        );
        const handleResize = (entry) => {
          widthRef.value = entry.contentRect.width;
        };
        const handleResizeRaf = (entry) => {
          beforeNextFrameOnce(handleResize, entry);
        };
        const overflowRef = vue.ref(false);
        const handleResizeRef = vue.computed(
          () => {
            if (props.responsive === "self") {
              return handleResizeRaf;
            }
            return void 0;
          }
        );
        const isSsrRef = vue.ref(false);
        const contentElRef = vue.ref();
        vue.onMounted(() => {
          const { value: contentEl } = contentElRef;
          if (contentEl) {
            if (contentEl.hasAttribute(SSR_ATTR_NAME)) {
              contentEl.removeAttribute(SSR_ATTR_NAME);
              isSsrRef.value = true;
            }
          }
        });
        vue.provide(gridInjectionKey, {
          layoutShiftDisabledRef: vue.toRef(props, "layoutShiftDisabled"),
          isSsrRef,
          itemStyleRef: vue.toRef(props, "itemStyle"),
          xGapRef: responsiveXGapRef,
          overflowRef
        });
        return {
          isSsr: !isBrowser$2,
          contentEl: contentElRef,
          mergedClsPrefix: mergedClsPrefixRef,
          style: vue.computed(() => {
            if (props.layoutShiftDisabled) {
              return {
                width: "100%",
                display: "grid",
                gridTemplateColumns: `repeat(${props.cols}, minmax(0, 1fr))`,
                columnGap: pxfy(props.xGap),
                rowGap: pxfy(props.yGap)
              };
            }
            return {
              width: "100%",
              display: "grid",
              gridTemplateColumns: `repeat(${responsiveColsRef.value}, minmax(0, 1fr))`,
              columnGap: pxfy(responsiveXGapRef.value),
              rowGap: pxfy(responsiveYGapRef.value)
            };
          }),
          isResponsive: isResponsiveRef,
          responsiveQuery: responsiveQueryRef,
          responsiveCols: responsiveColsRef,
          handleResize: handleResizeRef,
          overflow: overflowRef
        };
      },
      render() {
        if (this.layoutShiftDisabled) {
          return vue.h(
            "div",
            vue.mergeProps(
              {
                ref: "contentEl",
                class: `${this.mergedClsPrefix}-grid`,
                style: this.style
              },
              this.$attrs
            ),
            this.$slots
          );
        }
        const renderContent = () => {
          this.overflow = false;
          const rawChildren = flatten$3(getSlot$1(this));
          const childrenAndRawSpan = [];
          const { collapsed, collapsedRows, responsiveCols, responsiveQuery } = this;
          rawChildren.forEach((child) => {
            if (child?.type?.__GRID_ITEM__ !== true)
              return;
            if (isNodeVShowFalse(child)) {
              const clonedNode = vue.cloneVNode(child);
              if (clonedNode.props) {
                clonedNode.props.privateShow = false;
              } else {
                clonedNode.props = { privateShow: false };
              }
              childrenAndRawSpan.push({
                child: clonedNode,
                rawChildSpan: 0
              });
              return;
            }
            child.dirs = child.dirs?.filter(({ dir }) => dir !== vue.vShow) || null;
            const clonedChild = vue.cloneVNode(child);
            const rawChildSpan = Number(
              parseResponsivePropValue(
                clonedChild.props?.span,
                responsiveQuery
              ) ?? defaultSpan$1
            );
            if (rawChildSpan === 0)
              return;
            childrenAndRawSpan.push({
              child: clonedChild,
              rawChildSpan
            });
          });
          let suffixSpan = 0;
          const maybeSuffixNode = childrenAndRawSpan[childrenAndRawSpan.length - 1]?.child;
          if (maybeSuffixNode?.props) {
            const suffixPropValue = maybeSuffixNode.props?.suffix;
            if (suffixPropValue !== void 0 && suffixPropValue !== false) {
              suffixSpan = maybeSuffixNode.props?.span ?? defaultSpan$1;
              maybeSuffixNode.props.privateSpan = suffixSpan;
              maybeSuffixNode.props.privateColStart = responsiveCols + 1 - suffixSpan;
              maybeSuffixNode.props.privateShow = maybeSuffixNode.props.privateShow ?? true;
            }
          }
          let spanCounter = 0;
          let done = false;
          for (const { child, rawChildSpan } of childrenAndRawSpan) {
            if (done) {
              this.overflow = true;
            }
            if (!done) {
              const childOffset = Number(
                parseResponsivePropValue(
                  child.props?.offset,
                  responsiveQuery
                ) ?? 0
              );
              const childSpan = Math.min(rawChildSpan + childOffset, responsiveCols);
              if (!child.props) {
                child.props = {
                  privateSpan: childSpan,
                  privateOffset: childOffset
                };
              } else {
                child.props.privateSpan = childSpan;
                child.props.privateOffset = childOffset;
              }
              if (collapsed) {
                const remainder = spanCounter % responsiveCols;
                if (childSpan + remainder > responsiveCols) {
                  spanCounter += responsiveCols - remainder;
                }
                if (childSpan + spanCounter + suffixSpan > collapsedRows * responsiveCols) {
                  done = true;
                } else {
                  spanCounter += childSpan;
                }
              }
            }
            if (done) {
              if (child.props) {
                if (child.props.privateShow !== true) {
                  child.props.privateShow = false;
                }
              } else {
                child.props = {
                  privateShow: false
                };
              }
            }
          }
          return vue.h(
            "div",
            vue.mergeProps(
              {
                ref: "contentEl",
                class: `${this.mergedClsPrefix}-grid`,
                style: this.style,
                [SSR_ATTR_NAME]: this.isSsr || void 0
              },
              this.$attrs
            ),
            childrenAndRawSpan.map(({ child }) => child)
          );
        };
        return this.isResponsive && this.responsive === "self" ? /* @__PURE__ */ React.createElement(VResizeObserver, {
          onResize: this.handleResize
        }, {
          default: renderContent
        }) : renderContent();
      }
    });

    const self$w = vars => {
      const {
        primaryColor,
        baseColor
      } = vars;
      return {
        color: primaryColor,
        iconColor: baseColor
      };
    };
    const iconWrapperLight = {
      name: "IconWrapper",
      common: commonLight,
      self: self$w
    };
    var iconWrapperLight$1 = iconWrapperLight;

    const iconDark = {
      name: "IconWrapper",
      common: commonDark,
      self: self$w
    };
    var iconWrapperDark = iconDark;

    var style$F = cB("icon-wrapper", `
  transition:
    color .3s var(--n-bezier),
    background-color .3s var(--n-bezier);
  background-color: var(--n-color);
  display: inline-flex;
  align-items: center;
  justify-content: center;
  color: var(--n-icon-color);
`);

    const iconWrapperProps = {
      ...useTheme.props,
      size: {
        type: Number,
        default: 24
      },
      borderRadius: {
        type: Number,
        default: 6
      },
      color: String,
      iconColor: String
    };
    const NIconWrapper = vue.defineComponent({
      name: "IconWrapper",
      props: iconWrapperProps,
      setup(props, { slots }) {
        const themeRef = useTheme(
          "IconWrapper",
          "-icon-wrapper",
          style$F,
          iconWrapperLight$1,
          props
        );
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self: { color, iconColor }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-color": color,
            "--n-icon-color": iconColor
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("icon-wrapper", void 0, cssVarsRef, props) : void 0;
        return () => {
          const size = formatLength(props.size);
          themeClassHandle?.onRender();
          return /* @__PURE__ */ React.createElement("div", {
            class: [
              `${mergedClsPrefixRef.value}-icon-wrapper`,
              themeClassHandle?.themeClass.value
            ],
            style: [
              cssVarsRef?.value,
              {
                height: size,
                width: size,
                borderRadius: formatLength(props.borderRadius),
                backgroundColor: props.color,
                color: props.iconColor
              }
            ]
          }, slots);
        };
      }
    });

    const imagePreviewSharedProps = { ...useTheme.props,
      showToolbar: {
        type: Boolean,
        default: true
      },
      showToolbarTooltip: Boolean
    };

    function self$v() {
      return {
        toolbarIconColor: "rgba(255, 255, 255, .9)",
        toolbarColor: "rgba(0, 0, 0, .35)",
        toolbarBoxShadow: "none",
        toolbarBorderRadius: "24px"
      };
    }

    const imageLight = createTheme$1({
      name: "Image",
      common: commonLight,
      peers: {
        Tooltip: tooltipLight$1
      },
      self: self$v
    });

    var commonVars$3 = {
      closeMargin: "16px 12px",
      closeSize: "20px",
      closeIconSize: "16px",
      width: "365px",
      padding: "16px",
      titleFontSize: "16px",
      metaFontSize: "12px",
      descriptionFontSize: "12px"
    };

    const self$u = vars => {
      const {
        textColor2,
        successColor,
        infoColor,
        warningColor,
        errorColor,
        popoverColor,
        closeIconColor,
        closeIconColorHover,
        closeIconColorPressed,
        closeColorHover,
        closeColorPressed,
        textColor1,
        textColor3,
        borderRadius,
        fontWeightStrong,
        boxShadow2,
        lineHeight,
        fontSize
      } = vars;
      return { ...commonVars$3,
        borderRadius,
        lineHeight,
        fontSize,
        headerFontWeight: fontWeightStrong,
        iconColor: textColor2,
        iconColorSuccess: successColor,
        iconColorInfo: infoColor,
        iconColorWarning: warningColor,
        iconColorError: errorColor,
        color: popoverColor,
        textColor: textColor2,
        closeIconColor,
        closeIconColorHover,
        closeIconColorPressed,
        closeBorderRadius: borderRadius,
        closeColorHover,
        closeColorPressed,
        headerTextColor: textColor1,
        descriptionTextColor: textColor3,
        actionTextColor: textColor2,
        boxShadow: boxShadow2
      };
    };
    const notificationLight = createTheme$1({
      name: "Notification",
      common: commonLight,
      peers: {
        Scrollbar: scrollbarLight$1
      },
      self: self$u
    });
    var notificationLight$1 = notificationLight;

    const notificationDark = {
      name: "Notification",
      common: commonDark,
      peers: {
        Scrollbar: scrollbarDark$1
      },
      self: self$u
    };
    var notificationDark$1 = notificationDark;

    var rtlStyle$9 = cB("notification", [cM("rtl", `
    direction: rtl;
  `, [cB("notification-main", `
      margin-left: unset;
      margin-right: 8px;
    `, [cE("header", `
        margin: var(--n-icon-margin);
        margin-right: 0;
      `)]), cE("avatar", `
      left: unset;
      right: var(--n-padding-left);
    `), cM("show-avatar", [cB("notification-main", `
        margin-right: 40px;
        margin-reft: unset;
      `)]), cM("closable", [cB("notification-main", [c$1("> *:first-child", `
          padding-left: 20px;
          padding-right: unset;
        `)]), cE("close", `
        right: unset;
        left: 0;
      `)])])]);

    const notificationRtl = {
      name: "Notification",
      style: rtlStyle$9
    };

    var commonVariables$4 = {
      margin: "0 0 8px 0",
      padding: "10px 20px",
      maxWidth: "720px",
      minWidth: "420px",
      iconMargin: "0 10px 0 0",
      closeMargin: "0 0 0 10px",
      closeSize: "20px",
      closeIconSize: "16px",
      iconSize: "20px",
      fontSize: "14px"
    };

    const self$t = vars => {
      const {
        textColor2,
        closeIconColor,
        closeIconColorHover,
        closeIconColorPressed,
        infoColor,
        successColor,
        errorColor,
        warningColor,
        popoverColor,
        boxShadow2,
        primaryColor,
        lineHeight,
        borderRadius,
        closeColorHover,
        closeColorPressed
      } = vars;
      return { ...commonVariables$4,
        closeBorderRadius: borderRadius,
        textColor: textColor2,
        textColorInfo: textColor2,
        textColorSuccess: textColor2,
        textColorError: textColor2,
        textColorWarning: textColor2,
        textColorLoading: textColor2,
        color: popoverColor,
        colorInfo: popoverColor,
        colorSuccess: popoverColor,
        colorError: popoverColor,
        colorWarning: popoverColor,
        colorLoading: popoverColor,
        boxShadow: boxShadow2,
        boxShadowInfo: boxShadow2,
        boxShadowSuccess: boxShadow2,
        boxShadowError: boxShadow2,
        boxShadowWarning: boxShadow2,
        boxShadowLoading: boxShadow2,
        iconColor: textColor2,
        iconColorInfo: infoColor,
        iconColorSuccess: successColor,
        iconColorWarning: warningColor,
        iconColorError: errorColor,
        iconColorLoading: primaryColor,
        closeColorHover,
        closeColorPressed,
        closeIconColor,
        closeIconColorHover,
        closeIconColorPressed,
        closeColorHoverInfo: closeColorHover,
        closeColorPressedInfo: closeColorPressed,
        closeIconColorInfo: closeIconColor,
        closeIconColorHoverInfo: closeIconColorHover,
        closeIconColorPressedInfo: closeIconColorPressed,
        closeColorHoverSuccess: closeColorHover,
        closeColorPressedSuccess: closeColorPressed,
        closeIconColorSuccess: closeIconColor,
        closeIconColorHoverSuccess: closeIconColorHover,
        closeIconColorPressedSuccess: closeIconColorPressed,
        closeColorHoverError: closeColorHover,
        closeColorPressedError: closeColorPressed,
        closeIconColorError: closeIconColor,
        closeIconColorHoverError: closeIconColorHover,
        closeIconColorPressedError: closeIconColorPressed,
        closeColorHoverWarning: closeColorHover,
        closeColorPressedWarning: closeColorPressed,
        closeIconColorWarning: closeIconColor,
        closeIconColorHoverWarning: closeIconColorHover,
        closeIconColorPressedWarning: closeIconColorPressed,
        closeColorHoverLoading: closeColorHover,
        closeColorPressedLoading: closeColorPressed,
        closeIconColorLoading: closeIconColor,
        closeIconColorHoverLoading: closeIconColorHover,
        closeIconColorPressedLoading: closeIconColorPressed,
        loadingColor: primaryColor,
        lineHeight,
        borderRadius
      };
    };
    const messageLight = {
      name: "Message",
      common: commonLight,
      self: self$t
    };
    var messageLight$1 = messageLight;

    const messageDark = {
      name: "Message",
      common: commonDark,
      self: self$t
    };
    var messageDark$1 = messageDark;

    var rtlStyle$8 = cB("message", [cM("rtl", `
    direction: rtl;
  `, [cE("close", `
      margin: 0 10px 0 0;
    `), cE("icon", `
      margin: 0 0 0 10px;
    `)])]);

    const messageRtl = {
      name: "Message",
      style: rtlStyle$8
    };

    const buttonGroupDark = {
      name: "ButtonGroup",
      common: commonDark
    };
    var buttonGroupDark$1 = buttonGroupDark;

    const buttonGroupLight = {
      name: "ButtonGroup",
      common: commonLight
    };
    var buttonGroupLight$1 = buttonGroupLight;

    const inputNumberDark = {
      name: "InputNumber",
      common: commonDark,
      peers: {
        Button: buttonDark$1,
        Input: inputDark$1
      },

      self(vars) {
        const {
          textColorDisabled
        } = vars;
        return {
          iconColorDisabled: textColorDisabled
        };
      }

    };
    var inputNumberDark$1 = inputNumberDark;

    const self$s = vars => {
      const {
        textColorDisabled
      } = vars;
      return {
        iconColorDisabled: textColorDisabled
      };
    };

    const inputNumberLight = createTheme$1({
      name: "InputNumber",
      common: commonLight,
      peers: {
        Button: buttonLight$1,
        Input: inputLight$1
      },
      self: self$s
    });
    var inputNumberLight$1 = inputNumberLight;

    const layoutDark = {
      name: "Layout",
      common: commonDark,
      peers: {
        Scrollbar: scrollbarDark$1
      },

      self(vars) {
        const {
          textColor2,
          bodyColor,
          popoverColor,
          cardColor,
          dividerColor,
          scrollbarColor,
          scrollbarColorHover
        } = vars;
        return {
          textColor: textColor2,
          textColorInverted: textColor2,
          color: bodyColor,
          colorEmbedded: bodyColor,
          headerColor: cardColor,
          headerColorInverted: cardColor,
          footerColor: cardColor,
          footerColorInverted: cardColor,
          headerBorderColor: dividerColor,
          headerBorderColorInverted: dividerColor,
          footerBorderColor: dividerColor,
          footerBorderColorInverted: dividerColor,
          siderBorderColor: dividerColor,
          siderBorderColorInverted: dividerColor,
          siderColor: cardColor,
          siderColorInverted: cardColor,
          siderToggleButtonBorder: "1px solid transparent",
          siderToggleButtonColor: popoverColor,
          siderToggleButtonIconColor: textColor2,
          siderToggleButtonIconColorInverted: textColor2,
          siderToggleBarColor: composite(bodyColor, scrollbarColor),
          siderToggleBarColorHover: composite(bodyColor, scrollbarColorHover),
          __invertScrollbar: "false"
        };
      }

    };
    var layoutDark$1 = layoutDark;

    const self$r = vars => {
      const {
        baseColor,
        textColor2,
        bodyColor,
        cardColor,
        dividerColor,
        actionColor,
        scrollbarColor,
        scrollbarColorHover,
        invertedColor
      } = vars;
      return {
        textColor: textColor2,
        textColorInverted: "#FFF",
        color: bodyColor,
        colorEmbedded: actionColor,
        headerColor: cardColor,
        headerColorInverted: invertedColor,
        footerColor: actionColor,
        footerColorInverted: invertedColor,
        headerBorderColor: dividerColor,
        headerBorderColorInverted: invertedColor,
        footerBorderColor: dividerColor,
        footerBorderColorInverted: invertedColor,
        siderBorderColor: dividerColor,
        siderBorderColorInverted: invertedColor,
        siderColor: cardColor,
        siderColorInverted: invertedColor,
        siderToggleButtonBorder: `1px solid ${dividerColor}`,
        siderToggleButtonColor: baseColor,
        siderToggleButtonIconColor: textColor2,
        siderToggleButtonIconColorInverted: textColor2,
        siderToggleBarColor: composite(bodyColor, scrollbarColor),
        siderToggleBarColorHover: composite(bodyColor, scrollbarColorHover),
        __invertScrollbar: "true"
      };
    };
    const layoutLight = createTheme$1({
      name: "Layout",
      common: commonLight,
      peers: {
        Scrollbar: scrollbarLight$1
      },
      self: self$r
    });
    var layoutLight$1 = layoutLight;

    const self$q = vars => {
      const {
        textColor2,
        cardColor,
        modalColor,
        popoverColor,
        dividerColor,
        borderRadius,
        fontSize,
        hoverColor
      } = vars;
      return {
        textColor: textColor2,
        color: cardColor,
        colorHover: hoverColor,
        colorModal: modalColor,
        colorHoverModal: composite(modalColor, hoverColor),
        colorPopover: popoverColor,
        colorHoverPopover: composite(popoverColor, hoverColor),
        borderColor: dividerColor,
        borderColorModal: composite(modalColor, dividerColor),
        borderColorPopover: composite(popoverColor, dividerColor),
        borderRadius,
        fontSize
      };
    };
    const listLight = {
      name: "List",
      common: commonLight,
      self: self$q
    };
    var listLight$1 = listLight;

    const listDark$1 = {
      name: "List",
      common: commonDark,
      self: self$q
    };
    var listDark$2 = listDark$1;

    var rtlStyle$7 = cB("list", [cM("rtl", `
    direction: rtl;
    text-align: right;
  `, [cB("list-item", [cE("prefix", `
        margin-right: 0;
        margin-left: 20px;
      `), cE("suffix", `
        margin-right: 20px;
        margin-left: 0;
      `)])])]);

    const listRtl = {
      name: "List",
      style: rtlStyle$7
    };

    const loadingBarDark = {
      name: "LoadingBar",
      common: commonDark,

      self(vars) {
        const {
          primaryColor
        } = vars;
        return {
          colorError: "red",
          colorLoading: primaryColor,
          height: "2px"
        };
      }

    };
    var loadingBarDark$1 = loadingBarDark;

    const self$p = vars => {
      const {
        primaryColor,
        errorColor
      } = vars;
      return {
        colorError: errorColor,
        colorLoading: primaryColor,
        height: "2px"
      };
    };

    const loadingBarLight = {
      name: "LoadingBar",
      common: commonLight,
      self: self$p
    };
    var loadingBarLight$1 = loadingBarLight;

    const logDark = {
      name: "Log",
      common: commonDark,
      peers: {
        Scrollbar: scrollbarDark$1,
        Code: codeDark$1
      },

      self(vars) {
        const {
          textColor2,
          inputColor,
          fontSize,
          primaryColor
        } = vars;
        return {
          loaderFontSize: fontSize,
          loaderTextColor: textColor2,
          loaderColor: inputColor,
          loaderBorder: "1px solid #0000",
          loadingColor: primaryColor
        };
      }

    };
    var logDark$1 = logDark;

    const self$o = vars => {
      const {
        textColor2,
        modalColor,
        borderColor,
        fontSize,
        primaryColor
      } = vars;
      return {
        loaderFontSize: fontSize,
        loaderTextColor: textColor2,
        loaderColor: modalColor,
        loaderBorder: `1px solid ${borderColor}`,
        loadingColor: primaryColor
      };
    };

    const logLight = createTheme$1({
      name: "Log",
      common: commonLight,
      peers: {
        Scrollbar: scrollbarLight$1,
        Code: codeLight$1
      },
      self: self$o
    });
    var logLight$1 = logLight;

    const listDark = {
      name: "Mention",
      common: commonDark,
      peers: {
        InternalSelectMenu: internalSelectMenuDark$1,
        Input: inputDark$1
      },

      self(vars) {
        const {
          boxShadow2
        } = vars;
        return {
          menuBoxShadow: boxShadow2
        };
      }

    };
    var mentionDark = listDark;

    const self$n = vars => {
      const {
        boxShadow2
      } = vars;
      return {
        menuBoxShadow: boxShadow2
      };
    };

    const mentionLight = createTheme$1({
      name: "Mention",
      common: commonLight,
      peers: {
        InternalSelectMenu: internalSelectMenuLight$1,
        Input: inputLight$1
      },
      self: self$n
    });
    var mentionLight$1 = mentionLight;

    function createPartialInvertedVars(color, activeItemColor, activeTextColor, groupTextColor) {
      return {
        itemColorHoverInverted: "#0000",
        itemColorActiveInverted: activeItemColor,
        itemColorActiveHoverInverted: activeItemColor,
        itemColorActiveCollapsedInverted: activeItemColor,
        itemTextColorInverted: color,
        itemTextColorHoverInverted: activeTextColor,
        itemTextColorChildActiveInverted: activeTextColor,
        itemTextColorChildActiveHoverInverted: activeTextColor,
        itemTextColorActiveInverted: activeTextColor,
        itemTextColorActiveHoverInverted: activeTextColor,
        itemTextColorHorizontalInverted: color,
        itemTextColorHoverHorizontalInverted: activeTextColor,
        itemTextColorChildActiveHorizontalInverted: activeTextColor,
        itemTextColorChildActiveHoverHorizontalInverted: activeTextColor,
        itemTextColorActiveHorizontalInverted: activeTextColor,
        itemTextColorActiveHoverHorizontalInverted: activeTextColor,
        itemIconColorInverted: color,
        itemIconColorHoverInverted: activeTextColor,
        itemIconColorActiveInverted: activeTextColor,
        itemIconColorActiveHoverInverted: activeTextColor,
        itemIconColorChildActiveInverted: activeTextColor,
        itemIconColorChildActiveHoverInverted: activeTextColor,
        itemIconColorCollapsedInverted: color,
        itemIconColorHorizontalInverted: color,
        itemIconColorHoverHorizontalInverted: activeTextColor,
        itemIconColorActiveHorizontalInverted: activeTextColor,
        itemIconColorActiveHoverHorizontalInverted: activeTextColor,
        itemIconColorChildActiveHorizontalInverted: activeTextColor,
        itemIconColorChildActiveHoverHorizontalInverted: activeTextColor,
        arrowColorInverted: color,
        arrowColorHoverInverted: activeTextColor,
        arrowColorActiveInverted: activeTextColor,
        arrowColorActiveHoverInverted: activeTextColor,
        arrowColorChildActiveInverted: activeTextColor,
        arrowColorChildActiveHoverInverted: activeTextColor,
        groupTextColorInverted: groupTextColor
      };
    }
    const self$m = vars => {
      const {
        borderRadius,
        textColor3,
        primaryColor,
        textColor2,
        textColor1,
        fontSize,
        dividerColor,
        hoverColor,
        primaryColorHover
      } = vars;
      return {
        borderRadius,
        color: "#0000",
        groupTextColor: textColor3,
        itemColorHover: hoverColor,
        itemColorActive: changeColor(primaryColor, {
          alpha: 0.1
        }),
        itemColorActiveHover: changeColor(primaryColor, {
          alpha: 0.1
        }),
        itemColorActiveCollapsed: changeColor(primaryColor, {
          alpha: 0.1
        }),
        itemTextColor: textColor2,
        itemTextColorHover: textColor2,
        itemTextColorActive: primaryColor,
        itemTextColorActiveHover: primaryColor,
        itemTextColorChildActive: primaryColor,
        itemTextColorChildActiveHover: primaryColor,
        itemTextColorHorizontal: textColor2,
        itemTextColorHoverHorizontal: primaryColorHover,
        itemTextColorActiveHorizontal: primaryColor,
        itemTextColorActiveHoverHorizontal: primaryColor,
        itemTextColorChildActiveHorizontal: primaryColor,
        itemTextColorChildActiveHoverHorizontal: primaryColor,
        itemIconColor: textColor1,
        itemIconColorHover: textColor1,
        itemIconColorActive: primaryColor,
        itemIconColorActiveHover: primaryColor,
        itemIconColorChildActive: primaryColor,
        itemIconColorChildActiveHover: primaryColor,
        itemIconColorCollapsed: textColor1,
        itemIconColorHorizontal: textColor1,
        itemIconColorHoverHorizontal: primaryColorHover,
        itemIconColorActiveHorizontal: primaryColor,
        itemIconColorActiveHoverHorizontal: primaryColor,
        itemIconColorChildActiveHorizontal: primaryColor,
        itemIconColorChildActiveHoverHorizontal: primaryColor,
        itemHeight: "42px",
        arrowColor: textColor2,
        arrowColorHover: textColor2,
        arrowColorActive: primaryColor,
        arrowColorActiveHover: primaryColor,
        arrowColorChildActive: primaryColor,
        arrowColorChildActiveHover: primaryColor,
        colorInverted: "#0000",
        borderColorHorizontal: "#0000",
        fontSize,
        dividerColor,
        ...createPartialInvertedVars("#BBB", primaryColor, "#FFF", "#AAA")
      };
    };
    const menuLight = createTheme$1({
      name: "Menu",
      common: commonLight,
      peers: {
        Tooltip: tooltipLight$1,
        Dropdown: dropdownLight$1
      },
      self: self$m
    });
    var menuLight$1 = menuLight;

    const menuDark = {
      name: "Menu",
      common: commonDark,
      peers: {
        Tooltip: tooltipDark$1,
        Dropdown: dropdownDark$1
      },

      self(vars) {
        const {
          primaryColor,
          primaryColorSuppl
        } = vars;
        const commonSelf = self$m(vars);
        commonSelf.itemColorActive = changeColor(primaryColor, {
          alpha: 0.15
        });
        commonSelf.itemColorActiveHover = changeColor(primaryColor, {
          alpha: 0.15
        });
        commonSelf.itemColorActiveCollapsed = changeColor(primaryColor, {
          alpha: 0.15
        });
        commonSelf.itemColorActiveInverted = primaryColorSuppl;
        commonSelf.itemColorActiveHoverInverted = primaryColorSuppl;
        commonSelf.itemColorActiveCollapsedInverted = primaryColorSuppl;
        return commonSelf;
      }

    };
    var menuDark$1 = menuDark;

    var common = {
      titleFontSize: "18px",
      backSize: "22px"
    };

    function self$l(vars) {
      const {
        textColor1,
        textColor2,
        textColor3,
        fontSize,
        fontWeightStrong,
        primaryColorHover,
        primaryColorPressed
      } = vars;
      return { ...common,
        titleFontWeight: fontWeightStrong,
        fontSize,
        titleTextColor: textColor1,
        backColor: textColor2,
        backColorHover: primaryColorHover,
        backColorPressed: primaryColorPressed,
        subtitleTextColor: textColor3
      };
    }
    const pageHeaderLight = createTheme$1({
      name: "PageHeader",
      common: commonLight,
      self: self$l
    });

    const pageHeaderDark = {
      name: "PageHeader",
      common: commonDark,
      self: self$l
    };

    var rtlStyle$6 = cB("page-header-wrapper", [cM("rtl", [cB("page-header-header", `
      direction: rtl;
    `), cB("page-header", `
      direction: rtl;
    `, [cE("back", `
        margin-right: 0;
        margin-left: 16px;
      `), cE("avatar", `
        margin-right: 0;
        margin-left: 12px;
      `), cE("title", `
        margin-right: 0;
        margin-left: 16px;
      `)]), cB("page-header-content", `
      direction: rtl;
    `), cB("page-header-footer", `
      direction: rtl;
    `)])]);

    var rtl = {
      name: "PageHeader",
      style: rtlStyle$6
    };

    var commonVars$2 = {
      iconSize: "22px"
    };

    const self$k = vars => {
      const {
        fontSize,
        warningColor
      } = vars;
      return { ...commonVars$2,
        fontSize,
        iconColor: warningColor
      };
    };
    const popconfirmLight = createTheme$1({
      name: "Popconfirm",
      common: commonLight,
      peers: {
        Button: buttonLight$1,
        Popover: popoverLight$1
      },
      self: self$k
    });
    var popconfirmLight$1 = popconfirmLight;

    const popconfirmDark = {
      name: "Popconfirm",
      common: commonDark,
      peers: {
        Button: buttonDark$1,
        Popover: popoverDark$1
      },
      self: self$k
    };
    var popconfirmDark$1 = popconfirmDark;

    const self$j = vars => {
      const {
        infoColor,
        successColor,
        warningColor,
        errorColor,
        textColor2,
        progressRailColor,
        fontSize,
        fontWeight
      } = vars;
      return {
        fontSize,
        fontSizeCircle: "28px",
        fontWeightCircle: fontWeight,
        railColor: progressRailColor,
        railHeight: "8px",
        iconSizeCircle: "36px",
        iconSizeLine: "18px",
        iconColor: infoColor,
        iconColorInfo: infoColor,
        iconColorSuccess: successColor,
        iconColorWarning: warningColor,
        iconColorError: errorColor,
        textColorCircle: textColor2,
        textColorLineInner: "rgb(255, 255, 255)",
        textColorLineOuter: textColor2,
        fillColor: infoColor,
        fillColorInfo: infoColor,
        fillColorSuccess: successColor,
        fillColorWarning: warningColor,
        fillColorError: errorColor,
        lineBgProcessing: "linear-gradient(90deg, rgba(255, 255, 255, .3) 0%, rgba(255, 255, 255, .5) 100%)"
      };
    };
    const progressLight = {
      name: "Progress",
      common: commonLight,
      self: self$j
    };
    var progressLight$1 = progressLight;

    const progressDark = {
      name: "Progress",
      common: commonDark,

      self(vars) {
        const commonSelf = self$j(vars);
        commonSelf.textColorLineInner = "rgb(0, 0, 0)";
        commonSelf.lineBgProcessing = "linear-gradient(90deg, rgba(255, 255, 255, .3) 0%, rgba(255, 255, 255, .5) 100%)";
        return commonSelf;
      }

    };
    var progressDark$1 = progressDark;

    const rateDark = {
      name: "Rate",
      common: commonDark,

      self(vars) {
        const {
          railColor
        } = vars;
        return {
          itemColor: railColor,
          itemColorActive: "#CCAA33",
          itemSize: "20px",
          sizeSmall: "16px",
          sizeMedium: "20px",
          sizeLarge: "24px"
        };
      }

    };
    var rateDark$1 = rateDark;

    const self$i = vars => {
      const {
        railColor
      } = vars;
      return {
        itemColor: railColor,
        itemColorActive: "#FFCC33",
        sizeSmall: "16px",
        sizeMedium: "20px",
        sizeLarge: "24px"
      };
    };

    const themeLight = {
      name: "Rate",
      common: commonLight,
      self: self$i
    };
    var rateLight = themeLight;

    var commonVariables$3 = {
      titleFontSizeSmall: "26px",
      titleFontSizeMedium: "32px",
      titleFontSizeLarge: "40px",
      titleFontSizeHuge: "48px",
      fontSizeSmall: "14px",
      fontSizeMedium: "14px",
      fontSizeLarge: "15px",
      fontSizeHuge: "16px",
      iconSizeSmall: "64px",
      iconSizeMedium: "80px",
      iconSizeLarge: "100px",
      iconSizeHuge: "125px",
      iconColor418: void 0,
      iconColor404: void 0,
      iconColor403: void 0,
      iconColor500: void 0
    };

    const self$h = vars => {
      const {
        textColor2,
        textColor1,
        errorColor,
        successColor,
        infoColor,
        warningColor,
        lineHeight,
        fontWeightStrong
      } = vars;
      return { ...commonVariables$3,
        lineHeight,
        titleFontWeight: fontWeightStrong,
        titleTextColor: textColor1,
        textColor: textColor2,
        iconColorError: errorColor,
        iconColorSuccess: successColor,
        iconColorInfo: infoColor,
        iconColorWarning: warningColor
      };
    };
    const resultLight = {
      name: "Result",
      common: commonLight,
      self: self$h
    };
    var resultLight$1 = resultLight;

    const resultDark = {
      name: "Result",
      common: commonDark,
      self: self$h
    };
    var resultDark$1 = resultDark;

    var sizeVariables$3 = {
      railHeight: "4px",
      railWidthVertical: "4px",
      handleSize: "18px",
      dotHeight: "8px",
      dotWidth: "8px",
      dotBorderRadius: "4px"
    };

    const sliderDark = {
      name: "Slider",
      common: commonDark,

      self(vars) {
        const boxShadow = "0 2px 8px 0 rgba(0, 0, 0, 0.12)";
        const {
          railColor,
          modalColor,
          primaryColorSuppl,
          popoverColor,
          textColor2,
          cardColor,
          borderRadius,
          fontSize,
          opacityDisabled
        } = vars;
        return { ...sizeVariables$3,
          fontSize,
          railColor,
          railColorHover: railColor,
          fillColor: primaryColorSuppl,
          fillColorHover: primaryColorSuppl,
          opacityDisabled,
          handleColor: "#FFF",
          dotColor: cardColor,
          dotColorModal: modalColor,
          dotColorPopover: popoverColor,
          handleBoxShadow: "0px 2px 4px 0 rgba(0, 0, 0, 0.4)",
          handleBoxShadowHover: "0px 2px 4px 0 rgba(0, 0, 0, 0.4)",
          handleBoxShadowActive: "0px 2px 4px 0 rgba(0, 0, 0, 0.4)",
          handleBoxShadowFocus: "0px 2px 4px 0 rgba(0, 0, 0, 0.4)",
          indicatorColor: popoverColor,
          indicatorBoxShadow: boxShadow,
          indicatorTextColor: textColor2,
          indicatorBorderRadius: borderRadius,
          dotBorder: `2px solid ${railColor}`,
          dotBorderActive: `2px solid ${primaryColorSuppl}`,
          dotBoxShadow: ""
        };
      }

    };
    var sliderDark$1 = sliderDark;

    const self$g = vars => {
      const indicatorColor = "rgba(0, 0, 0, .85)";
      const boxShadow = "0 2px 8px 0 rgba(0, 0, 0, 0.12)";
      const {
        railColor,
        primaryColor,
        baseColor,
        cardColor,
        modalColor,
        popoverColor,
        borderRadius,
        fontSize,
        opacityDisabled
      } = vars;
      return { ...sizeVariables$3,
        fontSize,
        railColor,
        railColorHover: railColor,
        fillColor: primaryColor,
        fillColorHover: primaryColor,
        opacityDisabled,
        handleColor: "#FFF",
        dotColor: cardColor,
        dotColorModal: modalColor,
        dotColorPopover: popoverColor,
        handleBoxShadow: "0 1px 4px 0 rgba(0, 0, 0, 0.3), inset 0 0 1px 0 rgba(0, 0, 0, 0.05)",
        handleBoxShadowHover: "0 1px 4px 0 rgba(0, 0, 0, 0.3), inset 0 0 1px 0 rgba(0, 0, 0, 0.05)",
        handleBoxShadowActive: "0 1px 4px 0 rgba(0, 0, 0, 0.3), inset 0 0 1px 0 rgba(0, 0, 0, 0.05)",
        handleBoxShadowFocus: "0 1px 4px 0 rgba(0, 0, 0, 0.3), inset 0 0 1px 0 rgba(0, 0, 0, 0.05)",
        indicatorColor,
        indicatorBoxShadow: boxShadow,
        indicatorTextColor: baseColor,
        indicatorBorderRadius: borderRadius,
        dotBorder: `2px solid ${railColor}`,
        dotBorderActive: `2px solid ${primaryColor}`,
        dotBoxShadow: ""
      };
    };

    const sliderLight = {
      name: "Slider",
      common: commonLight,
      self: self$g
    };
    var sliderLight$1 = sliderLight;

    const self$f = vars => {
      const {
        opacityDisabled,
        heightTiny,
        heightSmall,
        heightMedium,
        heightLarge,
        heightHuge,
        primaryColor,
        fontSize
      } = vars;
      return {
        fontSize,
        textColor: primaryColor,
        sizeTiny: heightTiny,
        sizeSmall: heightSmall,
        sizeMedium: heightMedium,
        sizeLarge: heightLarge,
        sizeHuge: heightHuge,
        color: primaryColor,
        opacitySpinning: opacityDisabled
      };
    };
    const spinLight = {
      name: "Spin",
      common: commonLight,
      self: self$f
    };
    var spinLight$1 = spinLight;

    const spinDark = {
      name: "Spin",
      common: commonDark,
      self: self$f
    };
    var spinDark$1 = spinDark;

    const self$e = vars => {
      const {
        textColor2,
        textColor3,
        fontSize,
        fontWeight
      } = vars;
      return {
        labelFontSize: fontSize,
        labelFontWeight: fontWeight,
        valueFontWeight: fontWeight,
        valueFontSize: "24px",
        labelTextColor: textColor3,
        valuePrefixTextColor: textColor2,
        valueSuffixTextColor: textColor2,
        valueTextColor: textColor2
      };
    };
    const statisticLight = {
      name: "Statistic",
      common: commonLight,
      self: self$e
    };
    var statisticLight$1 = statisticLight;

    const statisticDark = {
      name: "Statistic",
      common: commonDark,
      self: self$e
    };
    var statisticDark$1 = statisticDark;

    var rtlStyle$5 = cB("statistic", [cM("rtl", `
    direction: rtl;
    text-align: right;
  `, [cB("statistic-value", [cE("prefix", `
        margin: 0 0 0 4px;
      `), cE("suffix", `
        margin: 0 4px 0 0;
      `)])])]);

    const statisticRtl = {
      name: "Statistic",
      style: rtlStyle$5
    };

    var commonVariables$2 = {
      stepHeaderFontSizeSmall: "14px",
      stepHeaderFontSizeMedium: "16px",
      indicatorIndexFontSizeSmall: "14px",
      indicatorIndexFontSizeMedium: "16px",
      indicatorSizeSmall: "22px",
      indicatorSizeMedium: "28px",
      indicatorIconSizeSmall: "14px",
      indicatorIconSizeMedium: "18px"
    };

    const self$d = vars => {
      const {
        fontWeightStrong,
        baseColor,
        textColorDisabled,
        primaryColor,
        errorColor,
        textColor1,
        textColor2
      } = vars;
      return { ...commonVariables$2,
        stepHeaderFontWeight: fontWeightStrong,
        indicatorTextColorProcess: baseColor,
        indicatorTextColorWait: textColorDisabled,
        indicatorTextColorFinish: primaryColor,
        indicatorTextColorError: errorColor,
        indicatorBorderColorProcess: primaryColor,
        indicatorBorderColorWait: textColorDisabled,
        indicatorBorderColorFinish: primaryColor,
        indicatorBorderColorError: errorColor,
        indicatorColorProcess: primaryColor,
        indicatorColorWait: "#0000",
        indicatorColorFinish: "#0000",
        indicatorColorError: "#0000",
        splitorColorProcess: textColorDisabled,
        splitorColorWait: textColorDisabled,
        splitorColorFinish: primaryColor,
        splitorColorError: textColorDisabled,
        headerTextColorProcess: textColor1,
        headerTextColorWait: textColorDisabled,
        headerTextColorFinish: textColorDisabled,
        headerTextColorError: errorColor,
        descriptionTextColorProcess: textColor2,
        descriptionTextColorWait: textColorDisabled,
        descriptionTextColorFinish: textColorDisabled,
        descriptionTextColorError: errorColor
      };
    };
    const stepsLight = {
      name: "Steps",
      common: commonLight,
      self: self$d
    };
    var stepsLight$1 = stepsLight;

    const stepsDark = {
      name: "Steps",
      common: commonDark,
      self: self$d
    };
    var stepsDark$1 = stepsDark;

    var rtlStyle$4 = c$1([cB("steps", [cM("rtl", `
      direction: rtl;
      text-align: right;
    `, [cB("step-content", [cB("step-content-header", `
          margin-left: 0;
          margin-right: 9px;
        `), cE("description", `
          margin-left: 0;
          margin-right: 9px;
        `)]), cM("vertical", [c$1(">", [cB("step", [c$1(">", [cB("step-indicator", [c$1(">", [cB("step-splitor", `
                    left: unset;
                    right: calc(var(--n-indicator-size) / 2);
                  `)])])])])])])])])]);

    const stepsRtl = {
      name: "Steps",
      style: rtlStyle$4
    };

    var commonVars$1 = {
      buttonHeightSmall: "14px",
      buttonHeightMedium: "18px",
      buttonHeightLarge: "22px",
      buttonWidthSmall: "14px",
      buttonWidthMedium: "18px",
      buttonWidthLarge: "22px",
      buttonWidthPressedSmall: "20px",
      buttonWidthPressedMedium: "24px",
      buttonWidthPressedLarge: "28px",
      railHeightSmall: "18px",
      railHeightMedium: "22px",
      railHeightLarge: "26px",
      railWidthSmall: "32px",
      railWidthMedium: "40px",
      railWidthLarge: "48px"
    };

    const switchDark = {
      name: "Switch",
      common: commonDark,

      self(vars) {
        const {
          primaryColorSuppl,
          opacityDisabled,
          borderRadius,
          primaryColor,
          textColor2,
          baseColor
        } = vars;
        const railOverlayColor = "rgba(255, 255, 255, .20)";
        return { ...commonVars$1,
          iconColor: baseColor,
          textColor: textColor2,
          loadingColor: primaryColorSuppl,
          opacityDisabled,
          railColor: railOverlayColor,
          railColorActive: primaryColorSuppl,
          buttonBoxShadow: "0px 2px 4px 0 rgba(0, 0, 0, 0.4)",
          buttonColor: "#FFF",
          railBorderRadiusSmall: borderRadius,
          railBorderRadiusMedium: borderRadius,
          railBorderRadiusLarge: borderRadius,
          buttonBorderRadiusSmall: borderRadius,
          buttonBorderRadiusMedium: borderRadius,
          buttonBorderRadiusLarge: borderRadius,
          boxShadowFocus: `0 0 8px 0 ${changeColor(primaryColor, {
        alpha: 0.3
      })}`
        };
      }

    };
    var switchDark$1 = switchDark;

    const self$c = vars => {
      const {
        primaryColor,
        opacityDisabled,
        borderRadius,
        textColor3
      } = vars;
      const railOverlayColor = "rgba(0, 0, 0, .14)";
      return { ...commonVars$1,
        iconColor: textColor3,
        textColor: "white",
        loadingColor: primaryColor,
        opacityDisabled,
        railColor: railOverlayColor,
        railColorActive: primaryColor,
        buttonBoxShadow: "0 1px 4px 0 rgba(0, 0, 0, 0.3), inset 0 0 1px 0 rgba(0, 0, 0, 0.05)",
        buttonColor: "#FFF",
        railBorderRadiusSmall: borderRadius,
        railBorderRadiusMedium: borderRadius,
        railBorderRadiusLarge: borderRadius,
        buttonBorderRadiusSmall: borderRadius,
        buttonBorderRadiusMedium: borderRadius,
        buttonBorderRadiusLarge: borderRadius,
        boxShadowFocus: `0 0 0 2px ${changeColor(primaryColor, {
      alpha: 0.2
    })}`
      };
    };

    const switchLight = {
      name: "Switch",
      common: commonLight,
      self: self$c
    };
    var switchLight$1 = switchLight;

    var sizeVariables$2 = {
      thPaddingSmall: "6px",
      thPaddingMedium: "12px",
      thPaddingLarge: "12px",
      tdPaddingSmall: "6px",
      tdPaddingMedium: "12px",
      tdPaddingLarge: "12px"
    };

    const self$b = vars => {
      const {
        dividerColor,
        cardColor,
        modalColor,
        popoverColor,
        tableHeaderColor,
        tableColorStriped,
        textColor1,
        textColor2,
        borderRadius,
        fontWeightStrong,
        lineHeight,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge
      } = vars;
      return { ...sizeVariables$2,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge,
        lineHeight,
        borderRadius,
        borderColor: composite(cardColor, dividerColor),
        borderColorModal: composite(modalColor, dividerColor),
        borderColorPopover: composite(popoverColor, dividerColor),
        tdColor: cardColor,
        tdColorModal: modalColor,
        tdColorPopover: popoverColor,
        tdColorStriped: composite(cardColor, tableColorStriped),
        tdColorStripedModal: composite(modalColor, tableColorStriped),
        tdColorStripedPopover: composite(popoverColor, tableColorStriped),
        thColor: composite(cardColor, tableHeaderColor),
        thColorModal: composite(modalColor, tableHeaderColor),
        thColorPopover: composite(popoverColor, tableHeaderColor),
        thTextColor: textColor1,
        tdTextColor: textColor2,
        thFontWeight: fontWeightStrong
      };
    };
    const tableLight = {
      name: "Table",
      common: commonLight,
      self: self$b
    };
    var tableLight$1 = tableLight;

    const tableDark = {
      name: "Table",
      common: commonDark,
      self: self$b
    };
    var tableDark$1 = tableDark;

    var rtlStyle$3 = c$1([cB("table", [cM("rtl", `
      direction: rtl;
      text-align: right;
    `, [c$1("th, td", `
        border-right: 0px solid var(--n-merged-border-color);
        border-left: 1px solid var(--n-merged-border-color);
      `, [c$1("&:last-child", `
          border-left: none;
          border-right: inherit;
        `)]), cM("single-line", [c$1("th, td", `
          border-left: 0px solid var(--n-merged-border-color);
        `)])])])]);

    const tableRtl = {
      name: "Table",
      style: rtlStyle$3
    };

    var sizeVariables$1 = {
      tabFontSizeSmall: "14px",
      tabFontSizeMedium: "14px",
      tabFontSizeLarge: "16px",
      tabGapSmallLine: "36px",
      tabGapMediumLine: "36px",
      tabGapLargeLine: "36px",
      tabPaddingSmallLine: "6px 0",
      tabPaddingMediumLine: "10px 0",
      tabPaddingLargeLine: "14px 0",
      tabGapSmallBar: "36px",
      tabGapMediumBar: "36px",
      tabGapLargeBar: "36px",
      tabPaddingSmallBar: "4px 0",
      tabPaddingMediumBar: "6px 0",
      tabPaddingLargeBar: "10px 0",
      tabGapSmallCard: "4px",
      tabGapMediumCard: "4px",
      tabGapLargeCard: "4px",
      tabPaddingSmallCard: "6px 10px",
      tabPaddingMediumCard: "8px 12px",
      tabPaddingLargeCard: "8px 16px",
      tabPaddingSmallSegment: "4px 0",
      tabPaddingMediumSegment: "6px 0",
      tabPaddingLargeSegment: "8px 0",
      tabGapSmallSegment: "0",
      tabGapMediumSegment: "0",
      tabGapLargeSegment: "0",
      panePaddingSmall: "8px 0 0 0",
      panePaddingMedium: "12px 0 0 0",
      panePaddingLarge: "16px 0 0 0",
      closeSize: "18px",
      closeIconSize: "14px"
    };

    const self$a = vars => {
      const {
        textColor2,
        primaryColor,
        textColorDisabled,
        closeIconColor,
        closeIconColorHover,
        closeIconColorPressed,
        closeColorHover,
        closeColorPressed,
        tabColor,
        baseColor,
        dividerColor,
        fontWeight,
        textColor1,
        borderRadius,
        fontSize,
        fontWeightStrong
      } = vars;
      return { ...sizeVariables$1,
        colorSegment: tabColor,
        tabFontSizeCard: fontSize,
        tabTextColorLine: textColor1,
        tabTextColorActiveLine: primaryColor,
        tabTextColorHoverLine: primaryColor,
        tabTextColorDisabledLine: textColorDisabled,
        tabTextColorSegment: textColor1,
        tabTextColorActiveSegment: textColor2,
        tabTextColorHoverSegment: textColor2,
        tabTextColorDisabledSegment: textColorDisabled,
        tabTextColorBar: textColor1,
        tabTextColorActiveBar: primaryColor,
        tabTextColorHoverBar: primaryColor,
        tabTextColorDisabledBar: textColorDisabled,
        tabTextColorCard: textColor1,
        tabTextColorHoverCard: textColor1,
        tabTextColorActiveCard: primaryColor,
        tabTextColorDisabledCard: textColorDisabled,
        barColor: primaryColor,
        closeIconColor,
        closeIconColorHover,
        closeIconColorPressed,
        closeColorHover,
        closeColorPressed,
        closeBorderRadius: borderRadius,
        tabColor,
        tabColorSegment: baseColor,
        tabBorderColor: dividerColor,
        tabFontWeightActive: fontWeight,
        tabFontWeight: fontWeight,
        tabBorderRadius: borderRadius,
        paneTextColor: textColor2,
        fontWeightStrong
      };
    };
    const tabsLight = {
      name: "Tabs",
      common: commonLight,
      self: self$a
    };
    var tabsLight$1 = tabsLight;

    const tabsDark = {
      name: "Tabs",
      common: commonDark,

      self(vars) {
        const commonSelf = self$a(vars);
        const {
          inputColor
        } = vars;
        commonSelf.colorSegment = inputColor;
        commonSelf.tabColorSegment = inputColor;
        return commonSelf;
      }

    };
    var tabsDark$1 = tabsDark;

    const self$9 = vars => {
      const {
        textColor1,
        textColor2,
        fontWeightStrong,
        fontSize
      } = vars;
      return {
        fontSize,
        titleTextColor: textColor1,
        textColor: textColor2,
        titleFontWeight: fontWeightStrong
      };
    };
    const thingLight = {
      name: "Thing",
      common: commonLight,
      self: self$9
    };
    var thingLight$1 = thingLight;

    const thingDark = {
      name: "Thing",
      common: commonDark,
      self: self$9
    };
    var thingDark$1 = thingDark;

    var rtlStyle$2 = cB("thing", [cM("rtl", `
    direction: rtl;
    text-align: right;
  `, [cB("thing-avatar", `
      margin-left: 12px;
      margin-right: 0;
    `)])]);

    const thingRtl = {
      name: "Thing",
      style: rtlStyle$2,
      peers: [buttonRtl, spaceRtl]
    };

    var sizeVariables = {
      titleMarginMedium: "0",
      titleMarginLarge: "-2px 0 0 0",
      titleFontSizeMedium: "14px",
      titleFontSizeLarge: "16px",
      iconSizeMedium: "14px",
      iconSizeLarge: "14px"
    };

    const timelineDark = {
      name: "Timeline",
      common: commonDark,

      self(vars) {
        const {
          textColor3,
          infoColorSuppl,
          errorColorSuppl,
          successColorSuppl,
          warningColorSuppl,
          textColor1,
          textColor2,
          railColor,
          fontWeightStrong,
          fontSize
        } = vars;
        return { ...sizeVariables,
          contentFontSize: fontSize,
          titleFontWeight: fontWeightStrong,
          circleBorder: `2px solid ${textColor3}`,
          circleBorderInfo: `2px solid ${infoColorSuppl}`,
          circleBorderError: `2px solid ${errorColorSuppl}`,
          circleBorderSuccess: `2px solid ${successColorSuppl}`,
          circleBorderWarning: `2px solid ${warningColorSuppl}`,
          iconColor: textColor3,
          iconColorInfo: infoColorSuppl,
          iconColorError: errorColorSuppl,
          iconColorSuccess: successColorSuppl,
          iconColorWarning: warningColorSuppl,
          titleTextColor: textColor1,
          contentTextColor: textColor2,
          metaTextColor: textColor3,
          lineColor: railColor
        };
      }

    };
    var timelineDark$1 = timelineDark;

    const self$8 = vars => {
      const {
        textColor3,
        infoColor,
        errorColor,
        successColor,
        warningColor,
        textColor1,
        textColor2,
        railColor,
        fontWeightStrong,
        fontSize
      } = vars;
      return { ...sizeVariables,
        contentFontSize: fontSize,
        titleFontWeight: fontWeightStrong,
        circleBorder: `2px solid ${textColor3}`,
        circleBorderInfo: `2px solid ${infoColor}`,
        circleBorderError: `2px solid ${errorColor}`,
        circleBorderSuccess: `2px solid ${successColor}`,
        circleBorderWarning: `2px solid ${warningColor}`,
        iconColor: textColor3,
        iconColorInfo: infoColor,
        iconColorError: errorColor,
        iconColorSuccess: successColor,
        iconColorWarning: warningColor,
        titleTextColor: textColor1,
        contentTextColor: textColor2,
        metaTextColor: textColor3,
        lineColor: railColor
      };
    };

    const timelineLight = {
      name: "Timeline",
      common: commonLight,
      self: self$8
    };
    var timelineLight$1 = timelineLight;

    var commonVariables$1 = {
      extraFontSizeSmall: "12px",
      extraFontSizeMedium: "12px",
      extraFontSizeLarge: "14px",
      titleFontSizeSmall: "14px",
      titleFontSizeMedium: "16px",
      titleFontSizeLarge: "16px",
      closeSize: "20px",
      closeIconSize: "16px",
      headerHeightSmall: "44px",
      headerHeightMedium: "44px",
      headerHeightLarge: "50px"
    };

    const transferDark$1 = {
      name: "Transfer",
      common: commonDark,
      peers: {
        Checkbox: checkboxDark$1,
        Scrollbar: scrollbarDark$1,
        Input: inputDark$1,
        Empty: emptyDark$1,
        Button: buttonDark$1
      },

      self(vars) {
        const {
          fontWeight,
          fontSizeLarge,
          fontSizeMedium,
          fontSizeSmall,
          heightLarge,
          heightMedium,
          borderRadius,
          inputColor,
          tableHeaderColor,
          textColor1,
          textColorDisabled,
          textColor2,
          textColor3,
          hoverColor,
          closeColorHover,
          closeColorPressed,
          closeIconColor,
          closeIconColorHover,
          closeIconColorPressed,
          dividerColor
        } = vars;
        return { ...commonVariables$1,
          itemHeightSmall: heightMedium,
          itemHeightMedium: heightMedium,
          itemHeightLarge: heightLarge,
          fontSizeSmall,
          fontSizeMedium,
          fontSizeLarge,
          borderRadius,
          dividerColor,
          borderColor: "#0000",
          listColor: inputColor,
          headerColor: tableHeaderColor,
          titleTextColor: textColor1,
          titleTextColorDisabled: textColorDisabled,
          extraTextColor: textColor3,
          extraTextColorDisabled: textColorDisabled,
          itemTextColor: textColor2,
          itemTextColorDisabled: textColorDisabled,
          itemColorPending: hoverColor,
          titleFontWeight: fontWeight,
          closeColorHover,
          closeColorPressed,
          closeIconColor,
          closeIconColorHover,
          closeIconColorPressed
        };
      }

    };
    var transferDark$2 = transferDark$1;

    const self$7 = vars => {
      const {
        fontWeight,
        fontSizeLarge,
        fontSizeMedium,
        fontSizeSmall,
        heightLarge,
        heightMedium,
        borderRadius,
        cardColor,
        tableHeaderColor,
        textColor1,
        textColorDisabled,
        textColor2,
        textColor3,
        borderColor,
        hoverColor,
        closeColorHover,
        closeColorPressed,
        closeIconColor,
        closeIconColorHover,
        closeIconColorPressed
      } = vars;
      return { ...commonVariables$1,
        itemHeightSmall: heightMedium,
        itemHeightMedium: heightMedium,
        itemHeightLarge: heightLarge,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge,
        borderRadius,
        dividerColor: borderColor,
        borderColor,
        listColor: cardColor,
        headerColor: composite(cardColor, tableHeaderColor),
        titleTextColor: textColor1,
        titleTextColorDisabled: textColorDisabled,
        extraTextColor: textColor3,
        extraTextColorDisabled: textColorDisabled,
        itemTextColor: textColor2,
        itemTextColorDisabled: textColorDisabled,
        itemColorPending: hoverColor,
        titleFontWeight: fontWeight,
        closeColorHover,
        closeColorPressed,
        closeIconColor,
        closeIconColorHover,
        closeIconColorPressed
      };
    };

    const transferLight$1 = createTheme$1({
      name: "Transfer",
      common: commonLight,
      peers: {
        Checkbox: checkboxLight$1,
        Scrollbar: scrollbarLight$1,
        Input: inputLight$1,
        Empty: emptyLight$1,
        Button: buttonLight$1
      },
      self: self$7
    });
    var transferLight$2 = transferLight$1;

    const self$6 = vars => {
      const {
        borderRadiusSmall,
        hoverColor,
        pressedColor,
        primaryColor,
        textColor3,
        textColor2,
        textColorDisabled,
        fontSize
      } = vars;
      return {
        fontSize,
        nodeBorderRadius: borderRadiusSmall,
        nodeColorHover: hoverColor,
        nodeColorPressed: pressedColor,
        nodeColorActive: changeColor(primaryColor, {
          alpha: 0.1
        }),
        arrowColor: textColor3,
        nodeTextColor: textColor2,
        nodeTextColorDisabled: textColorDisabled,
        loadingColor: primaryColor,
        dropMarkColor: primaryColor
      };
    };
    const treeLight = createTheme$1({
      name: "Tree",
      common: commonLight,
      peers: {
        Checkbox: checkboxLight$1,
        Scrollbar: scrollbarLight$1,
        Empty: emptyLight$1
      },
      self: self$6
    });
    var treeLight$1 = treeLight;

    const treeDark = {
      name: "Tree",
      common: commonDark,
      peers: {
        Checkbox: checkboxDark$1,
        Scrollbar: scrollbarDark$1,
        Empty: emptyDark$1
      },

      self(vars) {
        const {
          primaryColor
        } = vars;
        const commonSelf = self$6(vars);
        commonSelf.nodeColorActive = changeColor(primaryColor, {
          alpha: 0.15
        });
        return commonSelf;
      }

    };
    var treeDark$1 = treeDark;

    var rtlStyle$1 = cB("tree", [cM("rtl", `
    direction: rtl;
    text-align: right;
  `, [cB("tree-node-switcher", `
      transform: rotate(180deg);
    `, [cM("expanded", `
        transform: rotate(90deg);
      `)]), cB("tree-node-checkbox", `
      margin-right: 0;
      margin-left: 4px;
    `), cB("tree-node-content", [cE("prefix", `
        margin-right: 0;
        margin-left: 8px;
      `)]), cB("tree-node-checkbox", [cM("right", `
        margin-right: 4px;
      `)])])]);

    const treeRtl = {
      name: "Tree",
      style: rtlStyle$1
    };

    const treeSelectDark = {
      name: "TreeSelect",
      common: commonDark,
      peers: {
        Tree: treeDark$1,
        Empty: emptyDark$1,
        InternalSelection: internalSelectionDark$1
      }
    };
    var treeSelectDark$1 = treeSelectDark;

    const self$5 = vars => {
      const {
        popoverColor,
        boxShadow2,
        borderRadius,
        heightMedium,
        dividerColor,
        textColor2
      } = vars;
      return {
        menuPadding: "4px",
        menuColor: popoverColor,
        menuBoxShadow: boxShadow2,
        menuBorderRadius: borderRadius,
        menuHeight: `calc(${heightMedium} * 7.6)`,
        actionDividerColor: dividerColor,
        actionTextColor: textColor2,
        actionPadding: "8px 12px"
      };
    };
    const treeSelectLight = createTheme$1({
      name: "TreeSelect",
      common: commonLight,
      peers: {
        Tree: treeLight$1,
        Empty: emptyLight$1,
        InternalSelection: internalSelectionLight$1
      },
      self: self$5
    });
    var treeSelectLight$1 = treeSelectLight;

    var commonVars = {
      headerFontSize1: "30px",
      headerFontSize2: "22px",
      headerFontSize3: "18px",
      headerFontSize4: "16px",
      headerFontSize5: "16px",
      headerFontSize6: "16px",
      headerMargin1: "28px 0 20px 0",
      headerMargin2: "28px 0 20px 0",
      headerMargin3: "28px 0 20px 0",
      headerMargin4: "28px 0 18px 0",
      headerMargin5: "28px 0 18px 0",
      headerMargin6: "28px 0 18px 0",
      headerPrefixWidth1: "16px",
      headerPrefixWidth2: "16px",
      headerPrefixWidth3: "12px",
      headerPrefixWidth4: "12px",
      headerPrefixWidth5: "12px",
      headerPrefixWidth6: "12px",
      headerBarWidth1: "4px",
      headerBarWidth2: "4px",
      headerBarWidth3: "3px",
      headerBarWidth4: "3px",
      headerBarWidth5: "3px",
      headerBarWidth6: "3px",
      pMargin: "16px 0 16px 0",
      liMargin: ".25em 0 0 0",
      olPadding: "0 0 0 2em",
      ulPadding: "0 0 0 2em"
    };

    const self$4 = vars => {
      const {
        primaryColor,
        textColor2,
        borderColor,
        lineHeight,
        fontSize,
        borderRadiusSmall,
        dividerColor,
        fontWeightStrong,
        textColor1,
        textColor3,
        infoColor,
        warningColor,
        errorColor,
        successColor,
        codeColor
      } = vars;
      return { ...commonVars,
        aTextColor: primaryColor,
        blockquoteTextColor: textColor2,
        blockquotePrefixColor: borderColor,
        blockquoteLineHeight: lineHeight,
        blockquoteFontSize: fontSize,
        codeBorderRadius: borderRadiusSmall,
        liTextColor: textColor2,
        liLineHeight: lineHeight,
        liFontSize: fontSize,
        hrColor: dividerColor,
        headerFontWeight: fontWeightStrong,
        headerTextColor: textColor1,
        pTextColor: textColor2,
        pTextColor1Depth: textColor1,
        pTextColor2Depth: textColor2,
        pTextColor3Depth: textColor3,
        pLineHeight: lineHeight,
        pFontSize: fontSize,
        headerBarColor: primaryColor,
        headerBarColorPrimary: primaryColor,
        headerBarColorInfo: infoColor,
        headerBarColorError: errorColor,
        headerBarColorWarning: warningColor,
        headerBarColorSuccess: successColor,
        textColor: textColor2,
        textColor1Depth: textColor1,
        textColor2Depth: textColor2,
        textColor3Depth: textColor3,
        textColorPrimary: primaryColor,
        textColorInfo: infoColor,
        textColorSuccess: successColor,
        textColorWarning: warningColor,
        textColorError: errorColor,
        codeTextColor: textColor2,
        codeColor,
        codeBorder: "1px solid #0000"
      };
    };
    const typographyLight = {
      name: "Typography",
      common: commonLight,
      self: self$4
    };
    var typographyLight$1 = typographyLight;

    const typographyDark = {
      name: "Typography",
      common: commonDark,
      self: self$4
    };
    var typographyDark$1 = typographyDark;

    const self$3 = vars => {
      const {
        iconColor,
        primaryColor,
        errorColor,
        textColor2,
        successColor,
        opacityDisabled,
        actionColor,
        borderColor,
        hoverColor,
        lineHeight,
        borderRadius,
        fontSize
      } = vars;
      return {
        fontSize,
        lineHeight,
        borderRadius,
        draggerColor: actionColor,
        draggerBorder: `1px dashed ${borderColor}`,
        draggerBorderHover: `1px dashed ${primaryColor}`,
        itemColorHover: hoverColor,
        itemColorHoverError: changeColor(errorColor, {
          alpha: 0.06
        }),
        itemTextColor: textColor2,
        itemTextColorError: errorColor,
        itemTextColorSuccess: successColor,
        itemIconColor: iconColor,
        itemDisabledOpacity: opacityDisabled,
        itemBorderImageCardError: `1px solid ${errorColor}`,
        itemBorderImageCard: `1px solid ${borderColor}`
      };
    };
    const uploadLight = createTheme$1({
      name: "Upload",
      common: commonLight,
      peers: {
        Button: buttonLight$1,
        Progress: progressLight$1
      },
      self: self$3
    });
    var uploadLight$1 = uploadLight;

    const uploadDark = {
      name: "Upload",
      common: commonDark,
      peers: {
        Button: buttonDark$1,
        Progress: progressDark$1
      },

      self(vars) {
        const {
          errorColor
        } = vars;
        const commonSelf = self$3(vars);
        commonSelf.itemColorHoverError = changeColor(errorColor, {
          alpha: 0.09
        });
        return commonSelf;
      }

    };
    var uploadDark$1 = uploadDark;

    const watermarkDark = {
      name: "Watermark",
      common: commonDark,

      self(vars) {
        const {
          fontFamily
        } = vars;
        return {
          fontFamily
        };
      }

    };
    var watermarkDark$1 = watermarkDark;

    const watermarkLight = createTheme$1({
      name: "Watermark",
      common: commonLight,

      self(vars) {
        const {
          fontFamily
        } = vars;
        return {
          fontFamily
        };
      }

    });
    var watermarkLight$1 = watermarkLight;

    const rowLight = {
      name: "Row",
      common: commonLight
    };
    var rowLight$1 = rowLight;

    const rowDark = {
      name: "Row",
      common: commonDark
    };
    var rowDark$1 = rowDark;

    const positionStyles = Array.apply(null, {
      length: 24
    }).map((_, index) => {
      const prefixIndex = index + 1;
      const percent = `calc(100% / 24 * ${prefixIndex})`;
      return [cM(`${prefixIndex}-span`, {
        width: percent
      }), cM(`${prefixIndex}-offset`, {
        marginLeft: percent
      }), cM(`${prefixIndex}-push`, {
        right: percent,
        left: "unset"
      }), cM(`${prefixIndex}-pull`, {
        left: percent,
        right: "unset"
      })];
    });
    var rtlStyle = cB("row", [cM("rtl", `
    direction: rtl;
  `, [cB("col", positionStyles)])]);

    const rowRtl = {
      name: "Row",
      style: rtlStyle
    };

    const imageDark = {
      name: "Image",
      common: commonDark,
      peers: {
        Tooltip: tooltipDark$1
      },
      self: vars => {
        const {
          textColor2
        } = vars;
        return {
          toolbarIconColor: textColor2,
          toolbarColor: "rgba(0, 0, 0, .35)",
          toolbarBoxShadow: "none",
          toolbarBorderRadius: "24px"
        };
      }
    };

    const prevIcon = /* @__PURE__ */ React.createElement("svg", {
      viewBox: "0 0 20 20",
      fill: "none",
      xmlns: "http://www.w3.org/2000/svg"
    }, /* @__PURE__ */ React.createElement("path", {
      d: "M6 5C5.75454 5 5.55039 5.17688 5.50806 5.41012L5.5 5.5V14.5C5.5 14.7761 5.72386 15 6 15C6.24546 15 6.44961 14.8231 6.49194 14.5899L6.5 14.5V5.5C6.5 5.22386 6.27614 5 6 5ZM13.8536 5.14645C13.68 4.97288 13.4106 4.9536 13.2157 5.08859L13.1464 5.14645L8.64645 9.64645C8.47288 9.82001 8.4536 10.0894 8.58859 10.2843L8.64645 10.3536L13.1464 14.8536C13.3417 15.0488 13.6583 15.0488 13.8536 14.8536C14.0271 14.68 14.0464 14.4106 13.9114 14.2157L13.8536 14.1464L9.70711 10L13.8536 5.85355C14.0488 5.65829 14.0488 5.34171 13.8536 5.14645Z",
      fill: "currentColor"
    }));
    const nextIcon = /* @__PURE__ */ React.createElement("svg", {
      viewBox: "0 0 20 20",
      fill: "none",
      xmlns: "http://www.w3.org/2000/svg"
    }, /* @__PURE__ */ React.createElement("path", {
      d: "M13.5 5C13.7455 5 13.9496 5.17688 13.9919 5.41012L14 5.5V14.5C14 14.7761 13.7761 15 13.5 15C13.2545 15 13.0504 14.8231 13.0081 14.5899L13 14.5V5.5C13 5.22386 13.2239 5 13.5 5ZM5.64645 5.14645C5.82001 4.97288 6.08944 4.9536 6.28431 5.08859L6.35355 5.14645L10.8536 9.64645C11.0271 9.82001 11.0464 10.0894 10.9114 10.2843L10.8536 10.3536L6.35355 14.8536C6.15829 15.0488 5.84171 15.0488 5.64645 14.8536C5.47288 14.68 5.4536 14.4106 5.58859 14.2157L5.64645 14.1464L9.79289 10L5.64645 5.85355C5.45118 5.65829 5.45118 5.34171 5.64645 5.14645Z",
      fill: "currentColor"
    }));
    const closeIcon = /* @__PURE__ */ React.createElement("svg", {
      viewBox: "0 0 20 20",
      fill: "none",
      xmlns: "http://www.w3.org/2000/svg"
    }, /* @__PURE__ */ React.createElement("path", {
      d: "M4.089 4.216l.057-.07a.5.5 0 0 1 .638-.057l.07.057L10 9.293l5.146-5.147a.5.5 0 0 1 .638-.057l.07.057a.5.5 0 0 1 .057.638l-.057.07L10.707 10l5.147 5.146a.5.5 0 0 1 .057.638l-.057.07a.5.5 0 0 1-.638.057l-.07-.057L10 10.707l-5.146 5.147a.5.5 0 0 1-.638.057l-.07-.057a.5.5 0 0 1-.057-.638l.057-.07L9.293 10L4.146 4.854a.5.5 0 0 1-.057-.638l.057-.07l-.057.07z",
      fill: "currentColor"
    }));

    var style$E = c$1([c$1("body >", [cB("image-container", "position: fixed;")]), cB("image-preview-container", `
    position: fixed;
    left: 0;
    right: 0;
    top: 0;
    bottom: 0;
    display: flex;
  `), cB("image-preview-overlay", `
    z-index: -1;
    position: absolute;
    left: 0;
    right: 0;
    top: 0;
    bottom: 0;
    background: rgba(0, 0, 0, .3);
  `, [fadeInTransition()]), cB("image-preview-toolbar", `
    z-index: 1;
    position: absolute;
    left: 50%;
    transform: translateX(-50%);
    border-radius: var(--n-toolbar-border-radius);
    height: 48px;
    bottom: 40px;
    padding: 0 12px;
    background: var(--n-toolbar-color);
    box-shadow: var(--n-toolbar-box-shadow);
    color: var(--n-toolbar-icon-color);
    transition: color .3s var(--n-bezier);
    display: flex;
    align-items: center;
  `, [cB("base-icon", `
      padding: 0 8px;
      font-size: 28px;
      cursor: pointer;
    `), fadeInTransition()]), cB("image-preview-wrapper", `
    position: absolute;
    left: 0;
    right: 0;
    top: 0;
    bottom: 0;
    display: flex;
    pointer-events: none;
  `, [fadeInScaleUpTransition()]), cB("image-preview", `
    user-select: none;
    -webkit-user-select: none;
    pointer-events: all;
    margin: auto;
    max-height: calc(100vh - 32px);
    max-width: calc(100vw - 32px);
    transition: transform .3s var(--n-bezier);
  `), cB("image", `
    display: inline-flex;
    max-height: 100%;
    max-width: 100%;
  `, [cNotM("preview-disabled", `
      cursor: pointer;
    `), c$1("img", `
      border-radius: inherit;
    `)])]);

    const BLEEDING = 32;
    var NImagePreview = vue.defineComponent({
      name: "ImagePreview",
      props: {
        ...imagePreviewSharedProps,
        onNext: Function,
        onPrev: Function,
        clsPrefix: {
          type: String,
          required: true
        }
      },
      setup(props) {
        const themeRef = useTheme(
          "Image",
          "-image",
          style$E,
          imageLight,
          props,
          vue.toRef(props, "clsPrefix")
        );
        let thumbnailEl = null;
        const previewRef = vue.ref(null);
        const previewWrapperRef = vue.ref(null);
        const previewSrcRef = vue.ref(void 0);
        const showRef = vue.ref(false);
        const displayedRef = vue.ref(false);
        const { localeRef } = useLocale("Image");
        function syncTransformOrigin() {
          const { value: previewWrapper } = previewWrapperRef;
          if (!thumbnailEl || !previewWrapper)
            return;
          const { style: style2 } = previewWrapper;
          const tbox = thumbnailEl.getBoundingClientRect();
          const tx = tbox.left + tbox.width / 2;
          const ty = tbox.top + tbox.height / 2;
          style2.transformOrigin = `${tx}px ${ty}px`;
        }
        function handleKeydown(e) {
          switch (e.key) {
            case "ArrowLeft":
              props.onPrev?.();
              break;
            case "ArrowRight":
              props.onNext?.();
              break;
            case "Escape":
              toggleShow();
              break;
          }
        }
        vue.watch(showRef, (value) => {
          if (value) {
            on("keydown", document, handleKeydown);
          } else
            off("keydown", document, handleKeydown);
        });
        vue.onBeforeUnmount(() => {
          off("keydown", document, handleKeydown);
        });
        let startX = 0;
        let startY = 0;
        let offsetX = 0;
        let offsetY = 0;
        let startOffsetX = 0;
        let startOffsetY = 0;
        let mouseDownClientX = 0;
        let mouseDownClientY = 0;
        let dragging = false;
        function handleMouseMove(e) {
          const { clientX, clientY } = e;
          offsetX = clientX - startX;
          offsetY = clientY - startY;
          beforeNextFrameOnce(derivePreviewStyle);
        }
        function getMoveStrategy(opts) {
          const {
            mouseUpClientX,
            mouseUpClientY,
            mouseDownClientX: mouseDownClientX2,
            mouseDownClientY: mouseDownClientY2
          } = opts;
          const deltaHorizontal = mouseDownClientX2 - mouseUpClientX;
          const deltaVertical = mouseDownClientY2 - mouseUpClientY;
          const moveVerticalDirection = `vertical${deltaVertical > 0 ? "Top" : "Bottom"}`;
          const moveHorizontalDirection = `horizontal${deltaHorizontal > 0 ? "Left" : "Right"}`;
          return {
            moveVerticalDirection,
            moveHorizontalDirection,
            deltaHorizontal,
            deltaVertical
          };
        }
        function getDerivedOffset(moveStrategy) {
          const { value: preview } = previewRef;
          if (!preview)
            return { offsetX: 0, offsetY: 0 };
          const pbox = preview.getBoundingClientRect();
          const {
            moveVerticalDirection,
            moveHorizontalDirection,
            deltaHorizontal,
            deltaVertical
          } = moveStrategy || {};
          let nextOffsetX = 0;
          let nextOffsetY = 0;
          if (pbox.width <= window.innerWidth) {
            nextOffsetX = 0;
          } else if (pbox.left > 0) {
            nextOffsetX = (pbox.width - window.innerWidth) / 2;
          } else if (pbox.right < window.innerWidth) {
            nextOffsetX = -(pbox.width - window.innerWidth) / 2;
          } else if (moveHorizontalDirection === "horizontalRight") {
            nextOffsetX = Math.min(
              (pbox.width - window.innerWidth) / 2,
              startOffsetX - (deltaHorizontal ?? 0)
            );
          } else {
            nextOffsetX = Math.max(
              -((pbox.width - window.innerWidth) / 2),
              startOffsetX - (deltaHorizontal ?? 0)
            );
          }
          if (pbox.height <= window.innerHeight) {
            nextOffsetY = 0;
          } else if (pbox.top > 0) {
            nextOffsetY = (pbox.height - window.innerHeight) / 2;
          } else if (pbox.bottom < window.innerHeight) {
            nextOffsetY = -(pbox.height - window.innerHeight) / 2;
          } else if (moveVerticalDirection === "verticalBottom") {
            nextOffsetY = Math.min(
              (pbox.height - window.innerHeight) / 2,
              startOffsetY - (deltaVertical ?? 0)
            );
          } else {
            nextOffsetY = Math.max(
              -((pbox.height - window.innerHeight) / 2),
              startOffsetY - (deltaVertical ?? 0)
            );
          }
          return {
            offsetX: nextOffsetX,
            offsetY: nextOffsetY
          };
        }
        function handleMouseUp(e) {
          off("mousemove", document, handleMouseMove);
          off("mouseup", document, handleMouseUp);
          const { clientX: mouseUpClientX, clientY: mouseUpClientY } = e;
          dragging = false;
          const moveStrategy = getMoveStrategy({
            mouseUpClientX,
            mouseUpClientY,
            mouseDownClientX,
            mouseDownClientY
          });
          const offset = getDerivedOffset(moveStrategy);
          offsetX = offset.offsetX;
          offsetY = offset.offsetY;
          derivePreviewStyle();
        }
        function handlePreviewMousedown(e) {
          const { clientX, clientY } = e;
          dragging = true;
          startX = clientX - offsetX;
          startY = clientY - offsetY;
          startOffsetX = offsetX;
          startOffsetY = offsetY;
          mouseDownClientX = clientX;
          mouseDownClientY = clientY;
          derivePreviewStyle();
          on("mousemove", document, handleMouseMove);
          on("mouseup", document, handleMouseUp);
        }
        function handlePreviewDblclick() {
          const originalImageSizeScale = getOrignalImageSizeScale();
          scale = scale === originalImageSizeScale ? 1 : originalImageSizeScale;
          derivePreviewStyle();
        }
        const scaleRadix = 1.5;
        let scaleExp = 0;
        let scale = 1;
        let rotate = 0;
        function resetScale() {
          scale = 1;
          scaleExp = 0;
        }
        function handleSwitchPrev() {
          resetScale();
          rotate = 0;
          props.onPrev?.();
        }
        function handleSwitchNext() {
          resetScale();
          rotate = 0;
          props.onNext?.();
        }
        function rotateCounterclockwise() {
          rotate -= 90;
          derivePreviewStyle();
        }
        function rotateClockwise() {
          rotate += 90;
          derivePreviewStyle();
        }
        function getMaxScale() {
          const { value: preview } = previewRef;
          if (!preview)
            return 1;
          const { innerWidth, innerHeight } = window;
          const heightMaxScale = Math.max(
            1,
            preview.naturalHeight / (innerHeight - BLEEDING)
          );
          const widthMaxScale = Math.max(
            1,
            preview.naturalWidth / (innerWidth - BLEEDING)
          );
          return Math.max(3, heightMaxScale * 2, widthMaxScale * 2);
        }
        function getOrignalImageSizeScale() {
          const { value: preview } = previewRef;
          if (!preview)
            return 1;
          const { innerWidth, innerHeight } = window;
          const heightScale = preview.naturalHeight / (innerHeight - BLEEDING);
          const widthScale = preview.naturalWidth / (innerWidth - BLEEDING);
          if (heightScale < 1 && widthScale < 1) {
            return 1;
          }
          return Math.max(heightScale, widthScale);
        }
        function zoomIn() {
          const maxScale = getMaxScale();
          if (scale < maxScale) {
            scaleExp += 1;
            scale = Math.min(maxScale, Math.pow(scaleRadix, scaleExp));
            derivePreviewStyle();
          }
        }
        function zoomOut() {
          if (scale > 0.5) {
            const originalScale = scale;
            scaleExp -= 1;
            scale = Math.max(0.5, Math.pow(scaleRadix, scaleExp));
            const diff = originalScale - scale;
            derivePreviewStyle(false);
            const offset = getDerivedOffset();
            scale += diff;
            derivePreviewStyle(false);
            scale -= diff;
            offsetX = offset.offsetX;
            offsetY = offset.offsetY;
            derivePreviewStyle();
          }
        }
        function derivePreviewStyle(transition = true) {
          const { value: preview } = previewRef;
          if (!preview)
            return;
          const { style: style2 } = preview;
          const transformStyle = `transform-origin: center; transform: translateX(${offsetX}px) translateY(${offsetY}px) rotate(${rotate}deg) scale(${scale});`;
          if (dragging) {
            style2.cssText = "cursor: grabbing; transition: none;" + transformStyle;
          } else {
            style2.cssText = "cursor: grab;" + transformStyle + (transition ? "" : "transition: none;");
          }
          if (!transition) {
            void preview.offsetHeight;
          }
        }
        function toggleShow() {
          showRef.value = !showRef.value;
          displayedRef.value = true;
        }
        function resizeToOrignalImageSize() {
          scale = getOrignalImageSizeScale();
          scaleExp = Math.ceil(Math.log(scale) / Math.log(scaleRadix));
          offsetX = 0;
          offsetY = 0;
          derivePreviewStyle();
        }
        const exposedMethods = {
          setPreviewSrc: (src) => {
            previewSrcRef.value = src;
          },
          setThumbnailEl: (el) => {
            thumbnailEl = el;
          },
          toggleShow
        };
        function withTooltip(node, tooltipKey) {
          if (props.showToolbarTooltip) {
            const { value: theme } = themeRef;
            return /* @__PURE__ */ React.createElement(NTooltip, {
              to: false,
              theme: theme.peers.Tooltip,
              themeOverrides: theme.peerOverrides.Tooltip,
              keepAliveOnHover: false
            }, {
              default: () => {
                return localeRef.value[tooltipKey];
              },
              trigger: () => node
            });
          } else {
            return node;
          }
        }
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self: {
              toolbarIconColor,
              toolbarBorderRadius,
              toolbarBoxShadow,
              toolbarColor
            }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-toolbar-icon-color": toolbarIconColor,
            "--n-toolbar-color": toolbarColor,
            "--n-toolbar-border-radius": toolbarBorderRadius,
            "--n-toolbar-box-shadow": toolbarBoxShadow
          };
        });
        const { inlineThemeDisabled } = useConfig();
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("image-preview", void 0, cssVarsRef, props) : void 0;
        return {
          previewRef,
          previewWrapperRef,
          previewSrc: previewSrcRef,
          show: showRef,
          appear: isMounted(),
          displayed: displayedRef,
          handleWheel(e) {
            e.preventDefault();
          },
          handlePreviewMousedown,
          handlePreviewDblclick,
          syncTransformOrigin,
          handleAfterLeave: () => {
            resetScale();
            rotate = 0;
            displayedRef.value = false;
          },
          handleDragStart: (e) => {
            e.preventDefault();
          },
          zoomIn,
          zoomOut,
          rotateCounterclockwise,
          rotateClockwise,
          handleSwitchPrev,
          handleSwitchNext,
          withTooltip,
          resizeToOrignalImageSize,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender,
          ...exposedMethods
        };
      },
      render() {
        const { clsPrefix } = this;
        return /* @__PURE__ */ React.createElement(React.Fragment, null, this.$slots.default?.(), /* @__PURE__ */ React.createElement(LazyTeleport, {
          show: this.show
        }, {
          default: () => {
            if (!(this.show || this.displayed)) {
              return null;
            }
            this.onRender?.();
            return vue.withDirectives(
              /* @__PURE__ */ React.createElement("div", {
                class: [
                  `${clsPrefix}-image-preview-container`,
                  this.themeClass
                ],
                style: this.cssVars,
                onWheel: this.handleWheel
              }, /* @__PURE__ */ React.createElement(vue.Transition, {
                name: "fade-in-transition",
                appear: this.appear
              }, {
                default: () => this.show ? /* @__PURE__ */ React.createElement("div", {
                  class: `${clsPrefix}-image-preview-overlay`,
                  onClick: this.toggleShow
                }) : null
              }), this.showToolbar ? /* @__PURE__ */ React.createElement(vue.Transition, {
                name: "fade-in-transition",
                appear: this.appear
              }, {
                default: () => {
                  if (!this.show)
                    return null;
                  const { withTooltip } = this;
                  return /* @__PURE__ */ React.createElement("div", {
                    class: `${clsPrefix}-image-preview-toolbar`
                  }, this.onPrev ? /* @__PURE__ */ React.createElement(React.Fragment, null, withTooltip(
                    /* @__PURE__ */ React.createElement(NBaseIcon, {
                      clsPrefix,
                      onClick: this.handleSwitchPrev
                    }, { default: () => prevIcon }),
                    "tipPrevious"
                  ), withTooltip(
                    /* @__PURE__ */ React.createElement(NBaseIcon, {
                      clsPrefix,
                      onClick: this.handleSwitchNext
                    }, { default: () => nextIcon }),
                    "tipNext"
                  )) : null, withTooltip(
                    /* @__PURE__ */ React.createElement(NBaseIcon, {
                      clsPrefix,
                      onClick: this.rotateCounterclockwise
                    }, {
                      default: () => /* @__PURE__ */ React.createElement(RotateCounterclockwiseIcon, null)
                    }),
                    "tipCounterclockwise"
                  ), withTooltip(
                    /* @__PURE__ */ React.createElement(NBaseIcon, {
                      clsPrefix,
                      onClick: this.rotateClockwise
                    }, {
                      default: () => /* @__PURE__ */ React.createElement(RotateClockwiseIcon, null)
                    }),
                    "tipClockwise"
                  ), withTooltip(
                    /* @__PURE__ */ React.createElement(NBaseIcon, {
                      clsPrefix,
                      onClick: this.resizeToOrignalImageSize
                    }, {
                      default: () => {
                        return /* @__PURE__ */ React.createElement(ResizeSmallIcon, null);
                      }
                    }),
                    "tipOriginalSize"
                  ), withTooltip(
                    /* @__PURE__ */ React.createElement(NBaseIcon, {
                      clsPrefix,
                      onClick: this.zoomOut
                    }, { default: () => /* @__PURE__ */ React.createElement(ZoomOutIcon, null) }),
                    "tipZoomOut"
                  ), withTooltip(
                    /* @__PURE__ */ React.createElement(NBaseIcon, {
                      clsPrefix,
                      onClick: this.zoomIn
                    }, { default: () => /* @__PURE__ */ React.createElement(ZoomInIcon, null) }),
                    "tipZoomIn"
                  ), withTooltip(
                    /* @__PURE__ */ React.createElement(NBaseIcon, {
                      clsPrefix,
                      onClick: this.toggleShow
                    }, { default: () => closeIcon }),
                    "tipClose"
                  ));
                }
              }) : null, /* @__PURE__ */ React.createElement(vue.Transition, {
                name: "fade-in-scale-up-transition",
                onAfterLeave: this.handleAfterLeave,
                appear: this.appear,
                onEnter: this.syncTransformOrigin,
                onBeforeLeave: this.syncTransformOrigin
              }, {
                default: () => vue.withDirectives(
                  /* @__PURE__ */ React.createElement("div", {
                    class: `${clsPrefix}-image-preview-wrapper`,
                    ref: "previewWrapperRef"
                  }, /* @__PURE__ */ React.createElement("img", {
                    draggable: false,
                    onMousedown: this.handlePreviewMousedown,
                    onDblclick: this.handlePreviewDblclick,
                    class: `${clsPrefix}-image-preview`,
                    key: this.previewSrc,
                    src: this.previewSrc,
                    ref: "previewRef",
                    onDragstart: this.handleDragStart
                  })),
                  [[vue.vShow, this.show]]
                )
              })),
              [[zindexable$1, { enabled: this.show }]]
            );
          }
        }));
      }
    });

    const imageGroupInjectionKey = createInjectionKey("n-image-group");
    const imageGroupProps = imagePreviewSharedProps;
    var NImageGroup = vue.defineComponent({
      name: "ImageGroup",
      props: imageGroupProps,
      setup(props) {
        let currentSrc;
        const { mergedClsPrefixRef } = useConfig(props);
        const groupId = `c${createId()}`;
        const vm = vue.getCurrentInstance();
        const setPreviewSrc = (src) => {
          currentSrc = src;
          previewInstRef.value?.setPreviewSrc(src);
        };
        function go(step) {
          if (!vm?.proxy)
            return;
          const container = vm.proxy.$el.parentElement;
          const imgs = container.querySelectorAll(
            `[data-group-id=${groupId}]:not([data-error=true])`
          );
          if (!imgs.length)
            return;
          const index = Array.from(imgs).findIndex(
            (img) => img.dataset.previewSrc === currentSrc
          );
          if (~index) {
            setPreviewSrc(
              imgs[(index + step + imgs.length) % imgs.length].dataset.previewSrc
            );
          } else {
            setPreviewSrc(imgs[0].dataset.previewSrc);
          }
        }
        vue.provide(imageGroupInjectionKey, {
          mergedClsPrefixRef,
          setPreviewSrc,
          setThumbnailEl: (el) => {
            previewInstRef.value?.setThumbnailEl(el);
          },
          toggleShow: () => {
            previewInstRef.value?.toggleShow();
          },
          groupId
        });
        const previewInstRef = vue.ref(null);
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          previewInstRef,
          next: () => go(1),
          prev: () => go(-1)
        };
      },
      render() {
        return /* @__PURE__ */ React.createElement(NImagePreview, {
          theme: this.theme,
          themeOverrides: this.themeOverrides,
          clsPrefix: this.mergedClsPrefix,
          ref: "previewInstRef",
          onPrev: this.prev,
          onNext: this.next,
          showToolbar: this.showToolbar,
          showToolbarTooltip: this.showToolbarTooltip
        }, this.$slots);
      }
    });

    const imageProps = {
      alt: String,
      height: [String, Number],
      imgProps: Object,
      lazy: Boolean,
      intersectionObserverOptions: Object,
      objectFit: {
        type: String,
        default: "fill"
      },
      previewSrc: String,
      fallbackSrc: String,
      width: [String, Number],
      src: String,
      previewDisabled: Boolean,
      loadDescription: String,
      onError: Function,
      onLoad: Function,
      ...imagePreviewSharedProps
    };
    var NImage = vue.defineComponent({
      name: "Image",
      props: imageProps,
      inheritAttrs: false,
      setup(props) {
        const imageRef = vue.ref(null);
        const showErrorRef = vue.ref(false);
        const imgPropsRef = vue.toRef(props, "imgProps");
        const previewInstRef = vue.ref(null);
        const imageGroupHandle = vue.inject(imageGroupInjectionKey, null);
        const { mergedClsPrefixRef } = imageGroupHandle || useConfig(props);
        const exposedMethods = {
          click: () => {
            if (props.previewDisabled || showErrorRef.value)
              return;
            const mergedPreviewSrc = props.previewSrc || props.src;
            if (imageGroupHandle) {
              imageGroupHandle.setPreviewSrc(mergedPreviewSrc);
              imageGroupHandle.setThumbnailEl(imageRef.value);
              imageGroupHandle.toggleShow();
              return;
            }
            const { value: previewInst } = previewInstRef;
            if (!previewInst)
              return;
            previewInst.setPreviewSrc(mergedPreviewSrc);
            previewInst.setThumbnailEl(imageRef.value);
            previewInst.toggleShow();
          }
        };
        const shouldStartLoadingRef = vue.ref(!props.lazy);
        vue.onMounted(() => {
          imageRef.value?.setAttribute(
            "data-group-id",
            imageGroupHandle?.groupId || ""
          );
        });
        vue.onMounted(() => {
          if (isImageSupportNativeLazy) {
            return;
          }
          let unobserve;
          const stopWatchHandle = vue.watchEffect(() => {
            unobserve?.();
            unobserve = void 0;
            if (props.lazy) {
              unobserve = observeIntersection(
                imageRef.value,
                props.intersectionObserverOptions,
                shouldStartLoadingRef
              );
            }
          });
          vue.onBeforeUnmount(() => {
            stopWatchHandle();
            unobserve?.();
          });
        });
        vue.watchEffect(() => {
          void props.src;
          void props.imgProps?.src;
          showErrorRef.value = false;
        });
        const loadedRef = vue.ref(false);
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          groupId: imageGroupHandle?.groupId,
          previewInstRef,
          imageRef,
          imgProps: imgPropsRef,
          showError: showErrorRef,
          shouldStartLoading: shouldStartLoadingRef,
          loaded: loadedRef,
          mergedOnError: (e) => {
            if (!shouldStartLoadingRef.value)
              return;
            showErrorRef.value = true;
            const { onError, imgProps: { onError: imgPropsOnError } = {} } = props;
            onError?.(e);
            imgPropsOnError?.(e);
          },
          mergedOnLoad: (e) => {
            const { onLoad, imgProps: { onLoad: imgPropsOnLoad } = {} } = props;
            onLoad?.(e);
            imgPropsOnLoad?.(e);
            loadedRef.value = true;
          },
          ...exposedMethods
        };
      },
      render() {
        const { mergedClsPrefix, imgProps = {}, loaded, $attrs, lazy } = this;
        const placeholderNode = this.$slots.placeholder?.();
        const loadSrc = this.src || imgProps.src || "";
        const imgNode = vue.h("img", {
          ...imgProps,
          class: imgProps.class,
          ref: "imageRef",
          width: this.width || imgProps.width,
          height: this.height || imgProps.height,
          src: isImageSupportNativeLazy ? loadSrc : this.showError ? this.fallbackSrc : this.shouldStartLoading ? loadSrc : void 0,
          alt: this.alt || imgProps.alt,
          "aria-label": this.alt || imgProps.alt,
          onClick: this.click,
          onError: this.mergedOnError,
          onLoad: this.mergedOnLoad,
          loading: lazy ? "lazy" : "eager",
          style: [
            imgProps.style || "",
            placeholderNode && !loaded ? { height: "0", width: "0", visibility: "hidden" } : "",
            { objectFit: this.objectFit }
          ],
          "data-error": this.showError,
          "data-preview-src": this.previewSrc || this.src
        });
        return /* @__PURE__ */ React.createElement("div", {
          ...$attrs,
          role: "none",
          class: [
            $attrs.class,
            `${mergedClsPrefix}-image`,
            (this.previewDisabled || this.showError) && `${mergedClsPrefix}-image--preview-disabled`
          ]
        }, this.groupId ? imgNode : /* @__PURE__ */ React.createElement(NImagePreview, {
          theme: this.theme,
          themeOverrides: this.themeOverrides,
          clsPrefix: mergedClsPrefix,
          ref: "previewInstRef",
          showToolbar: this.showToolbar,
          showToolbarTooltip: this.showToolbarTooltip
        }, {
          default: () => imgNode
        }), !loaded && placeholderNode);
      }
    });

    function parse(value) {
      if (value === void 0 || value === null || typeof value === "string" && value.trim() === "") {
        return null;
      }

      return Number(value);
    }
    function isWipValue(value) {
      return value.includes(".") && (/^(-)?\d+.*(\.|0)$/.test(value) || /^\.\d+$/.test(value));
    }
    function validator(value) {
      if (value === void 0 || value === null) return true;
      if (Number.isNaN(value)) return false;
      return true;
    }
    function format(value, precision) {
      if (value === void 0 || value === null) return "";
      return precision === void 0 ? String(value) : value.toFixed(precision);
    }
    function parseNumber(number) {
      if (number === null) return null;

      if (typeof number === "number") {
        return number;
      } else {
        const parsedNumber = Number(number);
        if (Number.isNaN(parsedNumber)) return null;else {
          return parsedNumber;
        }
      }
    }

    var style$D = c$1([cB("input-number-suffix", `
    display: inline-block;
    margin-right: 10px;
  `), cB("input-number-prefix", `
    display: inline-block;
    margin-left: 10px;
  `)]);

    const HOLDING_CHANGE_THRESHOLD = 800;
    const HOLDING_CHANGE_INTERVAL = 100;
    const inputNumberProps = {
      ...useTheme.props,
      autofocus: Boolean,
      loading: {
        type: Boolean,
        default: void 0
      },
      placeholder: String,
      defaultValue: {
        type: Number,
        default: null
      },
      value: Number,
      step: {
        type: [Number, String],
        default: 1
      },
      min: [Number, String],
      max: [Number, String],
      size: String,
      disabled: {
        type: Boolean,
        default: void 0
      },
      validator: Function,
      bordered: {
        type: Boolean,
        default: void 0
      },
      showButton: {
        type: Boolean,
        default: true
      },
      buttonPlacement: {
        type: String,
        default: "right"
      },
      readonly: Boolean,
      clearable: Boolean,
      keyboard: {
        type: Object,
        default: {}
      },
      updateValueOnInput: {
        type: Boolean,
        default: true
      },
      parse: Function,
      format: Function,
      precision: Number,
      status: String,
      "onUpdate:value": [Function, Array],
      onUpdateValue: [Function, Array],
      onFocus: [Function, Array],
      onBlur: [Function, Array],
      onClear: [Function, Array],
      onChange: [Function, Array]
    };
    var InputNumber = vue.defineComponent({
      name: "InputNumber",
      props: inputNumberProps,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.onChange !== void 0) {
              warnOnce(
                "input-number",
                "`on-change` is deprecated, please use `on-update:value` instead"
              );
            }
          });
        }
        const { mergedBorderedRef, mergedClsPrefixRef, mergedRtlRef } = useConfig(props);
        const themeRef = useTheme(
          "InputNumber",
          "-input-number",
          style$D,
          inputNumberLight$1,
          props,
          mergedClsPrefixRef
        );
        const { localeRef } = useLocale("InputNumber");
        const formItem = useFormItem(props);
        const { mergedSizeRef, mergedDisabledRef, mergedStatusRef } = formItem;
        const inputInstRef = vue.ref(null);
        const minusButtonInstRef = vue.ref(null);
        const addButtonInstRef = vue.ref(null);
        const uncontrolledValueRef = vue.ref(props.defaultValue);
        const controlledValueRef = vue.toRef(props, "value");
        const mergedValueRef = useMergedState(
          controlledValueRef,
          uncontrolledValueRef
        );
        const displayedValueRef = vue.ref("");
        const getPrecision = (value) => {
          const fraction = String(value).split(".")[1];
          return fraction ? fraction.length : 0;
        };
        const getMaxPrecision = (currentValue) => {
          const precisions = [props.min, props.max, props.step, currentValue].map(
            (value) => {
              if (value === void 0)
                return 0;
              return getPrecision(value);
            }
          );
          return Math.max(...precisions);
        };
        const mergedPlaceholderRef = useMemo(() => {
          const { placeholder } = props;
          if (placeholder !== void 0)
            return placeholder;
          return localeRef.value.placeholder;
        });
        const mergedStepRef = useMemo(() => {
          const parsedNumber = parseNumber(props.step);
          if (parsedNumber !== null) {
            return parsedNumber === 0 ? 1 : Math.abs(parsedNumber);
          }
          return 1;
        });
        const mergedMinRef = useMemo(() => {
          const parsedNumber = parseNumber(props.min);
          if (parsedNumber !== null)
            return parsedNumber;
          else
            return null;
        });
        const mergedMaxRef = useMemo(() => {
          const parsedNumber = parseNumber(props.max);
          if (parsedNumber !== null)
            return parsedNumber;
          else
            return null;
        });
        const doUpdateValue = (value) => {
          const { value: mergedValue } = mergedValueRef;
          if (value === mergedValue) {
            deriveDisplayedValueFromValue();
            return;
          }
          const {
            "onUpdate:value": _onUpdateValue,
            onUpdateValue,
            onChange
          } = props;
          const { nTriggerFormInput, nTriggerFormChange } = formItem;
          if (onChange)
            call(onChange, value);
          if (onUpdateValue)
            call(onUpdateValue, value);
          if (_onUpdateValue)
            call(_onUpdateValue, value);
          uncontrolledValueRef.value = value;
          nTriggerFormInput();
          nTriggerFormChange();
        };
        const deriveValueFromDisplayedValue = ({
          offset,
          doUpdateIfValid,
          fixPrecision,
          isInputing
        }) => {
          const { value: displayedValue } = displayedValueRef;
          if (isInputing && isWipValue(displayedValue)) {
            return false;
          }
          const parsedValue = (props.parse || parse)(displayedValue);
          if (parsedValue === null) {
            if (doUpdateIfValid)
              doUpdateValue(null);
            return null;
          }
          if (validator(parsedValue)) {
            const currentPrecision = getPrecision(parsedValue);
            const { precision } = props;
            if (precision !== void 0 && precision < currentPrecision && !fixPrecision) {
              return false;
            }
            let nextValue = parseFloat(
              (parsedValue + offset).toFixed(
                precision ?? getMaxPrecision(parsedValue)
              )
            );
            if (validator(nextValue)) {
              const { value: mergedMax } = mergedMaxRef;
              const { value: mergedMin } = mergedMinRef;
              if (mergedMax !== null && nextValue > mergedMax) {
                if (!doUpdateIfValid || isInputing)
                  return false;
                nextValue = mergedMax;
              }
              if (mergedMin !== null && nextValue < mergedMin) {
                if (!doUpdateIfValid || isInputing)
                  return false;
                nextValue = mergedMin;
              }
              if (props.validator && !props.validator(nextValue))
                return false;
              if (doUpdateIfValid)
                doUpdateValue(nextValue);
              return nextValue;
            }
          }
          return false;
        };
        const deriveDisplayedValueFromValue = () => {
          const { value: mergedValue } = mergedValueRef;
          if (validator(mergedValue)) {
            const { format: formatProp, precision } = props;
            if (formatProp) {
              displayedValueRef.value = formatProp(mergedValue);
            } else {
              if (mergedValue === null || precision === void 0 || getPrecision(mergedValue) > precision) {
                displayedValueRef.value = format(mergedValue, void 0);
              } else {
                displayedValueRef.value = format(mergedValue, precision);
              }
            }
          } else {
            displayedValueRef.value = String(mergedValue);
          }
        };
        deriveDisplayedValueFromValue();
        const displayedValueInvalidRef = useMemo(() => {
          const derivedValue = deriveValueFromDisplayedValue({
            offset: 0,
            doUpdateIfValid: false,
            isInputing: false,
            fixPrecision: false
          });
          return derivedValue === false;
        });
        const minusableRef = useMemo(() => {
          const { value: mergedValue } = mergedValueRef;
          if (props.validator && mergedValue === null) {
            return false;
          }
          const { value: mergedStep } = mergedStepRef;
          const derivedNextValue = deriveValueFromDisplayedValue({
            offset: -mergedStep,
            doUpdateIfValid: false,
            isInputing: false,
            fixPrecision: false
          });
          return derivedNextValue !== false;
        });
        const addableRef = useMemo(() => {
          const { value: mergedValue } = mergedValueRef;
          if (props.validator && mergedValue === null) {
            return false;
          }
          const { value: mergedStep } = mergedStepRef;
          const derivedNextValue = deriveValueFromDisplayedValue({
            offset: +mergedStep,
            doUpdateIfValid: false,
            isInputing: false,
            fixPrecision: false
          });
          return derivedNextValue !== false;
        });
        function doFocus(e) {
          const { onFocus } = props;
          const { nTriggerFormFocus } = formItem;
          if (onFocus)
            call(onFocus, e);
          nTriggerFormFocus();
        }
        function doBlur(e) {
          if (e.target === inputInstRef.value?.wrapperElRef) {
            return;
          }
          const value = deriveValueFromDisplayedValue({
            offset: 0,
            doUpdateIfValid: true,
            isInputing: false,
            fixPrecision: true
          });
          if (value !== false) {
            const inputElRef = inputInstRef.value?.inputElRef;
            if (inputElRef) {
              inputElRef.value = String(value || "");
            }
            if (mergedValueRef.value === value) {
              deriveDisplayedValueFromValue();
            }
          } else {
            deriveDisplayedValueFromValue();
          }
          const { onBlur } = props;
          const { nTriggerFormBlur } = formItem;
          if (onBlur)
            call(onBlur, e);
          nTriggerFormBlur();
        }
        function doClear(e) {
          const { onClear } = props;
          if (onClear)
            call(onClear, e);
        }
        function doAdd() {
          const { value: addable } = addableRef;
          if (!addable) {
            clearAddHoldTimeout();
            return;
          }
          const { value: mergedValue } = mergedValueRef;
          if (mergedValue === null) {
            if (!props.validator) {
              doUpdateValue(createValidValue());
            }
          } else {
            const { value: mergedStep } = mergedStepRef;
            deriveValueFromDisplayedValue({
              offset: mergedStep,
              doUpdateIfValid: true,
              isInputing: false,
              fixPrecision: true
            });
          }
        }
        function doMinus() {
          const { value: minusable } = minusableRef;
          if (!minusable) {
            clearMinusHoldTimeout();
            return;
          }
          const { value: mergedValue } = mergedValueRef;
          if (mergedValue === null) {
            if (!props.validator) {
              doUpdateValue(createValidValue());
            }
          } else {
            const { value: mergedStep } = mergedStepRef;
            deriveValueFromDisplayedValue({
              offset: -mergedStep,
              doUpdateIfValid: true,
              isInputing: false,
              fixPrecision: true
            });
          }
        }
        const handleFocus = doFocus;
        const handleBlur = doBlur;
        function createValidValue() {
          if (props.validator)
            return null;
          const { value: mergedMin } = mergedMinRef;
          const { value: mergedMax } = mergedMaxRef;
          if (mergedMin !== null) {
            return Math.max(0, mergedMin);
          } else if (mergedMax !== null) {
            return Math.min(0, mergedMax);
          } else {
            return 0;
          }
        }
        function handleClear(e) {
          doClear(e);
          doUpdateValue(null);
        }
        function handleMouseDown(e) {
          if (addButtonInstRef.value?.$el.contains(e.target)) {
            e.preventDefault();
          }
          if (minusButtonInstRef.value?.$el.contains(e.target)) {
            e.preventDefault();
          }
          inputInstRef.value?.activate();
        }
        let minusHoldStateIntervalId = null;
        let addHoldStateIntervalId = null;
        let firstMinusMousedownId = null;
        function clearMinusHoldTimeout() {
          if (firstMinusMousedownId) {
            window.clearTimeout(firstMinusMousedownId);
            firstMinusMousedownId = null;
          }
          if (minusHoldStateIntervalId) {
            window.clearInterval(minusHoldStateIntervalId);
            minusHoldStateIntervalId = null;
          }
        }
        function clearAddHoldTimeout() {
          if (firstAddMousedownId) {
            window.clearTimeout(firstAddMousedownId);
            firstAddMousedownId = null;
          }
          if (addHoldStateIntervalId) {
            window.clearInterval(addHoldStateIntervalId);
            addHoldStateIntervalId = null;
          }
        }
        function handleMinusMousedown() {
          clearMinusHoldTimeout();
          firstMinusMousedownId = window.setTimeout(() => {
            minusHoldStateIntervalId = window.setInterval(() => {
              doMinus();
            }, HOLDING_CHANGE_INTERVAL);
          }, HOLDING_CHANGE_THRESHOLD);
          on("mouseup", document, clearMinusHoldTimeout, {
            once: true
          });
        }
        let firstAddMousedownId = null;
        function handleAddMousedown() {
          clearAddHoldTimeout();
          firstAddMousedownId = window.setTimeout(() => {
            addHoldStateIntervalId = window.setInterval(() => {
              doAdd();
            }, HOLDING_CHANGE_INTERVAL);
          }, HOLDING_CHANGE_THRESHOLD);
          on("mouseup", document, clearAddHoldTimeout, {
            once: true
          });
        }
        const handleAddClick = () => {
          if (addHoldStateIntervalId)
            return;
          doAdd();
        };
        const handleMinusClick = () => {
          if (minusHoldStateIntervalId)
            return;
          doMinus();
        };
        function handleKeyDown(e) {
          if (e.key === "Enter") {
            if (e.target === inputInstRef.value?.wrapperElRef) {
              return;
            }
            const value = deriveValueFromDisplayedValue({
              offset: 0,
              doUpdateIfValid: true,
              isInputing: false,
              fixPrecision: true
            });
            if (value !== false) {
              inputInstRef.value?.deactivate();
            }
          } else if (e.key === "ArrowUp") {
            if (!addableRef.value)
              return;
            if (props.keyboard.ArrowUp === false)
              return;
            e.preventDefault();
            const value = deriveValueFromDisplayedValue({
              offset: 0,
              doUpdateIfValid: true,
              isInputing: false,
              fixPrecision: true
            });
            if (value !== false) {
              doAdd();
            }
          } else if (e.key === "ArrowDown") {
            if (!minusableRef.value)
              return;
            if (props.keyboard.ArrowDown === false)
              return;
            e.preventDefault();
            const value = deriveValueFromDisplayedValue({
              offset: 0,
              doUpdateIfValid: true,
              isInputing: false,
              fixPrecision: true
            });
            if (value !== false) {
              doMinus();
            }
          }
        }
        function handleUpdateDisplayedValue(value) {
          displayedValueRef.value = value;
          if (props.updateValueOnInput && !props.format && !props.parse && props.precision === void 0) {
            deriveValueFromDisplayedValue({
              offset: 0,
              doUpdateIfValid: true,
              isInputing: true,
              fixPrecision: false
            });
          }
        }
        vue.watch(mergedValueRef, () => {
          deriveDisplayedValueFromValue();
        });
        const exposedMethods = {
          focus: () => inputInstRef.value?.focus(),
          blur: () => inputInstRef.value?.blur()
        };
        const rtlEnabledRef = useRtl(
          "InputNumber",
          mergedRtlRef,
          mergedClsPrefixRef
        );
        return {
          ...exposedMethods,
          rtlEnabled: rtlEnabledRef,
          inputInstRef,
          minusButtonInstRef,
          addButtonInstRef,
          mergedClsPrefix: mergedClsPrefixRef,
          mergedBordered: mergedBorderedRef,
          uncontrolledValue: uncontrolledValueRef,
          mergedValue: mergedValueRef,
          mergedPlaceholder: mergedPlaceholderRef,
          displayedValueInvalid: displayedValueInvalidRef,
          mergedSize: mergedSizeRef,
          mergedDisabled: mergedDisabledRef,
          displayedValue: displayedValueRef,
          addable: addableRef,
          minusable: minusableRef,
          mergedStatus: mergedStatusRef,
          handleFocus,
          handleBlur,
          handleClear,
          handleMouseDown,
          handleAddClick,
          handleMinusClick,
          handleAddMousedown,
          handleMinusMousedown,
          handleKeyDown,
          handleUpdateDisplayedValue,
          mergedTheme: themeRef,
          inputThemeOverrides: {
            paddingSmall: "0 8px 0 10px",
            paddingMedium: "0 8px 0 12px",
            paddingLarge: "0 8px 0 14px"
          },
          buttonThemeOverrides: vue.computed(() => {
            const {
              self: { iconColorDisabled }
            } = themeRef.value;
            const [r, g, b, a] = rgba(iconColorDisabled);
            return {
              textColorTextDisabled: `rgb(${r}, ${g}, ${b})`,
              opacityDisabled: `${a}`
            };
          })
        };
      },
      render() {
        const { mergedClsPrefix, $slots } = this;
        const renderMinusButton = () => {
          return /* @__PURE__ */ React.createElement(XButton, {
            text: true,
            disabled: !this.minusable || this.mergedDisabled || this.readonly,
            focusable: false,
            theme: this.mergedTheme.peers.Button,
            themeOverrides: this.mergedTheme.peerOverrides.Button,
            builtinThemeOverrides: this.buttonThemeOverrides,
            onClick: this.handleMinusClick,
            onMousedown: this.handleMinusMousedown,
            ref: "minusButtonInstRef"
          }, {
            icon: () => resolveSlot($slots["minus-icon"], () => [
              /* @__PURE__ */ React.createElement(NBaseIcon, {
                clsPrefix: mergedClsPrefix
              }, {
                default: () => /* @__PURE__ */ React.createElement(RemoveIcon, null)
              })
            ])
          });
        };
        const renderAddButton = () => {
          return /* @__PURE__ */ React.createElement(XButton, {
            text: true,
            disabled: !this.addable || this.mergedDisabled || this.readonly,
            focusable: false,
            theme: this.mergedTheme.peers.Button,
            themeOverrides: this.mergedTheme.peerOverrides.Button,
            builtinThemeOverrides: this.buttonThemeOverrides,
            onClick: this.handleAddClick,
            onMousedown: this.handleAddMousedown,
            ref: "addButtonInstRef"
          }, {
            icon: () => resolveSlot($slots["add-icon"], () => [
              /* @__PURE__ */ React.createElement(NBaseIcon, {
                clsPrefix: mergedClsPrefix
              }, {
                default: () => /* @__PURE__ */ React.createElement(AddIcon, null)
              })
            ])
          });
        };
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-input-number`,
            this.rtlEnabled && `${mergedClsPrefix}-input-number--rtl`
          ]
        }, /* @__PURE__ */ React.createElement(NInput, {
          ref: "inputInstRef",
          autofocus: this.autofocus,
          status: this.mergedStatus,
          bordered: this.mergedBordered,
          loading: this.loading,
          value: this.displayedValue,
          onUpdateValue: this.handleUpdateDisplayedValue,
          theme: this.mergedTheme.peers.Input,
          themeOverrides: this.mergedTheme.peerOverrides.Input,
          builtinThemeOverrides: this.inputThemeOverrides,
          size: this.mergedSize,
          placeholder: this.mergedPlaceholder,
          disabled: this.mergedDisabled,
          readonly: this.readonly,
          textDecoration: this.displayedValueInvalid ? "line-through" : void 0,
          onFocus: this.handleFocus,
          onBlur: this.handleBlur,
          onKeydown: this.handleKeyDown,
          onMousedown: this.handleMouseDown,
          onClear: this.handleClear,
          clearable: this.clearable,
          internalLoadingBeforeSuffix: true
        }, {
          prefix: () => this.showButton && this.buttonPlacement === "both" ? [
            renderMinusButton(),
            resolveWrappedSlot($slots.prefix, (children) => {
              if (children) {
                return /* @__PURE__ */ React.createElement("span", {
                  class: `${mergedClsPrefix}-input-number-prefix`
                }, children);
              }
              return null;
            })
          ] : $slots.prefix?.(),
          suffix: () => this.showButton ? [
            resolveWrappedSlot($slots.suffix, (children) => {
              if (children) {
                return /* @__PURE__ */ React.createElement("span", {
                  class: `${mergedClsPrefix}-input-number-suffix`
                }, children);
              }
              return null;
            }),
            this.buttonPlacement === "right" ? renderMinusButton() : null,
            renderAddButton()
          ] : $slots.suffix?.()
        }));
      }
    });

    const layoutSiderInjectionKey = createInjectionKey("n-layout-sider");
    const positionProp = {
      type: String,
      default: "static"
    };

    var style$C = cB("layout", `
  color: var(--n-text-color);
  background-color: var(--n-color);
  box-sizing: border-box;
  position: relative;
  z-index: auto;
  flex: auto;
  overflow: hidden;
  transition:
    box-shadow .3s var(--n-bezier),
    background-color .3s var(--n-bezier),
    color .3s var(--n-bezier);
`, [cB("layout-scroll-container", `
    overflow-x: hidden;
    box-sizing: border-box;
    height: 100%;
  `), cM("absolute-positioned", `
    position: absolute;
    left: 0;
    right: 0;
    top: 0;
    bottom: 0;
  `)]);

    const layoutProps = {
      embedded: Boolean,
      position: positionProp,
      nativeScrollbar: {
        type: Boolean,
        default: true
      },
      scrollbarProps: Object,
      onScroll: Function,
      contentStyle: {
        type: [String, Object],
        default: ""
      },
      hasSider: Boolean,
      siderPlacement: {
        type: String,
        default: "left"
      }
    };
    const layoutInjectionKey = createInjectionKey("n-layout");
    function createLayoutComponent(isContent) {
      return vue.defineComponent({
        name: isContent ? "LayoutContent" : "Layout",
        props: {
          ...useTheme.props,
          ...layoutProps
        },
        setup(props) {
          const scrollableElRef = vue.ref(null);
          const scrollbarInstRef = vue.ref(null);
          const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
          const themeRef = useTheme(
            "Layout",
            "-layout",
            style$C,
            layoutLight$1,
            props,
            mergedClsPrefixRef
          );
          function scrollTo(options, y) {
            if (props.nativeScrollbar) {
              const { value: scrollableEl } = scrollableElRef;
              if (scrollableEl) {
                if (y === void 0) {
                  scrollableEl.scrollTo(options);
                } else {
                  scrollableEl.scrollTo(options, y);
                }
              }
            } else {
              const { value: scrollbarInst } = scrollbarInstRef;
              if (scrollbarInst) {
                scrollbarInst.scrollTo(options, y);
              }
            }
          }
          vue.provide(layoutInjectionKey, props);
          let scrollX = 0;
          let scrollY = 0;
          const handleNativeElScroll = (e) => {
            const target = e.target;
            scrollX = target.scrollLeft;
            scrollY = target.scrollTop;
            props.onScroll?.(e);
          };
          useReactivated(() => {
            if (props.nativeScrollbar) {
              const el = scrollableElRef.value;
              if (el) {
                el.scrollTop = scrollY;
                el.scrollLeft = scrollX;
              }
            }
          });
          const hasSiderStyle = {
            display: "flex",
            flexWrap: "nowrap",
            width: "100%",
            flexDirection: "row"
          };
          const exposedMethods = {
            scrollTo
          };
          const cssVarsRef = vue.computed(() => {
            const {
              common: { cubicBezierEaseInOut },
              self
            } = themeRef.value;
            return {
              "--n-bezier": cubicBezierEaseInOut,
              "--n-color": props.embedded ? self.colorEmbedded : self.color,
              "--n-text-color": self.textColor
            };
          });
          const themeClassHandle = inlineThemeDisabled ? useThemeClass(
            "layout",
            vue.computed(() => {
              return props.embedded ? "e" : "";
            }),
            cssVarsRef,
            props
          ) : void 0;
          return {
            mergedClsPrefix: mergedClsPrefixRef,
            scrollableElRef,
            scrollbarInstRef,
            hasSiderStyle,
            mergedTheme: themeRef,
            handleNativeElScroll,
            cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
            themeClass: themeClassHandle?.themeClass,
            onRender: themeClassHandle?.onRender,
            ...exposedMethods
          };
        },
        render() {
          const { mergedClsPrefix, hasSider } = this;
          this.onRender?.();
          const hasSiderStyle = hasSider ? this.hasSiderStyle : void 0;
          const layoutClass = [
            this.themeClass,
            isContent && `${mergedClsPrefix}-layout-content`,
            `${mergedClsPrefix}-layout`,
            `${mergedClsPrefix}-layout--${this.position}-positioned`
          ];
          return /* @__PURE__ */ React.createElement("div", {
            class: layoutClass,
            style: this.cssVars
          }, this.nativeScrollbar ? /* @__PURE__ */ React.createElement("div", {
            ref: "scrollableElRef",
            class: `${mergedClsPrefix}-layout-scroll-container`,
            style: [this.contentStyle, hasSiderStyle],
            onScroll: this.handleNativeElScroll
          }, this.$slots) : /* @__PURE__ */ React.createElement(NScrollbar, {
            ...this.scrollbarProps,
            onScroll: this.onScroll,
            ref: "scrollbarInstRef",
            theme: this.mergedTheme.peers.Scrollbar,
            themeOverrides: this.mergedTheme.peerOverrides.Scrollbar,
            contentStyle: [this.contentStyle, hasSiderStyle]
          }, this.$slots));
        }
      });
    }
    var Layout = createLayoutComponent(false);

    var LayoutContent = createLayoutComponent(true);

    var style$B = cB("layout-header", `
  transition:
    color .3s var(--n-bezier),
    background-color .3s var(--n-bezier),
    box-shadow .3s var(--n-bezier),
    border-color .3s var(--n-bezier);
  box-sizing: border-box;
  width: 100%;
  background-color: var(--n-color);
  color: var(--n-text-color);
`, [cM("absolute-positioned", `
    position: absolute;
    left: 0;
    right: 0;
    top: 0;
  `), cM("bordered", `
    border-bottom: solid 1px var(--n-border-color);
  `)]);

    const headerProps$1 = {
      position: positionProp,
      inverted: Boolean,
      bordered: {
        type: Boolean,
        default: false
      }
    };
    var LayoutHeader = vue.defineComponent({
      name: "LayoutHeader",
      props: {
        ...useTheme.props,
        ...headerProps$1
      },
      setup(props) {
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Layout",
          "-layout-header",
          style$B,
          layoutLight$1,
          props,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self
          } = themeRef.value;
          const vars = {
            "--n-bezier": cubicBezierEaseInOut
          };
          if (props.inverted) {
            vars["--n-color"] = self.headerColorInverted;
            vars["--n-text-color"] = self.textColorInverted;
            vars["--n-border-color"] = self.headerBorderColorInverted;
          } else {
            vars["--n-color"] = self.headerColor;
            vars["--n-text-color"] = self.textColor;
            vars["--n-border-color"] = self.headerBorderColor;
          }
          return vars;
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "layout-header",
          vue.computed(() => props.inverted ? "a" : "b"),
          cssVarsRef,
          props
        ) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedClsPrefix } = this;
        this.onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-layout-header`,
            this.themeClass,
            this.position && `${mergedClsPrefix}-layout-header--${this.position}-positioned`,
            this.bordered && `${mergedClsPrefix}-layout-header--bordered`
          ],
          style: this.cssVars
        }, this.$slots);
      }
    });

    var style$A = cB("layout-footer", `
  transition:
    box-shadow .3s var(--n-bezier),
    color .3s var(--n-bezier),
    background-color .3s var(--n-bezier),
    border-color .3s var(--n-bezier);
  color: var(--n-text-color);
  background-color: var(--n-color);
  box-sizing: border-box;
`, [cM("absolute-positioned", `
    position: absolute;
    left: 0;
    right: 0;
    bottom: 0;
  `), cM("bordered", `
    border-top: solid 1px var(--n-border-color);
  `)]);

    const layoutFooterProps = {
      ...useTheme.props,
      inverted: Boolean,
      position: positionProp,
      bordered: Boolean
    };
    var LayoutFooter = vue.defineComponent({
      name: "LayoutFooter",
      props: layoutFooterProps,
      setup(props) {
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Layout",
          "-layout-footer",
          style$A,
          layoutLight$1,
          props,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self
          } = themeRef.value;
          const vars = {
            "--n-bezier": cubicBezierEaseInOut
          };
          if (props.inverted) {
            vars["--n-color"] = self.footerColorInverted;
            vars["--n-text-color"] = self.textColorInverted;
            vars["--n-border-color"] = self.footerBorderColorInverted;
          } else {
            vars["--n-color"] = self.footerColor;
            vars["--n-text-color"] = self.textColor;
            vars["--n-border-color"] = self.footerBorderColor;
          }
          return vars;
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "layout-footer",
          vue.computed(() => props.inverted ? "a" : "b"),
          cssVarsRef,
          props
        ) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedClsPrefix } = this;
        this.onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-layout-footer`,
            this.themeClass,
            this.position && `${mergedClsPrefix}-layout-footer--${this.position}-positioned`,
            this.bordered && `${mergedClsPrefix}-layout-footer--bordered`
          ],
          style: this.cssVars
        }, this.$slots);
      }
    });

    var style$z = cB("layout-sider", `
  flex-shrink: 0;
  box-sizing: border-box;
  position: relative;
  z-index: 1;
  color: var(--n-text-color);
  transition:
    color .3s var(--n-bezier),
    border-color .3s var(--n-bezier),
    min-width .3s var(--n-bezier),
    max-width .3s var(--n-bezier),
    transform .3s var(--n-bezier),
    background-color .3s var(--n-bezier);
  background-color: var(--n-color);
  display: flex;
  justify-content: flex-end;
`, [cM("bordered", [cE("border", `
      content: "";
      position: absolute;
      top: 0;
      bottom: 0;
      width: 1px;
      background-color: var(--n-border-color);
      transition: background-color .3s var(--n-bezier);
    `)]), cE("left-placement", [cM("bordered", [cE("border", `
        right: 0;
      `)])]), cM("right-placement", `
    justify-content: flex-start;
  `, [cM("bordered", [cE("border", `
        left: 0;
      `)]), cM("collapsed", [cB("layout-toggle-button", [cB("base-icon", `
          transform: rotate(180deg);
        `)]), cB("layout-toggle-bar", [c$1("&:hover", [cE("top", {
      transform: "rotate(-12deg) scale(1.15) translateY(-2px)"
    }), cE("bottom", {
      transform: "rotate(12deg) scale(1.15) translateY(2px)"
    })])])]), cB("layout-toggle-button", `
      left: 0;
      transform: translateX(-50%) translateY(-50%);
    `, [cB("base-icon", `
        transform: rotate(0);
      `)]), cB("layout-toggle-bar", `
      left: -28px;
      transform: rotate(180deg);
    `, [c$1("&:hover", [cE("top", {
      transform: "rotate(12deg) scale(1.15) translateY(-2px)"
    }), cE("bottom", {
      transform: "rotate(-12deg) scale(1.15) translateY(2px)"
    })])])]), cM("collapsed", [cB("layout-toggle-bar", [c$1("&:hover", [cE("top", {
      transform: "rotate(-12deg) scale(1.15) translateY(-2px)"
    }), cE("bottom", {
      transform: "rotate(12deg) scale(1.15) translateY(2px)"
    })])]), cB("layout-toggle-button", [cB("base-icon", `
        transform: rotate(0);
      `)])]), cB("layout-toggle-button", `
    transition:
      color .3s var(--n-bezier),
      right .3s var(--n-bezier),
      left .3s var(--n-bezier),
      border-color .3s var(--n-bezier),
      background-color .3s var(--n-bezier);
    cursor: pointer;
    width: 24px;
    height: 24px;
    position: absolute;
    top: 50%;
    right: 0;
    border-radius: 50%;
    display: flex;
    align-items: center;
    justify-content: center;
    font-size: 18px;
    color: var(--n-toggle-button-icon-color);
    border: var(--n-toggle-button-border);
    background-color: var(--n-toggle-button-color);
    box-shadow: 0 2px 4px 0px rgba(0, 0, 0, .06);
    transform: translateX(50%) translateY(-50%);
    z-index: 1;
  `, [cB("base-icon", `
      transition: transform .3s var(--n-bezier);
      transform: rotate(180deg);
    `)]), cB("layout-toggle-bar", `
    cursor: pointer;
    height: 72px;
    width: 32px;
    position: absolute;
    top: calc(50% - 36px);
    right: -28px;
  `, [cE("top, bottom", `
      position: absolute;
      width: 4px;
      border-radius: 2px;
      height: 38px;
      left: 14px;
      transition: 
        background-color .3s var(--n-bezier),
        transform .3s var(--n-bezier);
    `), cE("bottom", `
      position: absolute;
      top: 34px;
    `), c$1("&:hover", [cE("top", {
      transform: "rotate(12deg) scale(1.15) translateY(-2px)"
    }), cE("bottom", {
      transform: "rotate(-12deg) scale(1.15) translateY(2px)"
    })]), cE("top, bottom", {
      backgroundColor: "var(--n-toggle-bar-color)"
    }), c$1("&:hover", [cE("top, bottom", {
      backgroundColor: "var(--n-toggle-bar-color-hover)"
    })])]), cE("border", `
    position: absolute;
    top: 0;
    right: 0;
    bottom: 0;
    width: 1px;
    transition: background-color .3s var(--n-bezier);
  `), cB("layout-sider-scroll-container", `
    flex-grow: 1;
    flex-shrink: 0;
    box-sizing: border-box;
    height: 100%;
    opacity: 0;
    transition: opacity .3s var(--n-bezier);
    max-width: 100%;
  `), cM("show-content", [cB("layout-sider-scroll-container", {
      opacity: 1
    })]), cM("absolute-positioned", `
    position: absolute;
    left: 0;
    top: 0;
    bottom: 0;
  `)]);

    var ToggleButton = vue.defineComponent({
      name: "LayoutToggleButton",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        onClick: Function
      },
      render() {
        const { clsPrefix } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-layout-toggle-button`,
          onClick: this.onClick
        }, /* @__PURE__ */ React.createElement(NBaseIcon, {
          clsPrefix
        }, {
          default: () => /* @__PURE__ */ React.createElement(ChevronRightIcon, null)
        }));
      }
    });

    var ToggleBar = vue.defineComponent({
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        onClick: Function
      },
      render() {
        const { clsPrefix } = this;
        return /* @__PURE__ */ React.createElement("div", {
          onClick: this.onClick,
          class: `${clsPrefix}-layout-toggle-bar`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-layout-toggle-bar__top`
        }), /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-layout-toggle-bar__bottom`
        }));
      }
    });

    const layoutSiderProps = {
      position: positionProp,
      bordered: Boolean,
      collapsedWidth: {
        type: Number,
        default: 48
      },
      width: {
        type: [Number, String],
        default: 272
      },
      contentStyle: {
        type: [String, Object],
        default: ""
      },
      collapseMode: {
        type: String,
        default: "transform"
      },
      collapsed: {
        type: Boolean,
        default: void 0
      },
      defaultCollapsed: Boolean,
      showCollapsedContent: {
        type: Boolean,
        default: true
      },
      showTrigger: {
        type: [Boolean, String],
        default: false
      },
      nativeScrollbar: {
        type: Boolean,
        default: true
      },
      inverted: Boolean,
      scrollbarProps: Object,
      triggerStyle: [String, Object],
      collapsedTriggerStyle: [String, Object],
      "onUpdate:collapsed": [Function, Array],
      onUpdateCollapsed: [Function, Array],
      onAfterEnter: Function,
      onAfterLeave: Function,
      onExpand: [Function, Array],
      onCollapse: [Function, Array],
      onScroll: Function
    };
    var LayoutSider = vue.defineComponent({
      name: "LayoutSider",
      props: {
        ...useTheme.props,
        ...layoutSiderProps
      },
      setup(props) {
        const layoutProps = vue.inject(layoutInjectionKey);
        {
          if (!layoutProps) {
            warn$2(
              "layout-sider",
              "Layout sider is not allowed to be put outside layout."
            );
          } else {
            if (!layoutProps.hasSider) {
              warn$2(
                "layout-sider",
                "You are putting `n-layout-sider` in a `n-layout` but haven't set `has-sider` on the `n-layout`."
              );
            }
          }
        }
        const scrollableElRef = vue.ref(null);
        const scrollbarInstRef = vue.ref(null);
        const styleMaxWidthRef = vue.computed(() => {
          return formatLength(
            mergedCollapsedRef.value ? props.collapsedWidth : props.width
          );
        });
        const scrollContainerStyleRef = vue.computed(() => {
          if (props.collapseMode !== "transform")
            return {};
          return {
            minWidth: formatLength(props.width)
          };
        });
        const siderPlacementRef = vue.computed(() => {
          return layoutProps ? layoutProps.siderPlacement : "left";
        });
        const uncontrolledCollapsedRef = vue.ref(props.defaultCollapsed);
        const mergedCollapsedRef = useMergedState(
          vue.toRef(props, "collapsed"),
          uncontrolledCollapsedRef
        );
        function scrollTo(options, y) {
          if (props.nativeScrollbar) {
            const { value: scrollableEl } = scrollableElRef;
            if (scrollableEl) {
              if (y === void 0) {
                scrollableEl.scrollTo(options);
              } else {
                scrollableEl.scrollTo(options, y);
              }
            }
          } else {
            const { value: scrollbarInst } = scrollbarInstRef;
            if (scrollbarInst) {
              scrollbarInst.scrollTo(options, y);
            }
          }
        }
        function handleTriggerClick() {
          const {
            "onUpdate:collapsed": _onUpdateCollapsed,
            onUpdateCollapsed,
            onExpand,
            onCollapse
          } = props;
          const { value: collapsed } = mergedCollapsedRef;
          if (onUpdateCollapsed) {
            call(onUpdateCollapsed, !collapsed);
          }
          if (_onUpdateCollapsed) {
            call(_onUpdateCollapsed, !collapsed);
          }
          uncontrolledCollapsedRef.value = !collapsed;
          if (collapsed) {
            if (onExpand)
              call(onExpand);
          } else {
            if (onCollapse)
              call(onCollapse);
          }
        }
        let scrollX = 0;
        let scrollY = 0;
        const handleNativeElScroll = (e) => {
          const target = e.target;
          scrollX = target.scrollLeft;
          scrollY = target.scrollTop;
          props.onScroll?.(e);
        };
        useReactivated(() => {
          if (props.nativeScrollbar) {
            const el = scrollableElRef.value;
            if (el) {
              el.scrollTop = scrollY;
              el.scrollLeft = scrollX;
            }
          }
        });
        vue.provide(layoutSiderInjectionKey, {
          collapsedRef: mergedCollapsedRef,
          collapseModeRef: vue.toRef(props, "collapseMode")
        });
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Layout",
          "-layout-sider",
          style$z,
          layoutLight$1,
          props,
          mergedClsPrefixRef
        );
        function handleTransitionend(e) {
          if (e.propertyName === "max-width") {
            if (mergedCollapsedRef.value) {
              props.onAfterLeave?.();
            } else {
              props.onAfterEnter?.();
            }
          }
        }
        const exposedMethods = {
          scrollTo
        };
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self
          } = themeRef.value;
          const {
            siderToggleButtonColor,
            siderToggleButtonBorder,
            siderToggleBarColor,
            siderToggleBarColorHover
          } = self;
          const vars = {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-toggle-button-color": siderToggleButtonColor,
            "--n-toggle-button-border": siderToggleButtonBorder,
            "--n-toggle-bar-color": siderToggleBarColor,
            "--n-toggle-bar-color-hover": siderToggleBarColorHover
          };
          if (props.inverted) {
            vars["--n-color"] = self.siderColorInverted;
            vars["--n-text-color"] = self.textColorInverted;
            vars["--n-border-color"] = self.siderBorderColorInverted;
            vars["--n-toggle-button-icon-color"] = self.siderToggleButtonIconColorInverted;
            vars.__invertScrollbar = self.__invertScrollbar;
          } else {
            vars["--n-color"] = self.siderColor;
            vars["--n-text-color"] = self.textColor;
            vars["--n-border-color"] = self.siderBorderColor;
            vars["--n-toggle-button-icon-color"] = self.siderToggleButtonIconColor;
          }
          return vars;
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "layout-sider",
          vue.computed(() => props.inverted ? "a" : "b"),
          cssVarsRef,
          props
        ) : void 0;
        return {
          scrollableElRef,
          scrollbarInstRef,
          mergedClsPrefix: mergedClsPrefixRef,
          mergedTheme: themeRef,
          styleMaxWidth: styleMaxWidthRef,
          mergedCollapsed: mergedCollapsedRef,
          scrollContainerStyle: scrollContainerStyleRef,
          siderPlacement: siderPlacementRef,
          handleNativeElScroll,
          handleTransitionend,
          handleTriggerClick,
          inlineThemeDisabled,
          cssVars: cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender,
          ...exposedMethods
        };
      },
      render() {
        const { mergedClsPrefix, mergedCollapsed, showTrigger } = this;
        this.onRender?.();
        return /* @__PURE__ */ React.createElement("aside", {
          class: [
            `${mergedClsPrefix}-layout-sider`,
            this.themeClass,
            `${mergedClsPrefix}-layout-sider--${this.position}-positioned`,
            `${mergedClsPrefix}-layout-sider--${this.siderPlacement}-placement`,
            this.bordered && `${mergedClsPrefix}-layout-sider--bordered`,
            mergedCollapsed && `${mergedClsPrefix}-layout-sider--collapsed`,
            (!mergedCollapsed || this.showCollapsedContent) && `${mergedClsPrefix}-layout-sider--show-content`
          ],
          onTransitionend: this.handleTransitionend,
          style: [
            this.inlineThemeDisabled ? void 0 : this.cssVars,
            {
              maxWidth: this.styleMaxWidth,
              width: formatLength(this.width)
            }
          ]
        }, !this.nativeScrollbar ? /* @__PURE__ */ React.createElement(NScrollbar, {
          ...this.scrollbarProps,
          onScroll: this.onScroll,
          ref: "scrollbarInstRef",
          style: this.scrollContainerStyle,
          contentStyle: this.contentStyle,
          theme: this.mergedTheme.peers.Scrollbar,
          themeOverrides: this.mergedTheme.peerOverrides.Scrollbar,
          builtinThemeOverrides: this.inverted && this.cssVars.__invertScrollbar === "true" ? {
            colorHover: "rgba(255, 255, 255, .4)",
            color: "rgba(255, 255, 255, .3)"
          } : void 0
        }, this.$slots) : /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-layout-sider-scroll-container`,
          onScroll: this.handleNativeElScroll,
          style: [
            this.scrollContainerStyle,
            {
              overflow: "auto"
            },
            this.contentStyle
          ],
          ref: "scrollableElRef"
        }, this.$slots), showTrigger ? showTrigger === "bar" ? /* @__PURE__ */ React.createElement(ToggleBar, {
          clsPrefix: mergedClsPrefix,
          style: mergedCollapsed ? this.collapsedTriggerStyle : this.triggerStyle,
          onClick: this.handleTriggerClick
        }) : /* @__PURE__ */ React.createElement(ToggleButton, {
          clsPrefix: mergedClsPrefix,
          style: mergedCollapsed ? this.collapsedTriggerStyle : this.triggerStyle,
          onClick: this.handleTriggerClick
        }) : null, this.bordered ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-layout-sider__border`
        }) : null);
      }
    });

    var commonVariables = {
      extraFontSize: "12px",
      width: "440px"
    };

    const transferDark = {
      name: "Transfer",
      common: commonDark,
      peers: {
        Checkbox: checkboxDark$1,
        Scrollbar: scrollbarDark$1,
        Input: inputDark$1,
        Empty: emptyDark$1,
        Button: buttonDark$1
      },

      self(vars) {
        const {
          iconColorDisabled,
          iconColor,
          fontWeight,
          fontSizeLarge,
          fontSizeMedium,
          fontSizeSmall,
          heightLarge,
          heightMedium,
          heightSmall,
          borderRadius,
          inputColor,
          tableHeaderColor,
          textColor1,
          textColorDisabled,
          textColor2,
          hoverColor
        } = vars;
        return { ...commonVariables,
          itemHeightSmall: heightSmall,
          itemHeightMedium: heightMedium,
          itemHeightLarge: heightLarge,
          fontSizeSmall,
          fontSizeMedium,
          fontSizeLarge,
          borderRadius,
          borderColor: "#0000",
          listColor: inputColor,
          headerColor: tableHeaderColor,
          titleTextColor: textColor1,
          titleTextColorDisabled: textColorDisabled,
          extraTextColor: textColor2,
          filterDividerColor: "#0000",
          itemTextColor: textColor2,
          itemTextColorDisabled: textColorDisabled,
          itemColorPending: hoverColor,
          titleFontWeight: fontWeight,
          iconColor,
          iconColorDisabled
        };
      }

    };
    var legacyTransferDark = transferDark;

    const self$2 = vars => {
      const {
        fontWeight,
        iconColorDisabled,
        iconColor,
        fontSizeLarge,
        fontSizeMedium,
        fontSizeSmall,
        heightLarge,
        heightMedium,
        heightSmall,
        borderRadius,
        cardColor,
        tableHeaderColor,
        textColor1,
        textColorDisabled,
        textColor2,
        borderColor,
        hoverColor
      } = vars;
      return { ...commonVariables,
        itemHeightSmall: heightSmall,
        itemHeightMedium: heightMedium,
        itemHeightLarge: heightLarge,
        fontSizeSmall,
        fontSizeMedium,
        fontSizeLarge,
        borderRadius,
        borderColor,
        listColor: cardColor,
        headerColor: composite(cardColor, tableHeaderColor),
        titleTextColor: textColor1,
        titleTextColorDisabled: textColorDisabled,
        extraTextColor: textColor2,
        filterDividerColor: borderColor,
        itemTextColor: textColor2,
        itemTextColorDisabled: textColorDisabled,
        itemColorPending: hoverColor,
        titleFontWeight: fontWeight,
        iconColor,
        iconColorDisabled
      };
    };

    const transferLight = createTheme$1({
      name: "Transfer",
      common: commonLight,
      peers: {
        Checkbox: checkboxLight$1,
        Scrollbar: scrollbarLight$1,
        Input: inputLight$1,
        Empty: emptyLight$1,
        Button: buttonLight$1
      },
      self: self$2
    });
    var legacyTransferLight = transferLight;

    const transferInjectionKey$1 = createInjectionKey("n-transfer");

    var NTransferHeader$1 = vue.defineComponent({
      name: "TransferHeader",
      props: {
        source: {
          type: Boolean,
          default: false
        },
        onChange: {
          type: Function,
          required: true
        },
        title: String
      },
      setup(props) {
        const {
          srcOptsRef,
          tgtOptsRef,
          srcCheckedStatusRef,
          tgtCheckedStatusRef,
          srcCheckedValuesRef,
          tgtCheckedValuesRef,
          mergedThemeRef,
          disabledRef,
          mergedClsPrefixRef
        } = vue.inject(transferInjectionKey$1);
        const checkboxPropsRef = vue.computed(() => {
          const { source } = props;
          if (source) {
            return srcCheckedStatusRef.value;
          } else {
            return tgtCheckedStatusRef.value;
          }
        });
        return () => {
          const { source } = props;
          const { value: checkboxProps } = checkboxPropsRef;
          const { value: mergedTheme } = mergedThemeRef;
          const { value: mergedClsPrefix } = mergedClsPrefixRef;
          return /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-legacy-transfer-list-header`
          }, /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-legacy-transfer-list-header__checkbox`
          }, /* @__PURE__ */ React.createElement(NCheckbox, {
            theme: mergedTheme.peers.Checkbox,
            themeOverrides: mergedTheme.peerOverrides.Checkbox,
            checked: checkboxProps.checked,
            indeterminate: checkboxProps.indeterminate,
            disabled: checkboxProps.disabled || disabledRef.value,
            onUpdateChecked: props.onChange
          })), /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-legacy-transfer-list-header__header`
          }, props.title), /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-legacy-transfer-list-header__extra`
          }, source ? srcCheckedValuesRef.value.length : tgtCheckedValuesRef.value.length, "/", source ? srcOptsRef.value.length : tgtOptsRef.value.length));
        };
      }
    });

    var NTransferListItem$1 = vue.defineComponent({
      name: "NTransferListItem",
      props: {
        source: {
          type: Boolean,
          default: false
        },
        label: {
          type: String,
          required: true
        },
        value: {
          type: [String, Number],
          required: true
        },
        disabled: {
          type: Boolean,
          default: false
        }
      },
      setup(props) {
        const { source } = props;
        const {
          mergedClsPrefixRef,
          mergedThemeRef,
          srcCheckedValuesRef,
          tgtCheckedValuesRef,
          handleSrcCheckboxClick,
          handleTgtCheckboxClick
        } = vue.inject(transferInjectionKey$1);
        const checkedRef = source ? useMemo(() => srcCheckedValuesRef.value.includes(props.value)) : useMemo(() => tgtCheckedValuesRef.value.includes(props.value));
        const handleClick = source ? () => {
          if (!props.disabled) {
            handleSrcCheckboxClick(!checkedRef.value, props.value);
          }
        } : () => {
          if (!props.disabled) {
            handleTgtCheckboxClick(!checkedRef.value, props.value);
          }
        };
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          mergedTheme: mergedThemeRef,
          checked: checkedRef,
          handleClick
        };
      },
      render() {
        const { disabled, mergedTheme, mergedClsPrefix, label, checked, source } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-legacy-transfer-list-item`,
            disabled && `${mergedClsPrefix}-legacy-transfer-list-item--disabled`,
            source ? `${mergedClsPrefix}-legacy-transfer-list-item--source` : `${mergedClsPrefix}-legacy-transfer-list-item--target`
          ],
          onClick: this.handleClick
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-legacy-transfer-list-item__checkbox`
        }, /* @__PURE__ */ React.createElement(NCheckbox, {
          theme: mergedTheme.peers.Checkbox,
          themeOverrides: mergedTheme.peerOverrides.Checkbox,
          disabled,
          checked
        })), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-legacy-transfer-list-item__label`,
          title: getTitleAttribute(label)
        }, label));
      }
    });

    var NTransferList$1 = vue.defineComponent({
      name: "TransferList",
      props: {
        virtualScroll: {
          type: Boolean,
          required: true
        },
        itemSize: {
          type: Number,
          required: true
        },
        options: {
          type: Array,
          required: true
        },
        disabled: {
          type: Boolean,
          required: true
        },
        isMounted: {
          type: Boolean,
          required: true
        },
        isInputing: {
          type: Boolean,
          required: true
        },
        source: {
          type: Boolean,
          default: false
        }
      },
      setup() {
        const { mergedThemeRef, mergedClsPrefixRef } = vue.inject(transferInjectionKey$1);
        const scrollerInstRef = vue.ref(null);
        const vlInstRef = vue.ref(null);
        function syncVLScroller() {
          scrollerInstRef.value?.sync();
        }
        function scrollContainer() {
          const { value } = vlInstRef;
          if (!value)
            return null;
          const { listElRef } = value;
          return listElRef;
        }
        function scrollContent() {
          const { value } = vlInstRef;
          if (!value)
            return null;
          const { itemsElRef } = value;
          return itemsElRef;
        }
        return {
          mergedTheme: mergedThemeRef,
          mergedClsPrefix: mergedClsPrefixRef,
          scrollerInstRef,
          vlInstRef,
          syncVLScroller,
          scrollContainer,
          scrollContent
        };
      },
      render() {
        const { mergedTheme, mergedClsPrefix, virtualScroll, syncVLScroller } = this;
        return /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(NScrollbar, {
          ref: "scrollerInstRef",
          theme: mergedTheme.peers.Scrollbar,
          themeOverrides: mergedTheme.peerOverrides.Scrollbar,
          container: virtualScroll ? this.scrollContainer : void 0,
          content: virtualScroll ? this.scrollContent : void 0
        }, {
          default: () => virtualScroll ? /* @__PURE__ */ React.createElement(VVirtualList, {
            ref: "vlInstRef",
            style: { height: "100%" },
            class: `${mergedClsPrefix}-legacy-transfer-list-content`,
            items: this.options,
            itemSize: this.itemSize,
            showScrollbar: false,
            onResize: syncVLScroller,
            onScroll: syncVLScroller,
            keyField: "value"
          }, {
            default: ({ item }) => {
              const { source, disabled } = this;
              return /* @__PURE__ */ React.createElement(NTransferListItem$1, {
                source,
                key: item.value,
                value: item.value,
                disabled: item.disabled || disabled,
                label: item.label
              });
            }
          }) : /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-legacy-transfer-list-content`
          }, /* @__PURE__ */ React.createElement(vue.TransitionGroup, {
            name: "item",
            appear: this.isMounted,
            css: !this.isInputing
          }, {
            default: () => {
              const { source, disabled } = this;
              return this.options.map((option) => /* @__PURE__ */ React.createElement(NTransferListItem$1, {
                source,
                key: option.value,
                value: option.value,
                disabled: option.disabled || disabled,
                label: option.label
              }));
            }
          }))
        }), /* @__PURE__ */ React.createElement(vue.Transition, {
          name: "fade-in-transition",
          appear: this.isMounted,
          css: !this.isInputing
        }, {
          default: () => this.options.length ? null : /* @__PURE__ */ React.createElement(NEmpty, {
            theme: mergedTheme.peers.Empty,
            themeOverrides: mergedTheme.peerOverrides.Empty
          })
        }));
      }
    });

    var NTransferFilter$1 = vue.defineComponent({
      name: "TransferFilter",
      props: {
        value: String,
        placeholder: String,
        disabled: Boolean,
        onFocus: {
          type: Function,
          required: true
        },
        onBlur: {
          type: Function,
          required: true
        },
        onUpdateValue: {
          type: Function,
          required: true
        }
      },
      setup() {
        const { mergedThemeRef, mergedClsPrefixRef } = vue.inject(transferInjectionKey$1);
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          mergedTheme: mergedThemeRef
        };
      },
      render() {
        const { mergedTheme, mergedClsPrefix } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-legacy-transfer-filter`
        }, /* @__PURE__ */ React.createElement(NInput, {
          value: this.value,
          onUpdateValue: this.onUpdateValue,
          disabled: this.disabled,
          theme: mergedTheme.peers.Input,
          themeOverrides: mergedTheme.peerOverrides.Input,
          clearable: true,
          size: "small",
          placeholder: this.placeholder,
          onFocus: this.onFocus,
          onBlur: this.onBlur
        }, {
          "clear-icon-placeholder": () => /* @__PURE__ */ React.createElement(NBaseIcon, {
            clsPrefix: mergedClsPrefix,
            class: `${mergedClsPrefix}-legacy-transfer-icon`
          }, { default: () => /* @__PURE__ */ React.createElement(SearchIcon, null) })
        }));
      }
    });

    function useTransferData$1(props, mergedDisabledRef) {
      const uncontrolledValueRef = vue.ref(props.defaultValue);
      const controlledValueRef = vue.toRef(props, "value");
      const mergedValueRef = useMergedState(controlledValueRef, uncontrolledValueRef);
      const optMapRef = vue.computed(() => {
        const map = /* @__PURE__ */new Map();
        (props.options || []).forEach(opt => map.set(opt.value, opt));
        return map;
      });
      const tgtValueSetRef = vue.computed(() => new Set(mergedValueRef.value || []));
      const srcOptsRef = vue.computed(() => props.options.filter(option => !tgtValueSetRef.value.has(option.value)));
      const tgtOptsRef = vue.computed(() => {
        const optMap = optMapRef.value;
        return (mergedValueRef.value || []).map(v => optMap.get(v));
      });
      const srcPatternRef = vue.ref("");
      const tgtPatternRef = vue.ref("");
      const filteredSrcOptsRef = vue.computed(() => {
        if (!props.filterable) return srcOptsRef.value;
        const {
          filter
        } = props;
        return srcOptsRef.value.filter(opt => filter(srcPatternRef.value, opt, "source"));
      });
      const filteredTgtOptsRef = vue.computed(() => {
        if (!props.filterable) return tgtOptsRef.value;
        const {
          filter
        } = props;
        return tgtOptsRef.value.filter(opt => filter(tgtPatternRef.value, opt, "target"));
      });
      const avlSrcValueSetRef = vue.computed(() => new Set(filteredSrcOptsRef.value.filter(opt => !opt.disabled).map(opt => opt.value)));
      const avlTgtValueSetRef = vue.computed(() => new Set(filteredTgtOptsRef.value.filter(opt => !opt.disabled).map(opt => opt.value)));
      const srcCheckedValuesRef = vue.ref([]);
      const tgtCheckedValuesRef = vue.ref([]);
      const srcCheckedStatusRef = vue.computed(() => {
        const srcCheckedLength = srcCheckedValuesRef.value.filter(v => avlSrcValueSetRef.value.has(v)).length;
        const avlValueCount = avlSrcValueSetRef.value.size;

        if (avlValueCount === 0) {
          return {
            checked: false,
            indeterminate: false,
            disabled: true
          };
        } else if (srcCheckedLength === 0) {
          return {
            checked: false,
            indeterminate: false
          };
        } else if (srcCheckedLength === avlValueCount) {
          return {
            checked: true,
            indeterminate: false
          };
        } else {
          return {
            checked: false,
            indeterminate: true
          };
        }
      });
      const tgtCheckedStatusRef = vue.computed(() => {
        const tgtCheckedLength = tgtCheckedValuesRef.value.filter(v => avlTgtValueSetRef.value.has(v)).length;
        const avlValueCount = avlTgtValueSetRef.value.size;

        if (avlValueCount === 0) {
          return {
            checked: false,
            indeterminate: false,
            disabled: true
          };
        } else if (tgtCheckedLength === 0) {
          return {
            checked: false,
            indeterminate: false
          };
        } else if (tgtCheckedLength === avlValueCount) {
          return {
            checked: true,
            indeterminate: false
          };
        } else {
          return {
            checked: false,
            indeterminate: true
          };
        }
      });
      const fromButtonDisabledRef = useMemo(() => {
        if (mergedDisabledRef.value) return true;
        return tgtCheckedValuesRef.value.length === 0;
      });
      const toButtonDisabledRef = useMemo(() => {
        if (mergedDisabledRef.value) return true;
        return srcCheckedValuesRef.value.length === 0;
      });
      const isInputingRef = vue.ref(false);

      function handleInputFocus() {
        isInputingRef.value = true;
      }

      function handleInputBlur() {
        isInputingRef.value = false;
      }

      function handleSrcFilterUpdateValue(value) {
        srcPatternRef.value = value ?? "";
      }

      function handleTgtFilterUpdateValue(value) {
        tgtPatternRef.value = value ?? "";
      }

      return {
        uncontrolledValue: uncontrolledValueRef,
        mergedValue: mergedValueRef,
        avlSrcValueSet: avlSrcValueSetRef,
        avlTgtValueSet: avlTgtValueSetRef,
        tgtOpts: tgtOptsRef,
        srcOpts: srcOptsRef,
        filteredSrcOpts: filteredSrcOptsRef,
        filteredTgtOpts: filteredTgtOptsRef,
        srcCheckedValues: srcCheckedValuesRef,
        tgtCheckedValues: tgtCheckedValuesRef,
        srcCheckedStatus: srcCheckedStatusRef,
        tgtCheckedStatus: tgtCheckedStatusRef,
        srcPattern: srcPatternRef,
        tgtPattern: tgtPatternRef,
        isInputing: isInputingRef,
        fromButtonDisabled: fromButtonDisabledRef,
        toButtonDisabled: toButtonDisabledRef,
        handleInputFocus,
        handleInputBlur,
        handleTgtFilterUpdateValue,
        handleSrcFilterUpdateValue
      };
    }

    const animation = c$1([c$1("@keyframes legacy-transfer-slide-in-from-left", `
    0% {
      transform: translateX(-150%);
    }
    100% {
      transform: translateX(0);
    }
  `), c$1("@keyframes legacy-transfer-slide-out-to-right", `
    0% {
      transform: translateX(0);
    }
    100% {
      transform: translateX(150%);
    }
  `), c$1("@keyframes legacy-transfer-slide-in-from-right", `
    0% {
      transform: translateX(150%);
    }
    100% {
      transform: translateX(0);
    }
  `), c$1("@keyframes legacy-transfer-slide-out-to-left", `
    0% {
      transform: translateX(0);
    }
    100% {
      transform: translateX(-150%);
    }
  `), c$1("@keyframes legacy-transfer-height-collapse", `
    0% {
      max-height: var(--n-item-height);
    }
    100% {
      max-height: 0;
    }
  `), c$1("@keyframes legacy-transfer-height-expand", `
    0% {
      max-height: 0;
    }
    100% {
      max-height: var(--n-item-height);
    }
  `)]);
    var style$y = c$1([cB("legacy-transfer", `
    display: flex;
    width: var(--n-width);
    font-size: var(--n-font-size);
    height: 240px;
    display: flex;
    flex-wrap: nowrap;
  `, [cB("legacy-transfer-icon", `
      color: var(--n-icon-color);
      transition: color .3s var(--n-bezier);
    `), cM("disabled", [cB("legacy-transfer-icon", {
      color: "var(--n-icon-color-disabled)"
    })]), cB("legacy-transfer-list", `
      height: inherit;
      display: flex;
      flex-direction: column;
      background-clip: padding-box;
      width: calc(50% - 36px);
      position: relative;
      transition: background-color .3s var(--n-bezier);
      border-radius: var(--n-border-radius);
      background-color: var(--n-list-color);
    `, [cE("border", `
        border: 1px solid var(--n-border-color);
        transition: border-color .3s var(--n-bezier);
        pointer-events: none;
        border-radius: inherit;
        position: absolute;
        left: 0;
        right: 0;
        top: 0;
        bottom: 0;
      `), cB("legacy-transfer-list-header", `
        height: calc(var(--n-item-height) + 4px);
        box-sizing: border-box;
        display: flex;
        align-items: center;
        background-clip: padding-box;
        border-radius: inherit;
        border-bottom-left-radius: 0;
        border-bottom-right-radius: 0;
        background-color: var(--n-header-color);
        transition:
          border-color .3s var(--n-bezier),
          background-color .3s var(--n-bezier);
      `, [cE("checkbox", `
          display: flex;
          align-items: center;
          position: relative;
          padding: 0 9px 0 14px;
        `), cE("header", `
          flex: 1;
          line-height: 1;
          font-weight: var(--n-header-font-weight);
          transition: color .3s var(--n-bezier);
          color: var(--n-header-text-color);
        `, [cM("disabled", {
      color: "var(--n-header-text-color-disabled)"
    })]), cE("extra", `
          transition: color .3s var(--n-bezier);
          font-size: var(--n-extra-font-size);
          justify-self: flex-end;
          margin-right: 14px;
          white-space: nowrap;
          color: var(--n-header-extra-text-color);
        `)]), cB("legacy-transfer-list-body", `
        flex-basis: 0;
        flex-grow: 1;
        box-sizing: border-box;
        position: relative;
        display: flex;
        flex-direction: column;
        border-radius: inherit;
        border-top-left-radius: 0;
        border-top-right-radius: 0;
      `, [cB("legacy-transfer-filter", `
          padding: 0 8px 8px 8px;
          box-sizing: border-box;
          background-color: var(--n-header-color);
          transition:
            border-color .3s var(--n-bezier),
            background-color .3s var(--n-bezier);
          border-bottom: 1px solid var(--n-filter-divider-color);
        `), cB("legacy-transfer-list-flex-container", `
          flex: 1;
          position: relative;
        `, [cB("scrollbar", `
            position: absolute;
            left: 0;
            right: 0;
            top: 0;
            bottom: 0;
            height: unset;
          `, [cB("scrollbar-content", {
      width: "100%"
    })]), cB("empty", `
            position: absolute;
            left: 50%;
            top: 50%;
            transform: translateY(-50%) translateX(-50%);
          `, [fadeInTransition()]), cB("legacy-transfer-list-content", `
            padding: 0;
            margin: 0;
            position: relative;
          `, [cM("transition-disabled", [cB("legacy-transfer-list-item", {
      animation: "none !important"
    })]), cB("legacy-transfer-list-item", `
              height: var(--n-item-height);
              max-height: var(--n-item-height);
                transition:
                  background-color .3s var(--n-bezier),
                  color .3s var(--n-bezier);
              position: relative;
              cursor: pointer;
              display: flex;
              align-items: center;
              color: var(--n-item-text-color);
            `, [cNotM("disabled", [c$1("&:hover", {
      backgroundColor: "var(--n-item-color-pending)"
    })]), cE("extra", `
                text-overflow: ellipsis;
                overflow: hidden;
                white-space: nowrap;
                padding-right: 4px;
              `), cE("checkbox", `
                display: flex;
                align-items: center;
                position: relative;
                padding: 0 9px 0 14px;
              `), cM("disabled", `
                cursor: not-allowed
                background-color: #0000;
                color: var(--n-item-text-color-disabled);
              `), cM("source", {
      animationFillMode: "forwards"
    }, [c$1("&.item-enter-active", `
                  transform: translateX(150%);
                  animation-duration: .25s, .25s;
                  animation-timing-function: var(--n-bezier), var(--n-bezier-ease-out);
                  animation-delay: 0s, .25s;
                  animation-name: legacy-transfer-height-expand, legacy-transfer-slide-in-from-right;
                `), c$1("&.item-leave-active", `
                  transform: translateX(-150%);
                  animation-duration: .25s, .25s;
                  animation-timing-function: var(--n-bezier), var(--n-bezier-ease-in);
                  animation-delay: .25s, 0s;
                  animation-name: legacy-transfer-height-collapse, legacy-transfer-slide-out-to-right;
                `)]), cM("target", {
      animationFillMode: "forwards"
    }, [c$1("&.item-enter-active", `
                  transform: translateX(-150%);
                  animation-duration: .25s, .25s;
                  animation-timing-function: var(--n-bezier), var(--n-bezier-ease-out);
                  animation-delay: 0s, .25s;
                  animation-name: legacy-transfer-height-expand, legacy-transfer-slide-in-from-left;
                `), c$1("&.item-leave-active", `
                  transform: translateX(150%);
                  animation-duration: .25s, .25s;
                  animation-timing-function: var(--n-bezier), var(--n-bezier-ease-in);
                  animation-delay: .25s, 0s;
                  animation-name: legacy-transfer-height-collapse, legacy-transfer-slide-out-to-left;
                `)])])])])])]), cB("legacy-transfer-gap", {
      width: "72px",
      display: "flex",
      alignItems: "center",
      justifyContent: "center",
      flexDirection: "column"
    }), cB("button", [c$1("&:first-child", {
      marginBottom: "12px"
    })])]), animation]);

    const transferProps$1 = {
      ...useTheme.props,
      value: Array,
      defaultValue: {
        type: Array,
        default: null
      },
      options: {
        type: Array,
        default: () => []
      },
      disabled: {
        type: Boolean,
        default: void 0
      },
      virtualScroll: Boolean,
      sourceTitle: String,
      targetTitle: String,
      filterable: Boolean,
      sourceFilterPlaceholder: String,
      targetFilterPlaceholder: String,
      filter: {
        type: Function,
        default: (pattern, option) => {
          if (!pattern)
            return true;
          return ~("" + option.label).toLowerCase().indexOf(("" + pattern).toLowerCase());
        }
      },
      size: String,
      "onUpdate:value": [Function, Array],
      onUpdateValue: [Function, Array],
      onChange: [Function, Array]
    };
    var Transfer$1 = vue.defineComponent({
      name: "LegacyTransfer",
      props: transferProps$1,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.onChange !== void 0) {
              warnOnce(
                "legacy-transfer",
                "`on-change` is deprecated, please use `on-update:value` instead."
              );
            }
          });
        }
        const { mergedClsPrefixRef } = useConfig(props);
        const themeRef = useTheme(
          "LegacyTransfer",
          "-legacy-transfer",
          style$y,
          legacyTransferLight,
          props,
          mergedClsPrefixRef
        );
        const formItem = useFormItem(props);
        const { mergedSizeRef, mergedDisabledRef } = formItem;
        const itemSizeRef = vue.computed(() => {
          const { value: size } = mergedSizeRef;
          const {
            self: { [createKey("itemHeight", size)]: itemSize }
          } = themeRef.value;
          return depx(itemSize);
        });
        const {
          uncontrolledValue: uncontrolledValueRef,
          mergedValue: mergedValueRef,
          avlSrcValueSet: avlSrcValueSetRef,
          avlTgtValueSet: avlTgtValueSetRef,
          tgtOpts: tgtOptsRef,
          srcOpts: srcOptsRef,
          filteredSrcOpts: filteredSrcOptsRef,
          filteredTgtOpts: filteredTgtOptsRef,
          srcCheckedValues: srcCheckedValuesRef,
          tgtCheckedValues: tgtCheckedValuesRef,
          srcCheckedStatus: srcCheckedStatusRef,
          tgtCheckedStatus: tgtCheckedStatusRef,
          srcPattern: srcPatternRef,
          tgtPattern: tgtPatternRef,
          isInputing: isInputingRef,
          fromButtonDisabled: fromButtonDisabledRef,
          toButtonDisabled: toButtonDisabledRef,
          handleInputFocus,
          handleInputBlur,
          handleTgtFilterUpdateValue,
          handleSrcFilterUpdateValue
        } = useTransferData$1(props, mergedDisabledRef);
        function doUpdateValue(value) {
          const {
            onUpdateValue,
            "onUpdate:value": _onUpdateValue,
            onChange
          } = props;
          const { nTriggerFormInput, nTriggerFormChange } = formItem;
          if (onUpdateValue)
            call(onUpdateValue, value);
          if (_onUpdateValue)
            call(_onUpdateValue, value);
          if (onChange)
            call(onChange, value);
          uncontrolledValueRef.value = value;
          nTriggerFormInput();
          nTriggerFormChange();
        }
        function handleSrcHeaderCheck(value) {
          const {
            value: { checked, indeterminate }
          } = srcCheckedStatusRef;
          if (indeterminate || checked) {
            srcCheckedValuesRef.value = [];
          } else {
            srcCheckedValuesRef.value = Array.from(avlSrcValueSetRef.value);
          }
        }
        function handleTgtHeaderCheck() {
          const {
            value: { checked, indeterminate }
          } = tgtCheckedStatusRef;
          if (indeterminate || checked) {
            tgtCheckedValuesRef.value = [];
          } else {
            tgtCheckedValuesRef.value = Array.from(avlTgtValueSetRef.value);
          }
        }
        function handleTgtCheckboxClick(checked, optionValue) {
          if (checked) {
            tgtCheckedValuesRef.value.push(optionValue);
          } else {
            const index = tgtCheckedValuesRef.value.findIndex(
              (v) => v === optionValue
            );
            if (~index) {
              tgtCheckedValuesRef.value.splice(index, 1);
            }
          }
        }
        function handleSrcCheckboxClick(checked, optionValue) {
          if (checked) {
            srcCheckedValuesRef.value.push(optionValue);
          } else {
            const index = srcCheckedValuesRef.value.findIndex(
              (v) => v === optionValue
            );
            if (~index) {
              srcCheckedValuesRef.value.splice(index, 1);
            }
          }
        }
        function handleToTgtClick() {
          doUpdateValue(
            srcCheckedValuesRef.value.concat(mergedValueRef.value || [])
          );
          srcCheckedValuesRef.value = [];
        }
        function handleToSrcClick() {
          const tgtCheckedValueSet = new Set(tgtCheckedValuesRef.value);
          doUpdateValue(
            (mergedValueRef.value || []).filter((v) => !tgtCheckedValueSet.has(v))
          );
          tgtCheckedValuesRef.value = [];
        }
        vue.provide(transferInjectionKey$1, {
          mergedClsPrefixRef,
          mergedSizeRef,
          disabledRef: mergedDisabledRef,
          mergedThemeRef: themeRef,
          srcCheckedValuesRef,
          tgtCheckedValuesRef,
          srcOptsRef,
          tgtOptsRef,
          srcCheckedStatusRef,
          tgtCheckedStatusRef,
          handleSrcCheckboxClick,
          handleTgtCheckboxClick
        });
        const { localeRef } = useLocale("LegacyTransfer");
        return {
          locale: localeRef,
          mergedClsPrefix: mergedClsPrefixRef,
          mergedDisabled: mergedDisabledRef,
          itemSize: itemSizeRef,
          isMounted: isMounted(),
          isInputing: isInputingRef,
          mergedTheme: themeRef,
          filteredSrcOpts: filteredSrcOptsRef,
          filteredTgtOpts: filteredTgtOptsRef,
          srcPattern: srcPatternRef,
          tgtPattern: tgtPatternRef,
          toButtonDisabled: toButtonDisabledRef,
          fromButtonDisabled: fromButtonDisabledRef,
          handleSrcHeaderCheck,
          handleTgtHeaderCheck,
          handleToSrcClick,
          handleToTgtClick,
          handleInputFocus,
          handleInputBlur,
          handleTgtFilterUpdateValue,
          handleSrcFilterUpdateValue,
          cssVars: vue.computed(() => {
            const { value: size } = mergedSizeRef;
            const {
              common: {
                cubicBezierEaseInOut,
                cubicBezierEaseIn,
                cubicBezierEaseOut
              },
              self: {
                width,
                borderRadius,
                borderColor,
                listColor,
                headerColor,
                titleTextColor,
                titleTextColorDisabled,
                extraTextColor,
                filterDividerColor,
                itemTextColor,
                itemColorPending,
                itemTextColorDisabled,
                extraFontSize,
                titleFontWeight,
                iconColor,
                iconColorDisabled,
                [createKey("fontSize", size)]: fontSize,
                [createKey("itemHeight", size)]: itemHeight
              }
            } = themeRef.value;
            return {
              "--n-bezier": cubicBezierEaseInOut,
              "--n-bezier-ease-in": cubicBezierEaseIn,
              "--n-bezier-ease-out": cubicBezierEaseOut,
              "--n-border-color": borderColor,
              "--n-border-radius": borderRadius,
              "--n-extra-font-size": extraFontSize,
              "--n-filter-divider-color": filterDividerColor,
              "--n-font-size": fontSize,
              "--n-header-color": headerColor,
              "--n-header-extra-text-color": extraTextColor,
              "--n-header-font-weight": titleFontWeight,
              "--n-header-text-color": titleTextColor,
              "--n-header-text-color-disabled": titleTextColorDisabled,
              "--n-item-color-pending": itemColorPending,
              "--n-item-height": itemHeight,
              "--n-item-text-color": itemTextColor,
              "--n-item-text-color-disabled": itemTextColorDisabled,
              "--n-list-color": listColor,
              "--n-width": width,
              "--n-icon-color": iconColor,
              "--n-icon-color-disabled": iconColorDisabled
            };
          })
        };
      },
      render() {
        const { mergedClsPrefix } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-legacy-transfer`,
            this.mergedDisabled && `${mergedClsPrefix}-legacy-transfer--disabled`,
            this.filterable && `${mergedClsPrefix}-legacy-transfer--filterable`
          ],
          style: this.cssVars
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-legacy-transfer-list`
        }, /* @__PURE__ */ React.createElement(NTransferHeader$1, {
          source: true,
          onChange: this.handleSrcHeaderCheck,
          title: this.sourceTitle || this.locale.sourceTitle
        }), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-legacy-transfer-list-body`
        }, this.filterable ? /* @__PURE__ */ React.createElement(NTransferFilter$1, {
          onUpdateValue: this.handleSrcFilterUpdateValue,
          value: this.srcPattern,
          disabled: this.mergedDisabled,
          placeholder: this.sourceFilterPlaceholder,
          onFocus: this.handleInputFocus,
          onBlur: this.handleInputBlur
        }) : null, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-legacy-transfer-list-flex-container`
        }, /* @__PURE__ */ React.createElement(NTransferList$1, {
          source: true,
          options: this.filteredSrcOpts,
          disabled: this.mergedDisabled,
          virtualScroll: this.virtualScroll,
          isMounted: this.isMounted,
          isInputing: this.isInputing,
          itemSize: this.itemSize
        }))), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-legacy-transfer-list__border`
        })), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-legacy-transfer-gap`
        }, /* @__PURE__ */ React.createElement(NButton, {
          disabled: this.toButtonDisabled || this.mergedDisabled,
          theme: this.mergedTheme.peers.Button,
          themeOverrides: this.mergedTheme.peerOverrides.Button,
          onClick: this.handleToTgtClick
        }, {
          icon: () => /* @__PURE__ */ React.createElement(NBaseIcon, {
            clsPrefix: mergedClsPrefix
          }, { default: () => /* @__PURE__ */ React.createElement(ChevronRightIcon, null) })
        }), /* @__PURE__ */ React.createElement(NButton, {
          disabled: this.fromButtonDisabled || this.mergedDisabled,
          theme: this.mergedTheme.peers.Button,
          themeOverrides: this.mergedTheme.peerOverrides.Button,
          onClick: this.handleToSrcClick
        }, {
          icon: () => /* @__PURE__ */ React.createElement(NBaseIcon, {
            clsPrefix: mergedClsPrefix
          }, { default: () => /* @__PURE__ */ React.createElement(ChevronLeftIcon, null) })
        })), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-legacy-transfer-list`
        }, /* @__PURE__ */ React.createElement(NTransferHeader$1, {
          onChange: this.handleTgtHeaderCheck,
          title: this.targetTitle || this.locale.targetTitle
        }), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-legacy-transfer-list-body`
        }, this.filterable ? /* @__PURE__ */ React.createElement(NTransferFilter$1, {
          onUpdateValue: this.handleTgtFilterUpdateValue,
          value: this.tgtPattern,
          disabled: this.mergedDisabled,
          placeholder: this.targetFilterPlaceholder,
          onFocus: this.handleInputFocus,
          onBlur: this.handleInputBlur
        }) : null, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-legacy-transfer-list-flex-container`
        }, /* @__PURE__ */ React.createElement(NTransferList$1, {
          options: this.filteredTgtOpts,
          disabled: this.mergedDisabled,
          virtualScroll: this.virtualScroll,
          isMounted: this.isMounted,
          isInputing: this.isInputing,
          itemSize: this.itemSize
        }))), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-legacy-transfer-list__border`
        })));
      }
    });

    var style$x = c$1([cB("list", `
    --n-merged-border-color: var(--n-border-color);
    --n-merged-color: var(--n-color);
    --n-merged-color-hover: var(--n-color-hover);
    margin: 0;
    font-size: var(--n-font-size);
    transition:
      background-color .3s var(--n-bezier),
      color .3s var(--n-bezier),
      border-color .3s var(--n-bezier);
    padding: 0;
    list-style-type: none;
    color: var(--n-text-color);
    background-color: var(--n-merged-color);
  `, [cM("show-divider", [cB("list-item", [c$1("&:not(:last-child)", [cE("divider", `
            background-color: var(--n-merged-border-color);
          `)])])]), cM("clickable", [cB("list-item", `
        cursor: pointer;
      `)]), cM("bordered", `
      border: 1px solid var(--n-merged-border-color);
      border-radius: var(--n-border-radius);
    `), cM("hoverable", [cB("list-item", `
        border-radius: var(--n-border-radius);
      `, [c$1("&:hover", `
          background-color: var(--n-merged-color-hover);
        `, [cE("divider", `
            background-color: transparent;
          `)])])]), cM("bordered, hoverable", [cB("list-item", `
        padding: 12px 20px;
      `), cE("header, footer", `
        padding: 12px 20px;
      `)]), cE("header, footer", `
      padding: 12px 0;
      box-sizing: border-box;
      transition: border-color .3s var(--n-bezier);
    `, [c$1("&:not(:last-child)", `
        border-bottom: 1px solid var(--n-merged-border-color);
      `)]), cB("list-item", `
      position: relative;
      padding: 12px 0;    
      box-sizing: border-box;
      display: flex;
      flex-wrap: nowrap;
      align-items: center;
      transition:
        background-color .3s var(--n-bezier),
        border-color .3s var(--n-bezier);
    `, [cE("prefix", `
        margin-right: 20px;
        flex: 0;
      `), cE("suffix", `
        margin-left: 20px;
        flex: 0;
      `), cE("main", `
        flex: 1;
      `), cE("divider", `
        height: 1px;
        position: absolute;
        bottom: 0;
        left: 0;
        right: 0;
        background-color: transparent;
        transition: background-color .3s var(--n-bezier);
        pointer-events: none;
      `)])]), insideModal(cB("list", `
      --n-merged-color-hover: var(--n-color-hover-modal);
      --n-merged-color: var(--n-color-modal);
      --n-merged-border-color: var(--n-border-color-modal);
    `)), insidePopover(cB("list", `
      --n-merged-color-hover: var(--n-color-hover-popover);
      --n-merged-color: var(--n-color-popover);
      --n-merged-border-color: var(--n-border-color-popover);
    `))]);

    const listProps = {
      ...useTheme.props,
      size: {
        type: String,
        default: "medium"
      },
      bordered: Boolean,
      clickable: Boolean,
      hoverable: Boolean,
      showDivider: {
        type: Boolean,
        default: true
      }
    };
    const listInjectionKey = createInjectionKey("n-list");
    var List = vue.defineComponent({
      name: "List",
      props: listProps,
      setup(props) {
        const { mergedClsPrefixRef, inlineThemeDisabled, mergedRtlRef } = useConfig(props);
        const rtlEnabledRef = useRtl("List", mergedRtlRef, mergedClsPrefixRef);
        const themeRef = useTheme(
          "List",
          "-list",
          style$x,
          listLight$1,
          props,
          mergedClsPrefixRef
        );
        vue.provide(listInjectionKey, {
          showDividerRef: vue.toRef(props, "showDivider"),
          mergedClsPrefixRef
        });
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self: {
              fontSize,
              textColor,
              color,
              colorModal,
              colorPopover,
              borderColor,
              borderColorModal,
              borderColorPopover,
              borderRadius,
              colorHover,
              colorHoverModal,
              colorHoverPopover
            }
          } = themeRef.value;
          return {
            "--n-font-size": fontSize,
            "--n-bezier": cubicBezierEaseInOut,
            "--n-text-color": textColor,
            "--n-color": color,
            "--n-border-radius": borderRadius,
            "--n-border-color": borderColor,
            "--n-border-color-modal": borderColorModal,
            "--n-border-color-popover": borderColorPopover,
            "--n-color-modal": colorModal,
            "--n-color-popover": colorPopover,
            "--n-color-hover": colorHover,
            "--n-color-hover-modal": colorHoverModal,
            "--n-color-hover-popover": colorHoverPopover
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("list", void 0, cssVarsRef, props) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          rtlEnabled: rtlEnabledRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { $slots, mergedClsPrefix, onRender } = this;
        onRender?.();
        return /* @__PURE__ */ React.createElement("ul", {
          class: [
            `${mergedClsPrefix}-list`,
            this.rtlEnabled && `${mergedClsPrefix}-list--rtl`,
            this.bordered && `${mergedClsPrefix}-list--bordered`,
            this.showDivider && `${mergedClsPrefix}-list--show-divider`,
            this.hoverable && `${mergedClsPrefix}-list--hoverable`,
            this.clickable && `${mergedClsPrefix}-list--clickable`,
            this.themeClass
          ],
          style: this.cssVars
        }, $slots.header ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-list__header`
        }, $slots.header()) : null, $slots.default?.(), $slots.footer ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-list__footer`
        }, $slots.footer()) : null);
      }
    });

    var ListItem = vue.defineComponent({
      name: "ListItem",
      setup() {
        const listInjection = vue.inject(listInjectionKey, null);
        if (!listInjection) {
          throwError("list-item", "`n-list-item` must be placed in `n-list`.");
        }
        return {
          showDivider: listInjection.showDividerRef,
          mergedClsPrefix: listInjection.mergedClsPrefixRef
        };
      },
      render() {
        const { $slots, mergedClsPrefix } = this;
        return /* @__PURE__ */ React.createElement("li", {
          class: `${mergedClsPrefix}-list-item`
        }, $slots.prefix ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-list-item__prefix`
        }, $slots.prefix()) : null, $slots.default ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-list-item__main`
        }, $slots) : null, $slots.suffix ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-list-item__suffix`
        }, $slots.suffix()) : null, this.showDivider && /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-list-item__divider`
        }));
      }
    });

    const loadingBarProviderInjectionKey = createInjectionKey("n-loading-bar");
    const loadingBarApiInjectionKey = createInjectionKey("n-loading-bar-api");

    var style$w = cB("loading-bar-container", `
  z-index: 5999;
  position: fixed;
  top: 0;
  left: 0;
  right: 0;
  height: 2px;
`, [fadeInTransition({
      enterDuration: "0.3s",
      leaveDuration: "0.8s"
    }), cB("loading-bar", `
    width: 100%;
    transition:
      max-width 4s linear,
      background .2s linear;
    height: var(--n-height);
  `, [cM("starting", `
      background: var(--n-color-loading);
    `), cM("finishing", `
      background: var(--n-color-loading);
      transition:
        max-width .2s linear,
        background .2s linear;
    `), cM("error", `
      background: var(--n-color-error);
      transition:
        max-width .2s linear,
        background .2s linear;
    `)])]);

    function createClassName(status, clsPrefix) {
      return `${clsPrefix}-loading-bar ${clsPrefix}-loading-bar--${status}`;
    }
    var NLoadingBar = vue.defineComponent({
      name: "LoadingBar",
      setup(props) {
        const { inlineThemeDisabled } = useConfig();
        const {
          props: providerProps,
          mergedClsPrefixRef
        } = vue.inject(loadingBarProviderInjectionKey);
        const loadingBarRef = vue.ref(null);
        const enteringRef = vue.ref(false);
        const startedRef = vue.ref(false);
        const loadingRef = vue.ref(false);
        const transitionDisabledRef = vue.ref(false);
        let finishing = false;
        const erroringRef = vue.ref(false);
        const mergedLoadingBarStyle = vue.computed(() => {
          const { loadingBarStyle } = providerProps;
          if (!loadingBarStyle)
            return "";
          return loadingBarStyle[erroringRef.value ? "error" : "loading"];
        });
        async function init() {
          enteringRef.value = false;
          loadingRef.value = false;
          finishing = false;
          erroringRef.value = false;
          transitionDisabledRef.value = true;
          await vue.nextTick();
          transitionDisabledRef.value = false;
        }
        async function start(fromProgress = 0, toProgress = 80, status = "starting") {
          await init();
          loadingRef.value = true;
          startedRef.value = true;
          await vue.nextTick();
          const el = loadingBarRef.value;
          if (!el)
            return;
          el.style.maxWidth = `${fromProgress}%`;
          el.style.transition = "none";
          void el.offsetWidth;
          el.className = createClassName(status, mergedClsPrefixRef.value);
          el.style.transition = "";
          el.style.maxWidth = `${toProgress}%`;
        }
        function finish() {
          if (finishing || erroringRef.value || !loadingRef.value)
            return;
          finishing = true;
          const el = loadingBarRef.value;
          if (!el)
            return;
          el.className = createClassName("finishing", mergedClsPrefixRef.value);
          el.style.maxWidth = "100%";
          void el.offsetWidth;
          loadingRef.value = false;
        }
        function error() {
          if (finishing || erroringRef.value)
            return;
          if (!loadingRef.value) {
            void start(100, 100, "error").then(() => {
              erroringRef.value = true;
              const el = loadingBarRef.value;
              if (!el)
                return;
              el.className = createClassName("error", mergedClsPrefixRef.value);
              void el.offsetWidth;
              loadingRef.value = false;
            });
          } else {
            erroringRef.value = true;
            const el = loadingBarRef.value;
            if (!el)
              return;
            el.className = createClassName("error", mergedClsPrefixRef.value);
            el.style.maxWidth = "100%";
            void el.offsetWidth;
            loadingRef.value = false;
          }
        }
        function handleEnter() {
          enteringRef.value = true;
        }
        function handleAfterEnter() {
          enteringRef.value = false;
        }
        async function handleAfterLeave() {
          await init();
        }
        const themeRef = useTheme(
          "LoadingBar",
          "-loading-bar",
          style$w,
          loadingBarLight$1,
          providerProps,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const {
            self: { height, colorError, colorLoading }
          } = themeRef.value;
          return {
            "--n-height": height,
            "--n-color-loading": colorLoading,
            "--n-color-error": colorError
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("loading-bar", void 0, cssVarsRef, providerProps) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          loadingBarRef,
          started: startedRef,
          loading: loadingRef,
          entering: enteringRef,
          transitionDisabled: transitionDisabledRef,
          start,
          error,
          finish,
          handleEnter,
          handleAfterEnter,
          handleAfterLeave,
          mergedLoadingBarStyle,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        if (!this.started)
          return null;
        const { mergedClsPrefix } = this;
        return /* @__PURE__ */ React.createElement(vue.Transition, {
          name: "fade-in-transition",
          appear: true,
          onEnter: this.handleEnter,
          onAfterEnter: this.handleAfterEnter,
          onAfterLeave: this.handleAfterLeave,
          css: !this.transitionDisabled
        }, {
          default: () => {
            this.onRender?.();
            return vue.withDirectives(
              /* @__PURE__ */ React.createElement("div", {
                class: [
                  `${mergedClsPrefix}-loading-bar-container`,
                  this.themeClass
                ]
              }, /* @__PURE__ */ React.createElement("div", {
                ref: "loadingBarRef",
                class: [`${mergedClsPrefix}-loading-bar`],
                style: [
                  this.cssVars,
                  this.mergedLoadingBarStyle
                ]
              })),
              [[vue.vShow, this.loading || !this.loading && this.entering]]
            );
          }
        });
      }
    });

    const loadingBarProviderProps = {
      ...useTheme.props,
      to: {
        type: [String, Object],
        default: void 0
      },
      loadingBarStyle: {
        type: Object
      }
    };
    var NLoadingBarProvider = vue.defineComponent({
      name: "LoadingBarProvider",
      props: loadingBarProviderProps,
      setup(props) {
        const isMountedRef = isMounted();
        const loadingBarRef = vue.ref(null);
        const methods = {
          start() {
            if (isMountedRef.value) {
              loadingBarRef.value?.start();
            } else {
              void vue.nextTick(() => {
                loadingBarRef.value?.start();
              });
            }
          },
          error() {
            if (isMountedRef.value) {
              loadingBarRef.value?.error();
            } else {
              void vue.nextTick(() => {
                loadingBarRef.value?.error();
              });
            }
          },
          finish() {
            if (isMountedRef.value) {
              loadingBarRef.value?.finish();
            } else {
              void vue.nextTick(() => {
                loadingBarRef.value?.finish();
              });
            }
          }
        };
        const { mergedClsPrefixRef } = useConfig(props);
        vue.provide(loadingBarApiInjectionKey, methods);
        vue.provide(loadingBarProviderInjectionKey, {
          props,
          mergedClsPrefixRef
        });
        return Object.assign(methods, {
          loadingBarRef
        });
      },
      render() {
        return /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(vue.Teleport, {
          to: this.to ?? "body"
        }, /* @__PURE__ */ React.createElement(NLoadingBar, {
          ref: "loadingBarRef"
        })), this.$slots.default?.());
      }
    });

    function useLoadingBar() {
      const loadingBar = vue.inject(loadingBarApiInjectionKey, null);

      if (loadingBar === null) {
        throwError("use-loading-bar", "No outer <n-loading-bar-provider /> founded.");
      }

      return loadingBar;
    }

    var NLogLoader = vue.defineComponent({
      name: "LogLoader",
      props: {
        clsPrefix: {
          type: String,
          required: true
        }
      },
      setup() {
        return {
          locale: useLocale("Log").localeRef
        };
      },
      render() {
        const { clsPrefix } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-log-loader`
        }, /* @__PURE__ */ React.createElement(NBaseLoading, {
          clsPrefix,
          strokeWidth: 24,
          scale: 0.85
        }), /* @__PURE__ */ React.createElement("span", {
          class: `${clsPrefix}-log-loader__content`
        }, this.locale.loading));
      }
    });

    const logInjectionKey = createInjectionKey("n-log");

    var NLogLine = vue.defineComponent({
      props: {
        line: {
          type: String,
          default: ""
        }
      },
      setup(props) {
        const { trimRef, highlightRef, languageRef, mergedHljsRef } = vue.inject(logInjectionKey);
        const selfRef = vue.ref(null);
        const maybeTrimmedLinesRef = vue.computed(() => {
          return trimRef.value ? props.line.trim() : props.line;
        });
        function setInnerHTML() {
          if (selfRef.value) {
            selfRef.value.innerHTML = generateCodeHTML(
              languageRef.value,
              maybeTrimmedLinesRef.value
            );
          }
        }
        function generateCodeHTML(language, code) {
          const { value: hljs } = mergedHljsRef;
          if (hljs) {
            if (language && hljs.getLanguage(language)) {
              return hljs.highlight(code, { language }).value;
            }
          }
          return code;
        }
        vue.onMounted(() => {
          if (highlightRef.value) {
            setInnerHTML();
          }
        });
        vue.watch(vue.toRef(props, "line"), () => {
          if (highlightRef.value) {
            setInnerHTML();
          }
        });
        return {
          highlight: highlightRef,
          selfRef,
          maybeTrimmedLines: maybeTrimmedLinesRef
        };
      },
      render() {
        const { highlight, maybeTrimmedLines } = this;
        return /* @__PURE__ */ React.createElement("pre", {
          ref: "selfRef"
        }, highlight ? null : maybeTrimmedLines);
      }
    });

    var style$v = cB("log", `
  position: relative;
  box-sizing: border-box;
  transition: border-color .3s var(--n-bezier);
`, [c$1("pre", `
    white-space: pre-wrap;
    word-break: break-word;
    margin: 0;
  `), cB("log-loader", `
    transition:
      color .3s var(--n-bezier),
      background-color .3s var(--n-bezier),
      border-color .3s var(--n-bezier);
    box-sizing: border-box;
    position: absolute;
    right: 16px;
    top: 8px;
    height: 34px;
    border-radius: 17px;
    line-height: 34px;
    white-space: nowrap;
    overflow: hidden;
    border: var(--n-loader-border);
    color: var(--n-loader-text-color);
    background-color: var(--n-loader-color);
    font-size: var(--n-loader-font-size);
  `, [fadeInScaleUpTransition(), cE("content", `
      display: inline-block;
      vertical-align: bottom;
      line-height: 34px;
      padding-left: 40px;
      padding-right: 20px;
      white-space: nowrap;
    `), cB("base-loading", `
      color: var(--n-loading-color);
      position: absolute;
      left: 12px;
      top: calc(50% - 10px);
      font-size: 20px;
      width: 20px;
      height: 20px;
      display: inline-block;
    `)])]);

    const logProps = {
      ...useTheme.props,
      loading: Boolean,
      trim: Boolean,
      log: String,
      fontSize: {
        type: Number,
        default: 14
      },
      lines: {
        type: Array,
        default: () => []
      },
      lineHeight: {
        type: Number,
        default: 1.25
      },
      language: String,
      rows: {
        type: Number,
        default: 15
      },
      offsetTop: {
        type: Number,
        default: 0
      },
      offsetBottom: {
        type: Number,
        default: 0
      },
      hljs: Object,
      onReachTop: Function,
      onReachBottom: Function,
      onRequireMore: Function
    };
    var Log = vue.defineComponent({
      name: "Log",
      props: logProps,
      setup(props) {
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const slientRef = vue.ref(false);
        const highlightRef = vue.computed(() => {
          return props.language !== void 0;
        });
        const styleHeightRef = vue.computed(() => {
          return `calc(${Math.round(
        props.rows * props.lineHeight * props.fontSize
      )}px)`;
        });
        const mergedLinesRef = vue.computed(() => {
          const { log } = props;
          if (log) {
            return log.split("\n");
          }
          return props.lines;
        });
        const scrollbarRef = vue.ref(null);
        const themeRef = useTheme(
          "Log",
          "-log",
          style$v,
          logLight$1,
          props,
          mergedClsPrefixRef
        );
        function handleScroll(e) {
          const container = e.target;
          const content = container.firstElementChild;
          if (slientRef.value) {
            void vue.nextTick(() => {
              slientRef.value = false;
            });
            return;
          }
          const containerHeight = container.offsetHeight;
          const containerScrollTop = container.scrollTop;
          const contentHeight = content.offsetHeight;
          const scrollTop = containerScrollTop;
          const scrollBottom = contentHeight - containerScrollTop - containerHeight;
          if (scrollTop <= props.offsetTop) {
            const { onReachTop, onRequireMore } = props;
            if (onRequireMore)
              onRequireMore("top");
            if (onReachTop)
              onReachTop();
          }
          if (scrollBottom <= props.offsetBottom) {
            const { onReachBottom, onRequireMore } = props;
            if (onRequireMore)
              onRequireMore("bottom");
            if (onReachBottom)
              onReachBottom();
          }
        }
        const handleWheel = lodash.exports.throttle(_handleWheel, 300);
        function _handleWheel(e) {
          if (slientRef.value) {
            void vue.nextTick(() => {
              slientRef.value = false;
            });
            return;
          }
          if (scrollbarRef.value) {
            const { containerRef, contentRef } = scrollbarRef.value;
            if (containerRef && contentRef) {
              const containerHeight = containerRef.offsetHeight;
              const containerScrollTop = containerRef.scrollTop;
              const contentHeight = contentRef.offsetHeight;
              const scrollTop = containerScrollTop;
              const scrollBottom = contentHeight - containerScrollTop - containerHeight;
              const deltaY = e.deltaY;
              if (scrollTop === 0 && deltaY < 0) {
                const { onRequireMore } = props;
                if (onRequireMore)
                  onRequireMore("top");
              }
              if (scrollBottom <= 0 && deltaY > 0) {
                const { onRequireMore } = props;
                if (onRequireMore)
                  onRequireMore("bottom");
              }
            }
          }
        }
        function scrollTo(options) {
          const { value: scrollbarInst } = scrollbarRef;
          if (!scrollbarInst)
            return;
          const { slient, top, position } = options;
          if (slient) {
            slientRef.value = true;
          }
          if (top !== void 0) {
            scrollbarInst.scrollTo({ left: 0, top });
          } else if (position === "bottom" || position === "top") {
            scrollbarInst.scrollTo({ position });
          }
        }
        function scrollToTop(slient = false) {
          warn$2(
            "log",
            "`scrollToTop` is deprecated, please use `scrollTo({ position: 'top'})` instead."
          );
          scrollTo({
            position: "top",
            slient
          });
        }
        function scrollToBottom(slient = false) {
          warn$2(
            "log",
            "`scrollToTop` is deprecated, please use `scrollTo({ position: 'bottom'})` instead."
          );
          scrollTo({
            position: "bottom",
            slient
          });
        }
        vue.provide(logInjectionKey, {
          languageRef: vue.toRef(props, "language"),
          mergedHljsRef: useHljs(props, highlightRef),
          trimRef: vue.toRef(props, "trim"),
          highlightRef
        });
        const exportedMethods = {
          scrollTo
        };
        const cssVarsRef = vue.computed(() => {
          const {
            self: {
              loaderFontSize,
              loaderTextColor,
              loaderColor,
              loaderBorder,
              loadingColor
            },
            common: { cubicBezierEaseInOut }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-loader-font-size": loaderFontSize,
            "--n-loader-border": loaderBorder,
            "--n-loader-color": loaderColor,
            "--n-loader-text-color": loaderTextColor,
            "--n-loading-color": loadingColor
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("log", void 0, cssVarsRef, props) : void 0;
        return {
          ...exportedMethods,
          mergedClsPrefix: mergedClsPrefixRef,
          scrollbarRef,
          mergedTheme: themeRef,
          styleHeight: styleHeightRef,
          mergedLines: mergedLinesRef,
          scrollToTop,
          scrollToBottom,
          handleWheel,
          handleScroll,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedClsPrefix, mergedTheme, onRender } = this;
        onRender?.();
        return vue.h(
          "div",
          {
            class: [`${mergedClsPrefix}-log`, this.themeClass],
            style: [
              {
                lineHeight: this.lineHeight,
                height: this.styleHeight
              },
              this.cssVars
            ],
            onWheelPassive: this.handleWheel
          },
          [
            /* @__PURE__ */ React.createElement(NScrollbar, {
              ref: "scrollbarRef",
              theme: mergedTheme.peers.Scrollbar,
              themeOverrides: mergedTheme.peerOverrides.Scrollbar,
              onScroll: this.handleScroll
            }, {
              default: () => /* @__PURE__ */ React.createElement(NCode, {
                internalNoHighlight: true,
                internalFontSize: this.fontSize,
                theme: mergedTheme.peers.Code,
                themeOverrides: mergedTheme.peerOverrides.Code
              }, {
                default: () => this.mergedLines.map((line, index) => {
                  return /* @__PURE__ */ React.createElement(NLogLine, {
                    key: index,
                    line
                  });
                })
              })
            }),
            /* @__PURE__ */ React.createElement(vue.Transition, {
              name: "fade-in-scale-up-transition"
            }, {
              default: () => this.loading ? /* @__PURE__ */ React.createElement(NLogLoader, {
                clsPrefix: mergedClsPrefix
              }) : null
            })
          ]
        );
      }
    });

    const menuInjectionKey = createInjectionKey("n-menu");
    const submenuInjectionKey = createInjectionKey("n-submenu");
    const menuItemGroupInjectionKey = createInjectionKey("n-menu-item-group");

    const ICON_MARGIN_RIGHT = 8;
    function useMenuChild(props) {
      const NMenu = vue.inject(menuInjectionKey);
      const {
        props: menuProps,
        mergedCollapsedRef
      } = NMenu;
      const NSubmenu = vue.inject(submenuInjectionKey, null);
      const NMenuOptionGroup = vue.inject(menuItemGroupInjectionKey, null);
      const horizontalRef = vue.computed(() => {
        return menuProps.mode === "horizontal";
      });
      const dropdownPlacementRef = vue.computed(() => {
        if (horizontalRef.value) {
          return menuProps.dropdownPlacement;
        }

        if ("tmNodes" in props) return "right-start";
        return "right";
      });
      const maxIconSizeRef = vue.computed(() => {
        return Math.max(menuProps.collapsedIconSize ?? menuProps.iconSize, menuProps.iconSize);
      });
      const activeIconSizeRef = vue.computed(() => {
        if (!horizontalRef.value && props.root && mergedCollapsedRef.value) {
          return menuProps.collapsedIconSize ?? menuProps.iconSize;
        } else {
          return menuProps.iconSize;
        }
      });
      const paddingLeftRef = vue.computed(() => {
        if (horizontalRef.value) return void 0;
        const {
          collapsedWidth,
          indent,
          rootIndent
        } = menuProps;
        const {
          root,
          isGroup
        } = props;
        const mergedRootIndent = rootIndent === void 0 ? indent : rootIndent;

        if (root) {
          if (mergedCollapsedRef.value) {
            return collapsedWidth / 2 - maxIconSizeRef.value / 2;
          }

          return mergedRootIndent;
        }

        if (NMenuOptionGroup) {
          return indent / 2 + NMenuOptionGroup.paddingLeftRef.value;
        }

        if (NSubmenu) {
          return (isGroup ? indent / 2 : indent) + NSubmenu.paddingLeftRef.value;
        }

        return void 0;
      });
      const iconMarginRightRef = vue.computed(() => {
        const {
          collapsedWidth,
          indent,
          rootIndent
        } = menuProps;
        const {
          value: maxIconSize
        } = maxIconSizeRef;
        const {
          root
        } = props;
        if (horizontalRef.value) return ICON_MARGIN_RIGHT;
        if (!root) return ICON_MARGIN_RIGHT;
        if (!mergedCollapsedRef.value) return ICON_MARGIN_RIGHT;
        const mergedRootIndent = rootIndent === void 0 ? indent : rootIndent;
        return mergedRootIndent + maxIconSize + ICON_MARGIN_RIGHT - (collapsedWidth + maxIconSize) / 2;
      });
      return {
        dropdownPlacement: dropdownPlacementRef,
        activeIconSize: activeIconSizeRef,
        maxIconSize: maxIconSizeRef,
        paddingLeft: paddingLeftRef,
        iconMarginRight: iconMarginRightRef,
        NMenu,
        NSubmenu
      };
    }

    const useMenuChildProps = {
      internalKey: {
        type: [String, Number],
        required: true
      },
      root: Boolean,
      isGroup: Boolean,
      level: {
        type: Number,
        required: true
      },
      title: [String, Function],
      extra: [String, Function]
    };

    const menuItemGroupProps = {
      ...useMenuChildProps,
      tmNode: {
        type: Object,
        required: true
      },
      tmNodes: {
        type: Array,
        required: true
      }
    };
    const NMenuOptionGroup = vue.defineComponent({
      name: "MenuOptionGroup",
      props: menuItemGroupProps,
      setup(props) {
        vue.provide(submenuInjectionKey, null);
        const MenuChild = useMenuChild(props);
        vue.provide(menuItemGroupInjectionKey, {
          paddingLeftRef: MenuChild.paddingLeft
        });
        const { mergedClsPrefixRef, props: menuProps } = vue.inject(menuInjectionKey);
        return function() {
          const { value: mergedClsPrefix } = mergedClsPrefixRef;
          const paddingLeft = MenuChild.paddingLeft.value;
          const { nodeProps } = menuProps;
          const attrs = nodeProps?.(props.tmNode.rawNode);
          return /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-menu-item-group`,
            role: "group"
          }, /* @__PURE__ */ React.createElement("div", {
            ...attrs,
            class: [`${mergedClsPrefix}-menu-item-group-title`, attrs?.class],
            style: [
              attrs?.style || "",
              paddingLeft !== void 0 ? `padding-left: ${paddingLeft}px;` : ""
            ]
          }, render$1(props.title), props.extra ? /* @__PURE__ */ React.createElement(React.Fragment, null, " ", render$1(props.extra)) : null), /* @__PURE__ */ React.createElement("div", null, props.tmNodes.map((tmNode) => itemRenderer(tmNode, menuProps))));
        };
      }
    });

    var NMenuOptionContent = vue.defineComponent({
      name: "MenuOptionContent",
      props: {
        collapsed: Boolean,
        disabled: Boolean,
        title: [String, Function],
        icon: Function,
        extra: [String, Function],
        showArrow: Boolean,
        childActive: Boolean,
        hover: Boolean,
        paddingLeft: Number,
        selected: Boolean,
        maxIconSize: {
          type: Number,
          required: true
        },
        activeIconSize: {
          type: Number,
          required: true
        },
        iconMarginRight: {
          type: Number,
          required: true
        },
        clsPrefix: {
          type: String,
          required: true
        },
        onClick: Function,
        tmNode: {
          type: Object,
          required: true
        }
      },
      setup(props) {
        const { props: menuProps } = vue.inject(menuInjectionKey);
        return {
          menuProps,
          style: vue.computed(() => {
            const { paddingLeft } = props;
            return { paddingLeft: paddingLeft && `${paddingLeft}px` };
          }),
          iconStyle: vue.computed(() => {
            const { maxIconSize, activeIconSize, iconMarginRight } = props;
            return {
              width: `${maxIconSize}px`,
              height: `${maxIconSize}px`,
              fontSize: `${activeIconSize}px`,
              marginRight: `${iconMarginRight}px`
            };
          })
        };
      },
      render() {
        const {
          clsPrefix,
          tmNode,
          menuProps: { renderIcon, renderLabel, renderExtra, expandIcon }
        } = this;
        const icon = renderIcon ? renderIcon(tmNode.rawNode) : render$1(this.icon);
        return /* @__PURE__ */ React.createElement("div", {
          onClick: (e) => {
            this.onClick?.(e);
          },
          role: "none",
          class: [
            `${clsPrefix}-menu-item-content`,
            {
              [`${clsPrefix}-menu-item-content--selected`]: this.selected,
              [`${clsPrefix}-menu-item-content--collapsed`]: this.collapsed,
              [`${clsPrefix}-menu-item-content--child-active`]: this.childActive,
              [`${clsPrefix}-menu-item-content--disabled`]: this.disabled,
              [`${clsPrefix}-menu-item-content--hover`]: this.hover
            }
          ],
          style: this.style
        }, icon && /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-menu-item-content__icon`,
          style: this.iconStyle,
          role: "none"
        }, [icon]), /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-menu-item-content-header`,
          role: "none"
        }, renderLabel ? renderLabel(tmNode.rawNode) : render$1(this.title), this.extra || renderExtra ? /* @__PURE__ */ React.createElement("span", {
          class: `${clsPrefix}-menu-item-content-header__extra`
        }, " ", renderExtra ? renderExtra(tmNode.rawNode) : render$1(this.extra)) : null), this.showArrow ? /* @__PURE__ */ React.createElement(NBaseIcon, {
          ariaHidden: true,
          class: `${clsPrefix}-menu-item-content__arrow`,
          clsPrefix
        }, {
          default: () => expandIcon ? expandIcon(tmNode.rawNode) : /* @__PURE__ */ React.createElement(ChevronDownFilledIcon, null)
        }) : null);
      }
    });

    const submenuProps = {
      ...useMenuChildProps,
      rawNodes: {
        type: Array,
        default: () => []
      },
      tmNodes: {
        type: Array,
        default: () => []
      },
      tmNode: {
        type: Object,
        required: true
      },
      disabled: {
        type: Boolean,
        default: false
      },
      icon: Function,
      onClick: Function
    };
    const NSubmenu = vue.defineComponent({
      name: "Submenu",
      props: submenuProps,
      setup(props) {
        const MenuChild = useMenuChild(props);
        const { NMenu, NSubmenu: NSubmenu2 } = MenuChild;
        const { props: menuProps, mergedCollapsedRef, mergedThemeRef } = NMenu;
        const mergedDisabledRef = vue.computed(() => {
          const { disabled } = props;
          if (NSubmenu2?.mergedDisabledRef.value)
            return true;
          if (menuProps.disabled)
            return true;
          return disabled;
        });
        const dropdownShowRef = vue.ref(false);
        vue.provide(submenuInjectionKey, {
          paddingLeftRef: MenuChild.paddingLeft,
          mergedDisabledRef
        });
        vue.provide(menuItemGroupInjectionKey, null);
        function doClick() {
          const { onClick } = props;
          if (onClick)
            onClick();
        }
        function handleClick() {
          if (!mergedDisabledRef.value) {
            if (!mergedCollapsedRef.value) {
              NMenu.toggleExpand(props.internalKey);
            }
            doClick();
          }
        }
        function handlePopoverShowChange(value) {
          dropdownShowRef.value = value;
        }
        return {
          menuProps,
          mergedTheme: mergedThemeRef,
          doSelect: NMenu.doSelect,
          inverted: NMenu.invertedRef,
          isHorizontal: NMenu.isHorizontalRef,
          mergedClsPrefix: NMenu.mergedClsPrefixRef,
          maxIconSize: MenuChild.maxIconSize,
          activeIconSize: MenuChild.activeIconSize,
          iconMarginRight: MenuChild.iconMarginRight,
          dropdownPlacement: MenuChild.dropdownPlacement,
          dropdownShow: dropdownShowRef,
          paddingLeft: MenuChild.paddingLeft,
          mergedDisabled: mergedDisabledRef,
          mergedValue: NMenu.mergedValueRef,
          childActive: useMemo(() => {
            return NMenu.activePathRef.value.includes(props.internalKey);
          }),
          collapsed: vue.computed(() => {
            if (menuProps.mode === "horizontal")
              return false;
            if (mergedCollapsedRef.value) {
              return true;
            }
            return !NMenu.mergedExpandedKeysRef.value.includes(props.internalKey);
          }),
          dropdownEnabled: vue.computed(() => {
            return !mergedDisabledRef.value && (menuProps.mode === "horizontal" || mergedCollapsedRef.value);
          }),
          handlePopoverShowChange,
          handleClick
        };
      },
      render() {
        const {
          mergedClsPrefix,
          menuProps: { renderIcon, renderLabel }
        } = this;
        const createSubmenuItem = () => {
          const {
            isHorizontal,
            paddingLeft,
            collapsed,
            mergedDisabled,
            maxIconSize,
            activeIconSize,
            title,
            childActive,
            icon,
            handleClick,
            menuProps: { nodeProps },
            dropdownShow,
            iconMarginRight,
            tmNode,
            mergedClsPrefix: mergedClsPrefix2
          } = this;
          const attrs = nodeProps?.(tmNode.rawNode);
          return /* @__PURE__ */ React.createElement("div", {
            ...attrs,
            class: [`${mergedClsPrefix2}-menu-item`, attrs?.class],
            role: "menuitem"
          }, /* @__PURE__ */ React.createElement(NMenuOptionContent, {
            tmNode,
            paddingLeft,
            collapsed,
            disabled: mergedDisabled,
            iconMarginRight,
            maxIconSize,
            activeIconSize,
            title,
            extra: this.extra,
            showArrow: !isHorizontal,
            childActive,
            clsPrefix: mergedClsPrefix2,
            icon,
            hover: dropdownShow,
            onClick: handleClick
          }));
        };
        const createSubmenuChildren = () => {
          return /* @__PURE__ */ React.createElement(NFadeInExpandTransition, null, {
            default: () => {
              const { tmNodes, collapsed } = this;
              return !collapsed ? /* @__PURE__ */ React.createElement("div", {
                class: `${mergedClsPrefix}-submenu-children`,
                role: "menu"
              }, tmNodes.map((item) => itemRenderer(item, this.menuProps))) : null;
            }
          });
        };
        return this.root ? /* @__PURE__ */ React.createElement(NDropdown, {
          size: "large",
          ...this.menuProps?.dropdownProps,
          themeOverrides: this.mergedTheme.peerOverrides.Dropdown,
          theme: this.mergedTheme.peers.Dropdown,
          builtinThemeOverrides: {
            fontSizeLarge: "14px",
            optionIconSizeLarge: "18px"
          },
          value: this.mergedValue,
          trigger: "hover",
          disabled: !this.dropdownEnabled,
          placement: this.dropdownPlacement,
          keyField: this.menuProps.keyField,
          labelField: this.menuProps.labelField,
          childrenField: this.menuProps.childrenField,
          onUpdateShow: this.handlePopoverShowChange,
          options: this.rawNodes,
          onSelect: this.doSelect,
          inverted: this.inverted,
          renderIcon,
          renderLabel
        }, {
          default: () => /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-submenu`,
            role: "menuitem",
            "aria-expanded": !this.collapsed
          }, createSubmenuItem(), this.isHorizontal ? null : createSubmenuChildren())
        }) : /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-submenu`,
          role: "menuitem",
          "aria-expanded": !this.collapsed
        }, createSubmenuItem(), createSubmenuChildren());
      }
    });

    const menuItemProps = {
      ...useMenuChildProps,
      tmNode: {
        type: Object,
        required: true
      },
      disabled: Boolean,
      icon: Function,
      onClick: Function
    };
    const NMenuOption = vue.defineComponent({
      name: "MenuOption",
      props: menuItemProps,
      setup(props) {
        const MenuChild = useMenuChild(props);
        const { NSubmenu, NMenu } = MenuChild;
        const { props: menuProps, mergedClsPrefixRef, mergedCollapsedRef } = NMenu;
        const submenuDisabledRef = NSubmenu ? NSubmenu.mergedDisabledRef : { value: false };
        const mergedDisabledRef = vue.computed(() => {
          return submenuDisabledRef.value || props.disabled;
        });
        function doClick(e) {
          const { onClick } = props;
          if (onClick)
            onClick(e);
        }
        function handleClick(e) {
          if (!mergedDisabledRef.value) {
            NMenu.doSelect(props.internalKey, props.tmNode.rawNode);
            doClick(e);
          }
        }
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          dropdownPlacement: MenuChild.dropdownPlacement,
          paddingLeft: MenuChild.paddingLeft,
          iconMarginRight: MenuChild.iconMarginRight,
          maxIconSize: MenuChild.maxIconSize,
          activeIconSize: MenuChild.activeIconSize,
          mergedTheme: NMenu.mergedThemeRef,
          menuProps,
          dropdownEnabled: useMemo(() => {
            return props.root && mergedCollapsedRef.value && menuProps.mode !== "horizontal" && !mergedDisabledRef.value;
          }),
          selected: vue.computed(() => {
            if (NMenu.mergedValueRef.value === props.internalKey)
              return true;
            return false;
          }),
          mergedDisabled: mergedDisabledRef,
          handleClick
        };
      },
      render() {
        const {
          mergedClsPrefix,
          mergedTheme,
          tmNode,
          menuProps: { renderLabel, nodeProps }
        } = this;
        const attrs = nodeProps?.(tmNode.rawNode);
        return /* @__PURE__ */ React.createElement("div", {
          ...attrs,
          role: "menuitem",
          class: [`${mergedClsPrefix}-menu-item`, attrs?.class]
        }, /* @__PURE__ */ React.createElement(NTooltip, {
          theme: mergedTheme.peers.Tooltip,
          themeOverrides: mergedTheme.peerOverrides.Tooltip,
          trigger: "hover",
          placement: this.dropdownPlacement,
          disabled: !this.dropdownEnabled || this.title === void 0,
          internalExtraClass: ["menu-tooltip"]
        }, {
          default: () => renderLabel ? renderLabel(tmNode.rawNode) : render$1(this.title),
          trigger: () => /* @__PURE__ */ React.createElement(NMenuOptionContent, {
            tmNode,
            clsPrefix: mergedClsPrefix,
            paddingLeft: this.paddingLeft,
            iconMarginRight: this.iconMarginRight,
            maxIconSize: this.maxIconSize,
            activeIconSize: this.activeIconSize,
            selected: this.selected,
            title: this.title,
            extra: this.extra,
            disabled: this.mergedDisabled,
            icon: this.icon,
            onClick: this.handleClick
          })
        }));
      }
    });

    var NMenuDivider = vue.defineComponent({
      name: "MenuDivider",
      setup() {
        const NMenu = vue.inject(menuInjectionKey);
        const { mergedClsPrefixRef, isHorizontalRef } = NMenu;
        return () => isHorizontalRef.value ? null : /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefixRef.value}-menu-divider`
        });
      }
    });

    const groupPropKeys = keysOf(menuItemGroupProps);
    const itemPropKeys = keysOf(menuItemProps);
    const submenuPropKeys = keysOf(submenuProps);
    function isIgnoredNode(rawNode) {
      return rawNode.type === "divider" || rawNode.type === "render";
    }
    function isDividerNode(rawNode) {
      return rawNode.type === "divider";
    }
    function itemRenderer(tmNode, menuProps) {
      const { rawNode } = tmNode;
      const { show } = rawNode;
      if (typeof show === "boolean" && !show) {
        return null;
      }
      if (isIgnoredNode(rawNode)) {
        if (isDividerNode(rawNode)) {
          return /* @__PURE__ */ React.createElement(NMenuDivider, {
            key: tmNode.key,
            ...rawNode.props
          });
        }
        return null;
      }
      const { labelField } = menuProps;
      const { key, level, isGroup } = tmNode;
      const props = {
        ...rawNode,
        title: rawNode.title || rawNode[labelField],
        extra: rawNode.titleExtra || rawNode.extra,
        key,
        internalKey: key,
        level,
        root: level === 0,
        isGroup
      };
      if (tmNode.children) {
        if (tmNode.isGroup) {
          return vue.h(
            NMenuOptionGroup,
            keep(props, groupPropKeys, { tmNode, tmNodes: tmNode.children, key })
          );
        }
        return vue.h(
          NSubmenu,
          keep(props, submenuPropKeys, {
            key,
            rawNodes: rawNode[menuProps.childrenField],
            tmNodes: tmNode.children,
            tmNode
          })
        );
      } else {
        return vue.h(
          NMenuOption,
          keep(props, itemPropKeys, {
            key,
            tmNode
          })
        );
      }
    }

    const hoverStyleChildren = [c$1("&::before", "background-color: var(--n-item-color-hover);"), cE("arrow", `
    color: var(--n-arrow-color-hover);
  `), cE("icon", `
    color: var(--n-item-icon-color-hover);
  `), cB("menu-item-content-header", `
    color: var(--n-item-text-color-hover);
  `, [c$1("a", `
      color: var(--n-item-text-color-hover);
    `), cE("extra", `
      color: var(--n-item-text-color-hover);
    `)])];
    const horizontalHoverStyleChildren = [cE("icon", `
    color: var(--n-item-icon-color-hover-horizontal);
  `), cB("menu-item-content-header", `
    color: var(--n-item-text-color-hover-horizontal);
  `, [c$1("a", `
      color: var(--n-item-text-color-hover-horizontal);
    `), cE("extra", `
      color: var(--n-item-text-color-hover-horizontal);
    `)])];
    var style$u = c$1([cB("menu", `
    background-color: var(--n-color);
    color: var(--n-item-text-color);
    overflow: hidden;
    transition: background-color .3s var(--n-bezier);
    box-sizing: border-box;
    font-size: var(--n-font-size);
    padding-bottom: 6px;
  `, [cM("horizontal", `
      display: inline-flex;
      padding-bottom: 0;
    `, [cB("submenu", "margin: 0;"), cB("menu-item", "margin: 0;"), cB("menu-item-content", `
        padding: 0 20px;
        border-bottom: 2px solid #0000;
      `, [c$1("&::before", "display: none;"), cM("selected", "border-bottom: 2px solid var(--n-border-color-horizontal)")]), cB("menu-item-content", [cM("selected", [cE("icon", "color: var(--n-item-icon-color-active-horizontal);"), cB("menu-item-content-header", `
            color: var(--n-item-text-color-active-horizontal);
          `, [c$1("a", "color: var(--n-item-text-color-active-horizontal);"), cE("extra", "color: var(--n-item-text-color-active-horizontal);")])]), cM("child-active", `
          border-bottom: 2px solid var(--n-border-color-horizontal);
        `, [cB("menu-item-content-header", `
            color: var(--n-item-text-color-child-active-horizontal);
          `, [c$1("a", `
              color: var(--n-item-text-color-child-active-horizontal);
            `), cE("extra", `
              color: var(--n-item-text-color-child-active-horizontal);
            `)]), cE("icon", `
            color: var(--n-item-icon-color-child-active-horizontal);
          `)]), cNotM("disabled", [cNotM("selected, child-active", [c$1("&:focus-within", horizontalHoverStyleChildren)]), cM("selected", [hoverStyle(null, [cE("icon", "color: var(--n-item-icon-color-active-hover-horizontal);"), cB("menu-item-content-header", `
                color: var(--n-item-text-color-active-hover-horizontal);
              `, [c$1("a", "color: var(--n-item-text-color-active-hover-horizontal);"), cE("extra", "color: var(--n-item-text-color-active-hover-horizontal);")])])]), cM("child-active", [hoverStyle(null, [cE("icon", "color: var(--n-item-icon-color-child-active-hover-horizontal);"), cB("menu-item-content-header", `
                color: var(--n-item-text-color-child-active-hover-horizontal);
              `, [c$1("a", "color: var(--n-item-text-color-child-active-hover-horizontal);"), cE("extra", "color: var(--n-item-text-color-child-active-hover-horizontal);")])])]), hoverStyle("border-bottom: 2px solid var(--n-border-color-horizontal);", horizontalHoverStyleChildren)]), cB("menu-item-content-header", [c$1("a", "color: var(--n-item-text-color-horizontal);")])])]), cM("collapsed", [cB("menu-item-content", [cM("selected", [c$1("&::before", `
            background-color: var(--n-item-color-active-collapsed) !important;
          `)]), cB("menu-item-content-header", "opacity: 0;"), cE("arrow", "opacity: 0;"), cE("icon", "color: var(--n-item-icon-color-collapsed);")])]), cB("menu-item", `
      height: var(--n-item-height);
      margin-top: 6px;
      position: relative;
    `), cB("menu-item-content", `
      box-sizing: border-box;
      line-height: 1.75;
      height: 100%;
      display: grid;
      grid-template-areas: "icon content arrow";
      grid-template-columns: auto 1fr auto;
      align-items: center;
      cursor: pointer;
      position: relative;
      padding-right: 18px;
      transition:
        background-color .3s var(--n-bezier),
        padding-left .3s var(--n-bezier),
        border-color .3s var(--n-bezier);
    `, [c$1("> *", "z-index: 1;"), c$1("&::before", `
        z-index: auto;
        content: "";
        background-color: #0000;
        position: absolute;
        left: 8px;
        right: 8px;
        top: 0;
        bottom: 0;
        pointer-events: none;
        border-radius: var(--n-border-radius);
        transition: background-color .3s var(--n-bezier);
      `), cM("disabled", `
        opacity: .45;
        cursor: not-allowed;
      `), cM("collapsed", [cE("arrow", "transform: rotate(0);")]), cM("selected", [c$1("&::before", "background-color: var(--n-item-color-active);"), cE("arrow", "color: var(--n-arrow-color-active);"), cE("icon", "color: var(--n-item-icon-color-active);"), cB("menu-item-content-header", `
          color: var(--n-item-text-color-active);
        `, [c$1("a", "color: var(--n-item-text-color-active);"), cE("extra", "color: var(--n-item-text-color-active);")])]), cM("child-active", [cB("menu-item-content-header", `
          color: var(--n-item-text-color-child-active);
        `, [c$1("a", `
            color: var(--n-item-text-color-child-active);
          `), cE("extra", `
            color: var(--n-item-text-color-child-active);
          `)]), cE("arrow", `
          color: var(--n-arrow-color-child-active);
        `), cE("icon", `
          color: var(--n-item-icon-color-child-active);
        `)]), cNotM("disabled", [cNotM("selected, child-active", [c$1("&:focus-within", hoverStyleChildren)]), cM("selected", [hoverStyle(null, [cE("arrow", "color: var(--n-arrow-color-active-hover);"), cE("icon", "color: var(--n-item-icon-color-active-hover);"), cB("menu-item-content-header", `
              color: var(--n-item-text-color-active-hover);
            `, [c$1("a", "color: var(--n-item-text-color-active-hover);"), cE("extra", "color: var(--n-item-text-color-active-hover);")])])]), cM("child-active", [hoverStyle(null, [cE("arrow", "color: var(--n-arrow-color-child-active-hover);"), cE("icon", "color: var(--n-item-icon-color-child-active-hover);"), cB("menu-item-content-header", `
              color: var(--n-item-text-color-child-active-hover);
            `, [c$1("a", "color: var(--n-item-text-color-child-active-hover);"), cE("extra", "color: var(--n-item-text-color-child-active-hover);")])])]), cM("selected", [hoverStyle(null, [c$1("&::before", "background-color: var(--n-item-color-active-hover);")])]), hoverStyle(null, hoverStyleChildren)]), cE("icon", `
        grid-area: icon;
        color: var(--n-item-icon-color);
        transition:
          color .3s var(--n-bezier),
          font-size .3s var(--n-bezier),
          margin-right .3s var(--n-bezier);
        box-sizing: content-box;
        display: inline-flex;
        align-items: center;
        justify-content: center;
      `), cE("arrow", `
        grid-area: arrow;
        font-size: 16px;
        color: var(--n-arrow-color);
        transform: rotate(180deg);
        opacity: 1;
        transition:
          color .3s var(--n-bezier),
          transform 0.2s var(--n-bezier),
          opacity 0.2s var(--n-bezier);
      `), cB("menu-item-content-header", `
        grid-area: content;
        transition:
          color .3s var(--n-bezier),
          opacity .3s var(--n-bezier);
        opacity: 1;
        white-space: nowrap;
        overflow: hidden;
        text-overflow: ellipsis;
        color: var(--n-item-text-color);
      `, [c$1("a", `
          outline: none;
          text-decoration: none;
          transition: color .3s var(--n-bezier);
          color: var(--n-item-text-color);
        `, [c$1("&::before", `
            content: "";
            position: absolute;
            left: 0;
            right: 0;
            top: 0;
            bottom: 0;
          `)]), cE("extra", `
          font-size: .93em;
          color: var(--n-group-text-color);
          transition: color .3s var(--n-bezier);
        `)])]), cB("submenu", `
      cursor: pointer;
      position: relative;
      margin-top: 6px;
    `, [cB("menu-item-content", `
        height: var(--n-item-height);
      `), cB("submenu-children", `
        overflow: hidden;
        padding: 0;
      `, [fadeInHeightExpandTransition({
      duration: ".2s"
    })])]), cB("menu-item-group", [cB("menu-item-group-title", `
        margin-top: 6px;
        color: var(--n-group-text-color);
        cursor: default;
        font-size: .93em;
        height: 36px;
        display: flex;
        align-items: center;
        transition:
          padding-left .3s var(--n-bezier),
          color .3s var(--n-bezier);
      `)])]), cB("menu-tooltip", [c$1("a", `
      color: inherit;
      text-decoration: none;
    `)]), cB("menu-divider", `
    transition: background-color .3s var(--n-bezier);
    background-color: var(--n-divider-color);
    height: 1px;
    margin: 6px 18px;
  `)]);

    function hoverStyle(props, children) {
      return [cM("hover", props, children), c$1("&:hover", props, children)];
    }

    function useCheckDeprecated(props) {
      vue.watchEffect(() => {
        if (props.items) {
          warnOnce("menu", "`items` is deprecated, please use `options` instead.");
        }

        if (props.onOpenNamesChange) {
          warnOnce("menu", "`on-open-names-change` is deprecated, please use `on-update:expanded-keys` instead.");
        }

        if (props.onSelect) {
          warnOnce("menu", "`on-select` is deprecated, please use `on-update:value` instead.");
        }

        if (props.onExpandedNamesChange) {
          warnOnce("menu", "`on-expanded-names-change` is deprecated, please use `on-update:expanded-keys` instead.");
        }

        if (props.expandedNames) {
          warnOnce("menu", "`expanded-names` is deprecated, please use `expanded-keys` instead.");
        }

        if (props.defaultExpandedNames) {
          warnOnce("menu", "`default-expanded-names` is deprecated, please use `default-expanded-keys` instead.");
        }
      });
    }

    const menuProps = {
      ...useTheme.props,
      options: {
        type: Array,
        default: () => []
      },
      collapsed: {
        type: Boolean,
        default: void 0
      },
      collapsedWidth: {
        type: Number,
        default: 48
      },
      iconSize: {
        type: Number,
        default: 20
      },
      collapsedIconSize: {
        type: Number,
        default: 24
      },
      rootIndent: Number,
      indent: {
        type: Number,
        default: 32
      },
      labelField: {
        type: String,
        default: "label"
      },
      keyField: {
        type: String,
        default: "key"
      },
      childrenField: {
        type: String,
        default: "children"
      },
      disabledField: {
        type: String,
        default: "disabled"
      },
      defaultExpandAll: Boolean,
      defaultExpandedKeys: Array,
      expandedKeys: Array,
      value: [String, Number],
      defaultValue: {
        type: [String, Number],
        default: null
      },
      mode: {
        type: String,
        default: "vertical"
      },
      watchProps: {
        type: Array,
        default: void 0
      },
      disabled: Boolean,
      show: {
        type: Boolean,
        defalut: true
      },
      inverted: Boolean,
      "onUpdate:expandedKeys": [Function, Array],
      onUpdateExpandedKeys: [Function, Array],
      onUpdateValue: [Function, Array],
      "onUpdate:value": [Function, Array],
      expandIcon: Function,
      renderIcon: Function,
      renderLabel: Function,
      renderExtra: Function,
      dropdownProps: Object,
      accordion: Boolean,
      nodeProps: Function,
      items: Array,
      onOpenNamesChange: [Function, Array],
      onSelect: [Function, Array],
      onExpandedNamesChange: [Function, Array],
      expandedNames: Array,
      defaultExpandedNames: Array,
      dropdownPlacement: {
        type: String,
        default: "bottom"
      }
    };
    var Menu = vue.defineComponent({
      name: "Menu",
      props: menuProps,
      setup(props) {
        {
          useCheckDeprecated(props);
        }
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Menu",
          "-menu",
          style$u,
          menuLight$1,
          props,
          mergedClsPrefixRef
        );
        const layoutSider = vue.inject(layoutSiderInjectionKey, null);
        const mergedCollapsedRef = vue.computed(() => {
          const { collapsed } = props;
          if (collapsed !== void 0)
            return collapsed;
          if (layoutSider) {
            const { collapseModeRef, collapsedRef } = layoutSider;
            if (collapseModeRef.value === "width") {
              return collapsedRef.value ?? false;
            }
          }
          return false;
        });
        const treeMateRef = vue.computed(() => {
          const { keyField, childrenField, disabledField } = props;
          return createTreeMate(
            props.items || props.options,
            {
              getChildren(node) {
                return node[childrenField];
              },
              getDisabled(node) {
                return node[disabledField];
              },
              getKey(node) {
                return node[keyField] ?? node.name;
              }
            }
          );
        });
        const treeKeysLevelOneRef = vue.computed(
          () => new Set(treeMateRef.value.treeNodes.map((e) => e.key))
        );
        const { watchProps } = props;
        const uncontrolledValueRef = vue.ref(null);
        if (watchProps?.includes("defaultValue")) {
          vue.watchEffect(() => {
            uncontrolledValueRef.value = props.defaultValue;
          });
        } else {
          uncontrolledValueRef.value = props.defaultValue;
        }
        const controlledValueRef = vue.toRef(props, "value");
        const mergedValueRef = useMergedState(
          controlledValueRef,
          uncontrolledValueRef
        );
        const uncontrolledExpandedKeysRef = vue.ref([]);
        const initUncontrolledExpandedKeys = () => {
          uncontrolledExpandedKeysRef.value = props.defaultExpandAll ? treeMateRef.value.getNonLeafKeys() : props.defaultExpandedNames || props.defaultExpandedKeys || treeMateRef.value.getPath(mergedValueRef.value, {
            includeSelf: false
          }).keyPath;
        };
        if (watchProps?.includes("defaultExpandedKeys")) {
          vue.watchEffect(initUncontrolledExpandedKeys);
        } else {
          initUncontrolledExpandedKeys();
        }
        const controlledExpandedKeysRef = useCompitable(props, [
          "expandedNames",
          "expandedKeys"
        ]);
        const mergedExpandedKeysRef = useMergedState(
          controlledExpandedKeysRef,
          uncontrolledExpandedKeysRef
        );
        const tmNodesRef = vue.computed(() => treeMateRef.value.treeNodes);
        const activePathRef = vue.computed(() => {
          return treeMateRef.value.getPath(mergedValueRef.value).keyPath;
        });
        vue.provide(menuInjectionKey, {
          props,
          mergedCollapsedRef,
          mergedThemeRef: themeRef,
          mergedValueRef,
          mergedExpandedKeysRef,
          activePathRef,
          mergedClsPrefixRef,
          isHorizontalRef: vue.computed(() => props.mode === "horizontal"),
          invertedRef: vue.toRef(props, "inverted"),
          doSelect,
          toggleExpand
        });
        function doSelect(value, item) {
          const {
            "onUpdate:value": _onUpdateValue,
            onUpdateValue,
            onSelect
          } = props;
          if (onUpdateValue) {
            call(onUpdateValue, value, item);
          }
          if (_onUpdateValue) {
            call(_onUpdateValue, value, item);
          }
          if (onSelect) {
            call(onSelect, value, item);
          }
          uncontrolledValueRef.value = value;
        }
        function doUpdateExpandedKeys(value) {
          const {
            "onUpdate:expandedKeys": _onUpdateExpandedKeys,
            onUpdateExpandedKeys,
            onExpandedNamesChange,
            onOpenNamesChange
          } = props;
          if (_onUpdateExpandedKeys) {
            call(_onUpdateExpandedKeys, value);
          }
          if (onUpdateExpandedKeys) {
            call(onUpdateExpandedKeys, value);
          }
          if (onExpandedNamesChange) {
            call(onExpandedNamesChange, value);
          }
          if (onOpenNamesChange) {
            call(onOpenNamesChange, value);
          }
          uncontrolledExpandedKeysRef.value = value;
        }
        function toggleExpand(key) {
          const currentExpandedKeys = Array.from(mergedExpandedKeysRef.value);
          const index = currentExpandedKeys.findIndex(
            (expanededKey) => expanededKey === key
          );
          if (~index) {
            currentExpandedKeys.splice(index, 1);
          } else {
            if (props.accordion) {
              if (treeKeysLevelOneRef.value.has(key)) {
                const closeKeyIndex = currentExpandedKeys.findIndex(
                  (e) => treeKeysLevelOneRef.value.has(e)
                );
                if (closeKeyIndex > -1) {
                  currentExpandedKeys.splice(closeKeyIndex, 1);
                }
              }
            }
            currentExpandedKeys.push(key);
          }
          doUpdateExpandedKeys(currentExpandedKeys);
        }
        const showOption = (key) => {
          const selectedKeyPath = treeMateRef.value.getPath(
            key ?? mergedValueRef.value,
            {
              includeSelf: false
            }
          ).keyPath;
          if (!selectedKeyPath.length)
            return;
          const currentExpandedKeys = Array.from(mergedExpandedKeysRef.value);
          const nextExpandedKeys = /* @__PURE__ */ new Set([
            ...currentExpandedKeys,
            ...selectedKeyPath
          ]);
          if (props.accordion) {
            treeKeysLevelOneRef.value.forEach((firstLevelKey) => {
              if (nextExpandedKeys.has(firstLevelKey) && !selectedKeyPath.includes(firstLevelKey)) {
                nextExpandedKeys.delete(firstLevelKey);
              }
            });
          }
          doUpdateExpandedKeys(Array.from(nextExpandedKeys));
        };
        const cssVarsRef = vue.computed(() => {
          const { inverted } = props;
          const {
            common: { cubicBezierEaseInOut },
            self
          } = themeRef.value;
          const {
            borderRadius,
            borderColorHorizontal,
            fontSize,
            itemHeight,
            dividerColor
          } = self;
          const vars = {
            "--n-divider-color": dividerColor,
            "--n-bezier": cubicBezierEaseInOut,
            "--n-font-size": fontSize,
            "--n-border-color-horizontal": borderColorHorizontal,
            "--n-border-radius": borderRadius,
            "--n-item-height": itemHeight
          };
          if (inverted) {
            vars["--n-group-text-color"] = self.groupTextColorInverted;
            vars["--n-color"] = self.colorInverted;
            vars["--n-item-text-color"] = self.itemTextColorInverted;
            vars["--n-item-text-color-hover"] = self.itemTextColorHoverInverted;
            vars["--n-item-text-color-active"] = self.itemTextColorActiveInverted;
            vars["--n-item-text-color-child-active"] = self.itemTextColorChildActiveInverted;
            vars["--n-item-text-color-child-active-hover"] = self.itemTextColorChildActiveInverted;
            vars["--n-item-text-color-active-hover"] = self.itemTextColorActiveHoverInverted;
            vars["--n-item-icon-color"] = self.itemIconColorInverted;
            vars["--n-item-icon-color-hover"] = self.itemIconColorHoverInverted;
            vars["--n-item-icon-color-active"] = self.itemIconColorActiveInverted;
            vars["--n-item-icon-color-active-hover"] = self.itemIconColorActiveHoverInverted;
            vars["--n-item-icon-color-child-active"] = self.itemIconColorChildActiveInverted;
            vars["--n-item-icon-color-child-active-hover"] = self.itemIconColorChildActiveHoverInverted;
            vars["--n-item-icon-color-collapsed"] = self.itemIconColorCollapsedInverted;
            vars["--n-item-text-color-horizontal"] = self.itemTextColorHorizontalInverted;
            vars["--n-item-text-color-hover-horizontal"] = self.itemTextColorHoverHorizontalInverted;
            vars["--n-item-text-color-active-horizontal"] = self.itemTextColorActiveHorizontalInverted;
            vars["--n-item-text-color-child-active-horizontal"] = self.itemTextColorChildActiveHorizontalInverted;
            vars["--n-item-text-color-child-active-hover-horizontal"] = self.itemTextColorChildActiveHoverHorizontalInverted;
            vars["--n-item-text-color-active-hover-horizontal"] = self.itemTextColorActiveHoverHorizontalInverted;
            vars["--n-item-icon-color-horizontal"] = self.itemIconColorHorizontalInverted;
            vars["--n-item-icon-color-hover-horizontal"] = self.itemIconColorHoverHorizontalInverted;
            vars["--n-item-icon-color-active-horizontal"] = self.itemIconColorActiveHorizontalInverted;
            vars["--n-item-icon-color-active-hover-horizontal"] = self.itemIconColorActiveHoverHorizontalInverted;
            vars["--n-item-icon-color-child-active-horizontal"] = self.itemIconColorChildActiveHorizontalInverted;
            vars["--n-item-icon-color-child-active-hover-horizontal"] = self.itemIconColorChildActiveHoverHorizontalInverted;
            vars["--n-arrow-color"] = self.arrowColorInverted;
            vars["--n-arrow-color-hover"] = self.arrowColorHoverInverted;
            vars["--n-arrow-color-active"] = self.arrowColorActiveInverted;
            vars["--n-arrow-color-active-hover"] = self.arrowColorActiveHoverInverted;
            vars["--n-arrow-color-child-active"] = self.arrowColorChildActiveInverted;
            vars["--n-arrow-color-child-active-hover"] = self.arrowColorChildActiveHoverInverted;
            vars["--n-item-color-hover"] = self.itemColorHoverInverted;
            vars["--n-item-color-active"] = self.itemColorActiveInverted;
            vars["--n-item-color-active-hover"] = self.itemColorActiveHoverInverted;
            vars["--n-item-color-active-collapsed"] = self.itemColorActiveCollapsedInverted;
          } else {
            vars["--n-group-text-color"] = self.groupTextColor;
            vars["--n-color"] = self.color;
            vars["--n-item-text-color"] = self.itemTextColor;
            vars["--n-item-text-color-hover"] = self.itemTextColorHover;
            vars["--n-item-text-color-active"] = self.itemTextColorActive;
            vars["--n-item-text-color-child-active"] = self.itemTextColorChildActive;
            vars["--n-item-text-color-child-active-hover"] = self.itemTextColorChildActiveHover;
            vars["--n-item-text-color-active-hover"] = self.itemTextColorActiveHover;
            vars["--n-item-icon-color"] = self.itemIconColor;
            vars["--n-item-icon-color-hover"] = self.itemIconColorHover;
            vars["--n-item-icon-color-active"] = self.itemIconColorActive;
            vars["--n-item-icon-color-active-hover"] = self.itemIconColorActiveHover;
            vars["--n-item-icon-color-child-active"] = self.itemIconColorChildActive;
            vars["--n-item-icon-color-child-active-hover"] = self.itemIconColorChildActiveHover;
            vars["--n-item-icon-color-collapsed"] = self.itemIconColorCollapsed;
            vars["--n-item-text-color-horizontal"] = self.itemTextColorHorizontal;
            vars["--n-item-text-color-hover-horizontal"] = self.itemTextColorHoverHorizontal;
            vars["--n-item-text-color-active-horizontal"] = self.itemTextColorActiveHorizontal;
            vars["--n-item-text-color-child-active-horizontal"] = self.itemTextColorChildActiveHorizontal;
            vars["--n-item-text-color-child-active-hover-horizontal"] = self.itemTextColorChildActiveHoverHorizontal;
            vars["--n-item-text-color-active-hover-horizontal"] = self.itemTextColorActiveHoverHorizontal;
            vars["--n-item-icon-color-horizontal"] = self.itemIconColorHorizontal;
            vars["--n-item-icon-color-hover-horizontal"] = self.itemIconColorHoverHorizontal;
            vars["--n-item-icon-color-active-horizontal"] = self.itemIconColorActiveHorizontal;
            vars["--n-item-icon-color-active-hover-horizontal"] = self.itemIconColorActiveHoverHorizontal;
            vars["--n-item-icon-color-child-active-horizontal"] = self.itemIconColorChildActiveHorizontal;
            vars["--n-item-icon-color-child-active-hover-horizontal"] = self.itemIconColorChildActiveHoverHorizontal;
            vars["--n-arrow-color"] = self.arrowColor;
            vars["--n-arrow-color-hover"] = self.arrowColorHover;
            vars["--n-arrow-color-active"] = self.arrowColorActive;
            vars["--n-arrow-color-active-hover"] = self.arrowColorActiveHover;
            vars["--n-arrow-color-child-active"] = self.arrowColorChildActive;
            vars["--n-arrow-color-child-active-hover"] = self.arrowColorChildActiveHover;
            vars["--n-item-color-hover"] = self.itemColorHover;
            vars["--n-item-color-active"] = self.itemColorActive;
            vars["--n-item-color-active-hover"] = self.itemColorActiveHover;
            vars["--n-item-color-active-collapsed"] = self.itemColorActiveCollapsed;
          }
          return vars;
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "menu",
          vue.computed(() => props.inverted ? "a" : "b"),
          cssVarsRef,
          props
        ) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          controlledExpandedKeys: controlledExpandedKeysRef,
          uncontrolledExpanededKeys: uncontrolledExpandedKeysRef,
          mergedExpandedKeys: mergedExpandedKeysRef,
          uncontrolledValue: uncontrolledValueRef,
          mergedValue: mergedValueRef,
          activePath: activePathRef,
          tmNodes: tmNodesRef,
          mergedTheme: themeRef,
          mergedCollapsed: mergedCollapsedRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender,
          showOption
        };
      },
      render() {
        const { mergedClsPrefix, mode, themeClass, onRender } = this;
        onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          role: mode === "horizontal" ? "menubar" : "menu",
          class: [
            `${mergedClsPrefix}-menu`,
            themeClass,
            `${mergedClsPrefix}-menu--${mode}`,
            this.mergedCollapsed && `${mergedClsPrefix}-menu--collapsed`
          ],
          style: this.cssVars
        }, this.tmNodes.map((tmNode) => itemRenderer(tmNode, this.$props)));
      }
    });

    function getRelativePosition(element) {
      let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {
        debug: false,
        useSelectionEnd: false,
        checkWidthOverflow: true
      };
      const selectionStart = element.selectionStart !== null ? element.selectionStart : 0;
      const selectionEnd = element.selectionEnd !== null ? element.selectionEnd : 0;
      const position = options.useSelectionEnd ? selectionEnd : selectionStart;
      const properties = ["direction", "boxSizing", "width", "height", "overflowX", "overflowY", "borderTopWidth", "borderRightWidth", "borderBottomWidth", "borderLeftWidth", "borderStyle", "paddingTop", "paddingRight", "paddingBottom", "paddingLeft", "fontStyle", "fontVariant", "fontWeight", "fontStretch", "fontSize", "fontSizeAdjust", "lineHeight", "fontFamily", "textAlign", "textTransform", "textIndent", "textDecoration", "letterSpacing", "wordSpacing", "tabSize", "MozTabSize"];
      const isFirefox = navigator.userAgent.toLowerCase().includes("firefox");

      if (!isBrowser$2) {
        throw new Error("textarea-caret-position#getCaretPosition should only be called in a browser");
      }

      const debug = options === null || options === void 0 ? void 0 : options.debug;

      if (debug) {
        const el = document.querySelector("#input-textarea-caret-position-mirror-div");
        if (el !== null && el !== void 0 && el.parentNode) el.parentNode.removeChild(el);
      }

      const div = document.createElement("div");
      div.id = "input-textarea-caret-position-mirror-div";
      document.body.appendChild(div);
      const style = div.style;
      const computed = window.getComputedStyle ? window.getComputedStyle(element) : element.currentStyle;
      const isInput = element.nodeName === "INPUT";
      style.whiteSpace = isInput ? "nowrap" : "pre-wrap";
      if (!isInput) style.wordWrap = "break-word";
      style.position = "absolute";
      if (!debug) style.visibility = "hidden";
      properties.forEach(prop => {
        if (isInput && prop === "lineHeight") {
          if (computed.boxSizing === "border-box") {
            const height = parseInt(computed.height);
            const outerHeight = parseInt(computed.paddingTop) + parseInt(computed.paddingBottom) + parseInt(computed.borderTopWidth) + parseInt(computed.borderBottomWidth);
            const targetHeight = outerHeight + parseInt(computed.lineHeight);

            if (height > targetHeight) {
              style.lineHeight = `${height - outerHeight}px`;
            } else if (height === targetHeight) {
              style.lineHeight = computed.lineHeight;
            } else {
              style.lineHeight = "0";
            }
          } else {
            style.lineHeight = computed.height;
          }
        } else {
          style[prop] = computed[prop];
        }
      });

      if (isFirefox) {
        if (element.scrollHeight > parseInt(computed.height)) {
          style.overflowY = "scroll";
        }
      } else {
        style.overflow = "hidden";
      }

      div.textContent = element.value.substring(0, position);

      if (isInput && div.textContent) {
        div.textContent = div.textContent.replace(/\s/g, "\xA0");
      }

      const span = document.createElement("span");
      span.textContent = element.value.substring(position) || ".";
      span.style.position = "relative";
      span.style.left = `${-element.scrollLeft}px`;
      span.style.top = `${-element.scrollTop}px`;
      div.appendChild(span);
      const relativePosition = {
        top: span.offsetTop + parseInt(computed.borderTopWidth),
        left: span.offsetLeft + parseInt(computed.borderLeftWidth),
        absolute: false,
        height: parseInt(computed.fontSize) * 1.5
      };

      if (debug) {
        span.style.backgroundColor = "#aaa";
      } else {
        document.body.removeChild(div);
      }

      if (relativePosition.left >= element.clientWidth && options.checkWidthOverflow) {
        relativePosition.left = element.clientWidth;
      }

      return relativePosition;
    }

    var style$t = c$1([cB("mention", "width: 100%; z-index: auto; position: relative;"), cB("mention-menu", `
    box-shadow: var(--n-menu-box-shadow);
  `, [fadeInScaleUpTransition({
      originalTransition: "background-color .3s var(--n-bezier), box-shadow .3s var(--n-bezier)"
    })])]);

    const mentionProps = {
      ...useTheme.props,
      to: useAdjustedTo.propTo,
      autosize: [Boolean, Object],
      options: {
        type: Array,
        default: []
      },
      type: {
        type: String,
        default: "text"
      },
      separator: {
        type: String,
        validator: (separator) => {
          if (separator.length !== 1) {
            warn$2("mention", "`separator`'s length must be 1.");
            return false;
          }
          return true;
        },
        default: " "
      },
      bordered: {
        type: Boolean,
        default: void 0
      },
      disabled: Boolean,
      value: String,
      defaultValue: {
        type: String,
        default: ""
      },
      loading: Boolean,
      prefix: {
        type: [String, Array],
        default: "@"
      },
      placeholder: {
        type: String,
        default: ""
      },
      placement: {
        type: String,
        default: "bottom-start"
      },
      size: String,
      renderLabel: Function,
      status: String,
      "onUpdate:value": [Array, Function],
      onUpdateValue: [Array, Function],
      onSearch: Function,
      onSelect: Function,
      onFocus: Function,
      onBlur: Function,
      internalDebug: Boolean
    };
    var Mention = vue.defineComponent({
      name: "Mention",
      props: mentionProps,
      setup(props) {
        const {
          namespaceRef,
          mergedClsPrefixRef,
          mergedBorderedRef,
          inlineThemeDisabled
        } = useConfig(props);
        const themeRef = useTheme(
          "Mention",
          "-mention",
          style$t,
          mentionLight$1,
          props,
          mergedClsPrefixRef
        );
        const formItem = useFormItem(props);
        const inputInstRef = vue.ref(null);
        const cursorRef = vue.ref(null);
        const followerRef = vue.ref(null);
        const partialPatternRef = vue.ref("");
        let cachedPrefix = null;
        let cachedPartialPatternStart = null;
        let cachedPartialPatternEnd = null;
        const filteredOptionsRef = vue.computed(() => {
          const { value: pattern } = partialPatternRef;
          return props.options.filter((option) => {
            if (!pattern)
              return true;
            if (typeof option.label === "string") {
              return option.label.startsWith(pattern);
            }
            if (typeof option.value === "string") {
              return option.value.startsWith(pattern);
            }
            return false;
          });
        });
        const treeMateRef = vue.computed(() => {
          return createTreeMate(filteredOptionsRef.value, {
            getKey: (v) => {
              return v.value;
            }
          });
        });
        const selectMenuInstRef = vue.ref(null);
        const showMenuRef = vue.ref(false);
        const uncontrolledValueRef = vue.ref(props.defaultValue);
        const controlledValueRef = vue.toRef(props, "value");
        const mergedValueRef = useMergedState(
          controlledValueRef,
          uncontrolledValueRef
        );
        const cssVarsRef = vue.computed(() => {
          const {
            self: { menuBoxShadow }
          } = themeRef.value;
          return {
            "--n-menu-box-shadow": menuBoxShadow
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("mention", void 0, cssVarsRef, props) : void 0;
        function doUpdateShowMenu(show) {
          if (props.disabled)
            return;
          if (!show) {
            cachedPrefix = null;
            cachedPartialPatternStart = null;
            cachedPartialPatternEnd = null;
          }
          showMenuRef.value = show;
        }
        function doUpdateValue(value) {
          const { onUpdateValue, "onUpdate:value": _onUpdateValue } = props;
          const { nTriggerFormChange, nTriggerFormInput } = formItem;
          if (_onUpdateValue) {
            call(_onUpdateValue, value);
          }
          if (onUpdateValue) {
            call(onUpdateValue, value);
          }
          nTriggerFormInput();
          nTriggerFormChange();
          uncontrolledValueRef.value = value;
        }
        function getInputEl() {
          return props.type === "text" ? inputInstRef.value.inputElRef : inputInstRef.value.textareaElRef;
        }
        function deriveShowMenu() {
          const inputEl = getInputEl();
          if (document.activeElement !== inputEl) {
            doUpdateShowMenu(false);
            return;
          }
          const { selectionEnd } = inputEl;
          if (selectionEnd === null) {
            doUpdateShowMenu(false);
            return;
          }
          const inputValue = inputEl.value;
          const { separator } = props;
          const { prefix } = props;
          const prefixArray = typeof prefix === "string" ? [prefix] : prefix;
          for (let i = selectionEnd - 1; i >= 0; --i) {
            const char = inputValue[i];
            if (char === separator || char === "\n" || char === "\r") {
              doUpdateShowMenu(false);
              return;
            }
            if (prefixArray.includes(char)) {
              const partialPattern = inputValue.slice(i + 1, selectionEnd);
              doUpdateShowMenu(true);
              props.onSearch?.(partialPattern, char);
              partialPatternRef.value = partialPattern;
              cachedPrefix = char;
              cachedPartialPatternStart = i + 1;
              cachedPartialPatternEnd = selectionEnd;
              return;
            }
          }
          doUpdateShowMenu(false);
        }
        function syncCursor() {
          const { value: cursorAnchor } = cursorRef;
          if (!cursorAnchor)
            return;
          const inputEl = getInputEl();
          const cursorPos = getRelativePosition(inputEl);
          cursorPos.left += inputEl.parentElement.offsetLeft;
          cursorAnchor.style.left = `${cursorPos.left}px`;
          cursorAnchor.style.top = `${cursorPos.top + cursorPos.height}px`;
        }
        function syncPosition() {
          if (!showMenuRef.value)
            return;
          followerRef.value?.syncPosition();
        }
        function handleInputUpdateValue(value) {
          doUpdateValue(value);
          syncAfterCursorMove();
        }
        function syncAfterCursorMove() {
          setTimeout(() => {
            syncCursor();
            deriveShowMenu();
            void vue.nextTick().then(syncPosition);
          }, 0);
        }
        function handleInputKeyDown(e) {
          if (e.key === "ArrowLeft" || e.key === "ArrowRight") {
            if (inputInstRef.value?.isCompositing)
              return;
            syncAfterCursorMove();
          } else if (e.key === "ArrowUp" || e.key === "ArrowDown" || e.key === "Enter") {
            if (inputInstRef.value?.isCompositing)
              return;
            const { value: selectMenuInst } = selectMenuInstRef;
            if (showMenuRef.value) {
              if (selectMenuInst) {
                e.preventDefault();
                if (e.key === "ArrowUp") {
                  selectMenuInst.prev();
                } else if (e.key === "ArrowDown") {
                  selectMenuInst.next();
                } else {
                  const pendingOptionTmNode = selectMenuInst.getPendingTmNode();
                  if (pendingOptionTmNode) {
                    handleSelect(pendingOptionTmNode);
                  } else {
                    doUpdateShowMenu(false);
                  }
                }
              }
            } else {
              syncAfterCursorMove();
            }
          }
        }
        function handleInputFocus(e) {
          const { onFocus } = props;
          onFocus?.(e);
          const { nTriggerFormFocus } = formItem;
          nTriggerFormFocus();
          syncAfterCursorMove();
        }
        function focus() {
          inputInstRef.value?.focus();
        }
        function blur() {
          inputInstRef.value?.blur();
        }
        function handleInputBlur(e) {
          const { onBlur } = props;
          onBlur?.(e);
          const { nTriggerFormBlur } = formItem;
          nTriggerFormBlur();
          doUpdateShowMenu(false);
        }
        function handleSelect(tmNode) {
          if (cachedPrefix === null || cachedPartialPatternStart === null || cachedPartialPatternEnd === null) {
            {
              warn$2(
                "mention",
                "Cache works unexpectly, this is probably a bug. Please create an issue."
              );
            }
            return;
          }
          const {
            rawNode: { value = "" }
          } = tmNode;
          const inputEl = getInputEl();
          const inputValue = inputEl.value;
          const { separator } = props;
          const nextEndPart = inputValue.slice(cachedPartialPatternEnd);
          const alreadySeparated = nextEndPart.startsWith(separator);
          const nextMiddlePart = `${value}${alreadySeparated ? "" : separator}`;
          doUpdateValue(
            inputValue.slice(0, cachedPartialPatternStart) + nextMiddlePart + nextEndPart
          );
          props.onSelect?.(tmNode.rawNode, cachedPrefix);
          const nextSelectionEnd = cachedPartialPatternStart + nextMiddlePart.length + (alreadySeparated ? 1 : 0);
          void vue.nextTick().then(() => {
            inputEl.selectionStart = nextSelectionEnd;
            inputEl.selectionEnd = nextSelectionEnd;
            deriveShowMenu();
          });
        }
        function handleInputMouseDown() {
          if (!props.disabled) {
            syncAfterCursorMove();
          }
        }
        return {
          namespace: namespaceRef,
          mergedClsPrefix: mergedClsPrefixRef,
          mergedBordered: mergedBorderedRef,
          mergedSize: formItem.mergedSizeRef,
          mergedStatus: formItem.mergedStatusRef,
          mergedTheme: themeRef,
          treeMate: treeMateRef,
          selectMenuInstRef,
          inputInstRef,
          cursorRef,
          followerRef,
          showMenu: showMenuRef,
          adjustedTo: useAdjustedTo(props),
          isMounted: isMounted(),
          mergedValue: mergedValueRef,
          handleInputFocus,
          handleInputBlur,
          handleInputUpdateValue,
          handleInputKeyDown,
          handleSelect,
          handleInputMouseDown,
          focus,
          blur,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedTheme, mergedClsPrefix, $slots } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-mention`
        }, /* @__PURE__ */ React.createElement(NInput, {
          status: this.mergedStatus,
          themeOverrides: mergedTheme.peerOverrides.Input,
          theme: mergedTheme.peers.Input,
          size: this.mergedSize,
          autosize: this.autosize,
          type: this.type,
          ref: "inputInstRef",
          placeholder: this.placeholder,
          onMousedown: this.handleInputMouseDown,
          onUpdateValue: this.handleInputUpdateValue,
          onKeydown: this.handleInputKeyDown,
          onFocus: this.handleInputFocus,
          onBlur: this.handleInputBlur,
          bordered: this.mergedBordered,
          disabled: this.disabled,
          value: this.mergedValue
        }), /* @__PURE__ */ React.createElement(VBinder, null, {
          default: () => [
            /* @__PURE__ */ React.createElement(VTarget, null, {
              default: () => {
                const style2 = {
                  position: "absolute",
                  width: 0,
                  height: 0
                };
                if (this.internalDebug) {
                  style2.width = "1px";
                  style2.height = "1px";
                  style2.background = "red";
                }
                return /* @__PURE__ */ React.createElement("div", {
                  style: style2,
                  ref: "cursorRef"
                });
              }
            }),
            /* @__PURE__ */ React.createElement(VFollower, {
              ref: "followerRef",
              placement: this.placement,
              show: this.showMenu,
              containerClass: this.namespace,
              to: this.adjustedTo,
              teleportDisabled: this.adjustedTo === useAdjustedTo.tdkey
            }, {
              default: () => /* @__PURE__ */ React.createElement(vue.Transition, {
                name: "fade-in-scale-up-transition",
                appear: this.isMounted
              }, {
                default: () => {
                  const { mergedTheme: mergedTheme2, onRender } = this;
                  onRender?.();
                  return this.showMenu ? /* @__PURE__ */ React.createElement(NInternalSelectMenu, {
                    clsPrefix: mergedClsPrefix,
                    theme: mergedTheme2.peers.InternalSelectMenu,
                    themeOverrides: mergedTheme2.peerOverrides.InternalSelectMenu,
                    autoPending: true,
                    ref: "selectMenuInstRef",
                    class: [
                      `${mergedClsPrefix}-mention-menu`,
                      this.themeClass
                    ],
                    loading: this.loading,
                    treeMate: this.treeMate,
                    virtualScroll: false,
                    style: this.cssVars,
                    onToggle: this.handleSelect,
                    renderLabel: this.renderLabel
                  }, $slots) : null;
                }
              })
            })
          ]
        }));
      }
    });

    const messageProps = {
      icon: Function,
      type: {
        type: String,
        default: "info"
      },
      content: [String, Number, Function],
      showIcon: {
        type: Boolean,
        default: true
      },
      closable: Boolean,
      keepAliveOnHover: Boolean,
      onClose: Function,
      onMouseenter: Function,
      onMouseleave: Function
    };

    const messageApiInjectionKey = createInjectionKey("n-message-api");
    const messageProviderInjectionKey = createInjectionKey("n-message-provider");

    var style$s = c$1([cB("message-wrapper", `
    margin: var(--n-margin);
    z-index: 0;
    transform-origin: top center;
    display: flex;
  `, [fadeInHeightExpandTransition({
      overflow: "visible",
      originalTransition: "transform .3s var(--n-bezier)",
      enterToProps: {
        transform: "scale(1)"
      },
      leaveToProps: {
        transform: "scale(0.85)"
      }
    })]), cB("message", `
    box-sizing: border-box;
    display: flex;
    align-items: center;
    transition:
      color .3s var(--n-bezier),
      box-shadow .3s var(--n-bezier),
      background-color .3s var(--n-bezier),
      opacity .3s var(--n-bezier),
      transform .3s var(--n-bezier),
      margin-bottom .3s var(--n-bezier);
    padding: var(--n-padding);
    border-radius: var(--n-border-radius);
    flex-wrap: nowrap;
    overflow: hidden;
    max-width: var(--n-max-width);
    color: var(--n-text-color);
    background-color: var(--n-color);
    box-shadow: var(--n-box-shadow);
  `, [cE("content", `
      display: inline-block;
      line-height: var(--n-line-height);
      font-size: var(--n-font-size);
    `), cE("icon", `
      position: relative;
      margin: var(--n-icon-margin);
      height: var(--n-icon-size);
      width: var(--n-icon-size);
      font-size: var(--n-icon-size);
      flex-shrink: 0;
    `, [["default", "info", "success", "warning", "error", "loading"].map(type => cM(`${type}-type`, [c$1("> *", `
            color: var(--n-icon-color-${type});
            transition: color .3s var(--n-bezier);
          `)])), c$1("> *", `
        position: absolute;
        left: 0;
        top: 0;
        right: 0;
        bottom: 0;
      `, [iconSwitchTransition()])]), cE("close", `
      margin: var(--n-close-margin);
      transition:
        background-color .3s var(--n-bezier),
        color .3s var(--n-bezier);
      flex-shrink: 0;
    `, [c$1("&:hover", `
        color: var(--n-close-icon-color-hover);
      `), c$1("&:active", `
        color: var(--n-close-icon-color-pressed);
      `)])]), cB("message-container", `
    z-index: 6000;
    position: fixed;
    height: 0;
    overflow: visible;
    display: flex;
    flex-direction: column;
    align-items: center;
  `, [cM("top", `
      top: 12px;
      left: 0;
      right: 0;
    `), cM("top-left", `
      top: 12px;
      left: 12px;
      right: 0;
      align-items: flex-start;
    `), cM("top-right", `
      top: 12px;
      left: 0;
      right: 12px;
      align-items: flex-end;
    `), cM("bottom", `
      bottom: 4px;
      left: 0;
      right: 0;
      justify-content: flex-end;
    `), cM("bottom-left", `
      bottom: 4px;
      left: 12px;
      right: 0;
      justify-content: flex-end;
      align-items: flex-start;
    `), cM("bottom-right", `
      bottom: 4px;
      left: 0;
      right: 12px;
      justify-content: flex-end;
      align-items: flex-end;
    `)])]);

    const iconRenderMap$1 = {
      info: () => /* @__PURE__ */ React.createElement(InfoIcon, null),
      success: () => /* @__PURE__ */ React.createElement(SuccessIcon, null),
      warning: () => /* @__PURE__ */ React.createElement(WarningIcon, null),
      error: () => /* @__PURE__ */ React.createElement(ErrorIcon, null),
      default: () => null
    };
    var NMessage = vue.defineComponent({
      name: "Message",
      props: {
        ...messageProps,
        render: Function
      },
      setup(props) {
        const { inlineThemeDisabled, mergedRtlRef } = useConfig(props);
        const {
          props: messageProviderProps,
          mergedClsPrefixRef
        } = vue.inject(messageProviderInjectionKey);
        const rtlEnabledRef = useRtl("Message", mergedRtlRef, mergedClsPrefixRef);
        const themeRef = useTheme(
          "Message",
          "-message",
          style$s,
          messageLight$1,
          messageProviderProps,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const { type } = props;
          const {
            common: { cubicBezierEaseInOut },
            self: {
              padding,
              margin,
              maxWidth,
              iconMargin,
              closeMargin,
              closeSize,
              iconSize,
              fontSize,
              lineHeight,
              borderRadius,
              iconColorInfo,
              iconColorSuccess,
              iconColorWarning,
              iconColorError,
              iconColorLoading,
              closeIconSize,
              closeBorderRadius,
              [createKey("textColor", type)]: textColor,
              [createKey("boxShadow", type)]: boxShadow,
              [createKey("color", type)]: color,
              [createKey("closeColorHover", type)]: closeColorHover,
              [createKey("closeColorPressed", type)]: closeColorPressed,
              [createKey("closeIconColor", type)]: closeIconColor,
              [createKey("closeIconColorPressed", type)]: closeIconColorPressed,
              [createKey("closeIconColorHover", type)]: closeIconColorHover
            }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-margin": margin,
            "--n-padding": padding,
            "--n-max-width": maxWidth,
            "--n-font-size": fontSize,
            "--n-icon-margin": iconMargin,
            "--n-icon-size": iconSize,
            "--n-close-icon-size": closeIconSize,
            "--n-close-border-radius": closeBorderRadius,
            "--n-close-size": closeSize,
            "--n-close-margin": closeMargin,
            "--n-text-color": textColor,
            "--n-color": color,
            "--n-box-shadow": boxShadow,
            "--n-icon-color-info": iconColorInfo,
            "--n-icon-color-success": iconColorSuccess,
            "--n-icon-color-warning": iconColorWarning,
            "--n-icon-color-error": iconColorError,
            "--n-icon-color-loading": iconColorLoading,
            "--n-close-color-hover": closeColorHover,
            "--n-close-color-pressed": closeColorPressed,
            "--n-close-icon-color": closeIconColor,
            "--n-close-icon-color-pressed": closeIconColorPressed,
            "--n-close-icon-color-hover": closeIconColorHover,
            "--n-line-height": lineHeight,
            "--n-border-radius": borderRadius
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "message",
          vue.computed(() => props.type[0]),
          cssVarsRef,
          {}
        ) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          rtlEnabled: rtlEnabledRef,
          messageProviderProps,
          handleClose() {
            props.onClose?.();
          },
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender,
          placement: messageProviderProps.placement
        };
      },
      render() {
        const {
          render: renderMessage,
          type,
          closable,
          content,
          mergedClsPrefix,
          cssVars,
          themeClass,
          onRender,
          icon,
          handleClose,
          showIcon
        } = this;
        onRender?.();
        let iconNode;
        return /* @__PURE__ */ React.createElement("div", {
          class: [`${mergedClsPrefix}-message-wrapper`, themeClass],
          onMouseenter: this.onMouseenter,
          onMouseleave: this.onMouseleave,
          style: [
            {
              alignItems: this.placement.startsWith("top") ? "flex-start" : "flex-end"
            },
            cssVars
          ]
        }, renderMessage ? renderMessage(this.$props) : /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-message ${mergedClsPrefix}-message--${type}-type`,
            this.rtlEnabled && `${mergedClsPrefix}-message--rtl`
          ]
        }, (iconNode = createIconVNode(icon, type, mergedClsPrefix)) && showIcon ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-message__icon ${mergedClsPrefix}-message__icon--${type}-type`
        }, /* @__PURE__ */ React.createElement(NIconSwitchTransition, null, {
          default: () => iconNode
        })) : null, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-message__content`
        }, render$1(content)), closable ? /* @__PURE__ */ React.createElement(NBaseClose, {
          clsPrefix: mergedClsPrefix,
          class: `${mergedClsPrefix}-message__close`,
          onClick: handleClose,
          absolute: true
        }) : null));
      }
    });
    function createIconVNode(icon, type, clsPrefix) {
      if (typeof icon === "function") {
        return icon();
      } else {
        const innerIcon = type === "loading" ? /* @__PURE__ */ React.createElement(NBaseLoading, {
          clsPrefix,
          strokeWidth: 24,
          scale: 0.85
        }) : iconRenderMap$1[type]();
        if (!innerIcon)
          return null;
        return /* @__PURE__ */ React.createElement(NBaseIcon, {
          clsPrefix,
          key: type
        }, {
          default: () => innerIcon
        });
      }
    }

    var MessageEnvironment = vue.defineComponent({
      name: "MessageEnvironment",
      props: {
        ...messageProps,
        duration: {
          type: Number,
          default: 3e3
        },
        onAfterLeave: Function,
        onLeave: Function,
        internalKey: {
          type: String,
          required: true
        },
        onInternalAfterLeave: Function,
        onHide: Function,
        onAfterHide: Function
      },
      setup(props) {
        let timerId = null;
        const showRef = vue.ref(true);
        vue.onMounted(() => {
          setHideTimeout();
        });
        function setHideTimeout() {
          const { duration } = props;
          if (duration) {
            timerId = window.setTimeout(hide, duration);
          }
        }
        function handleMouseenter(e) {
          if (e.currentTarget !== e.target)
            return;
          if (timerId !== null) {
            window.clearTimeout(timerId);
            timerId = null;
          }
        }
        function handleMouseleave(e) {
          if (e.currentTarget !== e.target)
            return;
          setHideTimeout();
        }
        function hide() {
          const { onHide } = props;
          showRef.value = false;
          if (timerId) {
            window.clearTimeout(timerId);
            timerId = null;
          }
          if (onHide)
            onHide();
        }
        function handleClose() {
          const { onClose } = props;
          if (onClose)
            onClose();
          hide();
        }
        function handleAfterLeave() {
          const { onAfterLeave, onInternalAfterLeave, onAfterHide, internalKey } = props;
          if (onAfterLeave)
            onAfterLeave();
          if (onInternalAfterLeave)
            onInternalAfterLeave(internalKey);
          if (onAfterHide)
            onAfterHide();
        }
        function deactivate() {
          hide();
        }
        return {
          show: showRef,
          hide,
          handleClose,
          handleAfterLeave,
          handleMouseleave,
          handleMouseenter,
          deactivate
        };
      },
      render() {
        return /* @__PURE__ */ React.createElement(NFadeInExpandTransition, {
          appear: true,
          onAfterLeave: this.handleAfterLeave,
          onLeave: this.onLeave
        }, {
          default: () => [
            this.show ? /* @__PURE__ */ React.createElement(NMessage, {
              content: this.content,
              type: this.type,
              icon: this.icon,
              showIcon: this.showIcon,
              closable: this.closable,
              onClose: this.handleClose,
              onMouseenter: this.keepAliveOnHover ? this.handleMouseenter : void 0,
              onMouseleave: this.keepAliveOnHover ? this.handleMouseleave : void 0
            }) : null
          ]
        });
      }
    });

    const messageProviderProps = {
      ...useTheme.props,
      to: [String, Object],
      duration: {
        type: Number,
        default: 3e3
      },
      keepAliveOnHover: Boolean,
      max: Number,
      placement: {
        type: String,
        default: "top"
      },
      closable: Boolean,
      containerStyle: [String, Object]
    };
    var NMessageProvider = vue.defineComponent({
      name: "MessageProvider",
      props: messageProviderProps,
      setup(props) {
        const { mergedClsPrefixRef } = useConfig(props);
        const messageListRef = vue.ref([]);
        const messageRefs = vue.ref({});
        const api = {
          create(content, options) {
            return create(content, { type: "default", ...options });
          },
          info(content, options) {
            return create(content, { ...options, type: "info" });
          },
          success(content, options) {
            return create(content, { ...options, type: "success" });
          },
          warning(content, options) {
            return create(content, { ...options, type: "warning" });
          },
          error(content, options) {
            return create(content, { ...options, type: "error" });
          },
          loading(content, options) {
            return create(content, { ...options, type: "loading" });
          },
          destroyAll
        };
        vue.provide(messageProviderInjectionKey, {
          props,
          mergedClsPrefixRef
        });
        vue.provide(messageApiInjectionKey, api);
        function create(content, options) {
          const key = createId();
          const messageReactive = vue.reactive({
            ...options,
            content,
            key,
            destroy: () => {
              messageRefs.value[key]?.hide();
            }
          });
          const { max } = props;
          if (max && messageListRef.value.length >= max) {
            messageListRef.value.shift();
          }
          messageListRef.value.push(messageReactive);
          return messageReactive;
        }
        function handleAfterLeave(key) {
          messageListRef.value.splice(
            messageListRef.value.findIndex((message) => message.key === key),
            1
          );
          delete messageRefs.value[key];
        }
        function destroyAll() {
          Object.values(messageRefs.value).forEach((messageInstRef) => {
            messageInstRef.hide();
          });
        }
        return Object.assign(
          {
            mergedClsPrefix: mergedClsPrefixRef,
            messageRefs,
            messageList: messageListRef,
            handleAfterLeave
          },
          api
        );
      },
      render() {
        return /* @__PURE__ */ React.createElement(React.Fragment, null, this.$slots.default?.(), this.messageList.length ? /* @__PURE__ */ React.createElement(vue.Teleport, {
          to: this.to ?? "body"
        }, /* @__PURE__ */ React.createElement("div", {
          class: [
            `${this.mergedClsPrefix}-message-container`,
            `${this.mergedClsPrefix}-message-container--${this.placement}`
          ],
          key: "message-container",
          style: this.containerStyle
        }, this.messageList.map((message) => {
          return /* @__PURE__ */ React.createElement(MessageEnvironment, {
            ref: (inst) => {
              if (inst) {
                this.messageRefs[message.key] = inst;
              }
            },
            internalKey: message.key,
            onInternalAfterLeave: this.handleAfterLeave,
            ...omit(message, ["destroy"], void 0),
            duration: message.duration === void 0 ? this.duration : message.duration,
            keepAliveOnHover: message.keepAliveOnHover === void 0 ? this.keepAliveOnHover : message.keepAliveOnHover,
            closable: message.closable === void 0 ? this.closable : message.closable
          });
        }))) : null);
      }
    });

    function useMessage() {
      const api = vue.inject(messageApiInjectionKey, null);

      if (api === null) {
        throwError("use-message", "No outer <n-message-provider /> founded. See prerequisite in https://www.naiveui.com/en-US/os-theme/components/message for more details. If you want to use `useMessage` outside setup, please check https://www.naiveui.com/zh-CN/os-theme/components/message#Q-&-A.");
      }

      return api;
    }

    const notificationProviderInjectionKey = createInjectionKey("n-notification-provider");

    const NotificationContainer = vue.defineComponent({
      name: "NotificationContainer",
      props: {
        scrollable: {
          type: Boolean,
          required: true
        },
        placement: {
          type: String,
          required: true
        }
      },
      setup() {
        const { mergedThemeRef, mergedClsPrefixRef, wipTransitionCountRef } = vue.inject(notificationProviderInjectionKey);
        const selfRef = vue.ref(null);
        vue.watchEffect(() => {
          if (wipTransitionCountRef.value > 0) {
            selfRef?.value?.classList.add("transitioning");
          } else {
            selfRef?.value?.classList.remove("transitioning");
          }
        });
        return {
          selfRef,
          mergedTheme: mergedThemeRef,
          mergedClsPrefix: mergedClsPrefixRef,
          transitioning: wipTransitionCountRef
        };
      },
      render() {
        const { $slots, scrollable, mergedClsPrefix, mergedTheme, placement } = this;
        return /* @__PURE__ */ React.createElement("div", {
          ref: "selfRef",
          class: [
            `${mergedClsPrefix}-notification-container`,
            scrollable && `${mergedClsPrefix}-notification-container--scrollable`,
            `${mergedClsPrefix}-notification-container--${placement}`
          ]
        }, scrollable ? /* @__PURE__ */ React.createElement(NScrollbar, {
          theme: mergedTheme.peers.Scrollbar,
          themeOverrides: mergedTheme.peerOverrides.Scrollbar,
          contentStyle: { overflow: "hidden" }
        }, $slots) : $slots);
      }
    });

    const iconRenderMap = {
      info: () => /* @__PURE__ */ React.createElement(InfoIcon, null),
      success: () => /* @__PURE__ */ React.createElement(SuccessIcon, null),
      warning: () => /* @__PURE__ */ React.createElement(WarningIcon, null),
      error: () => /* @__PURE__ */ React.createElement(ErrorIcon, null),
      default: () => null
    };
    const notificationProps = {
      closable: {
        type: Boolean,
        default: true
      },
      type: {
        type: String,
        default: "default"
      },
      avatar: Function,
      title: [String, Function],
      description: [String, Function],
      content: [String, Function],
      meta: [String, Function],
      action: [String, Function],
      onClose: {
        type: Function,
        required: true
      },
      keepAliveOnHover: Boolean,
      onMouseenter: Function,
      onMouseleave: Function
    };
    const notificationPropKeys = keysOf(notificationProps);
    const Notification = vue.defineComponent({
      name: "Notification",
      props: notificationProps,
      setup(props) {
        const {
          mergedClsPrefixRef,
          mergedThemeRef,
          props: providerProps
        } = vue.inject(notificationProviderInjectionKey);
        const { inlineThemeDisabled, mergedRtlRef } = useConfig();
        const rtlEnabledRef = useRtl(
          "Notification",
          mergedRtlRef,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const { type } = props;
          const {
            self: {
              color,
              textColor,
              closeIconColor,
              closeIconColorHover,
              closeIconColorPressed,
              headerTextColor,
              descriptionTextColor,
              actionTextColor,
              borderRadius,
              headerFontWeight,
              boxShadow,
              lineHeight,
              fontSize,
              closeMargin,
              closeSize,
              width,
              padding,
              closeIconSize,
              closeBorderRadius,
              closeColorHover,
              closeColorPressed,
              titleFontSize,
              metaFontSize,
              descriptionFontSize,
              [createKey("iconColor", type)]: iconColor
            },
            common: { cubicBezierEaseOut, cubicBezierEaseIn, cubicBezierEaseInOut }
          } = mergedThemeRef.value;
          const { left, right, top, bottom } = getMargin(padding);
          return {
            "--n-color": color,
            "--n-font-size": fontSize,
            "--n-text-color": textColor,
            "--n-description-text-color": descriptionTextColor,
            "--n-action-text-color": actionTextColor,
            "--n-title-text-color": headerTextColor,
            "--n-title-font-weight": headerFontWeight,
            "--n-bezier": cubicBezierEaseInOut,
            "--n-bezier-ease-out": cubicBezierEaseOut,
            "--n-bezier-ease-in": cubicBezierEaseIn,
            "--n-border-radius": borderRadius,
            "--n-box-shadow": boxShadow,
            "--n-close-border-radius": closeBorderRadius,
            "--n-close-color-hover": closeColorHover,
            "--n-close-color-pressed": closeColorPressed,
            "--n-close-icon-color": closeIconColor,
            "--n-close-icon-color-hover": closeIconColorHover,
            "--n-close-icon-color-pressed": closeIconColorPressed,
            "--n-line-height": lineHeight,
            "--n-icon-color": iconColor,
            "--n-close-margin": closeMargin,
            "--n-close-size": closeSize,
            "--n-close-icon-size": closeIconSize,
            "--n-width": width,
            "--n-padding-left": left,
            "--n-padding-right": right,
            "--n-padding-top": top,
            "--n-padding-bottom": bottom,
            "--n-title-font-size": titleFontSize,
            "--n-meta-font-size": metaFontSize,
            "--n-description-font-size": descriptionFontSize
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "notification",
          vue.computed(() => props.type[0]),
          cssVarsRef,
          providerProps
        ) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          showAvatar: vue.computed(() => {
            return props.avatar || props.type !== "default";
          }),
          handleCloseClick() {
            props.onClose();
          },
          rtlEnabled: rtlEnabledRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedClsPrefix } = this;
        this.onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          class: [`${mergedClsPrefix}-notification-wrapper`, this.themeClass],
          onMouseenter: this.onMouseenter,
          onMouseleave: this.onMouseleave,
          style: this.cssVars
        }, /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-notification`,
            this.rtlEnabled && `${mergedClsPrefix}-notification--rtl`,
            this.themeClass,
            {
              [`${mergedClsPrefix}-notification--closable`]: this.closable,
              [`${mergedClsPrefix}-notification--show-avatar`]: this.showAvatar
            }
          ],
          style: this.cssVars
        }, this.showAvatar ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-notification__avatar`
        }, this.avatar ? render$1(this.avatar) : this.type !== "default" ? /* @__PURE__ */ React.createElement(NBaseIcon, {
          clsPrefix: mergedClsPrefix
        }, { default: () => iconRenderMap[this.type]() }) : null) : null, this.closable ? /* @__PURE__ */ React.createElement(NBaseClose, {
          clsPrefix: mergedClsPrefix,
          class: `${mergedClsPrefix}-notification__close`,
          onClick: this.handleCloseClick
        }) : null, /* @__PURE__ */ React.createElement("div", {
          ref: "bodyRef",
          class: `${mergedClsPrefix}-notification-main`
        }, this.title ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-notification-main__header`
        }, render$1(this.title)) : null, this.description ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-notification-main__description`
        }, render$1(this.description)) : null, this.content ? /* @__PURE__ */ React.createElement("pre", {
          class: `${mergedClsPrefix}-notification-main__content`
        }, render$1(this.content)) : null, this.meta || this.action ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-notification-main-footer`
        }, this.meta ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-notification-main-footer__meta`
        }, render$1(this.meta)) : null, this.action ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-notification-main-footer__action`
        }, render$1(this.action)) : null) : null)));
      }
    });

    const notificationEnvOptions = {
      ...notificationProps,
      duration: Number,
      onClose: Function,
      onLeave: Function,
      onAfterEnter: Function,
      onAfterLeave: Function,
      onHide: Function,
      onAfterShow: Function,
      onAfterHide: Function
    };
    const NotificationEnvironment = vue.defineComponent({
      name: "NotificationEnvironment",
      props: {
        ...notificationEnvOptions,
        internalKey: {
          type: String,
          required: true
        },
        onInternalAfterLeave: {
          type: Function,
          required: true
        }
      },
      setup(props) {
        const {
          wipTransitionCountRef
        } = vue.inject(notificationProviderInjectionKey);
        const showRef = vue.ref(true);
        let timerId = null;
        function hide() {
          showRef.value = false;
          if (timerId) {
            window.clearTimeout(timerId);
          }
        }
        function handleBeforeEnter(el) {
          wipTransitionCountRef.value++;
          void vue.nextTick(() => {
            el.style.height = `${el.offsetHeight}px`;
            el.style.maxHeight = "0";
            el.style.transition = "none";
            void el.offsetHeight;
            el.style.transition = "";
            el.style.maxHeight = el.style.height;
          });
        }
        function handleAfterEnter(el) {
          wipTransitionCountRef.value--;
          el.style.height = "";
          el.style.maxHeight = "";
          const { onAfterEnter, onAfterShow } = props;
          if (onAfterEnter)
            onAfterEnter();
          if (onAfterShow)
            onAfterShow();
        }
        function handleBeforeLeave(el) {
          wipTransitionCountRef.value++;
          el.style.maxHeight = `${el.offsetHeight}px`;
          el.style.height = `${el.offsetHeight}px`;
          void el.offsetHeight;
        }
        function handleLeave(el) {
          const { onHide } = props;
          if (onHide)
            onHide();
          el.style.maxHeight = "0";
          void el.offsetHeight;
        }
        function handleAfterLeave() {
          wipTransitionCountRef.value--;
          const { onAfterLeave, onInternalAfterLeave, onAfterHide, internalKey } = props;
          if (onAfterLeave)
            onAfterLeave();
          onInternalAfterLeave(internalKey);
          if (onAfterHide)
            onAfterHide();
        }
        function setHideTimeout() {
          const { duration } = props;
          if (duration) {
            timerId = window.setTimeout(hide, duration);
          }
        }
        function handleMouseenter(e) {
          if (e.currentTarget !== e.target)
            return;
          if (timerId !== null) {
            window.clearTimeout(timerId);
            timerId = null;
          }
        }
        function handleMouseleave(e) {
          if (e.currentTarget !== e.target)
            return;
          setHideTimeout();
        }
        function handleClose() {
          const { onClose } = props;
          if (onClose) {
            void Promise.resolve(onClose()).then((feedback) => {
              if (feedback === false)
                return;
              hide();
            });
          } else {
            hide();
          }
        }
        vue.onMounted(() => {
          if (props.duration) {
            timerId = window.setTimeout(hide, props.duration);
          }
        });
        return {
          show: showRef,
          hide,
          handleClose,
          handleAfterLeave,
          handleLeave,
          handleBeforeLeave,
          handleAfterEnter,
          handleBeforeEnter,
          handleMouseenter,
          handleMouseleave
        };
      },
      render() {
        return /* @__PURE__ */ React.createElement(vue.Transition, {
          name: "notification-transition",
          appear: true,
          onBeforeEnter: this.handleBeforeEnter,
          onAfterEnter: this.handleAfterEnter,
          onBeforeLeave: this.handleBeforeLeave,
          onLeave: this.handleLeave,
          onAfterLeave: this.handleAfterLeave
        }, {
          default: () => {
            return this.show ? /* @__PURE__ */ React.createElement(Notification, {
              ...keep(this.$props, notificationPropKeys),
              onClose: this.handleClose,
              onMouseenter: this.duration && this.keepAliveOnHover ? this.handleMouseenter : void 0,
              onMouseleave: this.duration && this.keepAliveOnHover ? this.handleMouseleave : void 0
            }) : null;
          }
        });
      }
    });

    var style$r = c$1([cB("notification-container", `
    z-index: 4000;
    position: fixed;
    overflow: visible;
    display: flex;
    flex-direction: column;
    align-items: flex-end;
  `, [c$1(">", [cB("scrollbar", `
        width: initial;
        overflow: visible;
        height: -moz-fit-content !important;
        height: fit-content !important;
        max-height: 100vh !important;
      `, [c$1(">", [cB("scrollbar-container", `
            height: -moz-fit-content !important;
            height: fit-content !important;
            max-height: 100vh !important;
          `, [cB("scrollbar-content", `
              padding-top: 12px;
              padding-bottom: 33px;
            `)])])])]), cM("top, top-right, top-left", `
      top: 12px;
    `, [c$1("&.transitioning >", [cB("scrollbar", [c$1(">", [cB("scrollbar-container", `
              min-height: 100vh !important;
            `)])])])]), cM("bottom, bottom-right, bottom-left", `
      bottom: 12px;
    `, [c$1(">", [cB("scrollbar", [c$1(">", [cB("scrollbar-container", [cB("scrollbar-content", `
                padding-bottom: 12px;
              `)])])])]), cB("notification-wrapper", `
        display: flex;
        align-items: flex-end;
        margin-bottom: 0;
        margin-top: 12px;
      `)]), cM("top, bottom", `
      left: 50%;
      transform: translateX(-50%);
    `, [cB("notification-wrapper", [c$1("&.notification-transition-enter-from, &.notification-transition-leave-to", `
          transform: scale(0.85);
        `), c$1("&.notification-transition-leave-from, &.notification-transition-enter-to", `
          transform: scale(1);
        `)])]), cM("top", [cB("notification-wrapper", `
        transform-origin: top center;
      `)]), cM("bottom", [cB("notification-wrapper", `
        transform-origin: bottom center;
      `)]), cM("top-right, bottom-right", [cB("notification", `
        margin-left: 28px;
        margin-right: 16px;
      `)]), cM("top-left, bottom-left", [cB("notification", `
        margin-left: 16px;
        margin-right: 28px;
      `)]), cM("top-right", `
      right: 0;
    `, [placementTransformStyle("top-right")]), cM("top-left", `
      left: 0;
    `, [placementTransformStyle("top-left")]), cM("bottom-right", `
      right: 0;
    `, [placementTransformStyle("bottom-right")]), cM("bottom-left", `
      left: 0;
    `, [placementTransformStyle("bottom-left")]), cM("scrollable", [cM("top-right", `
        top: 0;
      `), cM("top-left", `
        top: 0;
      `), cM("bottom-right", `
        bottom: 0;
      `), cM("bottom-left", `
        bottom: 0;
      `)]), cB("notification-wrapper", `
      margin-bottom: 12px;
    `, [c$1("&.notification-transition-enter-from, &.notification-transition-leave-to", `
        opacity: 0;
        margin-top: 0 !important;
        margin-bottom: 0 !important;
      `), c$1("&.notification-transition-leave-from, &.notification-transition-enter-to", `
        opacity: 1;
      `), c$1("&.notification-transition-leave-active", `
        transition:
          background-color .3s var(--n-bezier),
          color .3s var(--n-bezier),
          opacity .3s var(--n-bezier),
          transform .3s var(--n-bezier-ease-in),
          max-height .3s var(--n-bezier),
          margin-top .3s linear,
          margin-bottom .3s linear,
          box-shadow .3s var(--n-bezier);
      `), c$1("&.notification-transition-enter-active", `
        transition:
          background-color .3s var(--n-bezier),
          color .3s var(--n-bezier),
          opacity .3s var(--n-bezier),
          transform .3s var(--n-bezier-ease-out),
          max-height .3s var(--n-bezier),
          margin-top .3s linear,
          margin-bottom .3s linear,
          box-shadow .3s var(--n-bezier);
      `)]), cB("notification", `
      background-color: var(--n-color);
      color: var(--n-text-color);
      transition:
        background-color .3s var(--n-bezier),
        color .3s var(--n-bezier),
        opacity .3s var(--n-bezier),
        box-shadow .3s var(--n-bezier);
      font-family: inherit;
      font-size: var(--n-font-size);
      font-weight: 400;
      position: relative;
      display: flex;
      overflow: hidden;
      flex-shrink: 0;
      padding-left: var(--n-padding-left);
      padding-right: var(--n-padding-right);
      width: var(--n-width);
      border-radius: var(--n-border-radius);
      box-shadow: var(--n-box-shadow);
      box-sizing: border-box;
      opacity: 1;
    `, [cE("avatar", [cB("icon", {
      color: "var(--n-icon-color)"
    }), cB("base-icon", {
      color: "var(--n-icon-color)"
    })]), cM("show-avatar", [cB("notification-main", `
          margin-left: 40px;
          width: calc(100% - 40px);  
        `)]), cM("closable", [cB("notification-main", [c$1("> *:first-child", {
      paddingRight: "20px"
    })]), cE("close", `
          position: absolute;
          top: 0;
          right: 0;
          margin: var(--n-close-margin);
          transition:
            background-color .3s var(--n-bezier),
            color .3s var(--n-bezier);
        `)]), cE("avatar", `
        position: absolute;
        top: var(--n-padding-top);
        left: var(--n-padding-left);
        width: 28px;
        height: 28px;
        font-size: 28px;
        display: flex;
        align-items: center;
        justify-content: center;
      `, [cB("icon", "transition: color .3s var(--n-bezier);")]), cB("notification-main", `
        padding-top: var(--n-padding-top);
        padding-bottom: var(--n-padding-bottom);
        box-sizing: border-box;
        display: flex;
        flex-direction: column;
        margin-left: 8px;
        width: calc(100% - 8px);
      `, [cB("notification-main-footer", `
          display: flex;
          align-items: center;
          justify-content: space-between;
          margin-top: 12px;
        `, [cE("meta", `
            font-size: var(--n-meta-font-size);
            transition: color .3s var(--n-bezier-ease-out);
            color: var(--n-description-text-color);
          `), cE("action", `
            cursor: pointer;
            transition: color .3s var(--n-bezier-ease-out);
            color: var(--n-action-text-color);
          `)]), cE("header", `
          font-weight: var(--n-title-font-weight);
          font-size: var(--n-title-font-size);
          transition: color .3s var(--n-bezier-ease-out);
          color: var(--n-title-text-color);
        `), cE("description", `
          margin-top: 8px;
          font-size: var(--n-description-font-size);
          transition: color .3s var(--n-bezier-ease-out);
          color: var(--n-description-text-color);
        `), cE("content", `
          line-height: var(--n-line-height);
          margin: 12px 0 0 0;
          font-family: inherit;
          white-space: pre-wrap;
          word-wrap: break-word;
          transition: color .3s var(--n-bezier-ease-out);
          color: var(--n-text-color);
        `, [c$1("&:first-child", {
      margin: 0
    })])])])])]);

    function placementTransformStyle(placement) {
      const direction = placement.split("-")[1];
      const transformXEnter = direction === "left" ? "calc(-100%)" : "calc(100%)";
      const transformXLeave = "0";
      return cB("notification-wrapper", [c$1("&.notification-transition-enter-from, &.notification-transition-leave-to", `
      transform: translate(${transformXEnter}, 0);
    `), c$1("&.notification-transition-leave-from, &.notification-transition-enter-to", `
      transform: translate(${transformXLeave}, 0);
    `)]);
    }

    const notificationApiInjectionKey = createInjectionKey("n-notification-api");
    const notificationProviderProps = {
      ...useTheme.props,
      containerStyle: [String, Object],
      to: [String, Object],
      scrollable: {
        type: Boolean,
        default: true
      },
      max: Number,
      placement: {
        type: String,
        default: "top-right"
      },
      keepAliveOnHover: Boolean
    };
    var NNotificationProvider = vue.defineComponent({
      name: "NotificationProvider",
      props: notificationProviderProps,
      setup(props) {
        const { mergedClsPrefixRef } = useConfig(props);
        const notificationListRef = vue.ref([]);
        const notificationRefs = {};
        const leavingKeySet = /* @__PURE__ */ new Set();
        function create(options) {
          const key = createId();
          const destroy = () => {
            leavingKeySet.add(key);
            if (notificationRefs[key]) {
              notificationRefs[key].hide();
            }
          };
          const notificationReactive = vue.reactive({
            ...options,
            key,
            destroy,
            hide: destroy,
            deactivate: destroy
          });
          const { max } = props;
          if (max && notificationListRef.value.length - leavingKeySet.size >= max) {
            let someoneMountedRemoved = false;
            let index = 0;
            for (const notification of notificationListRef.value) {
              if (!leavingKeySet.has(notification.key)) {
                if (notificationRefs[notification.key]) {
                  notification.destroy();
                  someoneMountedRemoved = true;
                }
                break;
              }
              index++;
            }
            if (!someoneMountedRemoved) {
              notificationListRef.value.splice(index, 1);
            }
          }
          notificationListRef.value.push(notificationReactive);
          return notificationReactive;
        }
        const apis = ["info", "success", "warning", "error"].map(
          (type) => {
            return (options) => create({ ...options, type });
          }
        );
        function handleAfterLeave(key) {
          leavingKeySet.delete(key);
          notificationListRef.value.splice(
            notificationListRef.value.findIndex(
              (notification) => notification.key === key
            ),
            1
          );
        }
        const themeRef = useTheme(
          "Notification",
          "-notification",
          style$r,
          notificationLight$1,
          props,
          mergedClsPrefixRef
        );
        const api = {
          create,
          info: apis[0],
          success: apis[1],
          warning: apis[2],
          error: apis[3],
          open,
          destroyAll
        };
        const wipTransitionCountRef = vue.ref(0);
        vue.provide(notificationApiInjectionKey, api);
        vue.provide(notificationProviderInjectionKey, {
          props,
          mergedClsPrefixRef,
          mergedThemeRef: themeRef,
          wipTransitionCountRef
        });
        function open(options) {
          return create(options);
        }
        function destroyAll() {
          Object.values(notificationListRef.value).forEach((notification) => {
            notification.hide();
          });
        }
        return Object.assign(
          {
            mergedClsPrefix: mergedClsPrefixRef,
            notificationList: notificationListRef,
            notificationRefs,
            handleAfterLeave
          },
          api
        );
      },
      render() {
        const { placement } = this;
        return /* @__PURE__ */ React.createElement(React.Fragment, null, this.$slots.default?.(), this.notificationList.length ? /* @__PURE__ */ React.createElement(vue.Teleport, {
          to: this.to ?? "body"
        }, /* @__PURE__ */ React.createElement(NotificationContainer, {
          style: this.containerStyle,
          scrollable: this.scrollable && placement !== "top" && placement !== "bottom",
          placement
        }, {
          default: () => {
            return this.notificationList.map((notification) => {
              return /* @__PURE__ */ React.createElement(NotificationEnvironment, {
                ref: (inst) => {
                  const refKey = notification.key;
                  if (inst === null) {
                    delete this.notificationRefs[refKey];
                  } else
                    this.notificationRefs[refKey] = inst;
                },
                ...omit(notification, [
                  "destroy",
                  "hide",
                  "deactivate"
                ]),
                internalKey: notification.key,
                onInternalAfterLeave: this.handleAfterLeave,
                keepAliveOnHover: notification.keepAliveOnHover === void 0 ? this.keepAliveOnHover : notification.keepAliveOnHover
              });
            });
          }
        })) : null);
      }
    });

    function useNotification() {
      const api = vue.inject(notificationApiInjectionKey, null);

      if (api === null) {
        throwError("use-notification", "No outer `n-notification-provider` found.");
      }

      return api;
    }

    var style$q = c$1([cB("page-header-header", `
    margin-bottom: 20px;
  `), cB("page-header", `
    display: flex;
    align-items: center;
    justify-content: space-between;
    line-height: 1.5;
    font-size: var(--n-font-size);
  `, [cE("main", `
      display: flex;
      flex-wrap: nowrap;
      align-items: center;
    `), cE("back", `
      display: flex;
      margin-right: 16px;
      font-size: var(--n-back-size);
      cursor: pointer;
      color: var(--n-back-color);
      transition: color .3s var(--n-bezier);
    `, [c$1("&:hover", "color: var(--n-back-color-hover);"), c$1("&:active", "color: var(--n-back-color-pressed);")]), cE("avatar", `
      display: flex;
      margin-right: 12px
    `), cE("title", `
      margin-right: 16px;
      transition: color .3s var(--n-bezier);
      font-size: var(--n-title-font-size);
      font-weight: var(--n-title-font-weight);
      color: var(--n-title-text-color);
    `), cE("subtitle", `
      font-size: 14px;
      transition: color .3s var(--n-bezier);
      color: var(--n-subtitle-text-color);
    `)]), cB("page-header-content", `
    font-size: var(--n-font-size);
  `, [c$1("&:not(:first-child)", "margin-top: 20px;")]), cB("page-header-footer", `
    font-size: var(--n-font-size);
  `, [c$1("&:not(:first-child)", "margin-top: 20px;")])]);

    const pageHeaderProps = {
      ...useTheme.props,
      title: String,
      subtitle: String,
      extra: String,
      onBack: Function
    };
    var PageHeader = vue.defineComponent({
      name: "PageHeader",
      props: pageHeaderProps,
      setup(props) {
        const { mergedClsPrefixRef, mergedRtlRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "PageHeader",
          "-page-header",
          style$q,
          pageHeaderLight,
          props,
          mergedClsPrefixRef
        );
        const rtlEnabledRef = useRtl("PageHeader", mergedRtlRef, mergedClsPrefixRef);
        const cssVarsRef = vue.computed(() => {
          const {
            self: {
              titleTextColor,
              subtitleTextColor,
              backColor,
              fontSize,
              titleFontSize,
              backSize,
              titleFontWeight,
              backColorHover,
              backColorPressed
            },
            common: { cubicBezierEaseInOut }
          } = themeRef.value;
          return {
            "--n-title-text-color": titleTextColor,
            "--n-title-font-size": titleFontSize,
            "--n-title-font-weight": titleFontWeight,
            "--n-font-size": fontSize,
            "--n-back-size": backSize,
            "--n-subtitle-text-color": subtitleTextColor,
            "--n-back-color": backColor,
            "--n-back-color-hover": backColorHover,
            "--n-back-color-pressed": backColorPressed,
            "--n-bezier": cubicBezierEaseInOut
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("page-header", void 0, cssVarsRef, props) : void 0;
        return {
          rtlEnabled: rtlEnabledRef,
          mergedClsPrefix: mergedClsPrefixRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { onBack, title, subtitle, extra, mergedClsPrefix, cssVars, $slots } = this;
        this.onRender?.();
        const {
          title: titleSlot,
          subtitle: subtitleSlot,
          extra: extraSlot,
          default: defaultSlot,
          header: headerSlot,
          avatar: avatarSlot,
          footer: footerSlot,
          back: backSlot
        } = $slots;
        const showBack = onBack;
        const showTitle = title || titleSlot;
        const showSubtitle = subtitle || subtitleSlot;
        const showExtra = extra || extraSlot;
        return /* @__PURE__ */ React.createElement("div", {
          style: cssVars,
          class: [
            `${mergedClsPrefix}-page-header-wrapper`,
            this.themeClass,
            this.rtlEnabled && `${mergedClsPrefix}-page-header-wrapper--rtl`
          ]
        }, headerSlot ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-page-header-header`,
          key: "breadcrumb"
        }, headerSlot()) : null, (showBack || avatarSlot || showTitle || showSubtitle || showExtra) && /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-page-header`,
          key: "header"
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-page-header__main`,
          key: "back"
        }, showBack ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-page-header__back`,
          onClick: onBack
        }, backSlot ? backSlot() : /* @__PURE__ */ React.createElement(NBaseIcon, {
          clsPrefix: mergedClsPrefix
        }, {
          default: () => /* @__PURE__ */ React.createElement(ArrowBackIcon, null)
        })) : null, avatarSlot ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-page-header__avatar`
        }, avatarSlot()) : null, showTitle ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-page-header__title`,
          key: "title"
        }, title || titleSlot()) : null, showSubtitle ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-page-header__subtitle`,
          key: "subtitle"
        }, subtitle || subtitleSlot()) : null), showExtra ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-page-header__extra`
        }, extra || extraSlot()) : null), defaultSlot ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-page-header-content`,
          key: "content"
        }, defaultSlot()) : null, footerSlot ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-page-header-footer`,
          key: "footer"
        }, footerSlot()) : null);
      }
    });

    const popconfirmInjectionKey = createInjectionKey("n-popconfirm");

    const panelProps = {
      positiveText: String,
      negativeText: String,
      showIcon: {
        type: Boolean,
        default: true
      },
      onPositiveClick: {
        type: Function,
        required: true
      },
      onNegativeClick: {
        type: Function,
        required: true
      }
    };
    const panelPropKeys = keysOf(panelProps);
    var PopconfirmPanel = vue.defineComponent({
      name: "NPopconfirmPanel",
      props: panelProps,
      setup(props) {
        const { localeRef } = useLocale("Popconfirm");
        const { inlineThemeDisabled } = useConfig();
        const {
          mergedClsPrefixRef,
          mergedThemeRef,
          props: popconfirmProps
        } = vue.inject(popconfirmInjectionKey);
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self: { fontSize, iconSize, iconColor }
          } = mergedThemeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-font-size": fontSize,
            "--n-icon-size": iconSize,
            "--n-icon-color": iconColor
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "popconfirm-panel",
          void 0,
          cssVarsRef,
          popconfirmProps
        ) : void 0;
        return {
          ...useLocale("Popconfirm"),
          mergedClsPrefix: mergedClsPrefixRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          localizedPositiveText: vue.computed(() => {
            return props.positiveText || localeRef.value.positiveText;
          }),
          localizedNegativeText: vue.computed(() => {
            return props.negativeText || localeRef.value.negativeText;
          }),
          positiveButtonProps: vue.toRef(popconfirmProps, "positiveButtonProps"),
          negativeButtonProps: vue.toRef(popconfirmProps, "negativeButtonProps"),
          handlePositiveClick(e) {
            props.onPositiveClick(e);
          },
          handleNegativeClick(e) {
            props.onNegativeClick(e);
          },
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedClsPrefix, showIcon, $slots } = this;
        const actionContentNode = resolveSlot(
          $slots.action,
          () => this.negativeText === null && this.positiveText === null ? [] : [
            this.negativeText !== null && /* @__PURE__ */ React.createElement(NButton, {
              size: "small",
              onClick: this.handleNegativeClick,
              ...this.negativeButtonProps
            }, { default: () => this.localizedNegativeText }),
            this.positiveText !== null && /* @__PURE__ */ React.createElement(NButton, {
              size: "small",
              type: "primary",
              onClick: this.handlePositiveClick,
              ...this.positiveButtonProps
            }, { default: () => this.localizedPositiveText })
          ]
        );
        this.onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          class: [`${mergedClsPrefix}-popconfirm__panel`, this.themeClass],
          style: this.cssVars
        }, resolveWrappedSlot(
          $slots.default,
          (children) => showIcon || children ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-popconfirm__body`
          }, showIcon ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-popconfirm__icon`
          }, resolveSlot($slots.icon, () => [
            /* @__PURE__ */ React.createElement(NBaseIcon, {
              clsPrefix: mergedClsPrefix
            }, { default: () => /* @__PURE__ */ React.createElement(WarningIcon, null) })
          ])) : null, children) : null
        ), actionContentNode ? /* @__PURE__ */ React.createElement("div", {
          class: [`${mergedClsPrefix}-popconfirm__action`]
        }, actionContentNode) : null);
      }
    });

    var style$p = cB("popconfirm", [cE("body", `
    font-size: var(--n-font-size);
    display: flex;
    align-items: center;
    flex-wrap: nowrap;
    position: relative;
  `, [cE("icon", `
      display: flex;
      font-size: var(--n-icon-size);
      color: var(--n-icon-color);
      transition: color .3s var(--n-bezier);
      margin: 0 8px 0 0;
    `)]), cE("action", `
    display: flex;
    justify-content: flex-end;
  `, [c$1("&:not(:first-child)", "margin-top: 8px"), cB("button", [c$1("&:not(:last-child)", "margin-right: 8px;")])])]);

    const popconfirmProps = { ...useTheme.props,
      ...popoverBaseProps,
      positiveText: String,
      negativeText: String,
      showIcon: {
        type: Boolean,
        default: true
      },
      trigger: {
        type: String,
        default: "click"
      },
      positiveButtonProps: Object,
      negativeButtonProps: Object,
      onPositiveClick: Function,
      onNegativeClick: Function
    };
    var Popconfirm = vue.defineComponent({
      name: "Popconfirm",
      props: popconfirmProps,
      __popover__: true,

      setup(props) {
        const {
          mergedClsPrefixRef
        } = useConfig();
        const themeRef = useTheme("Popconfirm", "-popconfirm", style$p, popconfirmLight$1, props, mergedClsPrefixRef);
        const popoverInstRef = vue.ref(null);

        function handlePositiveClick(e) {
          const {
            onPositiveClick,
            "onUpdate:show": onUpdateShow
          } = props;
          void Promise.resolve(onPositiveClick ? onPositiveClick(e) : true).then(value => {
            var _popoverInstRef$value;

            if (value === false) return;
            (_popoverInstRef$value = popoverInstRef.value) === null || _popoverInstRef$value === void 0 ? void 0 : _popoverInstRef$value.setShow(false);
            if (onUpdateShow) call(onUpdateShow, false);
          });
        }

        function handleNegativeClick(e) {
          const {
            onNegativeClick,
            "onUpdate:show": onUpdateShow
          } = props;
          void Promise.resolve(onNegativeClick ? onNegativeClick(e) : true).then(value => {
            var _popoverInstRef$value2;

            if (value === false) return;
            (_popoverInstRef$value2 = popoverInstRef.value) === null || _popoverInstRef$value2 === void 0 ? void 0 : _popoverInstRef$value2.setShow(false);
            if (onUpdateShow) call(onUpdateShow, false);
          });
        }

        vue.provide(popconfirmInjectionKey, {
          mergedThemeRef: themeRef,
          mergedClsPrefixRef,
          props
        });
        const exposedMethods = {
          setShow(value) {
            var _popoverInstRef$value3;

            (_popoverInstRef$value3 = popoverInstRef.value) === null || _popoverInstRef$value3 === void 0 ? void 0 : _popoverInstRef$value3.setShow(value);
          },

          syncPosition() {
            var _popoverInstRef$value4;

            (_popoverInstRef$value4 = popoverInstRef.value) === null || _popoverInstRef$value4 === void 0 ? void 0 : _popoverInstRef$value4.syncPosition();
          }

        };
        return { ...exposedMethods,
          mergedTheme: themeRef,
          popoverInstRef,
          handlePositiveClick,
          handleNegativeClick
        };
      },

      render() {
        const {
          $slots: slots,
          $props: props,
          mergedTheme
        } = this;
        return vue.h(NPopover, omit(props, panelPropKeys, {
          theme: mergedTheme.peers.Popover,
          themeOverrides: mergedTheme.peerOverrides.Popover,
          internalExtraClass: ["popconfirm"],
          ref: "popoverInstRef"
        }), {
          trigger: slots.activator || slots.trigger,
          default: () => {
            const panelProps = keep(props, panelPropKeys);
            return vue.h(PopconfirmPanel, { ...panelProps,
              onPositiveClick: this.handlePositiveClick,
              onNegativeClick: this.handleNegativeClick
            }, slots);
          }
        });
      }

    });

    var style$o = c$1([cB("progress", {
      display: "inline-block"
    }, [cB("progress-icon", `
      color: var(--n-icon-color);
      transition: color .3s var(--n-bezier);
    `), cM("line", `
      width: 100%;
      display: block;
    `, [cB("progress-content", `
        display: flex;
        align-items: center;
      `, [cB("progress-graph", {
      flex: 1
    })]), cB("progress-custom-content", {
      marginLeft: "14px"
    }), cB("progress-icon", `
        width: 30px;
        padding-left: 14px;
        height: var(--n-icon-size-line);
        line-height: var(--n-icon-size-line);
        font-size: var(--n-icon-size-line);
      `, [cM("as-text", `
          color: var(--n-text-color-line-outer);
          text-align: center;
          width: 40px;
          font-size: var(--n-font-size);
          padding-left: 4px;
          transition: color .3s var(--n-bezier);
        `)])]), cM("circle, dashboard", {
      width: "120px"
    }, [cB("progress-custom-content", `
        position: absolute;
        left: 50%;
        top: 50%;
        transform: translateX(-50%) translateY(-50%);
        display: flex;
        align-items: center;
        justify-content: center;
      `), cB("progress-text", `
        position: absolute;
        left: 50%;
        top: 50%;
        transform: translateX(-50%) translateY(-50%);
        display: flex;
        align-items: center;
        color: inherit;
        font-size: var(--n-font-size-circle);
        color: var(--n-text-color-circle);
        font-weight: var(--n-font-weight-circle);
        transition: color .3s var(--n-bezier);
        white-space: nowrap;
      `), cB("progress-icon", `
        position: absolute;
        left: 50%;
        top: 50%;
        transform: translateX(-50%) translateY(-50%);
        display: flex;
        align-items: center;
        color: var(--n-icon-color);
        font-size: var(--n-icon-size-circle);
      `)]), cM("multiple-circle", `
      width: 200px;
      color: inherit;
    `, [cB("progress-text", `
        font-weight: var(--n-font-weight-circle);
        color: var(--n-text-color-circle);
        position: absolute;
        left: 50%;
        top: 50%;
        transform: translateX(-50%) translateY(-50%);
        display: flex;
        align-items: center;
        justify-content: center;
        transition: color .3s var(--n-bezier);
      `)]), cB("progress-content", {
      position: "relative"
    }), cB("progress-graph", {
      position: "relative"
    }, [cB("progress-graph-circle", [c$1("svg", {
      verticalAlign: "bottom"
    }), cB("progress-graph-circle-fill", `
          stroke: var(--n-fill-color);
          transition:
            opacity .3s var(--n-bezier),
            stroke .3s var(--n-bezier),
            stroke-dasharray .3s var(--n-bezier);
        `, [cM("empty", {
      opacity: 0
    })]), cB("progress-graph-circle-rail", `
          transition: stroke .3s var(--n-bezier);
          overflow: hidden;
          stroke: var(--n-rail-color);
        `)]), cB("progress-graph-line", [cM("indicator-inside", [cB("progress-graph-line-rail", `
            height: 16px;
            line-height: 16px;
            border-radius: 10px;
          `, [cB("progress-graph-line-fill", `
              height: inherit;
              border-radius: 10px;
            `), cB("progress-graph-line-indicator", `
              background: #0000;
              white-space: nowrap;
              text-align: right;
              margin-left: 14px;
              margin-right: 14px;
              height: inherit;
              font-size: 12px;
              color: var(--n-text-color-line-inner);
              transition: color .3s var(--n-bezier);
            `)])]), cM("indicator-inside-label", `
          height: 16px;
          display: flex;
          align-items: center;
        `, [cB("progress-graph-line-rail", `
            flex: 1;
            transition: background-color .3s var(--n-bezier);
          `), cB("progress-graph-line-indicator", `
            background: var(--n-fill-color);
            font-size: 12px;
            transform: translateZ(0);
            display: flex;
            vertical-align: middle;
            height: 16px;
            line-height: 16px;
            padding: 0 10px;
            border-radius: 10px;
            position: absolute;
            white-space: nowrap;
            color: var(--n-text-color-line-inner);
            transition:
              right .2s var(--n-bezier),
              color .3s var(--n-bezier),
              background-color .3s var(--n-bezier);
          `)]), cB("progress-graph-line-rail", `
          position: relative;
          overflow: hidden;
          height: var(--n-rail-height);
          border-radius: 5px;
          background-color: var(--n-rail-color);
          transition: background-color .3s var(--n-bezier);
        `, [cB("progress-graph-line-fill", `
            background: var(--n-fill-color);
            position: relative;
            border-radius: 5px;
            height: inherit;
            width: 100%;
            max-width: 0%;
            transition:
              background-color .3s var(--n-bezier),
              max-width .2s var(--n-bezier);
          `, [cM("processing", [c$1("&::after", `
                content: "";
                background-image: var(--n-line-bg-processing);
                animation: progress-processing-animation 2s var(--n-bezier) infinite;
              `)])])])])])]), c$1("@keyframes progress-processing-animation", `
    0% {
      position: absolute;
      left: 0;
      top: 0;
      bottom: 0;
      right: 100%;
      opacity: 1;
    }
    66% {
      position: absolute;
      left: 0;
      top: 0;
      bottom: 0;
      right: 0;
      opacity: 0;
    }
    100% {
      position: absolute;
      left: 0;
      top: 0;
      bottom: 0;
      right: 0;
      opacity: 0;
    }
  `)]);

    const iconMap$2 = {
      success: /* @__PURE__ */ React.createElement(SuccessIcon, null),
      error: /* @__PURE__ */ React.createElement(ErrorIcon, null),
      warning: /* @__PURE__ */ React.createElement(WarningIcon, null),
      info: /* @__PURE__ */ React.createElement(InfoIcon, null)
    };
    var Line = vue.defineComponent({
      name: "ProgressLine",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        percentage: {
          type: Number,
          default: 0
        },
        railColor: String,
        railStyle: [String, Object],
        fillColor: String,
        status: {
          type: String,
          required: true
        },
        indicatorPlacement: {
          type: String,
          required: true
        },
        indicatorTextColor: String,
        unit: {
          type: String,
          default: "%"
        },
        processing: {
          type: Boolean,
          required: true
        },
        showIndicator: {
          type: Boolean,
          required: true
        },
        height: [String, Number],
        railBorderRadius: [String, Number],
        fillBorderRadius: [String, Number]
      },
      setup(props, { slots }) {
        const styleHeightRef = vue.computed(() => {
          return formatLength(props.height);
        });
        const styleRailBorderRadiusRef = vue.computed(() => {
          if (props.railBorderRadius !== void 0) {
            return formatLength(props.railBorderRadius);
          }
          if (props.height !== void 0) {
            return formatLength(props.height, { c: 0.5 });
          }
          return "";
        });
        const styleFillBorderRadiusRef = vue.computed(() => {
          if (props.fillBorderRadius !== void 0) {
            return formatLength(props.fillBorderRadius);
          }
          if (props.railBorderRadius !== void 0) {
            return formatLength(props.railBorderRadius);
          }
          if (props.height !== void 0) {
            return formatLength(props.height, { c: 0.5 });
          }
          return "";
        });
        return () => {
          const {
            indicatorPlacement,
            railColor,
            railStyle,
            percentage,
            unit,
            indicatorTextColor,
            status,
            showIndicator,
            fillColor,
            processing,
            clsPrefix
          } = props;
          return /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-progress-content`,
            role: "none"
          }, /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-progress-graph`,
            "aria-hidden": true
          }, /* @__PURE__ */ React.createElement("div", {
            class: [
              `${clsPrefix}-progress-graph-line`,
              {
                [`${clsPrefix}-progress-graph-line--indicator-${indicatorPlacement}`]: true
              }
            ]
          }, /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-progress-graph-line-rail`,
            style: [
              {
                backgroundColor: railColor,
                height: styleHeightRef.value,
                borderRadius: styleRailBorderRadiusRef.value
              },
              railStyle
            ]
          }, /* @__PURE__ */ React.createElement("div", {
            class: [
              `${clsPrefix}-progress-graph-line-fill`,
              processing && `${clsPrefix}-progress-graph-line-fill--processing`
            ],
            style: {
              maxWidth: `${props.percentage}%`,
              backgroundColor: fillColor,
              height: styleHeightRef.value,
              lineHeight: styleHeightRef.value,
              borderRadius: styleFillBorderRadiusRef.value
            }
          }, indicatorPlacement === "inside" ? /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-progress-graph-line-indicator`
          }, percentage, unit) : null)))), showIndicator && indicatorPlacement === "outside" ? /* @__PURE__ */ React.createElement("div", null, slots.default ? /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-progress-custom-content`,
            style: {
              color: indicatorTextColor
            },
            role: "none"
          }, slots.default()) : status === "default" ? /* @__PURE__ */ React.createElement("div", {
            role: "none",
            class: `${clsPrefix}-progress-icon ${clsPrefix}-progress-icon--as-text`,
            style: {
              color: indicatorTextColor
            }
          }, percentage, unit) : /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-progress-icon`,
            "aria-hidden": true
          }, /* @__PURE__ */ React.createElement(NBaseIcon, {
            clsPrefix
          }, { default: () => iconMap$2[status] }))) : null);
        };
      }
    });

    const iconMap$1 = {
      success: /* @__PURE__ */ React.createElement(SuccessIcon, null),
      error: /* @__PURE__ */ React.createElement(ErrorIcon, null),
      warning: /* @__PURE__ */ React.createElement(WarningIcon, null),
      info: /* @__PURE__ */ React.createElement(InfoIcon, null)
    };
    var Circle = vue.defineComponent({
      name: "ProgressCircle",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        status: {
          type: String,
          required: true
        },
        strokeWidth: {
          type: Number,
          required: true
        },
        fillColor: String,
        railColor: String,
        railStyle: [String, Object],
        percentage: {
          type: Number,
          default: 0
        },
        offsetDegree: {
          type: Number,
          default: 0
        },
        showIndicator: {
          type: Boolean,
          required: true
        },
        indicatorTextColor: String,
        unit: String,
        viewBoxWidth: {
          type: Number,
          required: true
        },
        gapDegree: {
          type: Number,
          required: true
        },
        gapOffsetDegree: {
          type: Number,
          default: 0
        }
      },
      setup(props, { slots }) {
        function getPathStyles(percent, offsetDegree, strokeColor) {
          const { gapDegree, viewBoxWidth } = props;
          const radius = 50;
          const beginPositionX = 0;
          const beginPositionY = radius;
          const endPositionX = 0;
          const endPositionY = 2 * radius;
          const pathString = `M 55,55 m ${beginPositionX},${beginPositionY}
      a ${radius},${radius} 0 1 1 ${endPositionX},${-endPositionY}
      a ${radius},${radius} 0 1 1 ${-endPositionX},${endPositionY}`;
          const len = Math.PI * 2 * radius;
          const pathStyle = {
            stroke: strokeColor,
            strokeDasharray: `${percent / 100 * (len - gapDegree)}px ${viewBoxWidth * 8}px`,
            strokeDashoffset: `-${gapDegree / 2}px`,
            transformOrigin: offsetDegree ? "center" : void 0,
            transform: offsetDegree ? `rotate(${offsetDegree}deg)` : void 0
          };
          return {
            pathString,
            pathStyle
          };
        }
        return () => {
          const {
            fillColor,
            railColor,
            strokeWidth,
            offsetDegree,
            status,
            percentage,
            showIndicator,
            indicatorTextColor,
            unit,
            gapOffsetDegree,
            clsPrefix
          } = props;
          const { pathString: railPathString, pathStyle: railPathStyle } = getPathStyles(100, 0, railColor);
          const { pathString: fillPathString, pathStyle: fillPathStyle } = getPathStyles(percentage, offsetDegree, fillColor);
          return /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-progress-content`,
            role: "none"
          }, /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-progress-graph`,
            "aria-hidden": true
          }, /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-progress-graph-circle`,
            style: {
              transform: gapOffsetDegree ? `rotate(${gapOffsetDegree}deg)` : void 0
            }
          }, /* @__PURE__ */ React.createElement("svg", {
            viewBox: "0 0 110 110"
          }, /* @__PURE__ */ React.createElement("g", null, /* @__PURE__ */ React.createElement("path", {
            class: `${clsPrefix}-progress-graph-circle-rail`,
            d: railPathString,
            "stroke-width": strokeWidth,
            "stroke-linecap": "round",
            fill: "none",
            style: railPathStyle
          })), /* @__PURE__ */ React.createElement("g", null, /* @__PURE__ */ React.createElement("path", {
            class: [
              `${clsPrefix}-progress-graph-circle-fill`,
              percentage === 0 && `${clsPrefix}-progress-graph-circle-fill--empty`
            ],
            d: fillPathString,
            "stroke-width": strokeWidth,
            "stroke-linecap": "round",
            fill: "none",
            style: fillPathStyle
          }))))), showIndicator ? /* @__PURE__ */ React.createElement("div", null, slots.default ? /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-progress-custom-content`,
            role: "none"
          }, slots.default()) : status !== "default" ? /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-progress-icon`,
            "aria-hidden": true
          }, /* @__PURE__ */ React.createElement(NBaseIcon, {
            clsPrefix
          }, {
            default: () => iconMap$1[status]
          })) : /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-progress-text`,
            style: {
              color: indicatorTextColor
            },
            role: "none"
          }, /* @__PURE__ */ React.createElement("span", {
            class: `${clsPrefix}-progress-text__percentage`
          }, percentage), /* @__PURE__ */ React.createElement("span", {
            class: `${clsPrefix}-progress-text__unit`
          }, unit))) : null);
        };
      }
    });

    function circlePath(r, sw, vw = 100) {
      return `m ${vw / 2} ${vw / 2 - r} a ${r} ${r} 0 1 1 0 ${2 * r} a ${r} ${r} 0 1 1 0 -${2 * r}`;
    }
    var MultipleCircle = vue.defineComponent({
      name: "ProgressMultipleCircle",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        viewBoxWidth: {
          type: Number,
          required: true
        },
        percentage: {
          type: Array,
          default: [0]
        },
        strokeWidth: {
          type: Number,
          required: true
        },
        circleGap: {
          type: Number,
          required: true
        },
        showIndicator: {
          type: Boolean,
          required: true
        },
        fillColor: {
          type: Array,
          default: () => []
        },
        railColor: {
          type: Array,
          default: () => []
        },
        railStyle: {
          type: Array,
          default: () => []
        }
      },
      setup(props, { slots }) {
        const strokeDasharrayRef = vue.computed(() => {
          const strokeDasharrays = props.percentage.map(
            (v, i) => `${Math.PI * v / 100 * (props.viewBoxWidth / 2 - props.strokeWidth / 2 * (1 + 2 * i) - props.circleGap * i) * 2}, ${props.viewBoxWidth * 8}`
          );
          return strokeDasharrays;
        });
        return () => {
          const {
            viewBoxWidth,
            strokeWidth,
            circleGap,
            showIndicator,
            fillColor,
            railColor,
            railStyle,
            percentage,
            clsPrefix
          } = props;
          return /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-progress-content`,
            role: "none"
          }, /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-progress-graph`,
            "aria-hidden": true
          }, /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-progress-graph-circle`
          }, /* @__PURE__ */ React.createElement("svg", {
            viewBox: `0 0 ${viewBoxWidth} ${viewBoxWidth}`
          }, percentage.map((p, index) => {
            return /* @__PURE__ */ React.createElement("g", {
              key: index
            }, /* @__PURE__ */ React.createElement("path", {
              class: `${clsPrefix}-progress-graph-circle-rail`,
              d: circlePath(
                viewBoxWidth / 2 - strokeWidth / 2 * (1 + 2 * index) - circleGap * index,
                strokeWidth,
                viewBoxWidth
              ),
              "stroke-width": strokeWidth,
              "stroke-linecap": "round",
              fill: "none",
              style: [
                {
                  strokeDashoffset: 0,
                  stroke: railColor[index]
                },
                railStyle[index]
              ]
            }), /* @__PURE__ */ React.createElement("path", {
              class: [
                `${clsPrefix}-progress-graph-circle-fill`,
                p === 0 && `${clsPrefix}-progress-graph-circle-fill--empty`
              ],
              d: circlePath(
                viewBoxWidth / 2 - strokeWidth / 2 * (1 + 2 * index) - circleGap * index,
                strokeWidth,
                viewBoxWidth
              ),
              "stroke-width": strokeWidth,
              "stroke-linecap": "round",
              fill: "none",
              style: {
                strokeDasharray: strokeDasharrayRef.value[index],
                strokeDashoffset: 0,
                stroke: fillColor[index]
              }
            }));
          })))), showIndicator && slots.default ? /* @__PURE__ */ React.createElement("div", null, /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-progress-text`
          }, slots.default())) : null);
        };
      }
    });

    const progressProps = {
      ...useTheme.props,
      processing: Boolean,
      type: {
        type: String,
        default: "line"
      },
      gapDegree: Number,
      gapOffsetDegree: Number,
      status: {
        type: String,
        default: "default"
      },
      railColor: [String, Array],
      railStyle: [String, Array],
      color: [String, Array],
      viewBoxWidth: {
        type: Number,
        default: 100
      },
      strokeWidth: {
        type: Number,
        default: 7
      },
      percentage: [Number, Array],
      unit: {
        type: String,
        default: "%"
      },
      showIndicator: {
        type: Boolean,
        default: true
      },
      indicatorPosition: {
        type: String,
        default: "outside"
      },
      indicatorPlacement: {
        type: String,
        default: "outside"
      },
      indicatorTextColor: String,
      circleGap: {
        type: Number,
        default: 1
      },
      height: Number,
      borderRadius: [String, Number],
      fillBorderRadius: [String, Number],
      offsetDegree: Number
    };
    var NProgress = vue.defineComponent({
      name: "Progress",
      props: progressProps,
      setup(props) {
        const mergedIndicatorPlacementRef = vue.computed(() => {
          return props.indicatorPlacement || props.indicatorPosition;
        });
        const gapDeg = vue.computed(() => {
          if (props.gapDegree || props.gapDegree === 0) {
            return props.gapDegree;
          }
          if (props.type === "dashboard") {
            return 75;
          }
          return void 0;
        });
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Progress",
          "-progress",
          style$o,
          progressLight$1,
          props,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const { status } = props;
          const {
            common: { cubicBezierEaseInOut },
            self: {
              fontSize,
              fontSizeCircle,
              railColor,
              railHeight,
              iconSizeCircle,
              iconSizeLine,
              textColorCircle,
              textColorLineInner,
              textColorLineOuter,
              lineBgProcessing,
              fontWeightCircle,
              [createKey("iconColor", status)]: iconColor,
              [createKey("fillColor", status)]: fillColor
            }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-fill-color": fillColor,
            "--n-font-size": fontSize,
            "--n-font-size-circle": fontSizeCircle,
            "--n-font-weight-circle": fontWeightCircle,
            "--n-icon-color": iconColor,
            "--n-icon-size-circle": iconSizeCircle,
            "--n-icon-size-line": iconSizeLine,
            "--n-line-bg-processing": lineBgProcessing,
            "--n-rail-color": railColor,
            "--n-rail-height": railHeight,
            "--n-text-color-circle": textColorCircle,
            "--n-text-color-line-inner": textColorLineInner,
            "--n-text-color-line-outer": textColorLineOuter
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "progress",
          vue.computed(() => props.status[0]),
          cssVarsRef,
          props
        ) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          mergedIndicatorPlacement: mergedIndicatorPlacementRef,
          gapDeg,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const {
          type,
          cssVars,
          indicatorTextColor,
          showIndicator,
          status,
          railColor,
          railStyle,
          color,
          percentage,
          viewBoxWidth,
          strokeWidth,
          mergedIndicatorPlacement,
          unit,
          borderRadius,
          fillBorderRadius,
          height,
          processing,
          circleGap,
          mergedClsPrefix,
          gapDeg,
          gapOffsetDegree,
          themeClass,
          $slots,
          onRender
        } = this;
        onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            themeClass,
            `${mergedClsPrefix}-progress`,
            `${mergedClsPrefix}-progress--${type}`,
            `${mergedClsPrefix}-progress--${status}`
          ],
          style: cssVars,
          "aria-valuemax": 100,
          "aria-valuemin": 0,
          "aria-valuenow": percentage,
          role: type === "circle" || type === "line" || type === "dashboard" ? "progressbar" : "none"
        }, type === "circle" || type === "dashboard" ? /* @__PURE__ */ React.createElement(Circle, {
          clsPrefix: mergedClsPrefix,
          status,
          showIndicator,
          indicatorTextColor,
          railColor,
          fillColor: color,
          railStyle,
          offsetDegree: this.offsetDegree,
          percentage,
          viewBoxWidth,
          strokeWidth,
          gapDegree: gapDeg === void 0 ? type === "dashboard" ? 75 : 0 : gapDeg,
          gapOffsetDegree,
          unit
        }, $slots) : type === "line" ? /* @__PURE__ */ React.createElement(Line, {
          clsPrefix: mergedClsPrefix,
          status,
          showIndicator,
          indicatorTextColor,
          railColor,
          fillColor: color,
          railStyle,
          percentage,
          processing,
          indicatorPlacement: mergedIndicatorPlacement,
          unit,
          fillBorderRadius,
          railBorderRadius: borderRadius,
          height
        }, $slots) : type === "multiple-circle" ? /* @__PURE__ */ React.createElement(MultipleCircle, {
          clsPrefix: mergedClsPrefix,
          strokeWidth,
          railColor,
          fillColor: color,
          railStyle,
          viewBoxWidth,
          percentage,
          showIndicator,
          circleGap
        }, $slots) : null);
      }
    });

    var StarIcon = /* @__PURE__ */ React.createElement("svg", {
      viewBox: "0 0 512 512"
    }, /* @__PURE__ */ React.createElement("path", {
      d: "M394 480a16 16 0 01-9.39-3L256 383.76 127.39 477a16 16 0 01-24.55-18.08L153 310.35 23 221.2a16 16 0 019-29.2h160.38l48.4-148.95a16 16 0 0130.44 0l48.4 149H480a16 16 0 019.05 29.2L359 310.35l50.13 148.53A16 16 0 01394 480z"
    }));

    var style$n = cB("rate", {
      display: "inline-flex",
      flexWrap: "nowrap"
    }, [c$1("&:hover", [cE("item", `
      transition:
        transform .1s var(--n-bezier),
        color .3s var(--n-bezier);
    `)]), cE("item", `
    position: relative;
    display: flex;
    transition:
      transform .1s var(--n-bezier),
      color .3s var(--n-bezier);
    transform: scale(1);
    font-size: var(--n-item-size);
    color: var(--n-item-color);
  `, [c$1("&:not(:first-child)", `
      margin-left: 6px;
    `), cM("active", `
      color: var(--n-item-color-active);
    `)]), cNotM("readonly", `
    cursor: pointer;
  `, [cE("item", [c$1("&:hover", `
        transform: scale(1.05);
      `), c$1("&:active", `
        transform: scale(0.96);
      `)])]), cE("half", `
    display: flex;
    transition: inherit;
    position: absolute;
    top: 0;
    left: 0;
    bottom: 0;
    width: 50%;
    overflow: hidden;
    color: rgba(255, 255, 255, 0);
  `, [cM("active", `
      color: var(--n-item-color-active);
    `)])]);

    const rateProps = {
      ...useTheme.props,
      allowHalf: Boolean,
      count: {
        type: Number,
        default: 5
      },
      value: Number,
      defaultValue: {
        type: Number,
        default: null
      },
      readonly: Boolean,
      size: {
        type: [String, Number],
        default: "medium"
      },
      clearable: Boolean,
      color: String,
      onClear: Function,
      "onUpdate:value": [Function, Array],
      onUpdateValue: [Function, Array]
    };
    var Rate = vue.defineComponent({
      name: "Rate",
      props: rateProps,
      setup(props) {
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Rate",
          "-rate",
          style$n,
          rateLight,
          props,
          mergedClsPrefixRef
        );
        const controlledValueRef = vue.toRef(props, "value");
        const uncontrolledValueRef = vue.ref(props.defaultValue);
        const hoverIndexRef = vue.ref(null);
        const formItem = useFormItem(props);
        const mergedValue = useMergedState(controlledValueRef, uncontrolledValueRef);
        function doUpdateValue(value) {
          const { "onUpdate:value": _onUpdateValue, onUpdateValue } = props;
          const { nTriggerFormChange, nTriggerFormInput } = formItem;
          if (_onUpdateValue) {
            call(_onUpdateValue, value);
          }
          if (onUpdateValue) {
            call(onUpdateValue, value);
          }
          uncontrolledValueRef.value = value;
          nTriggerFormChange();
          nTriggerFormInput();
        }
        function getDerivedValue(index, e) {
          if (props.allowHalf) {
            if (e.offsetX >= Math.floor(e.currentTarget.offsetWidth / 2)) {
              return index + 1;
            } else {
              return index + 0.5;
            }
          } else {
            return index + 1;
          }
        }
        let cleared = false;
        function handleMouseMove(index, e) {
          if (cleared)
            return;
          hoverIndexRef.value = getDerivedValue(index, e);
        }
        function handleMouseLeave() {
          hoverIndexRef.value = null;
        }
        function handleClick(index, e) {
          const { clearable } = props;
          const derivedValue = getDerivedValue(index, e);
          if (clearable && derivedValue === mergedValue.value) {
            cleared = true;
            props.onClear?.();
            hoverIndexRef.value = null;
            doUpdateValue(null);
          } else {
            doUpdateValue(derivedValue);
          }
        }
        function handleMouseEnterSomeStar() {
          cleared = false;
        }
        const mergedSizeRef = vue.computed(() => {
          const { size } = props;
          const { self } = themeRef.value;
          if (typeof size === "number") {
            return `${size}px`;
          } else {
            return self[createKey("size", size)];
          }
        });
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self
          } = themeRef.value;
          const { itemColor, itemColorActive } = self;
          const { color } = props;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-item-color": itemColor,
            "--n-item-color-active": color || itemColorActive,
            "--n-item-size": mergedSizeRef.value
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "rate",
          vue.computed(() => {
            const size = mergedSizeRef.value;
            const { color } = props;
            let hash = "";
            if (size) {
              hash += size[0];
            }
            if (color) {
              hash += color2Class(color);
            }
            return hash;
          }),
          cssVarsRef,
          props
        ) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          mergedValue,
          hoverIndex: hoverIndexRef,
          handleMouseMove,
          handleClick,
          handleMouseLeave,
          handleMouseEnterSomeStar,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const {
          readonly,
          hoverIndex,
          mergedValue,
          mergedClsPrefix,
          onRender,
          $slots: { default: defaultSlot }
        } = this;
        onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-rate`,
            {
              [`${mergedClsPrefix}-rate--readonly`]: readonly
            },
            this.themeClass
          ],
          style: this.cssVars,
          onMouseleave: this.handleMouseLeave
        }, vue.renderList(this.count, (_, index) => {
          const icon = defaultSlot ? defaultSlot() : /* @__PURE__ */ React.createElement(NBaseIcon, {
            clsPrefix: mergedClsPrefix
          }, { default: () => StarIcon });
          const entireStarActive = hoverIndex !== null ? index + 1 <= hoverIndex : index + 1 <= (mergedValue || 0);
          return /* @__PURE__ */ React.createElement("div", {
            key: index,
            class: [
              `${mergedClsPrefix}-rate__item`,
              entireStarActive && `${mergedClsPrefix}-rate__item--active`
            ],
            onClick: readonly ? void 0 : (e) => {
              this.handleClick(index, e);
            },
            onMouseenter: this.handleMouseEnterSomeStar,
            onMousemove: readonly ? void 0 : (e) => {
              this.handleMouseMove(index, e);
            }
          }, icon, this.allowHalf ? /* @__PURE__ */ React.createElement("div", {
            class: [
              `${mergedClsPrefix}-rate__half`,
              {
                [`${mergedClsPrefix}-rate__half--active`]: !entireStarActive && hoverIndex !== null ? index + 0.5 <= hoverIndex : index + 0.5 <= (mergedValue || 0)
              }
            ]
          }, icon) : null);
        }));
      }
    });

    var image404 = /* @__PURE__ */ React.createElement("svg", {
      xmlns: "http://www.w3.org/2000/svg",
      viewBox: "0 0 36 36"
    }, /* @__PURE__ */ React.createElement("circle", {
      fill: "#FFCB4C",
      cx: "18",
      cy: "17.018",
      r: "17"
    }), /* @__PURE__ */ React.createElement("path", {
      fill: "#65471B",
      d: "M14.524 21.036c-.145-.116-.258-.274-.312-.464-.134-.46.13-.918.59-1.021 4.528-1.021 7.577 1.363 7.706 1.465.384.306.459.845.173 1.205-.286.358-.828.401-1.211.097-.11-.084-2.523-1.923-6.182-1.098-.274.061-.554-.016-.764-.184z"
    }), /* @__PURE__ */ React.createElement("ellipse", {
      fill: "#65471B",
      cx: "13.119",
      cy: "11.174",
      rx: "2.125",
      ry: "2.656"
    }), /* @__PURE__ */ React.createElement("ellipse", {
      fill: "#65471B",
      cx: "24.375",
      cy: "12.236",
      rx: "2.125",
      ry: "2.656"
    }), /* @__PURE__ */ React.createElement("path", {
      fill: "#F19020",
      d: "M17.276 35.149s1.265-.411 1.429-1.352c.173-.972-.624-1.167-.624-1.167s1.041-.208 1.172-1.376c.123-1.101-.861-1.363-.861-1.363s.97-.4 1.016-1.539c.038-.959-.995-1.428-.995-1.428s5.038-1.221 5.556-1.341c.516-.12 1.32-.615 1.069-1.694-.249-1.08-1.204-1.118-1.697-1.003-.494.115-6.744 1.566-8.9 2.068l-1.439.334c-.54.127-.785-.11-.404-.512.508-.536.833-1.129.946-2.113.119-1.035-.232-2.313-.433-2.809-.374-.921-1.005-1.649-1.734-1.899-1.137-.39-1.945.321-1.542 1.561.604 1.854.208 3.375-.833 4.293-2.449 2.157-3.588 3.695-2.83 6.973.828 3.575 4.377 5.876 7.952 5.048l3.152-.681z"
    }), /* @__PURE__ */ React.createElement("path", {
      fill: "#65471B",
      d: "M9.296 6.351c-.164-.088-.303-.224-.391-.399-.216-.428-.04-.927.393-1.112 4.266-1.831 7.699-.043 7.843.034.433.231.608.747.391 1.154-.216.405-.74.546-1.173.318-.123-.063-2.832-1.432-6.278.047-.257.109-.547.085-.785-.042zm12.135 3.75c-.156-.098-.286-.243-.362-.424-.187-.442.023-.927.468-1.084 4.381-1.536 7.685.48 7.823.567.415.26.555.787.312 1.178-.242.39-.776.495-1.191.238-.12-.072-2.727-1.621-6.267-.379-.266.091-.553.046-.783-.096z"
    }));

    var image500 = /* @__PURE__ */ React.createElement("svg", {
      xmlns: "http://www.w3.org/2000/svg",
      viewBox: "0 0 36 36"
    }, /* @__PURE__ */ React.createElement("path", {
      fill: "#FFCC4D",
      d: "M36 18c0 9.941-8.059 18-18 18-9.94 0-18-8.059-18-18C0 8.06 8.06 0 18 0c9.941 0 18 8.06 18 18"
    }), /* @__PURE__ */ React.createElement("ellipse", {
      fill: "#664500",
      cx: "18",
      cy: "27",
      rx: "5",
      ry: "6"
    }), /* @__PURE__ */ React.createElement("path", {
      fill: "#664500",
      d: "M5.999 11c-.208 0-.419-.065-.599-.2-.442-.331-.531-.958-.2-1.4C8.462 5.05 12.816 5 13 5c.552 0 1 .448 1 1 0 .551-.445.998-.996 1-.155.002-3.568.086-6.204 3.6-.196.262-.497.4-.801.4zm24.002 0c-.305 0-.604-.138-.801-.4-2.64-3.521-6.061-3.598-6.206-3.6-.55-.006-.994-.456-.991-1.005C22.006 5.444 22.45 5 23 5c.184 0 4.537.05 7.8 4.4.332.442.242 1.069-.2 1.4-.18.135-.39.2-.599.2zm-16.087 4.5l1.793-1.793c.391-.391.391-1.023 0-1.414s-1.023-.391-1.414 0L12.5 14.086l-1.793-1.793c-.391-.391-1.023-.391-1.414 0s-.391 1.023 0 1.414l1.793 1.793-1.793 1.793c-.391.391-.391 1.023 0 1.414.195.195.451.293.707.293s.512-.098.707-.293l1.793-1.793 1.793 1.793c.195.195.451.293.707.293s.512-.098.707-.293c.391-.391.391-1.023 0-1.414L13.914 15.5zm11 0l1.793-1.793c.391-.391.391-1.023 0-1.414s-1.023-.391-1.414 0L23.5 14.086l-1.793-1.793c-.391-.391-1.023-.391-1.414 0s-.391 1.023 0 1.414l1.793 1.793-1.793 1.793c-.391.391-.391 1.023 0 1.414.195.195.451.293.707.293s.512-.098.707-.293l1.793-1.793 1.793 1.793c.195.195.451.293.707.293s.512-.098.707-.293c.391-.391.391-1.023 0-1.414L24.914 15.5z"
    }));

    var image418 = /* @__PURE__ */ React.createElement("svg", {
      xmlns: "http://www.w3.org/2000/svg",
      viewBox: "0 0 36 36"
    }, /* @__PURE__ */ React.createElement("ellipse", {
      fill: "#292F33",
      cx: "18",
      cy: "26",
      rx: "18",
      ry: "10"
    }), /* @__PURE__ */ React.createElement("ellipse", {
      fill: "#66757F",
      cx: "18",
      cy: "24",
      rx: "18",
      ry: "10"
    }), /* @__PURE__ */ React.createElement("path", {
      fill: "#E1E8ED",
      d: "M18 31C3.042 31 1 16 1 12h34c0 2-1.958 19-17 19z"
    }), /* @__PURE__ */ React.createElement("path", {
      fill: "#77B255",
      d: "M35 12.056c0 5.216-7.611 9.444-17 9.444S1 17.271 1 12.056C1 6.84 8.611 3.611 18 3.611s17 3.229 17 8.445z"
    }), /* @__PURE__ */ React.createElement("ellipse", {
      fill: "#A6D388",
      cx: "18",
      cy: "13",
      rx: "15",
      ry: "7"
    }), /* @__PURE__ */ React.createElement("path", {
      d: "M21 17c-.256 0-.512-.098-.707-.293-2.337-2.337-2.376-4.885-.125-8.262.739-1.109.9-2.246.478-3.377-.461-1.236-1.438-1.996-1.731-2.077-.553 0-.958-.443-.958-.996 0-.552.491-.995 1.043-.995.997 0 2.395 1.153 3.183 2.625 1.034 1.933.91 4.039-.351 5.929-1.961 2.942-1.531 4.332-.125 5.738.391.391.391 1.023 0 1.414-.195.196-.451.294-.707.294zm-6-2c-.256 0-.512-.098-.707-.293-2.337-2.337-2.376-4.885-.125-8.262.727-1.091.893-2.083.494-2.947-.444-.961-1.431-1.469-1.684-1.499-.552 0-.989-.447-.989-1 0-.552.458-1 1.011-1 .997 0 2.585.974 3.36 2.423.481.899 1.052 2.761-.528 5.131-1.961 2.942-1.531 4.332-.125 5.738.391.391.391 1.023 0 1.414-.195.197-.451.295-.707.295z",
      fill: "#5C913B"
    }));

    var image403 = /* @__PURE__ */ React.createElement("svg", {
      xmlns: "http://www.w3.org/2000/svg",
      viewBox: "0 0 36 36"
    }, /* @__PURE__ */ React.createElement("path", {
      fill: "#EF9645",
      d: "M15.5 2.965c1.381 0 2.5 1.119 2.5 2.5v.005L20.5.465c1.381 0 2.5 1.119 2.5 2.5V4.25l2.5-1.535c1.381 0 2.5 1.119 2.5 2.5V8.75L29 18H15.458L15.5 2.965z"
    }), /* @__PURE__ */ React.createElement("path", {
      fill: "#FFDC5D",
      d: "M4.625 16.219c1.381-.611 3.354.208 4.75 2.188.917 1.3 1.187 3.151 2.391 3.344.46.073 1.234-.313 1.234-1.397V4.5s0-2 2-2 2 2 2 2v11.633c0-.029 1-.064 1-.082V2s0-2 2-2 2 2 2 2v14.053c0 .017 1 .041 1 .069V4.25s0-2 2-2 2 2 2 2v12.638c0 .118 1 .251 1 .398V8.75s0-2 2-2 2 2 2 2V24c0 6.627-5.373 12-12 12-4.775 0-8.06-2.598-9.896-5.292C8.547 28.423 8.096 26.051 8 25.334c0 0-.123-1.479-1.156-2.865-1.469-1.969-2.5-3.156-3.125-3.866-.317-.359-.625-1.707.906-2.384z"
    }));

    var style$m = cB("result", `
  color: var(--n-text-color);
  line-height: var(--n-line-height);
  font-size: var(--n-font-size);
  transition:
    color .3s var(--n-bezier);
`, [cB("result-icon", `
    display: flex;
    justify-content: center;
    transition: color .3s var(--n-bezier);
  `, [cE("status-image", `
      font-size: var(--n-icon-size);
      width: 1em;
      height: 1em;
    `), cB("base-icon", `
      color: var(--n-icon-color);
      font-size: var(--n-icon-size);
    `)]), cB("result-content", {
      marginTop: "24px"
    }), cB("result-footer", `
    margin-top: 24px;
    text-align: center;
  `), cB("result-header", [cE("title", `
      margin-top: 16px;
      font-weight: var(--n-title-font-weight);
      transition: color .3s var(--n-bezier);
      text-align: center;
      color: var(--n-title-text-color);
      font-size: var(--n-title-font-size);
    `), cE("description", `
      margin-top: 4px;
      text-align: center;
      font-size: var(--n-font-size);
    `)])]);

    const iconMap = {
      403: image403,
      404: image404,
      418: image418,
      500: image500,
      info: /* @__PURE__ */ React.createElement(InfoIcon, null),
      success: /* @__PURE__ */ React.createElement(SuccessIcon, null),
      warning: /* @__PURE__ */ React.createElement(WarningIcon, null),
      error: /* @__PURE__ */ React.createElement(ErrorIcon, null)
    };
    const resultProps = {
      ...useTheme.props,
      size: {
        type: String,
        default: "medium"
      },
      status: {
        type: String,
        default: "info"
      },
      title: String,
      description: String
    };
    var Result = vue.defineComponent({
      name: "Result",
      props: resultProps,
      setup(props) {
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Result",
          "-result",
          style$m,
          resultLight$1,
          props,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const { size, status } = props;
          const {
            common: { cubicBezierEaseInOut },
            self: {
              textColor,
              lineHeight,
              titleTextColor,
              titleFontWeight,
              [createKey("iconColor", status)]: iconColor,
              [createKey("fontSize", size)]: fontSize,
              [createKey("titleFontSize", size)]: titleFontSize,
              [createKey("iconSize", size)]: iconSize
            }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-font-size": fontSize,
            "--n-icon-size": iconSize,
            "--n-line-height": lineHeight,
            "--n-text-color": textColor,
            "--n-title-font-size": titleFontSize,
            "--n-title-font-weight": titleFontWeight,
            "--n-title-text-color": titleTextColor,
            "--n-icon-color": iconColor || ""
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "result",
          vue.computed(() => {
            const { size, status } = props;
            let hash = "";
            if (size) {
              hash += size[0];
            }
            if (status) {
              hash += status[0];
            }
            return hash;
          }),
          cssVarsRef,
          props
        ) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { status, $slots, mergedClsPrefix, onRender } = this;
        onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          class: [`${mergedClsPrefix}-result`, this.themeClass],
          style: this.cssVars
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-result-icon`
        }, $slots.icon?.() || /* @__PURE__ */ React.createElement(NBaseIcon, {
          clsPrefix: mergedClsPrefix
        }, { default: () => iconMap[status] })), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-result-header`
        }, this.title ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-result-header__title`
        }, this.title) : null, this.description ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-result-header__description`
        }, this.description) : null), $slots.default && /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-result-content`
        }, $slots), $slots.footer && /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-result-footer`
        }, $slots.footer()));
      }
    });

    const scrollbarProps = {
      ...useTheme.props,
      trigger: String,
      xScrollable: Boolean,
      onScroll: Function
    };
    const Scrollbar = vue.defineComponent({
      name: "Scrollbar",
      props: scrollbarProps,
      setup() {
        const scrollbarInstRef = vue.ref(null);
        const exposedMethods = {
          scrollTo: (...args) => {
            scrollbarInstRef.value?.scrollTo(args[0], args[1]);
          },
          scrollBy: (...args) => {
            scrollbarInstRef.value?.scrollBy(args[0], args[1]);
          }
        };
        return {
          ...exposedMethods,
          scrollbarInstRef
        };
      },
      render() {
        return /* @__PURE__ */ React.createElement(NScrollbar, {
          ref: "scrollbarInstRef",
          ...this.$props
        }, this.$slots);
      }
    });
    var Scrollbar$1 = Scrollbar;

    const skeletonDark = {
      name: "Skeleton",
      common: commonDark,

      self(vars) {
        const {
          heightSmall,
          heightMedium,
          heightLarge,
          borderRadius
        } = vars;
        return {
          color: "rgba(255, 255, 255, 0.12)",
          colorEnd: "rgba(255, 255, 255, 0.18)",
          borderRadius,
          heightSmall,
          heightMedium,
          heightLarge
        };
      }

    };

    const self$1 = vars => {
      const {
        heightSmall,
        heightMedium,
        heightLarge,
        borderRadius
      } = vars;
      return {
        color: "#eee",
        colorEnd: "#ddd",
        borderRadius,
        heightSmall,
        heightMedium,
        heightLarge
      };
    };

    const skeletonLight = {
      name: "Skeleton",
      common: commonLight,
      self: self$1
    };

    var style$l = c$1([cB("skeleton", `
    height: 1em;
    width: 100%;
    transition: background-color .3s var(--n-bezier);
    transition:
      --n-color-start .3s var(--n-bezier),
      --n-color-end .3s var(--n-bezier),
      background-color .3s var(--n-bezier);
    animation: 2s skeleton-loading infinite cubic-bezier(0.36, 0, 0.64, 1);
    background-color: var(--n-color-start);
  `), c$1("@keyframes skeleton-loading", `
    0% {
      background: var(--n-color-start);
    }
    40% {
      background: var(--n-color-end);
    }
    80% {
      background: var(--n-color-start);
    }
    100% {
      background: var(--n-color-start);
    }
  `)]);

    const skeletonProps = {
      ...useTheme.props,
      text: Boolean,
      round: Boolean,
      circle: Boolean,
      height: [String, Number],
      width: [String, Number],
      size: String,
      repeat: {
        type: Number,
        default: 1
      },
      animated: {
        type: Boolean,
        default: true
      },
      sharp: {
        type: Boolean,
        default: true
      }
    };
    var Skeleton = vue.defineComponent({
      name: "Skeleton",
      inheritAttrs: false,
      props: skeletonProps,
      setup(props) {
        useHoudini();
        const { mergedClsPrefixRef } = useConfig(props);
        const themeRef = useTheme(
          "Skeleton",
          "-skeleton",
          style$l,
          skeletonLight,
          props,
          mergedClsPrefixRef
        );
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          style: vue.computed(() => {
            const theme = themeRef.value;
            const {
              common: { cubicBezierEaseInOut }
            } = theme;
            const selfThemeVars = theme.self;
            const { color, colorEnd, borderRadius } = selfThemeVars;
            let sizeHeight;
            const { circle, sharp, round, width, height, size, text, animated } = props;
            if (size !== void 0) {
              sizeHeight = selfThemeVars[createKey("height", size)];
            }
            const mergedWidth = circle ? width ?? height ?? sizeHeight : width;
            const mergedHeight = (circle ? width ?? height : height) ?? sizeHeight;
            return {
              display: text ? "inline-block" : "",
              verticalAlign: text ? "-0.125em" : "",
              borderRadius: circle ? "50%" : round ? "4096px" : sharp ? "" : borderRadius,
              width: typeof mergedWidth === "number" ? pxfy(mergedWidth) : mergedWidth,
              height: typeof mergedHeight === "number" ? pxfy(mergedHeight) : mergedHeight,
              animation: !animated ? "none" : "",
              "--n-bezier": cubicBezierEaseInOut,
              "--n-color-start": color,
              "--n-color-end": colorEnd
            };
          })
        };
      },
      render() {
        const { repeat, style: style2, mergedClsPrefix, $attrs } = this;
        const child = vue.h(
          "div",
          vue.mergeProps(
            {
              class: `${mergedClsPrefix}-skeleton`,
              style: style2
            },
            $attrs
          )
        );
        if (repeat > 1) {
          return /* @__PURE__ */ React.createElement(React.Fragment, null, Array.apply(null, { length: repeat }).map((_) => [
            child,
            "\n"
          ]));
        }
        return child;
      }
    });

    function isTouchEvent(e) {
      return window.TouchEvent && e instanceof window.TouchEvent;
    }
    function useRefs() {
      const refs = vue.ref( /* @__PURE__ */new Map());

      const setRefs = index => el => {
        refs.value.set(index, el);
      };

      vue.onBeforeUpdate(() => refs.value.clear());
      return [refs, setRefs];
    }

    var style$k = c$1([cB("slider", `
    display: block;
    padding: calc((var(--n-handle-size) - var(--n-rail-height)) / 2) 0;
    position: relative;
    z-index: 0;
    width: 100%;
    cursor: pointer;
    user-select: none;
    -webkit-user-select: none;
  `, [cM("reverse", [cB("slider-handles", [cB("slider-handle-wrapper", `
          transform: translate(50%, -50%);
        `)]), cB("slider-dots", [cB("slider-dot", `
          transform: translateX(50%, -50%);
        `)]), cM("vertical", [cB("slider-handles", [cB("slider-handle-wrapper", `
            transform: translate(-50%, -50%);
          `)]), cB("slider-marks", [cB("slider-mark", `
            transform: translateY(calc(-50% + var(--n-dot-height) / 2));
          `)]), cB("slider-dots", [cB("slider-dot", `
            transform: translateX(-50%) translateY(0);
          `)])])]), cM("vertical", `
      padding: 0 calc((var(--n-handle-size) - var(--n-rail-height)) / 2);
      width: var(--n-rail-width-vertical);
      height: 100%;
    `, [cB("slider-handles", `
        top: calc(var(--n-handle-size) / 2);
        right: 0;
        bottom: calc(var(--n-handle-size) / 2);
        left: 0;
      `, [cB("slider-handle-wrapper", `
          top: unset;
          left: 50%;
          transform: translate(-50%, 50%);
        `)]), cB("slider-rail", `
        height: 100%;
      `, [cE("fill", `
          top: unset;
          right: 0;
          bottom: unset;
          left: 0;
        `)]), cM("with-mark", `
        width: var(--n-rail-width-vertical);
        margin: 0 32px 0 8px;
      `), cB("slider-marks", `
        top: calc(var(--n-handle-size) / 2);
        right: unset;
        bottom: calc(var(--n-handle-size) / 2);
        left: 22px;
      `, [cB("slider-mark", `
          transform: translateY(50%);
          white-space: nowrap;
        `)]), cB("slider-dots", `
        top: calc(var(--n-handle-size) / 2);
        right: unset;
        bottom: calc(var(--n-handle-size) / 2);
        left: 50%;
      `, [cB("slider-dot", `
          transform: translateX(-50%) translateY(50%);
        `)])]), cM("disabled", `
      cursor: not-allowed;
      opacity: var(--n-opacity-disabled);
    `, [cB("slider-handle", `
        cursor: not-allowed;
      `)]), cM("with-mark", `
      width: 100%;
      margin: 8px 0 32px 0;
    `), c$1("&:hover", [cB("slider-rail", {
      backgroundColor: "var(--n-rail-color-hover)"
    }, [cE("fill", {
      backgroundColor: "var(--n-fill-color-hover)"
    })]), cB("slider-handle", {
      boxShadow: "var(--n-handle-box-shadow-hover)"
    })]), cM("active", [cB("slider-rail", {
      backgroundColor: "var(--n-rail-color-hover)"
    }, [cE("fill", {
      backgroundColor: "var(--n-fill-color-hover)"
    })]), cB("slider-handle", {
      boxShadow: "var(--n-handle-box-shadow-hover)"
    })]), cB("slider-marks", `
      position: absolute;
      top: 18px;
      left: calc(var(--n-handle-size) / 2);
      right: calc(var(--n-handle-size) / 2);
    `, [cB("slider-mark", `
        position: absolute;
        transform: translateX(-50%);
        white-space: nowrap;
      `)]), cB("slider-rail", `
      width: 100%;
      position: relative;
      height: var(--n-rail-height);
      background-color: var(--n-rail-color);
      transition: background-color .3s var(--n-bezier);
      border-radius: calc(var(--n-rail-height) / 2);
    `, [cE("fill", `
        position: absolute;
        top: 0;
        bottom: 0;
        border-radius: calc(var(--n-rail-height) / 2);
        transition: background-color .3s var(--n-bezier);
        background-color: var(--n-fill-color);
      `)]), cB("slider-handles", `
      position: absolute;
      top: 0;
      right: calc(var(--n-handle-size) / 2);
      bottom: 0;
      left: calc(var(--n-handle-size) / 2);
    `, [cB("slider-handle-wrapper", `
        outline: none;
        position: absolute;
        top: 50%;
        transform: translate(-50%, -50%);
        cursor: pointer;
        display: flex;
      `, [cB("slider-handle", `
          height: var(--n-handle-size);
          width: var(--n-handle-size);
          border-radius: 50%;
          overflow: hidden;
          transition: box-shadow .2s var(--n-bezier), background-color .3s var(--n-bezier);
          background-color: var(--n-handle-color);
          box-shadow: var(--n-handle-box-shadow);
        `, [c$1("&:hover", `
            box-shadow: var(--n-handle-box-shadow-hover);
          `)]), c$1("&:focus", [cB("slider-handle", `
            box-shadow: var(--n-handle-box-shadow-focus);
          `, [c$1("&:hover", `
              box-shadow: var(--n-handle-box-shadow-active);
            `)])])])]), cB("slider-dots", `
      position: absolute;
      top: 50%;
      left: calc(var(--n-handle-size) / 2);
      right: calc(var(--n-handle-size) / 2);
    `, [cM("transition-disabled", [cB("slider-dot", "transition: none;")]), cB("slider-dot", `
        transition:
          border-color .3s var(--n-bezier),
          box-shadow .3s var(--n-bezier),
          background-color .3s var(--n-bezier);
        position: absolute;
        transform: translate(-50%, -50%);
        height: var(--n-dot-height);
        width:  var(--n-dot-width);
        border-radius: var(--n-dot-border-radius);
        overflow: hidden;
        box-sizing: border-box;
        border: var(--n-dot-border);
        background-color: var(--n-dot-color);
      `, [cM("active", "border: var(--n-dot-border-active);")])])]), cB("slider-handle-indicator", `
    font-size: var(--n-font-size);
    padding: 6px 10px;
    border-radius: var(--n-indicator-border-radius);
    color: var(--n-indicator-text-color);
    background-color: var(--n-indicator-color);
    box-shadow: var(--n-indicator-box-shadow);
  `, [fadeInScaleUpTransition()]), cB("slider-handle-indicator", `
    font-size: var(--n-font-size);
    padding: 6px 10px;
    border-radius: var(--n-indicator-border-radius);
    color: var(--n-indicator-text-color);
    background-color: var(--n-indicator-color);
    box-shadow: var(--n-indicator-box-shadow);
  `, [cM("top", `
      margin-bottom: 12px;
    `), cM("right", `
      margin-left: 12px;
    `), cM("bottom", `
      margin-top: 12px;
    `), cM("left", `
      margin-right: 12px;
    `), fadeInScaleUpTransition()]), insideModal(cB("slider", [cB("slider-dot", "background-color: var(--n-dot-color-modal);")])), insidePopover(cB("slider", [cB("slider-dot", "background-color: var(--n-dot-color-popover);")]))]);

    const eventButtonLeft = 0;
    const sliderProps = {
      ...useTheme.props,
      to: useAdjustedTo.propTo,
      defaultValue: {
        type: [Number, Array],
        default: 0
      },
      marks: Object,
      disabled: {
        type: Boolean,
        default: void 0
      },
      formatTooltip: Function,
      keyboard: {
        type: Boolean,
        default: true
      },
      min: {
        type: Number,
        default: 0
      },
      max: {
        type: Number,
        default: 100
      },
      step: {
        type: [Number, String],
        default: 1
      },
      range: Boolean,
      value: [Number, Array],
      placement: String,
      showTooltip: {
        type: Boolean,
        default: void 0
      },
      tooltip: {
        type: Boolean,
        default: true
      },
      vertical: Boolean,
      reverse: Boolean,
      "onUpdate:value": [Function, Array],
      onUpdateValue: [Function, Array]
    };
    var Slider = vue.defineComponent({
      name: "Slider",
      props: sliderProps,
      setup(props) {
        const { mergedClsPrefixRef, namespaceRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Slider",
          "-slider",
          style$k,
          sliderLight$1,
          props,
          mergedClsPrefixRef
        );
        const handleRailRef = vue.ref(null);
        const [handleRefs, setHandleRefs] = useRefs();
        const [followerRefs, setFollowerRefs] = useRefs();
        const followerEnabledIndexSetRef = vue.ref(/* @__PURE__ */ new Set());
        const formItem = useFormItem(props);
        const { mergedDisabledRef } = formItem;
        const precisionRef = vue.computed(() => {
          const { step } = props;
          if (step <= 0 || step === "mark")
            return 0;
          const stepString = step.toString();
          let precision = 0;
          if (stepString.includes(".")) {
            precision = stepString.length - stepString.indexOf(".") - 1;
          }
          return precision;
        });
        const uncontrolledValueRef = vue.ref(props.defaultValue);
        const controlledValueRef = vue.toRef(props, "value");
        const mergedValueRef = useMergedState(
          controlledValueRef,
          uncontrolledValueRef
        );
        const arrifiedValueRef = vue.computed(() => {
          const { value: mergedValue } = mergedValueRef;
          return (props.range ? mergedValue : [mergedValue]).map(
            clampValue
          );
        });
        const handleCountExceeds2Ref = vue.computed(
          () => arrifiedValueRef.value.length > 2
        );
        const mergedPlacementRef = vue.computed(() => {
          return props.placement === void 0 ? props.vertical ? "right" : "top" : props.placement;
        });
        const markValuesRef = vue.computed(() => {
          const { marks } = props;
          return marks ? Object.keys(marks).map(parseFloat) : null;
        });
        const activeIndexRef = vue.ref(-1);
        const previousIndexRef = vue.ref(-1);
        const hoverIndexRef = vue.ref(-1);
        const draggingRef = vue.ref(false);
        const dotTransitionDisabledRef = vue.ref(false);
        const styleDirectionRef = vue.computed(() => {
          const { vertical, reverse } = props;
          const left = reverse ? "right" : "left";
          const bottom = reverse ? "top" : "bottom";
          return vertical ? bottom : left;
        });
        const fillStyleRef = vue.computed(() => {
          if (handleCountExceeds2Ref.value)
            return;
          const values = arrifiedValueRef.value;
          const start = valueToPercentage(
            props.range ? Math.min(...values) : props.min
          );
          const end = valueToPercentage(
            props.range ? Math.max(...values) : values[0]
          );
          const { value: styleDirection } = styleDirectionRef;
          return props.vertical ? {
            [styleDirection]: `${start}%`,
            height: `${end - start}%`
          } : {
            [styleDirection]: `${start}%`,
            width: `${end - start}%`
          };
        });
        const markInfosRef = vue.computed(() => {
          const mergedMarks = [];
          const { marks } = props;
          if (marks) {
            const orderValues = arrifiedValueRef.value.slice();
            orderValues.sort((a, b) => a - b);
            const { value: styleDirection } = styleDirectionRef;
            const { value: handleCountExceeds2 } = handleCountExceeds2Ref;
            const { range } = props;
            const isActive = handleCountExceeds2 ? () => false : (num) => range ? num >= orderValues[0] && num <= orderValues[orderValues.length - 1] : num <= orderValues[0];
            for (const key of Object.keys(marks)) {
              const num = Number(key);
              mergedMarks.push({
                active: isActive(num),
                label: marks[key],
                style: {
                  [styleDirection]: `${valueToPercentage(num)}%`
                }
              });
            }
          }
          return mergedMarks;
        });
        function getHandleStyle(value, index) {
          const percentage = valueToPercentage(value);
          const { value: styleDirection } = styleDirectionRef;
          return {
            [styleDirection]: `${percentage}%`,
            zIndex: index === activeIndexRef.value ? 1 : 0
          };
        }
        function isShowTooltip(index) {
          return props.showTooltip || hoverIndexRef.value === index || activeIndexRef.value === index && draggingRef.value;
        }
        function shouldKeepTooltipTransition(index) {
          if (!draggingRef.value)
            return true;
          return !(activeIndexRef.value === index && previousIndexRef.value === index);
        }
        function focusActiveHandle(index) {
          if (~index) {
            activeIndexRef.value = index;
            handleRefs.value.get(index)?.focus();
          }
        }
        function syncPosition() {
          followerRefs.value.forEach((inst, index) => {
            if (isShowTooltip(index))
              inst.syncPosition();
          });
        }
        function doUpdateValue(value) {
          const { "onUpdate:value": _onUpdateValue, onUpdateValue } = props;
          const { nTriggerFormInput, nTriggerFormChange } = formItem;
          if (onUpdateValue)
            call(onUpdateValue, value);
          if (_onUpdateValue)
            call(_onUpdateValue, value);
          uncontrolledValueRef.value = value;
          nTriggerFormInput();
          nTriggerFormChange();
        }
        function dispatchValueUpdate(value) {
          const { range } = props;
          if (range) {
            if (Array.isArray(value)) {
              const { value: oldValues } = arrifiedValueRef;
              if (value.join() !== oldValues.join()) {
                doUpdateValue(value);
              }
            }
          } else if (!Array.isArray(value)) {
            const oldValue = arrifiedValueRef.value[0];
            if (oldValue !== value) {
              doUpdateValue(value);
            }
          }
        }
        function doDispatchValue(value, index) {
          if (props.range) {
            const values = arrifiedValueRef.value.slice();
            values.splice(index, 1, value);
            dispatchValueUpdate(values);
          } else {
            dispatchValueUpdate(value);
          }
        }
        function sanitizeValue(value, currentValue, stepBuffer) {
          const stepping = stepBuffer !== void 0;
          if (!stepBuffer) {
            stepBuffer = value - currentValue > 0 ? 1 : -1;
          }
          const markValues = markValuesRef.value || [];
          const { step } = props;
          if (step === "mark") {
            const closestMark2 = getClosestMark(
              value,
              markValues.concat(currentValue),
              stepping ? stepBuffer : void 0
            );
            return closestMark2 ? closestMark2.value : currentValue;
          }
          if (step <= 0)
            return currentValue;
          const { value: precision } = precisionRef;
          let closestMark;
          if (stepping) {
            const currentStep = Number((currentValue / step).toFixed(precision));
            const actualStep = Math.floor(currentStep);
            const leftStep = currentStep > actualStep ? actualStep : actualStep - 1;
            const rightStep = currentStep < actualStep ? actualStep : actualStep + 1;
            closestMark = getClosestMark(
              currentValue,
              [
                Number((leftStep * step).toFixed(precision)),
                Number((rightStep * step).toFixed(precision)),
                ...markValues
              ],
              stepBuffer
            );
          } else {
            const roundValue = getRoundValue(value);
            closestMark = getClosestMark(value, [...markValues, roundValue]);
          }
          return closestMark ? clampValue(closestMark.value) : currentValue;
        }
        function clampValue(value) {
          return Math.min(props.max, Math.max(props.min, value));
        }
        function valueToPercentage(value) {
          const { max, min } = props;
          return (value - min) / (max - min) * 100;
        }
        function percentageToValue(percentage) {
          const { max, min } = props;
          return min + (max - min) * percentage;
        }
        function getRoundValue(value) {
          const { step, min } = props;
          if (step <= 0 || step === "mark")
            return value;
          const newValue = Math.round((value - min) / step) * step + min;
          return Number(newValue.toFixed(precisionRef.value));
        }
        function getClosestMark(currentValue, markValues = markValuesRef.value, buffer) {
          if (!markValues?.length)
            return null;
          let closestMark = null;
          let index = -1;
          while (++index < markValues.length) {
            const diff = markValues[index] - currentValue;
            const distance = Math.abs(diff);
            if ((buffer === void 0 || diff * buffer > 0) && (closestMark === null || distance < closestMark.distance)) {
              closestMark = {
                index,
                distance,
                value: markValues[index]
              };
            }
          }
          return closestMark;
        }
        function getPointValue(event) {
          const railEl = handleRailRef.value;
          if (!railEl)
            return;
          const touchEvent = isTouchEvent(event) ? event.touches[0] : event;
          const railRect = railEl.getBoundingClientRect();
          let percentage;
          if (props.vertical) {
            percentage = (railRect.bottom - touchEvent.clientY) / railRect.height;
          } else {
            percentage = (touchEvent.clientX - railRect.left) / railRect.width;
          }
          if (props.reverse) {
            percentage = 1 - percentage;
          }
          return percentageToValue(percentage);
        }
        function handleRailKeyDown(e) {
          if (mergedDisabledRef.value || !props.keyboard)
            return;
          const { vertical, reverse } = props;
          switch (e.key) {
            case "ArrowUp":
              e.preventDefault();
              handleStepValue(vertical && reverse ? -1 : 1);
              break;
            case "ArrowRight":
              e.preventDefault();
              handleStepValue(!vertical && reverse ? -1 : 1);
              break;
            case "ArrowDown":
              e.preventDefault();
              handleStepValue(vertical && reverse ? 1 : -1);
              break;
            case "ArrowLeft":
              e.preventDefault();
              handleStepValue(!vertical && reverse ? 1 : -1);
              break;
          }
        }
        function handleStepValue(ratio) {
          const activeIndex = activeIndexRef.value;
          if (activeIndex === -1)
            return;
          const { step } = props;
          const currentValue = arrifiedValueRef.value[activeIndex];
          const nextValue = step <= 0 || step === "mark" ? currentValue : currentValue + step * ratio;
          doDispatchValue(
            sanitizeValue(nextValue, currentValue, ratio > 0 ? 1 : -1),
            activeIndex
          );
        }
        function handleRailMouseDown(event) {
          if (mergedDisabledRef.value)
            return;
          if (!isTouchEvent(event) && event.button !== eventButtonLeft) {
            return;
          }
          const pointValue = getPointValue(event);
          if (pointValue === void 0)
            return;
          const values = arrifiedValueRef.value.slice();
          const activeIndex = props.range ? getClosestMark(pointValue, values)?.index ?? -1 : 0;
          if (activeIndex !== -1) {
            event.preventDefault();
            focusActiveHandle(activeIndex);
            startDragging();
            doDispatchValue(
              sanitizeValue(pointValue, arrifiedValueRef.value[activeIndex]),
              activeIndex
            );
          }
        }
        function startDragging() {
          if (!draggingRef.value) {
            draggingRef.value = true;
            on("touchend", document, handleMouseUp);
            on("mouseup", document, handleMouseUp);
            on("touchmove", document, handleMouseMove);
            on("mousemove", document, handleMouseMove);
          }
        }
        function stopDragging() {
          if (draggingRef.value) {
            draggingRef.value = false;
            off("touchend", document, handleMouseUp);
            off("mouseup", document, handleMouseUp);
            off("touchmove", document, handleMouseMove);
            off("mousemove", document, handleMouseMove);
          }
        }
        function handleMouseMove(event) {
          const { value: activeIndex } = activeIndexRef;
          if (!draggingRef.value || activeIndex === -1) {
            stopDragging();
            return;
          }
          const pointValue = getPointValue(event);
          doDispatchValue(
            sanitizeValue(pointValue, arrifiedValueRef.value[activeIndex]),
            activeIndex
          );
        }
        function handleMouseUp() {
          stopDragging();
        }
        function handleHandleFocus(index) {
          activeIndexRef.value = index;
          if (!mergedDisabledRef.value) {
            hoverIndexRef.value = index;
          }
        }
        function handleHandleBlur(index) {
          if (activeIndexRef.value === index) {
            activeIndexRef.value = -1;
            stopDragging();
          }
          if (hoverIndexRef.value === index) {
            hoverIndexRef.value = -1;
          }
        }
        function handleHandleMouseEnter(index) {
          hoverIndexRef.value = index;
        }
        function handleHandleMouseLeave(index) {
          if (hoverIndexRef.value === index) {
            hoverIndexRef.value = -1;
          }
        }
        vue.watch(
          activeIndexRef,
          (_, previous) => void vue.nextTick(() => previousIndexRef.value = previous)
        );
        vue.watch(mergedValueRef, () => {
          if (props.marks) {
            if (dotTransitionDisabledRef.value)
              return;
            dotTransitionDisabledRef.value = true;
            void vue.nextTick(() => {
              dotTransitionDisabledRef.value = false;
            });
          }
          void vue.nextTick(syncPosition);
        });
        vue.onBeforeUnmount(() => {
          stopDragging();
        });
        const cssVarsRef = vue.computed(() => {
          const {
            self: {
              railColor,
              railColorHover,
              fillColor,
              fillColorHover,
              handleColor,
              opacityDisabled,
              dotColor,
              dotColorModal,
              handleBoxShadow,
              handleBoxShadowHover,
              handleBoxShadowActive,
              handleBoxShadowFocus,
              dotBorder,
              dotBoxShadow,
              railHeight,
              railWidthVertical,
              handleSize,
              dotHeight,
              dotWidth,
              dotBorderRadius,
              fontSize,
              dotBorderActive,
              dotColorPopover
            },
            common: { cubicBezierEaseInOut }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-dot-border": dotBorder,
            "--n-dot-border-active": dotBorderActive,
            "--n-dot-border-radius": dotBorderRadius,
            "--n-dot-box-shadow": dotBoxShadow,
            "--n-dot-color": dotColor,
            "--n-dot-color-modal": dotColorModal,
            "--n-dot-color-popover": dotColorPopover,
            "--n-dot-height": dotHeight,
            "--n-dot-width": dotWidth,
            "--n-fill-color": fillColor,
            "--n-fill-color-hover": fillColorHover,
            "--n-font-size": fontSize,
            "--n-handle-box-shadow": handleBoxShadow,
            "--n-handle-box-shadow-active": handleBoxShadowActive,
            "--n-handle-box-shadow-focus": handleBoxShadowFocus,
            "--n-handle-box-shadow-hover": handleBoxShadowHover,
            "--n-handle-color": handleColor,
            "--n-handle-size": handleSize,
            "--n-opacity-disabled": opacityDisabled,
            "--n-rail-color": railColor,
            "--n-rail-color-hover": railColorHover,
            "--n-rail-height": railHeight,
            "--n-rail-width-vertical": railWidthVertical
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("slider", void 0, cssVarsRef, props) : void 0;
        const indicatorCssVarsRef = vue.computed(() => {
          const {
            self: {
              fontSize,
              indicatorColor,
              indicatorBoxShadow,
              indicatorTextColor,
              indicatorBorderRadius
            }
          } = themeRef.value;
          return {
            "--n-font-size": fontSize,
            "--n-indicator-border-radius": indicatorBorderRadius,
            "--n-indicator-box-shadow": indicatorBoxShadow,
            "--n-indicator-color": indicatorColor,
            "--n-indicator-text-color": indicatorTextColor
          };
        });
        const indicatorThemeClassHandle = inlineThemeDisabled ? useThemeClass("slider-indicator", void 0, indicatorCssVarsRef, props) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          namespace: namespaceRef,
          uncontrolledValue: uncontrolledValueRef,
          mergedValue: mergedValueRef,
          mergedDisabled: mergedDisabledRef,
          mergedPlacement: mergedPlacementRef,
          isMounted: isMounted(),
          adjustedTo: useAdjustedTo(props),
          dotTransitionDisabled: dotTransitionDisabledRef,
          markInfos: markInfosRef,
          isShowTooltip,
          shouldKeepTooltipTransition,
          handleRailRef,
          setHandleRefs,
          setFollowerRefs,
          fillStyle: fillStyleRef,
          getHandleStyle,
          activeIndex: activeIndexRef,
          arrifiedValues: arrifiedValueRef,
          followerEnabledIndexSet: followerEnabledIndexSetRef,
          handleRailMouseDown,
          handleHandleFocus,
          handleHandleBlur,
          handleHandleMouseEnter,
          handleHandleMouseLeave,
          handleRailKeyDown,
          indicatorCssVars: inlineThemeDisabled ? void 0 : indicatorCssVarsRef,
          indicatorThemeClass: indicatorThemeClassHandle?.themeClass,
          indicatorOnRender: indicatorThemeClassHandle?.onRender,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedClsPrefix, themeClass, formatTooltip } = this;
        this.onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-slider`,
            themeClass,
            {
              [`${mergedClsPrefix}-slider--disabled`]: this.mergedDisabled,
              [`${mergedClsPrefix}-slider--active`]: this.activeIndex !== -1,
              [`${mergedClsPrefix}-slider--with-mark`]: this.marks,
              [`${mergedClsPrefix}-slider--vertical`]: this.vertical,
              [`${mergedClsPrefix}-slider--reverse`]: this.reverse
            }
          ],
          style: this.cssVars,
          onKeydown: this.handleRailKeyDown,
          onMousedown: this.handleRailMouseDown,
          onTouchstart: this.handleRailMouseDown
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-slider-rail`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-slider-rail__fill`,
          style: this.fillStyle
        }), this.marks ? /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-slider-dots`,
            this.dotTransitionDisabled && `${mergedClsPrefix}-slider-dots--transition-disabled`
          ]
        }, this.markInfos.map((mark) => /* @__PURE__ */ React.createElement("div", {
          key: mark.label,
          class: [
            `${mergedClsPrefix}-slider-dot`,
            {
              [`${mergedClsPrefix}-slider-dot--active`]: mark.active
            }
          ],
          style: mark.style
        }))) : null, /* @__PURE__ */ React.createElement("div", {
          ref: "handleRailRef",
          class: `${mergedClsPrefix}-slider-handles`
        }, this.arrifiedValues.map((value, index) => {
          const showTooltip = this.isShowTooltip(index);
          return /* @__PURE__ */ React.createElement(VBinder, null, {
            default: () => [
              /* @__PURE__ */ React.createElement(VTarget, null, {
                default: () => /* @__PURE__ */ React.createElement("div", {
                  ref: this.setHandleRefs(index),
                  class: `${mergedClsPrefix}-slider-handle-wrapper`,
                  tabindex: this.mergedDisabled ? -1 : 0,
                  style: this.getHandleStyle(value, index),
                  onFocus: () => this.handleHandleFocus(index),
                  onBlur: () => this.handleHandleBlur(index),
                  onMouseenter: () => this.handleHandleMouseEnter(index),
                  onMouseleave: () => this.handleHandleMouseLeave(index)
                }, resolveSlot(this.$slots.thumb, () => [
                  /* @__PURE__ */ React.createElement("div", {
                    class: `${mergedClsPrefix}-slider-handle`
                  })
                ]))
              }),
              this.tooltip && /* @__PURE__ */ React.createElement(VFollower, {
                ref: this.setFollowerRefs(index),
                show: showTooltip,
                to: this.adjustedTo,
                enabled: this.showTooltip && !this.range || this.followerEnabledIndexSet.has(index),
                teleportDisabled: this.adjustedTo === useAdjustedTo.tdkey,
                placement: this.mergedPlacement,
                containerClass: this.namespace
              }, {
                default: () => /* @__PURE__ */ React.createElement(vue.Transition, {
                  name: "fade-in-scale-up-transition",
                  appear: this.isMounted,
                  css: this.shouldKeepTooltipTransition(index),
                  onEnter: () => {
                    this.followerEnabledIndexSet.add(index);
                  },
                  onAfterLeave: () => {
                    this.followerEnabledIndexSet.delete(index);
                  }
                }, {
                  default: () => {
                    if (showTooltip) {
                      this.indicatorOnRender?.();
                      return /* @__PURE__ */ React.createElement("div", {
                        class: [
                          `${mergedClsPrefix}-slider-handle-indicator`,
                          this.indicatorThemeClass,
                          `${mergedClsPrefix}-slider-handle-indicator--${this.mergedPlacement}`
                        ],
                        style: this.indicatorCssVars
                      }, typeof formatTooltip === "function" ? formatTooltip(value) : value);
                    }
                    return null;
                  }
                })
              })
            ]
          });
        })), this.marks ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-slider-marks`
        }, this.markInfos.map((mark) => /* @__PURE__ */ React.createElement("div", {
          key: mark.label,
          class: `${mergedClsPrefix}-slider-mark`,
          style: mark.style
        }, mark.label))) : null));
      }
    });

    var style$j = c$1([c$1("@keyframes spin-rotate", `
    from {
      transform: rotate(0);
    }
    to {
      transform: rotate(360deg);
    }
  `), cB("spin-container", {
      position: "relative"
    }, [cB("spin-body", `
      position: absolute;
      top: 50%;
      left: 50%;
      transform: translateX(-50%) translateY(-50%);
    `, [fadeInTransition()])]), cB("spin-body", `
    display: inline-flex;
    align-items: center;
    justify-content: center;
    flex-direction: column;
  `), cB("spin", `
    display: inline-flex;
    height: var(--n-size);
    width: var(--n-size);
    font-size: var(--n-size);
    color: var(--n-color);
  `, [cM("rotate", `
      animation: spin-rotate 2s linear infinite;
    `)]), cB("spin-description", `
    display: inline-block;
    font-size: var(--n-font-size);
    color: var(--n-text-color);
    transition: color .3s var(--n-bezier);
    margin-top: 8px;
  `), cB("spin-content", `
    opacity: 1;
    transition: opacity .3s var(--n-bezier);
    pointer-events: all;
  `, [cM("spinning", `
      user-select: none;
      -webkit-user-select: none;
      pointer-events: none;
      opacity: var(--n-opacity-spinning);
    `)])]);

    const STROKE_WIDTH = {
      small: 20,
      medium: 18,
      large: 16
    };
    const spinProps = {
      ...useTheme.props,
      description: String,
      stroke: String,
      size: {
        type: [String, Number],
        default: "medium"
      },
      show: {
        type: Boolean,
        default: true
      },
      strokeWidth: Number,
      rotate: {
        type: Boolean,
        default: true
      },
      spinning: {
        type: Boolean,
        validator: () => {
          return true;
        },
        default: void 0
      }
    };
    var Spin = vue.defineComponent({
      name: "Spin",
      props: spinProps,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.spinning !== void 0) {
              warnOnce(
                "spin",
                "`spinning` is deprecated, please use `show` instead."
              );
            }
          });
        }
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Spin",
          "-spin",
          style$j,
          spinLight$1,
          props,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const { size: spinSize } = props;
          const {
            common: { cubicBezierEaseInOut },
            self
          } = themeRef.value;
          const { opacitySpinning, color, textColor } = self;
          const size = typeof spinSize === "number" ? pxfy(spinSize) : self[createKey("size", spinSize)];
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-opacity-spinning": opacitySpinning,
            "--n-size": size,
            "--n-color": color,
            "--n-text-color": textColor
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "spin",
          vue.computed(() => {
            const { size } = props;
            return typeof size === "number" ? String(size) : size[0];
          }),
          cssVarsRef,
          props
        ) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          compitableShow: useCompitable(props, ["spinning", "show"]),
          mergedStrokeWidth: vue.computed(() => {
            const { strokeWidth } = props;
            if (strokeWidth !== void 0)
              return strokeWidth;
            const { size } = props;
            return STROKE_WIDTH[typeof size === "number" ? "medium" : size];
          }),
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { $slots, mergedClsPrefix, description } = this;
        const rotate = $slots.icon && this.rotate;
        const descriptionNode = (description || $slots.description) && /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-spin-description`
        }, description || $slots.description?.());
        const icon = $slots.icon ? /* @__PURE__ */ React.createElement("div", {
          class: [`${mergedClsPrefix}-spin-body`, this.themeClass]
        }, /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-spin`,
            rotate && `${mergedClsPrefix}-spin--rotate`
          ],
          style: $slots.default ? "" : this.cssVars
        }, $slots.icon()), descriptionNode) : /* @__PURE__ */ React.createElement("div", {
          class: [`${mergedClsPrefix}-spin-body`, this.themeClass]
        }, /* @__PURE__ */ React.createElement(NBaseLoading, {
          clsPrefix: mergedClsPrefix,
          style: $slots.default ? "" : this.cssVars,
          stroke: this.stroke,
          "stroke-width": this.mergedStrokeWidth,
          class: `${mergedClsPrefix}-spin`
        }), descriptionNode);
        this.onRender?.();
        return $slots.default ? /* @__PURE__ */ React.createElement("div", {
          class: [`${mergedClsPrefix}-spin-container`, this.themeClass],
          style: this.cssVars
        }, /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-spin-content`,
            this.compitableShow && `${mergedClsPrefix}-spin-content--spinning`
          ]
        }, $slots), /* @__PURE__ */ React.createElement(vue.Transition, {
          name: "fade-in-transition"
        }, {
          default: () => this.compitableShow ? icon : null
        })) : icon;
      }
    });

    var style$i = cB("statistic", [cE("label", `
    font-weight: var(--n-label-font-weight);
    transition: .3s color var(--n-bezier);
    font-size: var(--n-label-font-size);
    color: var(--n-label-text-color);
  `), cB("statistic-value", `
    margin-top: 4px;
    font-weight: var(--n-value-font-weight);
  `, [cE("prefix", `
      margin: 0 4px 0 0;
      font-size: var(--n-value-font-size);
      transition: .3s color var(--n-bezier);
      color: var(--n-value-prefix-text-color);
    `, [cB("icon", {
      verticalAlign: "-0.125em"
    })]), cE("content", `
      font-size: var(--n-value-font-size);
      transition: .3s color var(--n-bezier);
      color: var(--n-value-text-color);
    `), cE("suffix", `
      margin: 0 0 0 4px;
      font-size: var(--n-value-font-size);
      transition: .3s color var(--n-bezier);
      color: var(--n-value-suffix-text-color);
    `, [cB("icon", {
      verticalAlign: "-0.125em"
    })])])]);

    const statisticProps = {
      ...useTheme.props,
      tabularNums: Boolean,
      label: String,
      value: [String, Number]
    };
    var Statistic = vue.defineComponent({
      name: "Statistic",
      props: statisticProps,
      setup(props) {
        const { mergedClsPrefixRef, inlineThemeDisabled, mergedRtlRef } = useConfig(props);
        const themeRef = useTheme(
          "Statistic",
          "-statistic",
          style$i,
          statisticLight$1,
          props,
          mergedClsPrefixRef
        );
        const rtlEnabledRef = useRtl("Statistic", mergedRtlRef, mergedClsPrefixRef);
        const cssVarsRef = vue.computed(() => {
          const {
            self: {
              labelFontWeight,
              valueFontSize,
              valueFontWeight,
              valuePrefixTextColor,
              labelTextColor,
              valueSuffixTextColor,
              valueTextColor,
              labelFontSize
            },
            common: { cubicBezierEaseInOut }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-label-font-size": labelFontSize,
            "--n-label-font-weight": labelFontWeight,
            "--n-label-text-color": labelTextColor,
            "--n-value-font-weight": valueFontWeight,
            "--n-value-font-size": valueFontSize,
            "--n-value-prefix-text-color": valuePrefixTextColor,
            "--n-value-suffix-text-color": valueSuffixTextColor,
            "--n-value-text-color": valueTextColor
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("statistic", void 0, cssVarsRef, props) : void 0;
        return {
          rtlEnabled: rtlEnabledRef,
          mergedClsPrefix: mergedClsPrefixRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const {
          mergedClsPrefix,
          $slots: {
            default: defaultSlot,
            label: labelSlot,
            prefix: prefixSlot,
            suffix: suffixSlot
          }
        } = this;
        this.onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-statistic`,
            this.themeClass,
            this.rtlEnabled && `${mergedClsPrefix}-statistic--rtl`
          ],
          style: this.cssVars
        }, resolveWrappedSlot(labelSlot, (children) => /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-statistic__label`
        }, this.label || children)), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-statistic-value`,
          style: {
            fontVariantNumeric: this.tabularNums ? "tabular-nums" : ""
          }
        }, resolveWrappedSlot(
          prefixSlot,
          (children) => children && /* @__PURE__ */ React.createElement("span", {
            class: `${mergedClsPrefix}-statistic-value__prefix`
          }, children)
        ), this.value !== void 0 ? /* @__PURE__ */ React.createElement("span", {
          class: `${mergedClsPrefix}-statistic-value__content`
        }, this.value) : resolveWrappedSlot(
          defaultSlot,
          (children) => children && /* @__PURE__ */ React.createElement("span", {
            class: `${mergedClsPrefix}-statistic-value__content`
          }, children)
        ), resolveWrappedSlot(
          suffixSlot,
          (children) => children && /* @__PURE__ */ React.createElement("span", {
            class: `${mergedClsPrefix}-statistic-value__suffix`
          }, children)
        )));
      }
    });

    var style$h = cB("steps", `
  width: 100%;
  display: flex;
`, [cB("step", `
    position: relative;
    display: flex;
    flex: 1;
  `, [cM("disabled", "cursor: not-allowed"), cM("clickable", `
      cursor: pointer;
    `), c$1("&:last-child", [cB("step-splitor", "display: none;")])]), cB("step-splitor", `
    background-color: var(--n-splitor-color);
    margin-top: calc(var(--n-step-header-font-size) / 2);
    height: 1px;
    flex: 1;
    align-self: flex-start;
    margin-left: 12px;
    margin-right: 12px;
    transition:
      color .3s var(--n-bezier),
      background-color .3s var(--n-bezier);
  `), cB("step-content", "flex: 1;", [cB("step-content-header", `
      color: var(--n-header-text-color);
      margin-top: calc(var(--n-indicator-size) / 2 - var(--n-step-header-font-size) / 2);
      line-height: var(--n-step-header-font-size);
      font-size: var(--n-step-header-font-size);
      position: relative;
      display: flex;
      font-weight: var(--n-step-header-font-weight);
      margin-left: 9px;
      transition:
        color .3s var(--n-bezier),
        background-color .3s var(--n-bezier);
    `, [cE("title", `
        white-space: nowrap;
        flex: 0;
      `)]), cE("description", `
      color: var(--n-description-text-color);
      margin-top: 12px;
      margin-left: 9px;
      transition:
        color .3s var(--n-bezier),
        background-color .3s var(--n-bezier);
    `)]), cB("step-indicator", `
    background-color: var(--n-indicator-color);
    box-shadow: 0 0 0 1px var(--n-indicator-border-color);
    height: var(--n-indicator-size);
    width: var(--n-indicator-size);
    border-radius: 50%;
    display: flex;
    align-items: center;
    justify-content: center;
    transition:
      background-color .3s var(--n-bezier),
      box-shadow .3s var(--n-bezier);
  `, [cB("step-indicator-slot", `
      position: relative;
      width: var(--n-indicator-icon-size);
      height: var(--n-indicator-icon-size);
      font-size: var(--n-indicator-icon-size);
      line-height: var(--n-indicator-icon-size);
    `, [cE("index", `
        display: inline-block;
        text-align: center;
        position: absolute;
        left: 0;
        top: 0;
        font-size: var(--n-indicator-index-font-size);
        width: var(--n-indicator-icon-size);
        height: var(--n-indicator-icon-size);
        line-height: var(--n-indicator-icon-size);
        color: var(--n-indicator-text-color);
        transition: color .3s var(--n-bezier);
      `, [iconSwitchTransition()]), cB("icon", `
        color: var(--n-indicator-text-color);
        transition: color .3s var(--n-bezier);
      `, [iconSwitchTransition()]), cB("base-icon", `
        color: var(--n-indicator-text-color);
        transition: color .3s var(--n-bezier);
      `, [iconSwitchTransition()])])]), cM("vertical", "flex-direction: column;", [cNotM("show-description", [c$1(">", [cB("step", "padding-bottom: 8px;")])]), c$1(">", [cB("step", "margin-bottom: 16px;", [c$1("&:last-child", "margin-bottom: 0;"), c$1(">", [cB("step-indicator", [c$1(">", [cB("step-splitor", `
                position: absolute;
                bottom: -8px;
                width: 1px;
                margin: 0 !important;
                left: calc(var(--n-indicator-size) / 2);
                height: calc(100% - var(--n-indicator-size));
              `)])]), cB("step-content", [cE("description", "margin-top: 8px;")])])])])])]);

    function stepWithIndex(step, i) {
      if (typeof step !== "object" || step === null || Array.isArray(step)) {
        return null;
      }
      if (!step.props)
        step.props = {};
      step.props.internalIndex = i + 1;
      return step;
    }
    function stepsWithIndex(steps) {
      return steps.map((step, i) => stepWithIndex(step, i));
    }
    const stepsProps = {
      ...useTheme.props,
      current: Number,
      status: {
        type: String,
        default: "process"
      },
      size: {
        type: String,
        default: "medium"
      },
      vertical: Boolean,
      "onUpdate:current": [Function, Array],
      onUpdateCurrent: [Function, Array]
    };
    const stepsInjectionKey = createInjectionKey("n-steps");
    var Steps = vue.defineComponent({
      name: "Steps",
      props: stepsProps,
      setup(props, { slots }) {
        const { mergedClsPrefixRef, mergedRtlRef } = useConfig(props);
        const rtlEnabledRef = useRtl("Steps", mergedRtlRef, mergedClsPrefixRef);
        const themeRef = useTheme(
          "Steps",
          "-steps",
          style$h,
          stepsLight$1,
          props,
          mergedClsPrefixRef
        );
        vue.provide(stepsInjectionKey, {
          props,
          mergedThemeRef: themeRef,
          mergedClsPrefixRef,
          stepsSlots: slots
        });
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          rtlEnabled: rtlEnabledRef
        };
      },
      render() {
        const { mergedClsPrefix } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-steps`,
            this.rtlEnabled && `${mergedClsPrefix}-steps--rtl`,
            this.vertical && `${mergedClsPrefix}-steps--vertical`
          ]
        }, stepsWithIndex(flatten$3(getSlot$1(this))));
      }
    });

    const stepProps = {
      status: String,
      title: String,
      description: String,
      disabled: Boolean,
      internalIndex: {
        type: Number,
        default: 0
      }
    };
    var Step = vue.defineComponent({
      name: "Step",
      props: stepProps,
      setup(props) {
        const NSteps = vue.inject(stepsInjectionKey, null);
        if (!NSteps)
          throwError("step", "`n-step` must be placed inside `n-steps`.");
        const { inlineThemeDisabled } = useConfig();
        const {
          props: stepsProps,
          mergedThemeRef,
          mergedClsPrefixRef,
          stepsSlots
        } = NSteps;
        const verticalRef = vue.computed(() => {
          return stepsProps.vertical;
        });
        const mergedStatusRef = vue.computed(
          () => {
            const { status } = props;
            if (status) {
              return status;
            } else {
              const { internalIndex } = props;
              const { current } = stepsProps;
              if (current === void 0)
                return "process";
              if (internalIndex < current) {
                return "finish";
              } else if (internalIndex === current) {
                return stepsProps.status || "process";
              } else if (internalIndex > current) {
                return "wait";
              }
            }
            return "process";
          }
        );
        const cssVarsRef = vue.computed(() => {
          const { value: status } = mergedStatusRef;
          const { size } = stepsProps;
          const {
            common: { cubicBezierEaseInOut },
            self: {
              stepHeaderFontWeight,
              [createKey("stepHeaderFontSize", size)]: stepHeaderFontSize,
              [createKey("indicatorIndexFontSize", size)]: indicatorIndexFontSize,
              [createKey("indicatorSize", size)]: indicatorSize,
              [createKey("indicatorIconSize", size)]: indicatorIconSize,
              [createKey("indicatorTextColor", status)]: indicatorTextColor,
              [createKey("indicatorBorderColor", status)]: indicatorBorderColor,
              [createKey("headerTextColor", status)]: headerTextColor,
              [createKey("splitorColor", status)]: splitorColor,
              [createKey("indicatorColor", status)]: indicatorColor,
              [createKey("descriptionTextColor", status)]: descriptionTextColor
            }
          } = mergedThemeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-description-text-color": descriptionTextColor,
            "--n-header-text-color": headerTextColor,
            "--n-indicator-border-color": indicatorBorderColor,
            "--n-indicator-color": indicatorColor,
            "--n-indicator-icon-size": indicatorIconSize,
            "--n-indicator-index-font-size": indicatorIndexFontSize,
            "--n-indicator-size": indicatorSize,
            "--n-indicator-text-color": indicatorTextColor,
            "--n-splitor-color": splitorColor,
            "--n-step-header-font-size": stepHeaderFontSize,
            "--n-step-header-font-weight": stepHeaderFontWeight
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "step",
          vue.computed(() => {
            const { value: status } = mergedStatusRef;
            const { size } = stepsProps;
            return `${status[0]}${size[0]}`;
          }),
          cssVarsRef,
          stepsProps
        ) : void 0;
        const handleStepClick = vue.computed(() => {
          if (props.disabled)
            return void 0;
          const { onUpdateCurrent, "onUpdate:current": _onUpdateCurrent } = stepsProps;
          return onUpdateCurrent || _onUpdateCurrent ? () => {
            if (onUpdateCurrent) {
              call(onUpdateCurrent, props.internalIndex);
            }
            if (_onUpdateCurrent) {
              call(_onUpdateCurrent, props.internalIndex);
            }
          } : void 0;
        });
        return {
          stepsSlots,
          mergedClsPrefix: mergedClsPrefixRef,
          vertical: verticalRef,
          mergedStatus: mergedStatusRef,
          handleStepClick,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedClsPrefix, onRender, handleStepClick, disabled } = this;
        const descriptionNode = resolveWrappedSlot(
          this.$slots.default,
          (children) => {
            const mergedDescription = children || this.description;
            if (mergedDescription) {
              return /* @__PURE__ */ React.createElement("div", {
                class: `${mergedClsPrefix}-step-content__description`
              }, mergedDescription);
            }
            return null;
          }
        );
        onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-step`,
            disabled && `${mergedClsPrefix}-step--disabled`,
            !disabled && handleStepClick && `${mergedClsPrefix}-step--clickable`,
            this.themeClass,
            descriptionNode && `${mergedClsPrefix}-step--show-description`,
            `${mergedClsPrefix}-step--${this.mergedStatus}-status`
          ],
          style: this.cssVars,
          onClick: handleStepClick
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-step-indicator`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-step-indicator-slot`
        }, /* @__PURE__ */ React.createElement(NIconSwitchTransition, null, {
          default: () => {
            return resolveWrappedSlot(this.$slots.icon, (icon) => {
              const { mergedStatus, stepsSlots } = this;
              return !(mergedStatus === "finish" || mergedStatus === "error") ? icon || /* @__PURE__ */ React.createElement("div", {
                key: this.internalIndex,
                class: `${mergedClsPrefix}-step-indicator-slot__index`
              }, this.internalIndex) : mergedStatus === "finish" ? /* @__PURE__ */ React.createElement(NBaseIcon, {
                clsPrefix: mergedClsPrefix,
                key: "finish"
              }, {
                default: () => resolveSlot(stepsSlots["finish-icon"], () => [
                  /* @__PURE__ */ React.createElement(FinishedIcon, null)
                ])
              }) : mergedStatus === "error" ? /* @__PURE__ */ React.createElement(NBaseIcon, {
                clsPrefix: mergedClsPrefix,
                key: "error"
              }, {
                default: () => resolveSlot(stepsSlots["error-icon"], () => [
                  /* @__PURE__ */ React.createElement(ErrorIcon$1, null)
                ])
              }) : null;
            });
          }
        })), this.vertical ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-step-splitor`
        }) : null), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-step-content`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-step-content-header`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-step-content-header__title`
        }, resolveSlot(this.$slots.title, () => [this.title])), !this.vertical ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-step-splitor`
        }) : null), descriptionNode));
      }
    });

    var style$g = cB("switch", `
  height: var(--n-height);
  min-width: var(--n-width);
  vertical-align: middle;
  user-select: none;
  -webkit-user-select: none;
  display: inline-flex;
  outline: none;
  justify-content: center;
  align-items: center;
`, [cE("children-placeholder", `
    height: var(--n-rail-height);
    display: flex;
    flex-direction: column;
    overflow: hidden;
    pointer-events: none;
    visibility: hidden;
  `), cE("rail-placeholder", `
    display: flex;
    flex-wrap: none;
  `), cE("button-placeholder", `
    width: calc(1.75 * var(--n-rail-height));
    height: var(--n-rail-height);
  `), cB("base-loading", `
    position: absolute;
    top: 50%;
    left: 50%;
    transform: translateX(-50%) translateY(-50%);
    font-size: calc(var(--n-button-width) - 4px);
    color: var(--n-loading-color);
    transition: color .3s var(--n-bezier);
  `, [iconSwitchTransition({
      left: "50%",
      top: "50%",
      originalTransform: "translateX(-50%) translateY(-50%)"
    })]), cE("checked, unchecked", `
    transition: color .3s var(--n-bezier);
    color: var(--n-text-color);
    box-sizing: border-box;
    position: absolute;
    white-space: nowrap;
    top: 0;
    bottom: 0;
    display: flex;
    align-items: center;
    line-height: 1;
  `), cE("checked", `
    right: 0;
    padding-right: calc(1.25 * var(--n-rail-height) - var(--n-offset));
  `), cE("unchecked", `
    left: 0;
    justify-content: flex-end;
    padding-left: calc(1.25 * var(--n-rail-height) - var(--n-offset));
  `), c$1("&:focus", [cE("rail", `
      box-shadow: var(--n-box-shadow-focus);
    `)]), cM("round", [cE("rail", "border-radius: calc(var(--n-rail-height) / 2);", [cE("button", "border-radius: calc(var(--n-button-height) / 2);")])]), cNotM("disabled", [cNotM("icon", [cM("rubber-band", [cM("pressed", [cE("rail", [cE("button", "max-width: var(--n-button-width-pressed);")])]), cE("rail", [c$1("&:active", [cE("button", "max-width: var(--n-button-width-pressed);")])]), cM("active", [cM("pressed", [cE("rail", [cE("button", "left: calc(100% - var(--n-offset) - var(--n-button-width-pressed));")])]), cE("rail", [c$1("&:active", [cE("button", "left: calc(100% - var(--n-offset) - var(--n-button-width-pressed));")])])])])])]), cM("active", [cE("rail", [cE("button", "left: calc(100% - var(--n-button-width) - var(--n-offset))")])]), cE("rail", `
    overflow: hidden;
    height: var(--n-rail-height);
    min-width: var(--n-rail-width);
    border-radius: var(--n-rail-border-radius);
    cursor: pointer;
    position: relative;
    transition:
      opacity .3s var(--n-bezier),
      background .3s var(--n-bezier),
      box-shadow .3s var(--n-bezier);
    background-color: var(--n-rail-color);
  `, [cE("button-icon", `
      color: var(--n-icon-color);
      transition: color .3s var(--n-bezier);
      font-size: calc(var(--n-button-height) - 4px);
      position: absolute;
      left: 0;
      right: 0;
      top: 0;
      bottom: 0;
      display: flex;
      justify-content: center;
      align-items: center;
      line-height: 1;
    `, [iconSwitchTransition()]), cE("button", `
      align-items: center;    
      top: var(--n-offset);
      left: var(--n-offset);
      height: var(--n-button-height);
      width: var(--n-button-width-pressed);
      max-width: var(--n-button-width);
      border-radius: var(--n-button-border-radius);
      background-color: var(--n-button-color);
      box-shadow: var(--n-button-box-shadow);
      box-sizing: border-box;
      cursor: inherit;
      content: "";
      position: absolute;
      transition:
        background-color .3s var(--n-bezier),
        left .3s var(--n-bezier),
        opacity .3s var(--n-bezier),
        max-width .3s var(--n-bezier),
        box-shadow .3s var(--n-bezier);
    `)]), cM("active", [cE("rail", "background-color: var(--n-rail-color-active);")]), cM("loading", [cE("rail", `
      cursor: wait;
    `)]), cM("disabled", [cE("rail", `
      cursor: not-allowed;
      opacity: .5;
    `)])]);

    const switchProps = {
      ...useTheme.props,
      size: {
        type: String,
        default: "medium"
      },
      value: {
        type: [String, Number, Boolean],
        default: void 0
      },
      loading: Boolean,
      defaultValue: {
        type: [String, Number, Boolean],
        default: false
      },
      disabled: {
        type: Boolean,
        default: void 0
      },
      round: {
        type: Boolean,
        default: true
      },
      "onUpdate:value": [Function, Array],
      onUpdateValue: [Function, Array],
      checkedValue: {
        type: [String, Number, Boolean],
        default: true
      },
      uncheckedValue: {
        type: [String, Number, Boolean],
        default: false
      },
      railStyle: Function,
      rubberBand: {
        type: Boolean,
        default: true
      },
      onChange: [Function, Array]
    };
    let supportCssMax;
    var Switch = vue.defineComponent({
      name: "Switch",
      props: switchProps,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.onChange) {
              warnOnce(
                "switch",
                "`on-change` is deprecated, please use `on-update:value` instead."
              );
            }
          });
        }
        if (supportCssMax === void 0) {
          if (typeof CSS !== "undefined") {
            if (typeof CSS.supports !== "undefined") {
              supportCssMax = CSS.supports("width", "max(1px)");
            } else {
              supportCssMax = false;
            }
          } else {
            supportCssMax = true;
          }
        }
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Switch",
          "-switch",
          style$g,
          switchLight$1,
          props,
          mergedClsPrefixRef
        );
        const formItem = useFormItem(props);
        const { mergedSizeRef, mergedDisabledRef } = formItem;
        const uncontrolledValueRef = vue.ref(props.defaultValue);
        const controlledValueRef = vue.toRef(props, "value");
        const mergedValueRef = useMergedState(
          controlledValueRef,
          uncontrolledValueRef
        );
        const checkedRef = vue.computed(() => {
          return mergedValueRef.value === props.checkedValue;
        });
        const pressedRef = vue.ref(false);
        const focusedRef = vue.ref(false);
        const mergedRailStyleRef = vue.computed(() => {
          const { railStyle } = props;
          if (!railStyle)
            return void 0;
          return railStyle({ focused: focusedRef.value, checked: checkedRef.value });
        });
        function doUpdateValue(value) {
          const {
            "onUpdate:value": _onUpdateValue,
            onChange,
            onUpdateValue
          } = props;
          const { nTriggerFormInput, nTriggerFormChange } = formItem;
          if (_onUpdateValue)
            call(_onUpdateValue, value);
          if (onUpdateValue)
            call(onUpdateValue, value);
          if (onChange)
            call(onChange, value);
          uncontrolledValueRef.value = value;
          nTriggerFormInput();
          nTriggerFormChange();
        }
        function doFocus() {
          const { nTriggerFormFocus } = formItem;
          nTriggerFormFocus();
        }
        function doBlur() {
          const { nTriggerFormBlur } = formItem;
          nTriggerFormBlur();
        }
        function handleClick() {
          if (props.loading || mergedDisabledRef.value)
            return;
          if (mergedValueRef.value !== props.checkedValue) {
            doUpdateValue(props.checkedValue);
          } else {
            doUpdateValue(props.uncheckedValue);
          }
        }
        function handleFocus() {
          focusedRef.value = true;
          doFocus();
        }
        function handleBlur() {
          focusedRef.value = false;
          doBlur();
          pressedRef.value = false;
        }
        function handleKeyup(e) {
          if (props.loading || mergedDisabledRef.value)
            return;
          if (e.key === " ") {
            if (mergedValueRef.value !== props.checkedValue) {
              doUpdateValue(props.checkedValue);
            } else {
              doUpdateValue(props.uncheckedValue);
            }
            pressedRef.value = false;
          }
        }
        function handleKeydown(e) {
          if (props.loading || mergedDisabledRef.value)
            return;
          if (e.key === " ") {
            e.preventDefault();
            pressedRef.value = true;
          }
        }
        const cssVarsRef = vue.computed(() => {
          const { value: size } = mergedSizeRef;
          const {
            self: {
              opacityDisabled,
              railColor,
              railColorActive,
              buttonBoxShadow,
              buttonColor,
              boxShadowFocus,
              loadingColor,
              textColor,
              iconColor,
              [createKey("buttonHeight", size)]: buttonHeight,
              [createKey("buttonWidth", size)]: buttonWidth,
              [createKey("buttonWidthPressed", size)]: buttonWidthPressed,
              [createKey("railHeight", size)]: railHeight,
              [createKey("railWidth", size)]: railWidth,
              [createKey("railBorderRadius", size)]: railBorderRadius,
              [createKey("buttonBorderRadius", size)]: buttonBorderRadius
            },
            common: { cubicBezierEaseInOut }
          } = themeRef.value;
          let offset;
          let height;
          let width;
          if (supportCssMax) {
            offset = `calc((${railHeight} - ${buttonHeight}) / 2)`;
            height = `max(${railHeight}, ${buttonHeight})`;
            width = `max(${railWidth}, calc(${railWidth} + ${buttonHeight} - ${railHeight}))`;
          } else {
            offset = pxfy((depx(railHeight) - depx(buttonHeight)) / 2);
            height = pxfy(Math.max(depx(railHeight), depx(buttonHeight)));
            width = depx(railHeight) > depx(buttonHeight) ? railWidth : pxfy(depx(railWidth) + depx(buttonHeight) - depx(railHeight));
          }
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-button-border-radius": buttonBorderRadius,
            "--n-button-box-shadow": buttonBoxShadow,
            "--n-button-color": buttonColor,
            "--n-button-width": buttonWidth,
            "--n-button-width-pressed": buttonWidthPressed,
            "--n-button-height": buttonHeight,
            "--n-height": height,
            "--n-offset": offset,
            "--n-opacity-disabled": opacityDisabled,
            "--n-rail-border-radius": railBorderRadius,
            "--n-rail-color": railColor,
            "--n-rail-color-active": railColorActive,
            "--n-rail-height": railHeight,
            "--n-rail-width": railWidth,
            "--n-width": width,
            "--n-box-shadow-focus": boxShadowFocus,
            "--n-loading-color": loadingColor,
            "--n-text-color": textColor,
            "--n-icon-color": iconColor
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "switch",
          vue.computed(() => {
            return mergedSizeRef.value[0];
          }),
          cssVarsRef,
          props
        ) : void 0;
        return {
          handleClick,
          handleBlur,
          handleFocus,
          handleKeyup,
          handleKeydown,
          mergedRailStyle: mergedRailStyleRef,
          pressed: pressedRef,
          mergedClsPrefix: mergedClsPrefixRef,
          mergedValue: mergedValueRef,
          checked: checkedRef,
          mergedDisabled: mergedDisabledRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const {
          mergedClsPrefix,
          mergedDisabled,
          checked,
          mergedRailStyle,
          onRender,
          $slots
        } = this;
        onRender?.();
        const {
          checked: checkedSlot,
          unchecked: uncheckedSlot,
          icon: iconSlot,
          "checked-icon": checkedIconSlot,
          "unchecked-icon": uncheckedIconSlot
        } = $slots;
        const hasIcon = !(isSlotEmpty(iconSlot) && isSlotEmpty(checkedIconSlot) && isSlotEmpty(uncheckedIconSlot));
        return /* @__PURE__ */ React.createElement("div", {
          role: "switch",
          "aria-checked": checked,
          class: [
            `${mergedClsPrefix}-switch`,
            this.themeClass,
            hasIcon && `${mergedClsPrefix}-switch--icon`,
            checked && `${mergedClsPrefix}-switch--active`,
            mergedDisabled && `${mergedClsPrefix}-switch--disabled`,
            this.round && `${mergedClsPrefix}-switch--round`,
            this.loading && `${mergedClsPrefix}-switch--loading`,
            this.pressed && `${mergedClsPrefix}-switch--pressed`,
            this.rubberBand && `${mergedClsPrefix}-switch--rubber-band`
          ],
          tabindex: !this.mergedDisabled ? 0 : void 0,
          style: this.cssVars,
          onClick: this.handleClick,
          onFocus: this.handleFocus,
          onBlur: this.handleBlur,
          onKeyup: this.handleKeyup,
          onKeydown: this.handleKeydown
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-switch__rail`,
          "aria-hidden": "true",
          style: mergedRailStyle
        }, resolveWrappedSlot(
          checkedSlot,
          (checkedSlotChildren) => resolveWrappedSlot(uncheckedSlot, (uncheckedSlotChildren) => {
            if (checkedSlotChildren || uncheckedSlotChildren) {
              return /* @__PURE__ */ React.createElement("div", {
                "aria-hidden": true,
                class: `${mergedClsPrefix}-switch__children-placeholder`
              }, /* @__PURE__ */ React.createElement("div", {
                class: `${mergedClsPrefix}-switch__rail-placeholder`
              }, /* @__PURE__ */ React.createElement("div", {
                class: `${mergedClsPrefix}-switch__button-placeholder`
              }), checkedSlotChildren), /* @__PURE__ */ React.createElement("div", {
                class: `${mergedClsPrefix}-switch__rail-placeholder`
              }, /* @__PURE__ */ React.createElement("div", {
                class: `${mergedClsPrefix}-switch__button-placeholder`
              }), uncheckedSlotChildren));
            }
            return null;
          })
        ), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-switch__button`
        }, resolveWrappedSlot(
          iconSlot,
          (icon) => resolveWrappedSlot(
            checkedIconSlot,
            (checkedIcon) => resolveWrappedSlot(uncheckedIconSlot, (uncheckedIcon) => {
              return /* @__PURE__ */ React.createElement(NIconSwitchTransition, null, {
                default: () => this.loading ? /* @__PURE__ */ React.createElement(NBaseLoading, {
                  key: "loading",
                  clsPrefix: mergedClsPrefix,
                  strokeWidth: 20
                }) : this.checked && (checkedIcon || icon) ? /* @__PURE__ */ React.createElement("div", {
                  class: `${mergedClsPrefix}-switch__button-icon`,
                  key: checkedIcon ? "checked-icon" : "icon"
                }, checkedIcon || icon) : !this.checked && (uncheckedIcon || icon) ? /* @__PURE__ */ React.createElement("div", {
                  class: `${mergedClsPrefix}-switch__button-icon`,
                  key: uncheckedIcon ? "unchecked-icon" : "icon"
                }, uncheckedIcon || icon) : null
              });
            })
          )
        ), resolveWrappedSlot(
          checkedSlot,
          (children) => children && /* @__PURE__ */ React.createElement("div", {
            key: "checked",
            class: `${mergedClsPrefix}-switch__checked`
          }, children)
        ), resolveWrappedSlot(
          uncheckedSlot,
          (children) => children && /* @__PURE__ */ React.createElement("div", {
            key: "unchecked",
            class: `${mergedClsPrefix}-switch__unchecked`
          }, children)
        ))));
      }
    });

    var style$f = c$1([cB("table", `
    font-size: var(--n-font-size);
    font-variant-numeric: tabular-nums;
    line-height: var(--n-line-height);
    width: 100%;
    border-radius: var(--n-border-radius) var(--n-border-radius) 0 0;
    text-align: left;
    border-collapse: separate;
    border-spacing: 0;
    overflow: hidden;
    background-color: var(--n-td-color);
    border-color: var(--n-merged-border-color);
    transition:
      background-color .3s var(--n-bezier),
      border-color .3s var(--n-bezier),
      color .3s var(--n-bezier);
    --n-merged-border-color: var(--n-border-color);
  `, [c$1("th", `
      white-space: nowrap;
      transition:
        background-color .3s var(--n-bezier),
        border-color .3s var(--n-bezier),
        color .3s var(--n-bezier);
      text-align: inherit;
      padding: var(--n-th-padding);
      vertical-align: inherit;
      text-transform: none;
      border: 0px solid var(--n-merged-border-color);
      font-weight: var(--n-th-font-weight);
      color: var(--n-th-text-color);
      background-color: var(--n-th-color);
      border-bottom: 1px solid var(--n-merged-border-color);
      border-right: 1px solid var(--n-merged-border-color);
    `, [c$1("&:last-child", `
        border-right: 0px solid var(--n-merged-border-color);
      `)]), c$1("td", `
      transition:
        background-color .3s var(--n-bezier),
        border-color .3s var(--n-bezier),
        color .3s var(--n-bezier);
      padding: var(--n-td-padding);
      color: var(--n-td-text-color);
      background-color: var(--n-td-color);
      border: 0px solid var(--n-merged-border-color);
      border-right: 1px solid var(--n-merged-border-color);
      border-bottom: 1px solid var(--n-merged-border-color);
    `, [c$1("&:last-child", `
        border-right: 0px solid var(--n-merged-border-color);
      `)]), cM("bordered", `
      border: 1px solid var(--n-merged-border-color);
      border-radius: var(--n-border-radius);
    `, [c$1("tr", [c$1("&:last-child", [c$1("td", `
            border-bottom: 0 solid var(--n-merged-border-color);
          `)])])]), cM("single-line", [c$1("th", `
        border-right: 0px solid var(--n-merged-border-color);
      `), c$1("td", `
        border-right: 0px solid var(--n-merged-border-color);
      `)]), cM("single-column", [c$1("tr", [c$1("&:not(:last-child)", [c$1("td", `
            border-bottom: 0px solid var(--n-merged-border-color);
          `)])])]), cM("striped", [c$1("tr:nth-of-type(even)", [c$1("td", "background-color: var(--n-td-color-striped)")])]), cNotM("bottom-bordered", [c$1("tr", [c$1("&:last-child", [c$1("td", `
            border-bottom: 0px solid var(--n-merged-border-color);
          `)])])])]), insideModal(cB("table", `
      background-color: var(--n-td-color-modal);
      --n-merged-border-color: var(--n-border-color-modal);
    `, [c$1("th", `
        background-color: var(--n-th-color-modal);
      `), c$1("td", `
        background-color: var(--n-td-color-modal);
      `)])), insidePopover(cB("table", `
      background-color: var(--n-td-color-popover);
      --n-merged-border-color: var(--n-border-color-popover);
    `, [c$1("th", `
        background-color: var(--n-th-color-popover);
      `), c$1("td", `
        background-color: var(--n-td-color-popover);
      `)]))]);

    const tableProps = {
      ...useTheme.props,
      bordered: {
        type: Boolean,
        default: true
      },
      bottomBordered: {
        type: Boolean,
        default: true
      },
      singleLine: {
        type: Boolean,
        default: true
      },
      striped: Boolean,
      singleColumn: Boolean,
      size: {
        type: String,
        default: "medium"
      }
    };
    var Table = vue.defineComponent({
      name: "Table",
      props: tableProps,
      setup(props) {
        const { mergedClsPrefixRef, inlineThemeDisabled, mergedRtlRef } = useConfig(props);
        const themeRef = useTheme(
          "Table",
          "-table",
          style$f,
          tableLight$1,
          props,
          mergedClsPrefixRef
        );
        const rtlEnabledRef = useRtl("Table", mergedRtlRef, mergedClsPrefixRef);
        const cssVarsRef = vue.computed(() => {
          const { size } = props;
          const {
            self: {
              borderColor,
              tdColor,
              tdColorModal,
              tdColorPopover,
              thColor,
              thColorModal,
              thColorPopover,
              thTextColor,
              tdTextColor,
              borderRadius,
              thFontWeight,
              lineHeight,
              borderColorModal,
              borderColorPopover,
              tdColorStriped,
              tdColorStripedModal,
              tdColorStripedPopover,
              [createKey("fontSize", size)]: fontSize,
              [createKey("tdPadding", size)]: tdPadding,
              [createKey("thPadding", size)]: thPadding
            },
            common: { cubicBezierEaseInOut }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-td-color": tdColor,
            "--n-td-color-modal": tdColorModal,
            "--n-td-color-popover": tdColorPopover,
            "--n-td-text-color": tdTextColor,
            "--n-border-color": borderColor,
            "--n-border-color-modal": borderColorModal,
            "--n-border-color-popover": borderColorPopover,
            "--n-border-radius": borderRadius,
            "--n-font-size": fontSize,
            "--n-th-color": thColor,
            "--n-th-color-modal": thColorModal,
            "--n-th-color-popover": thColorPopover,
            "--n-th-font-weight": thFontWeight,
            "--n-th-text-color": thTextColor,
            "--n-line-height": lineHeight,
            "--n-td-padding": tdPadding,
            "--n-th-padding": thPadding,
            "--n-td-color-striped": tdColorStriped,
            "--n-td-color-striped-modal": tdColorStripedModal,
            "--n-td-color-striped-popover": tdColorStripedPopover
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "table",
          vue.computed(() => {
            return props.size[0];
          }),
          cssVarsRef,
          props
        ) : void 0;
        return {
          rtlEnabled: rtlEnabledRef,
          mergedClsPrefix: mergedClsPrefixRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedClsPrefix } = this;
        this.onRender?.();
        return /* @__PURE__ */ React.createElement("table", {
          class: [
            `${mergedClsPrefix}-table`,
            this.themeClass,
            {
              [`${mergedClsPrefix}-table--rtl`]: this.rtlEnabled,
              [`${mergedClsPrefix}-table--bottom-bordered`]: this.bottomBordered,
              [`${mergedClsPrefix}-table--bordered`]: this.bordered,
              [`${mergedClsPrefix}-table--single-line`]: this.singleLine,
              [`${mergedClsPrefix}-table--single-column`]: this.singleColumn,
              [`${mergedClsPrefix}-table--striped`]: this.striped
            }
          ],
          style: this.cssVars
        }, this.$slots);
      }
    });

    var Th = vue.defineComponent({
      name: "Th",
      render() {
        return /* @__PURE__ */ React.createElement("th", null, this.$slots);
      }
    });

    var Tr = vue.defineComponent({
      name: "Tr",
      render() {
        return /* @__PURE__ */ React.createElement("tr", null, this.$slots);
      }
    });

    var Td = vue.defineComponent({
      name: "Td",
      render() {
        return /* @__PURE__ */ React.createElement("td", null, this.$slots);
      }
    });

    var Thead = vue.defineComponent({
      name: "Thead",
      render() {
        return /* @__PURE__ */ React.createElement("thead", null, this.$slots);
      }
    });

    var Tbody = vue.defineComponent({
      name: "Tbody",
      render() {
        return /* @__PURE__ */ React.createElement("tbody", null, this.$slots);
      }
    });

    const tabsInjectionKey = createInjectionKey("n-tabs");

    const tabPaneProps = {
      tab: [String, Number, Object, Function],
      name: {
        type: [String, Number],
        required: true
      },
      disabled: Boolean,
      displayDirective: {
        type: String,
        default: "if"
      },
      closable: {
        type: Boolean,
        default: void 0
      },
      tabProps: Object,
      label: [String, Number, Object, Function]
    };
    var TabPane = vue.defineComponent({
      __TAB_PANE__: true,
      name: "TabPane",
      alias: ["TabPanel"],
      props: tabPaneProps,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.label !== void 0) {
              warnOnce(
                "tab-pane",
                "`label` is deprecated, please use `tab` instead."
              );
            }
          });
        }
        const NTab = vue.inject(tabsInjectionKey, null);
        if (!NTab) {
          throwError("tab-pane", "`n-tab-pane` must be placed inside `n-tabs`.");
        }
        return {
          style: NTab.paneStyleRef,
          class: NTab.paneClassRef,
          mergedClsPrefix: NTab.mergedClsPrefixRef
        };
      },
      render() {
        return /* @__PURE__ */ React.createElement("div", {
          class: [`${this.mergedClsPrefix}-tab-pane`, this.class],
          style: this.style
        }, this.$slots);
      }
    });

    const tabProps = {
      internalLeftPadded: Boolean,
      internalAddable: Boolean,
      internalCreatedByPane: Boolean,
      ...omit(tabPaneProps, ["displayDirective"])
    };
    var Tab = vue.defineComponent({
      __TAB__: true,
      inheritAttrs: false,
      name: "Tab",
      props: tabProps,
      setup(props) {
        const {
          mergedClsPrefixRef,
          valueRef,
          typeRef,
          closableRef,
          tabStyleRef,
          tabChangeIdRef,
          onBeforeLeaveRef,
          triggerRef,
          handleAdd,
          activateTab,
          handleClose
        } = vue.inject(tabsInjectionKey);
        return {
          trigger: triggerRef,
          mergedClosable: vue.computed(() => {
            if (props.internalAddable)
              return false;
            const { closable } = props;
            if (closable === void 0)
              return closableRef.value;
            return closable;
          }),
          style: tabStyleRef,
          clsPrefix: mergedClsPrefixRef,
          value: valueRef,
          type: typeRef,
          handleClose(e) {
            e.stopPropagation();
            if (props.disabled)
              return;
            handleClose(props.name);
          },
          activateTab() {
            if (props.disabled)
              return;
            if (props.internalAddable) {
              handleAdd();
              return;
            }
            const { name: nameProp } = props;
            const id = ++tabChangeIdRef.id;
            if (nameProp !== valueRef.value) {
              const { value: onBeforeLeave } = onBeforeLeaveRef;
              if (!onBeforeLeave) {
                activateTab(nameProp);
              } else {
                void Promise.resolve(
                  onBeforeLeave(props.name, valueRef.value)
                ).then((allowLeave) => {
                  if (allowLeave && tabChangeIdRef.id === id) {
                    activateTab(nameProp);
                  }
                });
              }
            }
          }
        };
      },
      render() {
        const {
          internalAddable,
          clsPrefix,
          name,
          disabled,
          label,
          tab,
          value,
          mergedClosable,
          style,
          trigger,
          $slots: { default: defaultSlot }
        } = this;
        const mergedTab = label ?? tab;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-tabs-tab-wrapper`
        }, this.internalLeftPadded ? /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-tabs-tab-pad`
        }) : null, /* @__PURE__ */ React.createElement("div", {
          key: name,
          "data-name": name,
          "data-disabled": disabled ? true : void 0,
          ...vue.mergeProps(
            {
              class: [
                `${clsPrefix}-tabs-tab`,
                value === name && `${clsPrefix}-tabs-tab--active`,
                disabled && `${clsPrefix}-tabs-tab--disabled`,
                mergedClosable && `${clsPrefix}-tabs-tab--closable`,
                internalAddable && `${clsPrefix}-tabs-tab--addable`
              ],
              onClick: trigger === "click" ? this.activateTab : void 0,
              onMouseenter: trigger === "hover" ? this.activateTab : void 0,
              style: internalAddable ? void 0 : style
            },
            this.internalCreatedByPane ? this.tabProps || {} : this.$attrs
          )
        }, /* @__PURE__ */ React.createElement("span", {
          class: `${clsPrefix}-tabs-tab__label`
        }, internalAddable ? /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-tabs-tab__height-placeholder`
        }, "\xA0"), /* @__PURE__ */ React.createElement(NBaseIcon, {
          clsPrefix
        }, {
          default: () => /* @__PURE__ */ React.createElement(AddIcon, null)
        })) : defaultSlot ? defaultSlot() : typeof mergedTab === "object" ? mergedTab : render$1(mergedTab ?? name)), mergedClosable && this.type === "card" ? /* @__PURE__ */ React.createElement(NBaseClose, {
          clsPrefix,
          class: `${clsPrefix}-tabs-tab__close`,
          onClick: this.handleClose,
          disabled
        }) : null));
      }
    });

    var style$e = cB("tabs", `
  box-sizing: border-box;
  width: 100%;
  transition:
    background-color .3s var(--n-bezier),
    border-color .3s var(--n-bezier);
`, [cM("segment-type", [cB("tabs-rail", [c$1("&.transition-disabled", "color: red;", [cB("tabs-tab", `
          transition: none;
        `)])])]), cB("tabs-rail", `
    padding: 3px;
    border-radius: var(--n-tab-border-radius);
    width: 100%;
    background-color: var(--n-color-segment);
    transition: background-color .3s var(--n-bezier);
    display: flex;
    align-items: center;
  `, [cB("tabs-tab-wrapper", `
      flex-basis: 0;
      flex-grow: 1;
      display: flex;
      align-items: center;
      justify-content: center;
    `, [cB("tabs-tab", `
        overflow: hidden;
        border-radius: var(--n-tab-border-radius);
        width: 100%;
        display: flex;
        align-items: center;
        justify-content: center;
      `, [cM("active", `
          font-weight: var(--n-font-weight-strong);
          color: var(--n-tab-text-color-active);
          background-color: var(--n-tab-color-segment);
          box-shadow: 0 1px 3px 0 rgba(0, 0, 0, .08);
        `), c$1("&:hover", `
          color: var(--n-tab-text-color-hover);
        `)])])]), cM("flex", [cB("tabs-nav", {
      width: "100%"
    }, [cB("tabs-wrapper", {
      width: "100%"
    }, [cB("tabs-tab", {
      marginRight: 0
    })])])]), cB("tabs-nav", `
    box-sizing: border-box;
    line-height: 1.5;
    display: flex;
    transition: border-color .3s var(--n-bezier);
  `, [cE("prefix, suffix", `
      display: flex;
      align-items: center;
    `), cE("prefix", "padding-right: 16px;"), cE("suffix", "padding-left: 16px;")]), cB("tabs-nav-scroll-wrapper", `
    flex: 1;
    position: relative;
    overflow: hidden;
  `, [cM("shadow-before", [c$1("&::before", `
        box-shadow: inset 10px 0 8px -8px rgba(0, 0, 0, .12);
      `)]), cM("shadow-after", [c$1("&::after", `
        box-shadow: inset -10px 0 8px -8px rgba(0, 0, 0, .12);
      `)]), c$1("&::before, &::after", `
      transition: box-shadow .3s var(--n-bezier);
      pointer-events: none;
      content: "";
      position: absolute;
      top: 0;
      bottom: 0;
      width: 20px;
      z-index: 1;
    `), c$1("&::before", `
      left: 0;
    `), c$1("&::after", `
      right: 0;
    `)]), cB("tabs-nav-scroll-content", `
    display: flex;
    position: relative;
    min-width: 100%;
    width: fit-content;
  `), cB("tabs-wrapper", `
    display: inline-flex;
    flex-wrap: nowrap;
    position: relative;
  `), cB("tabs-tab-wrapper", `
    display: flex;
    flex-wrap: nowrap;
    flex-shrink: 0;
    flex-grow: 0;
  `), cB("tabs-tab", `
    cursor: pointer;
    white-space: nowrap;
    flex-wrap: nowrap;
    display: inline-flex;
    align-items: center;
    color: var(--n-tab-text-color);
    font-size: var(--n-tab-font-size);
    background-clip: padding-box;
    padding: var(--n-tab-padding);
    transition:
      box-shadow .3s var(--n-bezier),
      color .3s var(--n-bezier),
      background-color .3s var(--n-bezier),
      border-color .3s var(--n-bezier);
  `, [cM("disabled", {
      cursor: "not-allowed"
    }), cE("close", `
      margin-left: 6px;
      transition:
        background-color .3s var(--n-bezier),
        color .3s var(--n-bezier);
    `), cE("label", `
      display: flex;
      align-items: center;
    `)]), cB("tabs-bar", `
    position: absolute;
    bottom: 0;
    height: 2px;
    border-radius: 1px;
    background-color: var(--n-bar-color);
    transition:
      left .2s var(--n-bezier),
      max-width .2s var(--n-bezier),
      background-color .3s var(--n-bezier);
  `, [c$1("&.transition-disabled", `
      transition: none;
    `), cM("disabled", `
      background-color: var(--n-tab-text-color-disabled)
    `)]), cB("tabs-pane-wrapper", `
    position: relative;
    overflow: hidden;
    transition: max-height .2s var(--n-bezier);
  `), cB("tab-pane", `
    color: var(--n-pane-text-color);
    width: 100%;
    padding: var(--n-pane-padding);
    transition:
      color .3s var(--n-bezier),
      background-color .3s var(--n-bezier),
      opacity .2s var(--n-bezier);
    left: 0;
    right: 0;
    top: 0;
  `, [c$1("&.next-transition-leave-active, &.prev-transition-leave-active, &.next-transition-enter-active, &.prev-transition-enter-active", `
      transition:
      color .3s var(--n-bezier),
      background-color .3s var(--n-bezier),
      transform .2s var(--n-bezier),
      opacity .2s var(--n-bezier);
    `), c$1("&.next-transition-leave-active, &.prev-transition-leave-active", `
      position: absolute;
    `), c$1("&.next-transition-enter-from, &.prev-transition-leave-to", `
      transform: translateX(32px);
      opacity: 0;
    `), c$1("&.next-transition-leave-to, &.prev-transition-enter-from", `
      transform: translateX(-32px);
      opacity: 0;
    `), c$1("&.next-transition-leave-from, &.next-transition-enter-to, &.prev-transition-leave-from, &.prev-transition-enter-to", `
      transform: translateX(0);
      opacity: 1;
    `)]), cB("tabs-tab-pad", `
    width: var(--n-tab-gap);
    flex-grow: 0;
    flex-shrink: 0;
  `), cM("line-type, bar-type", [cB("tabs-tab", `
      font-weight: var(--n-tab-font-weight);
      box-sizing: border-box;
      vertical-align: bottom;
    `, [c$1("&:hover", {
      color: "var(--n-tab-text-color-hover)"
    }), cM("active", `
        color: var(--n-tab-text-color-active);
        font-weight: var(--n-tab-font-weight-active);
      `), cM("disabled", {
      color: "var(--n-tab-text-color-disabled)"
    })])]), cB("tabs-nav", [cM("line-type", [cE("prefix, suffix", `
        transition: border-color .3s var(--n-bezier);
        border-bottom: 1px solid var(--n-tab-border-color);
      `), cB("tabs-nav-scroll-content", `
        transition: border-color .3s var(--n-bezier);
        border-bottom: 1px solid var(--n-tab-border-color);
      `), cB("tabs-bar", `
        border-radius: 0;
        bottom: -1px;
      `)]), cM("card-type", [cE("prefix, suffix", `
        transition: border-color .3s var(--n-bezier);
        border-bottom: 1px solid var(--n-tab-border-color);
      `), cB("tabs-pad", `
        flex-grow: 1;
        transition: border-color .3s var(--n-bezier);
        border-bottom: 1px solid var(--n-tab-border-color);
      `), cB("tabs-tab-pad", `
        transition: border-color .3s var(--n-bezier);
        border-bottom: 1px solid var(--n-tab-border-color);
      `), cB("tabs-tab", `
        font-weight: var(--n-tab-font-weight);
        border: 1px solid var(--n-tab-border-color);
        border-top-left-radius: var(--n-tab-border-radius);
        border-top-right-radius: var(--n-tab-border-radius);
        background-color: var(--n-tab-color);
        box-sizing: border-box;
        position: relative;
        vertical-align: bottom;
        display: flex;
        justify-content: space-between;
        font-size: var(--n-tab-font-size);
        color: var(--n-tab-text-color);
      `, [cM("addable", `
          padding-left: 8px;
          padding-right: 8px;
          font-size: 16px;
        `, [cE("height-placeholder", `
            width: 0;
            font-size: var(--n-tab-font-size);
          `), cNotM("disabled", [c$1("&:hover", `
              color: var(--n-tab-text-color-hover);
            `)])]), cM("closable", "padding-right: 6px;"), cM("active", `
          border-bottom: 1px solid #0000;
          background-color: #0000;
          font-weight: var(--n-tab-font-weight-active);
          color: var(--n-tab-text-color-active);
        `), cM("disabled", "color: var(--n-tab-text-color-disabled);")]), cB("tabs-scroll-padding", "border-bottom: 1px solid var(--n-tab-border-color);")])])]);

    const tabsProps = {
      ...useTheme.props,
      value: [String, Number],
      defaultValue: [String, Number],
      trigger: {
        type: String,
        default: "click"
      },
      type: {
        type: String,
        default: "bar"
      },
      closable: Boolean,
      justifyContent: String,
      size: {
        type: String,
        default: "medium"
      },
      tabStyle: [String, Object],
      barWidth: Number,
      paneClass: String,
      paneStyle: [String, Object],
      addable: [Boolean, Object],
      tabsPadding: {
        type: Number,
        default: 0
      },
      animated: Boolean,
      onBeforeLeave: Function,
      onAdd: Function,
      "onUpdate:value": [Function, Array],
      onUpdateValue: [Function, Array],
      onClose: [Function, Array],
      labelSize: String,
      activeName: [String, Number],
      onActiveNameChange: [Function, Array]
    };
    var Tabs = vue.defineComponent({
      name: "Tabs",
      props: tabsProps,
      setup(props, { slots }) {
        {
          vue.watchEffect(() => {
            if (props.labelSize !== void 0) {
              warnOnce(
                "tabs",
                "`label-size` is deprecated, please use `size` instead."
              );
            }
            if (props.activeName !== void 0) {
              warnOnce(
                "tabs",
                "`active-name` is deprecated, please use `value` instead."
              );
            }
            if (props.onActiveNameChange !== void 0) {
              warnOnce(
                "tabs",
                "`on-active-name-change` is deprecated, please use `on-update:value` instead."
              );
            }
          });
        }
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Tabs",
          "-tabs",
          style$e,
          tabsLight$1,
          props,
          mergedClsPrefixRef
        );
        const tabsElRef = vue.ref(null);
        const barElRef = vue.ref(null);
        const scrollWrapperElRef = vue.ref(null);
        const addTabInstRef = vue.ref(null);
        const xScrollInstRef = vue.ref(
          null
        );
        const leftReachedRef = vue.ref(true);
        const rightReachedRef = vue.ref(true);
        const compitableSizeRef = useCompitable(props, ["labelSize", "size"]);
        const compitableValueRef = useCompitable(props, ["activeName", "value"]);
        const uncontrolledValueRef = vue.ref(
          compitableValueRef.value ?? props.defaultValue ?? (slots.default ? flatten$3(slots.default())[0]?.props?.name : null)
        );
        const mergedValueRef = useMergedState(
          compitableValueRef,
          uncontrolledValueRef
        );
        const tabChangeIdRef = { id: 0 };
        const tabWrapperStyleRef = vue.computed(() => {
          if (!props.justifyContent || props.type === "card")
            return void 0;
          return {
            display: "flex",
            justifyContent: props.justifyContent
          };
        });
        vue.watch(mergedValueRef, () => {
          tabChangeIdRef.id = 0;
          updateCurrentBarStyle();
        });
        function getCurrentEl() {
          const { value } = mergedValueRef;
          if (value === null)
            return null;
          const tabEl = tabsElRef.value?.querySelector(`[data-name="${value}"]`);
          return tabEl;
        }
        function updateBarStyle(tabEl) {
          if (props.type === "card")
            return;
          const { value: barEl } = barElRef;
          if (!barEl)
            return;
          if (tabEl) {
            const disabledClassName = `${mergedClsPrefixRef.value}-tabs-bar--disabled`;
            const { barWidth } = props;
            if (tabEl.dataset.disabled === "true") {
              barEl.classList.add(disabledClassName);
            } else {
              barEl.classList.remove(disabledClassName);
            }
            if (typeof barWidth === "number" && tabEl.offsetWidth >= barWidth) {
              const offsetDiffLeft = Math.floor((tabEl.offsetWidth - barWidth) / 2) + tabEl.offsetLeft;
              barEl.style.left = `${offsetDiffLeft}px`;
              barEl.style.maxWidth = `${barWidth}px`;
            } else {
              barEl.style.left = `${tabEl.offsetLeft}px`;
              barEl.style.maxWidth = `${tabEl.offsetWidth}px`;
            }
            barEl.style.width = "8192px";
            void barEl.offsetWidth;
          }
        }
        function updateCurrentBarStyle() {
          if (props.type === "card")
            return;
          const tabEl = getCurrentEl();
          if (tabEl) {
            updateBarStyle(tabEl);
          }
        }
        const tabsPaneWrapperRef = vue.ref(null);
        let fromHeight = 0;
        let hangingTransition = null;
        function onAnimationBeforeLeave(el) {
          const tabsPaneWrapperEl = tabsPaneWrapperRef.value;
          if (tabsPaneWrapperEl) {
            fromHeight = el.getBoundingClientRect().height;
            const fromHeightPx = `${fromHeight}px`;
            const applyFromStyle = () => {
              tabsPaneWrapperEl.style.height = fromHeightPx;
              tabsPaneWrapperEl.style.maxHeight = fromHeightPx;
            };
            if (!hangingTransition) {
              hangingTransition = applyFromStyle;
            } else {
              applyFromStyle();
              hangingTransition();
              hangingTransition = null;
            }
          }
        }
        function onAnimationEnter(el) {
          const tabsPaneWrapperEl = tabsPaneWrapperRef.value;
          if (tabsPaneWrapperEl) {
            const targetHeight = el.getBoundingClientRect().height;
            const applyTargetStyle = () => {
              void document.body.offsetHeight;
              tabsPaneWrapperEl.style.maxHeight = `${targetHeight}px`;
              tabsPaneWrapperEl.style.height = `${Math.max(
            fromHeight,
            targetHeight
          )}px`;
            };
            if (!hangingTransition) {
              hangingTransition = applyTargetStyle;
            } else {
              hangingTransition();
              hangingTransition = null;
              applyTargetStyle();
            }
          }
        }
        function onAnimationAfterEnter() {
          const tabsPaneWrapperEl = tabsPaneWrapperRef.value;
          if (tabsPaneWrapperEl) {
            tabsPaneWrapperEl.style.maxHeight = "";
            tabsPaneWrapperEl.style.height = "";
          }
        }
        const renderNameListRef = { value: [] };
        const animationDirectionRef = vue.ref("next");
        function activateTab(panelName) {
          const currentValue = mergedValueRef.value;
          let dir = "next";
          for (const name of renderNameListRef.value) {
            if (name === currentValue) {
              break;
            }
            if (name === panelName) {
              dir = "prev";
              break;
            }
          }
          animationDirectionRef.value = dir;
          doUpdateValue(panelName);
        }
        function doUpdateValue(panelName) {
          const {
            onActiveNameChange,
            onUpdateValue,
            "onUpdate:value": _onUpdateValue
          } = props;
          if (onActiveNameChange) {
            call(onActiveNameChange, panelName);
          }
          if (onUpdateValue)
            call(onUpdateValue, panelName);
          if (_onUpdateValue)
            call(_onUpdateValue, panelName);
          uncontrolledValueRef.value = panelName;
        }
        function handleClose(panelName) {
          const { onClose } = props;
          if (onClose)
            call(onClose, panelName);
        }
        function updateBarPositionInstantly() {
          const { value: barEl } = barElRef;
          if (!barEl)
            return;
          const disableTransitionClassName = "transition-disabled";
          barEl.classList.add(disableTransitionClassName);
          updateCurrentBarStyle();
          barEl.classList.remove(disableTransitionClassName);
        }
        let memorizedWidth = 0;
        function _handleNavResize(entry) {
          if (entry.contentRect.width === 0 && entry.contentRect.height === 0) {
            return;
          }
          if (memorizedWidth === entry.contentRect.width) {
            return;
          }
          memorizedWidth = entry.contentRect.width;
          const { type } = props;
          if (type === "line" || type === "bar") {
            {
              updateBarPositionInstantly();
            }
          }
          if (type !== "segment") {
            deriveScrollShadow(xScrollInstRef.value?.$el);
          }
        }
        const handleNavResize = lodash.exports.throttle(_handleNavResize, 64);
        vue.watch([() => props.justifyContent, () => props.size], () => {
          void vue.nextTick(() => {
            const { type } = props;
            if (type === "line" || type === "bar") {
              updateBarPositionInstantly();
            }
          });
        });
        const addTabFixedRef = vue.ref(false);
        function _handleTabsResize(entry) {
          const {
            target,
            contentRect: { width }
          } = entry;
          const containerWidth = target.parentElement.offsetWidth;
          if (!addTabFixedRef.value) {
            if (containerWidth < width) {
              addTabFixedRef.value = true;
            }
          } else {
            const { value: addTabInst } = addTabInstRef;
            if (!addTabInst)
              return;
            if (containerWidth - width > addTabInst.$el.offsetWidth) {
              addTabFixedRef.value = false;
            }
          }
          deriveScrollShadow(xScrollInstRef.value?.$el);
        }
        const handleTabsResize = lodash.exports.throttle(_handleTabsResize, 64);
        function handleAdd() {
          const { onAdd } = props;
          if (onAdd)
            onAdd();
          void vue.nextTick(() => {
            const currentEl = getCurrentEl();
            const { value: xScrollInst } = xScrollInstRef;
            if (!currentEl || !xScrollInst)
              return;
            xScrollInst.scrollTo({
              left: currentEl.offsetLeft,
              top: 0,
              behavior: "smooth"
            });
          });
        }
        function deriveScrollShadow(el) {
          if (!el)
            return;
          const { scrollLeft, scrollWidth, offsetWidth } = el;
          leftReachedRef.value = scrollLeft <= 0;
          rightReachedRef.value = scrollLeft + offsetWidth >= scrollWidth;
        }
        const handleScroll = lodash.exports.throttle((e) => {
          deriveScrollShadow(e.target);
        }, 64);
        vue.provide(tabsInjectionKey, {
          triggerRef: vue.toRef(props, "trigger"),
          tabStyleRef: vue.toRef(props, "tabStyle"),
          paneClassRef: vue.toRef(props, "paneClass"),
          paneStyleRef: vue.toRef(props, "paneStyle"),
          mergedClsPrefixRef,
          typeRef: vue.toRef(props, "type"),
          closableRef: vue.toRef(props, "closable"),
          valueRef: mergedValueRef,
          tabChangeIdRef,
          onBeforeLeaveRef: vue.toRef(props, "onBeforeLeave"),
          activateTab,
          handleClose,
          handleAdd
        });
        onFontsReady(() => {
          updateCurrentBarStyle();
        });
        vue.watchEffect(() => {
          const { value: el } = scrollWrapperElRef;
          if (!el)
            return;
          const { value: clsPrefix } = mergedClsPrefixRef;
          const shadowBeforeClass = `${clsPrefix}-tabs-nav-scroll-wrapper--shadow-before`;
          const shadowAfterClass = `${clsPrefix}-tabs-nav-scroll-wrapper--shadow-after`;
          if (leftReachedRef.value) {
            el.classList.remove(shadowBeforeClass);
          } else {
            el.classList.add(shadowBeforeClass);
          }
          if (rightReachedRef.value) {
            el.classList.remove(shadowAfterClass);
          } else {
            el.classList.add(shadowAfterClass);
          }
        });
        const tabsRailElRef = vue.ref(null);
        vue.watch(mergedValueRef, () => {
          if (props.type === "segment") {
            const tabsRailEl = tabsRailElRef.value;
            if (tabsRailEl) {
              void vue.nextTick(() => {
                tabsRailEl.classList.add("transition-disabled");
                void tabsRailEl.offsetWidth;
                tabsRailEl.classList.remove("transition-disabled");
              });
            }
          }
        });
        const exposedMethods = {
          syncBarPosition: () => {
            updateCurrentBarStyle();
          }
        };
        const cssVarsRef = vue.computed(() => {
          const { value: size } = compitableSizeRef;
          const { type } = props;
          const typeSuffix = {
            card: "Card",
            bar: "Bar",
            line: "Line",
            segment: "Segment"
          }[type];
          const sizeType = `${size}${typeSuffix}`;
          const {
            self: {
              barColor,
              closeIconColor,
              closeIconColorHover,
              closeIconColorPressed,
              tabColor,
              tabBorderColor,
              paneTextColor,
              tabFontWeight,
              tabBorderRadius,
              tabFontWeightActive,
              colorSegment,
              fontWeightStrong,
              tabColorSegment,
              closeSize,
              closeIconSize,
              closeColorHover,
              closeColorPressed,
              closeBorderRadius,
              [createKey("panePadding", size)]: panePadding,
              [createKey("tabPadding", sizeType)]: tabPadding,
              [createKey("tabGap", sizeType)]: tabGap,
              [createKey("tabTextColor", type)]: tabTextColor,
              [createKey("tabTextColorActive", type)]: tabTextColorActive,
              [createKey("tabTextColorHover", type)]: tabTextColorHover,
              [createKey("tabTextColorDisabled", type)]: tabTextColorDisabled,
              [createKey("tabFontSize", size)]: tabFontSize
            },
            common: { cubicBezierEaseInOut }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-color-segment": colorSegment,
            "--n-bar-color": barColor,
            "--n-tab-font-size": tabFontSize,
            "--n-tab-text-color": tabTextColor,
            "--n-tab-text-color-active": tabTextColorActive,
            "--n-tab-text-color-disabled": tabTextColorDisabled,
            "--n-tab-text-color-hover": tabTextColorHover,
            "--n-pane-text-color": paneTextColor,
            "--n-tab-border-color": tabBorderColor,
            "--n-tab-border-radius": tabBorderRadius,
            "--n-close-size": closeSize,
            "--n-close-icon-size": closeIconSize,
            "--n-close-color-hover": closeColorHover,
            "--n-close-color-pressed": closeColorPressed,
            "--n-close-border-radius": closeBorderRadius,
            "--n-close-icon-color": closeIconColor,
            "--n-close-icon-color-hover": closeIconColorHover,
            "--n-close-icon-color-pressed": closeIconColorPressed,
            "--n-tab-color": tabColor,
            "--n-tab-font-weight": tabFontWeight,
            "--n-tab-font-weight-active": tabFontWeightActive,
            "--n-tab-padding": tabPadding,
            "--n-tab-gap": tabGap,
            "--n-pane-padding": panePadding,
            "--n-font-weight-strong": fontWeightStrong,
            "--n-tab-color-segment": tabColorSegment
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "tabs",
          vue.computed(() => {
            return `${compitableSizeRef.value[0]}${props.type[0]}`;
          }),
          cssVarsRef,
          props
        ) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          mergedValue: mergedValueRef,
          renderedNames: /* @__PURE__ */ new Set(),
          tabsRailElRef,
          tabsPaneWrapperRef,
          tabsElRef,
          barElRef,
          addTabInstRef,
          xScrollInstRef,
          scrollWrapperElRef,
          addTabFixed: addTabFixedRef,
          tabWrapperStyle: tabWrapperStyleRef,
          handleNavResize,
          mergedSize: compitableSizeRef,
          handleScroll,
          handleTabsResize,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          animationDirection: animationDirectionRef,
          renderNameListRef,
          onAnimationBeforeLeave,
          onAnimationEnter,
          onAnimationAfterEnter,
          onRender: themeClassHandle?.onRender,
          ...exposedMethods
        };
      },
      render() {
        const {
          mergedClsPrefix,
          type,
          addTabFixed,
          addable,
          mergedSize,
          renderNameListRef,
          onRender,
          $slots: { default: defaultSlot, prefix: prefixSlot, suffix: suffixSlot }
        } = this;
        onRender?.();
        const tabPaneChildren = defaultSlot ? flatten$3(defaultSlot()).filter((v) => {
          return v.type.__TAB_PANE__ === true;
        }) : [];
        const tabChildren = defaultSlot ? flatten$3(defaultSlot()).filter((v) => {
          return v.type.__TAB__ === true;
        }) : [];
        const showPane = !tabChildren.length;
        const isCard = type === "card";
        const isSegment = type === "segment";
        const mergedJustifyContent = !isCard && !isSegment && this.justifyContent;
        renderNameListRef.value = [];
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-tabs`,
            this.themeClass,
            `${mergedClsPrefix}-tabs--${type}-type`,
            `${mergedClsPrefix}-tabs--${mergedSize}-size`,
            mergedJustifyContent && `${mergedClsPrefix}-tabs--flex`
          ],
          style: this.cssVars
        }, /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-tabs-nav--${type}-type`,
            `${mergedClsPrefix}-tabs-nav`
          ]
        }, resolveWrappedSlot(
          prefixSlot,
          (children) => children && /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-tabs-nav__prefix`
          }, children)
        ), isSegment ? /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-tabs-rail`,
          ref: "tabsRailElRef"
        }, showPane ? tabPaneChildren.map((tabPaneVNode, index) => {
          renderNameListRef.value.push(tabPaneVNode.props.name);
          return /* @__PURE__ */ React.createElement(Tab, {
            ...tabPaneVNode.props,
            internalCreatedByPane: true,
            internalLeftPadded: index !== 0
          }, tabPaneVNode.children ? {
            default: tabPaneVNode.children.tab
          } : void 0);
        }) : tabChildren.map((tabVNode, index) => {
          renderNameListRef.value.push(tabVNode.props.name);
          if (index === 0) {
            return tabVNode;
          } else {
            return createLeftPaddedTabVNode(tabVNode);
          }
        })) : /* @__PURE__ */ React.createElement(VResizeObserver, {
          onResize: this.handleNavResize
        }, {
          default: () => /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-tabs-nav-scroll-wrapper`,
            ref: "scrollWrapperElRef"
          }, /* @__PURE__ */ React.createElement(VXScroll, {
            ref: "xScrollInstRef",
            onScroll: this.handleScroll
          }, {
            default: () => {
              const rawWrappedTabs = /* @__PURE__ */ React.createElement("div", {
                style: this.tabWrapperStyle,
                class: `${mergedClsPrefix}-tabs-wrapper`
              }, mergedJustifyContent ? null : /* @__PURE__ */ React.createElement("div", {
                class: `${mergedClsPrefix}-tabs-scroll-padding`,
                style: { width: `${this.tabsPadding}px` }
              }), showPane ? tabPaneChildren.map(
                (tabPaneVNode, index) => {
                  renderNameListRef.value.push(
                    tabPaneVNode.props.name
                  );
                  return justifyTabDynamicProps(
                    /* @__PURE__ */ React.createElement(Tab, {
                      ...tabPaneVNode.props,
                      internalCreatedByPane: true,
                      internalLeftPadded: index !== 0 && (!mergedJustifyContent || mergedJustifyContent === "center" || mergedJustifyContent === "start" || mergedJustifyContent === "end")
                    }, tabPaneVNode.children ? {
                      default: tabPaneVNode.children.tab
                    } : void 0)
                  );
                }
              ) : tabChildren.map(
                (tabVNode, index) => {
                  renderNameListRef.value.push(
                    tabVNode.props.name
                  );
                  if (index !== 0 && !mergedJustifyContent) {
                    return justifyTabDynamicProps(
                      createLeftPaddedTabVNode(tabVNode)
                    );
                  } else {
                    return justifyTabDynamicProps(tabVNode);
                  }
                }
              ), !addTabFixed && addable && isCard ? createAddTag(
                addable,
                (showPane ? tabPaneChildren.length : tabChildren.length) !== 0
              ) : null, mergedJustifyContent ? null : /* @__PURE__ */ React.createElement("div", {
                class: `${mergedClsPrefix}-tabs-scroll-padding`,
                style: { width: `${this.tabsPadding}px` }
              }));
              let wrappedTabs = rawWrappedTabs;
              if (isCard && addable) {
                wrappedTabs = /* @__PURE__ */ React.createElement(VResizeObserver, {
                  onResize: this.handleTabsResize
                }, {
                  default: () => rawWrappedTabs
                });
              }
              return /* @__PURE__ */ React.createElement("div", {
                ref: "tabsElRef",
                class: `${mergedClsPrefix}-tabs-nav-scroll-content`
              }, wrappedTabs, isCard ? /* @__PURE__ */ React.createElement("div", {
                class: `${mergedClsPrefix}-tabs-pad`
              }) : null, isCard ? null : /* @__PURE__ */ React.createElement("div", {
                ref: "barElRef",
                class: `${mergedClsPrefix}-tabs-bar`
              }));
            }
          }))
        }), addTabFixed && addable && isCard ? createAddTag(addable, true) : null, resolveWrappedSlot(
          suffixSlot,
          (children) => children && /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-tabs-nav__suffix`
          }, children)
        )), showPane && (this.animated ? /* @__PURE__ */ React.createElement("div", {
          ref: "tabsPaneWrapperRef",
          class: `${mergedClsPrefix}-tabs-pane-wrapper`
        }, filterMapTabPanes(
          tabPaneChildren,
          this.mergedValue,
          this.renderedNames,
          this.onAnimationBeforeLeave,
          this.onAnimationEnter,
          this.onAnimationAfterEnter,
          this.animationDirection
        )) : filterMapTabPanes(
          tabPaneChildren,
          this.mergedValue,
          this.renderedNames
        )));
      }
    });
    function filterMapTabPanes(tabPaneVNodes, value, renderedNames, onBeforeLeave, onEnter, onAfterEnter, animationDirection) {
      const children = [];
      tabPaneVNodes.forEach((vNode) => {
        const {
          name,
          displayDirective,
          "display-directive": _displayDirective
        } = vNode.props;
        const matchDisplayDirective = (directive) => displayDirective === directive || _displayDirective === directive;
        const show = value === name;
        if (vNode.key !== void 0) {
          vNode.key = name;
        }
        if (show || matchDisplayDirective("show") || matchDisplayDirective("show:lazy") && renderedNames.has(name)) {
          if (!renderedNames.has(name)) {
            renderedNames.add(name);
          }
          const useVShow = !matchDisplayDirective("if");
          children.push(useVShow ? vue.withDirectives(vNode, [[vue.vShow, show]]) : vNode);
        }
      });
      if (!animationDirection) {
        return children;
      }
      return /* @__PURE__ */ React.createElement(vue.TransitionGroup, {
        name: `${animationDirection}-transition`,
        onBeforeLeave,
        onEnter,
        onAfterEnter
      }, { default: () => children });
    }
    function createAddTag(addable, internalLeftPadded) {
      return /* @__PURE__ */ React.createElement(Tab, {
        ref: "addTabInstRef",
        key: "__addable",
        name: "__addable",
        internalCreatedByPane: true,
        internalAddable: true,
        internalLeftPadded,
        disabled: typeof addable === "object" && addable.disabled
      });
    }
    function createLeftPaddedTabVNode(tabVNode) {
      const modifiedVNode = vue.cloneVNode(tabVNode);
      if (modifiedVNode.props) {
        modifiedVNode.props.internalLeftPadded = true;
      } else {
        modifiedVNode.props = {
          internalLeftPadded: true
        };
      }
      return modifiedVNode;
    }
    function justifyTabDynamicProps(tabVNode) {
      if (Array.isArray(tabVNode.dynamicProps)) {
        if (!tabVNode.dynamicProps.includes("internalLeftPadded")) {
          tabVNode.dynamicProps.push("internalLeftPadded");
        }
      } else {
        tabVNode.dynamicProps = ["internalLeftPadded"];
      }
      return tabVNode;
    }

    var style$d = cB("thing", `
  display: flex;
  transition: color .3s var(--n-bezier);
  font-size: var(--n-font-size);
  color: var(--n-text-color);
`, [cB("thing-avatar", `
    margin-right: 12px;
    margin-top: 2px;
  `), cB("thing-avatar-header-wrapper", `
    display: flex;
    flex-wrap: nowrap;
  `, [cB("thing-header-wrapper", `
      flex: 1;
    `)]), cB("thing-main", `
    flex-grow: 1;
  `, [cB("thing-header", `
      display: flex;
      margin-bottom: 4px;
      justify-content: space-between;
      align-items: center;
    `, [cE("title", `
        font-size: 16px;
        font-weight: var(--n-title-font-weight);
        transition: color .3s var(--n-bezier);
        color: var(--n-title-text-color);
      `)]), cE("description", [c$1("&:not(:last-child)", `
        margin-bottom: 4px;
      `)]), cE("content", [c$1("&:not(:first-child)", `
        margin-top: 12px;
      `)]), cE("footer", [c$1("&:not(:first-child)", `
        margin-top: 12px;
      `)]), cE("action", [c$1("&:not(:first-child)", `
        margin-top: 12px;
      `)])])]);

    const thingProps = {
      ...useTheme.props,
      title: String,
      titleExtra: String,
      description: String,
      descriptionStyle: [String, Object],
      content: String,
      contentStyle: [String, Object],
      contentIndented: Boolean
    };
    var Thing = vue.defineComponent({
      name: "Thing",
      props: thingProps,
      setup(props, { slots }) {
        const { mergedClsPrefixRef, inlineThemeDisabled, mergedRtlRef } = useConfig(props);
        const themeRef = useTheme(
          "Thing",
          "-thing",
          style$d,
          thingLight$1,
          props,
          mergedClsPrefixRef
        );
        const rtlEnabledRef = useRtl("Thing", mergedRtlRef, mergedClsPrefixRef);
        const cssVarsRef = vue.computed(() => {
          const {
            self: { titleTextColor, textColor, titleFontWeight, fontSize },
            common: { cubicBezierEaseInOut }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-font-size": fontSize,
            "--n-text-color": textColor,
            "--n-title-font-weight": titleFontWeight,
            "--n-title-text-color": titleTextColor
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("thing", void 0, cssVarsRef, props) : void 0;
        return () => {
          const { value: mergedClsPrefix } = mergedClsPrefixRef;
          const rtlEnabled = rtlEnabledRef ? rtlEnabledRef.value : false;
          themeClassHandle?.onRender?.();
          return /* @__PURE__ */ React.createElement("div", {
            class: [
              `${mergedClsPrefix}-thing`,
              themeClassHandle?.themeClass,
              rtlEnabled && `${mergedClsPrefix}-thing--rtl`
            ],
            style: inlineThemeDisabled ? void 0 : cssVarsRef.value
          }, slots.avatar && props.contentIndented ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-thing-avatar`
          }, slots.avatar()) : null, /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-thing-main`
          }, !props.contentIndented && (slots.header || props.title || slots["header-extra"] || props.titleExtra || slots.avatar) ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-thing-avatar-header-wrapper`
          }, slots.avatar ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-thing-avatar`
          }, slots.avatar()) : null, slots.header || props.title || slots["header-extra"] || props.titleExtra ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-thing-header-wrapper`
          }, /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-thing-header`
          }, slots.header || props.title ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-thing-header__title`
          }, slots.header ? slots.header() : props.title) : null, slots["header-extra"] || props.titleExtra ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-thing-header__extra`
          }, slots["header-extra"] ? slots["header-extra"]() : props.titleExtra) : null), slots.description || props.description ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-thing-main__description`,
            style: props.descriptionStyle
          }, slots.description ? slots.description() : props.description) : null) : null) : /* @__PURE__ */ React.createElement(React.Fragment, null, slots.header || props.title || slots["header-extra"] || props.titleExtra ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-thing-header`
          }, slots.header || props.title ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-thing-header__title`
          }, slots.header ? slots.header() : props.title) : null, slots["header-extra"] || props.titleExtra ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-thing-header__extra`
          }, slots["header-extra"] ? slots["header-extra"]() : props.titleExtra) : null) : null, slots.description || props.description ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-thing-main__description`,
            style: props.descriptionStyle
          }, slots.description ? slots.description() : props.description) : null), slots.default || props.content ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-thing-main__content`,
            style: props.contentStyle
          }, slots.default ? slots.default() : props.content) : null, slots.footer ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-thing-main__footer`
          }, slots.footer()) : null, slots.action ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-thing-main__action`
          }, slots.action()) : null));
        };
      }
    });

    const timeProps = {
      time: {
        type: [Number, Date],
        default: void 0
      },
      type: {
        type: String,
        default: "datetime"
      },
      to: {
        type: [Number, Date],
        default: void 0
      },
      unix: Boolean,
      format: String,
      text: Boolean,
      timeZone: String
    };
    var Time = vue.defineComponent({
      name: "Time",
      props: timeProps,

      setup(props) {
        const now = Date.now();
        const {
          localeRef,
          dateLocaleRef
        } = useLocale("Time");
        const mergedFormatRef = vue.computed(() => {
          const {
            timeZone
          } = props;

          if (timeZone) {
            return (time, _format, options) => {
              return formatInTimeZone(time, timeZone, _format, options);
            };
          }

          return format$4;
        });
        const dateFnsOptionsRef = vue.computed(() => {
          return {
            locale: dateLocaleRef.value.locale
          };
        });
        const mergedTimeRef = vue.computed(() => {
          const {
            time
          } = props;

          if (props.unix) {
            if (time === void 0) return now;
            return fromUnixTime(typeof time === "number" ? time : time.valueOf());
          }

          return time ?? now;
        });
        const mergedToRef = vue.computed(() => {
          const {
            to
          } = props;

          if (props.unix) {
            if (to === void 0) return now;
            return fromUnixTime(typeof to === "number" ? to : to.valueOf());
          }

          return to ?? now;
        });
        const renderedTimeRef = vue.computed(() => {
          if (props.format) {
            return mergedFormatRef.value(mergedTimeRef.value, props.format, dateFnsOptionsRef.value);
          } else if (props.type === "date") {
            return mergedFormatRef.value(mergedTimeRef.value, localeRef.value.dateFormat, dateFnsOptionsRef.value);
          } else if (props.type === "datetime") {
            return mergedFormatRef.value(mergedTimeRef.value, localeRef.value.dateTimeFormat, dateFnsOptionsRef.value);
          } else {
            return formatDistanceStrict(mergedTimeRef.value, mergedToRef.value, {
              addSuffix: true,
              locale: dateLocaleRef.value.locale
            });
          }
        });
        return {
          renderedTime: renderedTimeRef
        };
      },

      render() {
        return this.text ? vue.createTextVNode(this.renderedTime) : vue.h("time", [this.renderedTime]);
      }

    });

    const lineHeight = 1.25;
    var style$c = cB("timeline", `
  position: relative;
  width: 100%;
  display: flex;
  flex-direction: column;
  line-height: ${lineHeight};
`, [cM("horizontal", `
    flex-direction: row;
  `, [c$1(">", [cB("timeline-item", `
        flex-shrink: 0;
        padding-right: 40px;
      `, [c$1(">", [cB("timeline-item-content", `
          margin-top: calc(var(--n-icon-size) + 12px);
          `, [cE("meta", `
              margin-top: 6px;
              margin-bottom: unset;
            `)]), cB("timeline-item-timeline", `
            width: 100%;
            height: calc(var(--n-icon-size) + 12px);
          `, [cE("line", `
              left: var(--n-icon-size);
              top: calc(var(--n-icon-size) / 2 - 1px);
              right: 0px;
              width: unset;
              height: 2px;
            `)])])])])]), cM("right-placement", [cB("timeline-item", [cB("timeline-item-content", `
        text-align: right;
        margin-right: calc(var(--n-icon-size) + 12px);
      `), cB("timeline-item-timeline", `
        width: var(--n-icon-size);
        right: 0;
      `)])]), cM("left-placement", [cB("timeline-item", [cB("timeline-item-content", `
        margin-left: calc(var(--n-icon-size) + 12px);
      `), cB("timeline-item-timeline", `
        left: 0;
      `)])]), cB("timeline-item", `
    position: relative;
  `, [c$1("&:last-child", [cB("timeline-item-timeline", [cE("line", `
          display: none;
        `)]), cB("timeline-item-content", [cE("meta", `
          margin-bottom: 0;
        `)])]), cB("timeline-item-content", [cE("title", `
        margin: var(--n-title-margin);
        font-size: var(--n-title-font-size);
        transition: color .3s var(--n-bezier);
        font-weight: var(--n-title-font-weight);
        margin-bottom: 6px;
        color: var(--n-title-text-color);
      `), cE("content", `
        transition: color .3s var(--n-bezier);
        font-size: var(--n-content-font-size);
        color: var(--n-content-text-color);
      `), cE("meta", `
        transition: color .3s var(--n-bezier);
        font-size: 12px;
        margin-top: 6px;
        margin-bottom: 20px;
        color: var(--n-meta-text-color);
      `)]), cM("dashed-line-type", [cB("timeline-item-timeline", [cE("line", `
          --n-color-start: var(--n-line-color);
          transition: --n-color-start .3s var(--n-bezier);
          background-color: transparent;
          background-image: linear-gradient(180deg, var(--n-color-start), var(--n-color-start) 50%, transparent 50%, transparent 100%);
          background-size: 1px 10px;
        `)])]), cB("timeline-item-timeline", `
      width: calc(var(--n-icon-size) + 12px);
      position: absolute;
      top: calc(var(--n-title-font-size) * ${lineHeight} / 2 - var(--n-icon-size) / 2);
      height: 100%;
    `, [cE("circle", `
        border: var(--n-circle-border);
        transition:
          background-color .3s var(--n-bezier),
          border-color .3s var(--n-bezier);
        width: var(--n-icon-size);
        height: var(--n-icon-size);
        border-radius: var(--n-icon-size);
        box-sizing: border-box;
      `), cE("icon", `
        color: var(--n-icon-color);
        font-size: var(--n-icon-size);
        height: var(--n-icon-size);
        width: var(--n-icon-size);
        display: flex;
        align-items: center;
        justify-content: center;
      `), cE("line", `
        transition: background-color .3s var(--n-bezier);
        position: absolute;
        top: var(--n-icon-size);
        left: calc(var(--n-icon-size) / 2 - 1px);
        bottom: 0px;
        width: 2px;
        background-color: var(--n-line-color);
      `)])])]);

    const timelineProps = {
      ...useTheme.props,
      horizontal: Boolean,
      itemPlacement: {
        type: String,
        default: "left"
      },
      size: {
        type: String,
        default: "medium"
      },
      iconSize: Number
    };
    const timelineInjectionKey = createInjectionKey("n-timeline");
    var Timeline = vue.defineComponent({
      name: "Timeline",
      props: timelineProps,
      setup(props, { slots }) {
        const { mergedClsPrefixRef } = useConfig(props);
        const themeRef = useTheme(
          "Timeline",
          "-timeline",
          style$c,
          timelineLight$1,
          props,
          mergedClsPrefixRef
        );
        vue.provide(timelineInjectionKey, {
          props,
          mergedThemeRef: themeRef,
          mergedClsPrefixRef
        });
        return () => {
          const { value: mergedClsPrefix } = mergedClsPrefixRef;
          return /* @__PURE__ */ React.createElement("div", {
            class: [
              `${mergedClsPrefix}-timeline`,
              props.horizontal && `${mergedClsPrefix}-timeline--horizontal`,
              `${mergedClsPrefix}-timeline--${props.size}-size`,
              !props.horizontal && `${mergedClsPrefix}-timeline--${props.itemPlacement}-placement`
            ]
          }, slots);
        };
      }
    });

    const timelineItemProps = {
      time: [String, Number],
      title: String,
      content: String,
      color: String,
      lineType: {
        type: String,
        default: "default"
      },
      type: {
        type: String,
        default: "default"
      }
    };
    var TimelineItem = vue.defineComponent({
      name: "TimelineItem",
      props: timelineItemProps,
      setup(props) {
        const NTimeline = vue.inject(timelineInjectionKey);
        if (!NTimeline) {
          throwError(
            "timeline-item",
            "`n-timeline-item` must be placed inside `n-timeline`."
          );
        }
        useHoudini();
        const { inlineThemeDisabled } = useConfig();
        const cssVarsRef = vue.computed(() => {
          const {
            props: { size, iconSize: iconSizeProp },
            mergedThemeRef
          } = NTimeline;
          const { type } = props;
          const {
            self: {
              titleTextColor,
              contentTextColor,
              metaTextColor,
              lineColor,
              titleFontWeight,
              contentFontSize,
              [createKey("iconSize", size)]: iconSize,
              [createKey("titleMargin", size)]: titleMargin,
              [createKey("titleFontSize", size)]: titleFontSize,
              [createKey("circleBorder", type)]: circleBorder,
              [createKey("iconColor", type)]: iconColor
            },
            common: { cubicBezierEaseInOut }
          } = mergedThemeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-circle-border": circleBorder,
            "--n-icon-color": iconColor,
            "--n-content-font-size": contentFontSize,
            "--n-content-text-color": contentTextColor,
            "--n-line-color": lineColor,
            "--n-meta-text-color": metaTextColor,
            "--n-title-font-size": titleFontSize,
            "--n-title-font-weight": titleFontWeight,
            "--n-title-margin": titleMargin,
            "--n-title-text-color": titleTextColor,
            "--n-icon-size": formatLength(iconSizeProp) || iconSize
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "timeline-item",
          vue.computed(() => {
            const {
              props: { size, iconSize: iconSizeProp }
            } = NTimeline;
            const { type } = props;
            return `${size[0]}${iconSizeProp || "a"}${type[0]}`;
          }),
          cssVarsRef,
          NTimeline.props
        ) : void 0;
        return {
          mergedClsPrefix: NTimeline.mergedClsPrefixRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedClsPrefix, color, onRender, $slots } = this;
        onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-timeline-item`,
            this.themeClass,
            `${mergedClsPrefix}-timeline-item--${this.type}-type`,
            `${mergedClsPrefix}-timeline-item--${this.lineType}-line-type`
          ],
          style: this.cssVars
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-timeline-item-timeline`
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-timeline-item-timeline__line`
        }), resolveWrappedSlot($slots.icon, (children) => {
          return children ? /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-timeline-item-timeline__icon`,
            style: { color }
          }, children) : /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-timeline-item-timeline__circle`,
            style: { borderColor: color }
          });
        })), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-timeline-item-content`
        }, resolveWrappedSlot($slots.header, (children) => {
          const mergedChildren = children || this.title;
          if (mergedChildren) {
            return /* @__PURE__ */ React.createElement("div", {
              class: `${mergedClsPrefix}-timeline-item-content__title`
            }, children || this.title);
          }
          return null;
        }), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-timeline-item-content__content`
        }, resolveSlot($slots.default, () => [this.content])), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-timeline-item-content__meta`
        }, resolveSlot($slots.footer, () => [this.time]))));
      }
    });

    const transferInjectionKey = createInjectionKey("n-transfer");

    var NTransferHeader = vue.defineComponent({
      name: "TransferHeader",
      props: {
        size: {
          type: String,
          required: true
        },
        source: Boolean,
        onCheckedAll: Function,
        onClearAll: Function,
        title: String
      },
      setup(props) {
        const {
          targetOptionsRef,
          canNotSelectAnythingRef,
          canBeClearedRef,
          allCheckedRef,
          mergedThemeRef,
          disabledRef,
          mergedClsPrefixRef,
          srcOptionsLengthRef
        } = vue.inject(transferInjectionKey);
        const { localeRef } = useLocale("Transfer");
        return () => {
          const { source, onClearAll, onCheckedAll } = props;
          const { value: mergedTheme } = mergedThemeRef;
          const { value: mergedClsPrefix } = mergedClsPrefixRef;
          const { value: locale } = localeRef;
          const buttonSize = props.size === "large" ? "small" : "tiny";
          const { title } = props;
          return /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-transfer-list-header`
          }, title && /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-transfer-list-header__title`
          }, title), source && /* @__PURE__ */ React.createElement(NButton, {
            class: `${mergedClsPrefix}-transfer-list-header__button`,
            theme: mergedTheme.peers.Button,
            themeOverrides: mergedTheme.peerOverrides.Button,
            size: buttonSize,
            tertiary: true,
            onClick: allCheckedRef.value ? onClearAll : onCheckedAll,
            disabled: canNotSelectAnythingRef.value || disabledRef.value
          }, {
            default: () => allCheckedRef.value ? locale.unselectAll : locale.selectAll
          }), !source && canBeClearedRef.value && /* @__PURE__ */ React.createElement(NButton, {
            class: `${mergedClsPrefix}-transfer-list-header__button`,
            theme: mergedTheme.peers.Button,
            themeOverrides: mergedTheme.peerOverrides.Button,
            size: buttonSize,
            tertiary: true,
            onClick: onClearAll,
            disabled: disabledRef.value
          }, {
            default: () => locale.clearAll
          }), /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-transfer-list-header__extra`
          }, source ? locale.total(srcOptionsLengthRef.value) : locale.selected(targetOptionsRef.value.length)));
        };
      }
    });

    var NTransferListItem = vue.defineComponent({
      name: "NTransferListItem",
      props: {
        source: Boolean,
        label: {
          type: String,
          required: true
        },
        value: {
          type: [String, Number],
          required: true
        },
        disabled: Boolean,
        option: {
          type: Object,
          required: true
        }
      },
      setup(props) {
        const {
          targetValueSetRef,
          mergedClsPrefixRef,
          mergedThemeRef,
          handleItemCheck,
          renderSourceLabelRef,
          renderTargetLabelRef
        } = vue.inject(transferInjectionKey);
        const checkedRef = useMemo(() => targetValueSetRef.value.has(props.value));
        function handleClick() {
          if (!props.disabled) {
            handleItemCheck(!checkedRef.value, props.value);
          }
        }
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          mergedTheme: mergedThemeRef,
          checked: checkedRef,
          handleClick,
          renderSourceLabel: renderSourceLabelRef,
          renderTargetLabel: renderTargetLabelRef
        };
      },
      render() {
        const {
          disabled,
          mergedTheme,
          mergedClsPrefix,
          label,
          checked,
          source,
          renderSourceLabel,
          renderTargetLabel
        } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-transfer-list-item`,
            disabled && `${mergedClsPrefix}-transfer-list-item--disabled`,
            source ? `${mergedClsPrefix}-transfer-list-item--source` : `${mergedClsPrefix}-transfer-list-item--target`
          ],
          onClick: source ? this.handleClick : void 0
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-transfer-list-item__background`
        }), source && /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-transfer-list-item__checkbox`
        }, /* @__PURE__ */ React.createElement(NCheckbox, {
          theme: mergedTheme.peers.Checkbox,
          themeOverrides: mergedTheme.peerOverrides.Checkbox,
          disabled,
          checked
        })), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-transfer-list-item__label`,
          title: getTitleAttribute(label)
        }, source ? renderSourceLabel ? renderSourceLabel({
          option: this.option
        }) : label : renderTargetLabel ? renderTargetLabel({
          option: this.option
        }) : label), !source && !disabled && /* @__PURE__ */ React.createElement(NBaseClose, {
          focusable: false,
          class: `${mergedClsPrefix}-transfer-list-item__close`,
          clsPrefix: mergedClsPrefix,
          onClick: this.handleClick
        }));
      }
    });

    var NTransferList = vue.defineComponent({
      name: "TransferList",
      props: {
        virtualScroll: {
          type: Boolean,
          required: true
        },
        itemSize: {
          type: Number,
          required: true
        },
        options: {
          type: Array,
          required: true
        },
        disabled: {
          type: Boolean,
          required: true
        },
        source: Boolean
      },
      setup() {
        const { mergedThemeRef, mergedClsPrefixRef } = vue.inject(transferInjectionKey);
        const scrollerInstRef = vue.ref(null);
        const vlInstRef = vue.ref(null);
        function syncVLScroller() {
          scrollerInstRef.value?.sync();
        }
        function scrollContainer() {
          const { value } = vlInstRef;
          if (!value)
            return null;
          const { listElRef } = value;
          return listElRef;
        }
        function scrollContent() {
          const { value } = vlInstRef;
          if (!value)
            return null;
          const { itemsElRef } = value;
          return itemsElRef;
        }
        return {
          mergedTheme: mergedThemeRef,
          mergedClsPrefix: mergedClsPrefixRef,
          scrollerInstRef,
          vlInstRef,
          syncVLScroller,
          scrollContainer,
          scrollContent
        };
      },
      render() {
        const { mergedTheme, options } = this;
        if (options.length === 0) {
          return /* @__PURE__ */ React.createElement(NEmpty, {
            theme: mergedTheme.peers.Empty,
            themeOverrides: mergedTheme.peerOverrides.Empty
          });
        }
        const { mergedClsPrefix, virtualScroll, source, disabled, syncVLScroller } = this;
        return /* @__PURE__ */ React.createElement(NScrollbar, {
          ref: "scrollerInstRef",
          theme: mergedTheme.peers.Scrollbar,
          themeOverrides: mergedTheme.peerOverrides.Scrollbar,
          container: virtualScroll ? this.scrollContainer : void 0,
          content: virtualScroll ? this.scrollContent : void 0
        }, {
          default: () => virtualScroll ? /* @__PURE__ */ React.createElement(VVirtualList, {
            ref: "vlInstRef",
            style: { height: "100%" },
            class: `${mergedClsPrefix}-transfer-list-content`,
            items: this.options,
            itemSize: this.itemSize,
            showScrollbar: false,
            onResize: syncVLScroller,
            onScroll: syncVLScroller,
            keyField: "value"
          }, {
            default: ({ item }) => {
              const { source: source2, disabled: disabled2 } = this;
              return /* @__PURE__ */ React.createElement(NTransferListItem, {
                source: source2,
                key: item.value,
                value: item.value,
                disabled: item.disabled || disabled2,
                label: item.label,
                option: item
              });
            }
          }) : /* @__PURE__ */ React.createElement("div", {
            class: `${mergedClsPrefix}-transfer-list-content`
          }, options.map((option) => /* @__PURE__ */ React.createElement(NTransferListItem, {
            source,
            key: option.value,
            value: option.value,
            disabled: option.disabled || disabled,
            label: option.label,
            option
          })))
        });
      }
    });

    var NTransferFilter = vue.defineComponent({
      name: "TransferFilter",
      props: {
        value: String,
        placeholder: String,
        disabled: Boolean,
        onUpdateValue: {
          type: Function,
          required: true
        }
      },
      setup() {
        const { mergedThemeRef, mergedClsPrefixRef } = vue.inject(transferInjectionKey);
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          mergedTheme: mergedThemeRef
        };
      },
      render() {
        const { mergedTheme, mergedClsPrefix } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-transfer-filter`
        }, /* @__PURE__ */ React.createElement(NInput, {
          value: this.value,
          onUpdateValue: this.onUpdateValue,
          disabled: this.disabled,
          placeholder: this.placeholder,
          theme: mergedTheme.peers.Input,
          themeOverrides: mergedTheme.peerOverrides.Input,
          clearable: true,
          size: "small"
        }, {
          "clear-icon-placeholder": () => /* @__PURE__ */ React.createElement(NBaseIcon, {
            clsPrefix: mergedClsPrefix
          }, { default: () => /* @__PURE__ */ React.createElement(SearchIcon, null) })
        }));
      }
    });

    function useTransferData(props) {
      const uncontrolledValueRef = vue.ref(props.defaultValue);
      const mergedValueRef = useMergedState(vue.toRef(props, "value"), uncontrolledValueRef);
      const optionsMapRef = vue.computed(() => {
        const map = /* @__PURE__ */new Map();
        (props.options || []).forEach(opt => map.set(opt.value, opt));
        return map;
      });
      const targetValueSetRef = vue.computed(() => new Set(mergedValueRef.value || []));
      const targetOptionsRef = vue.computed(() => {
        const optionMap = optionsMapRef.value;
        const targetOptions = [];
        (mergedValueRef.value || []).forEach(v => {
          const option = optionMap.get(v);

          if (option) {
            targetOptions.push(option);
          }
        });
        return targetOptions;
      });
      const srcPatternRef = vue.ref("");
      const tgtPatternRef = vue.ref("");
      const mergedSrcFilterableRef = vue.computed(() => {
        return props.sourceFilterable || !!props.filterable;
      });
      const filteredSrcOptionsRef = vue.computed(() => {
        if (!mergedSrcFilterableRef.value) return props.options;
        const {
          filter
        } = props;
        return props.options.filter(opt => filter(srcPatternRef.value, opt, "source"));
      });
      const filteredTgtOptionsRef = vue.computed(() => {
        if (!props.targetFilterable) return targetOptionsRef.value;
        const {
          filter
        } = props;
        return targetOptionsRef.value.filter(opt => filter(tgtPatternRef.value, opt, "target"));
      });
      const mergedValueSetRef = vue.computed(() => {
        const {
          value
        } = mergedValueRef;
        if (value === null) return /* @__PURE__ */new Set();
        return new Set(value);
      });
      const valueSetForCheckAllRef = vue.computed(() => {
        const values = new Set(mergedValueSetRef.value);
        filteredSrcOptionsRef.value.forEach(option => {
          if (!option.disabled && !values.has(option.value)) {
            values.add(option.value);
          }
        });
        return values;
      });
      const valueSetForUncheckAllRef = vue.computed(() => {
        const values = new Set(mergedValueSetRef.value);
        filteredSrcOptionsRef.value.forEach(option => {
          if (!option.disabled && values.has(option.value)) {
            values.delete(option.value);
          }
        });
        return values;
      });
      const valueSetForClearRef = vue.computed(() => {
        const values = new Set(mergedValueSetRef.value);
        filteredTgtOptionsRef.value.forEach(option => {
          if (!option.disabled) {
            values.delete(option.value);
          }
        });
        return values;
      });
      const canNotSelectAnythingRef = vue.computed(() => {
        return filteredSrcOptionsRef.value.every(option => option.disabled);
      });
      const allCheckedRef = vue.computed(() => {
        if (!filteredSrcOptionsRef.value.length) {
          return false;
        }

        const mergedValueSet = mergedValueSetRef.value;
        return filteredSrcOptionsRef.value.every(option => option.disabled || mergedValueSet.has(option.value));
      });
      const canBeClearedRef = vue.computed(() => {
        return filteredTgtOptionsRef.value.some(option => !option.disabled);
      });

      function handleSrcFilterUpdateValue(value) {
        srcPatternRef.value = value ?? "";
      }

      function handleTgtFilterUpdateValue(value) {
        tgtPatternRef.value = value ?? "";
      }

      return {
        uncontrolledValueRef,
        mergedValueRef,
        targetValueSetRef,
        valueSetForCheckAllRef,
        valueSetForUncheckAllRef,
        valueSetForClearRef,
        filteredTgtOptionsRef,
        filteredSrcOptionsRef,
        targetOptionsRef,
        canNotSelectAnythingRef,
        canBeClearedRef,
        allCheckedRef,
        srcPatternRef,
        tgtPatternRef,
        mergedSrcFilterableRef,
        handleSrcFilterUpdateValue,
        handleTgtFilterUpdateValue
      };
    }

    var style$b = cB("transfer", `
  width: 100%;
  font-size: var(--n-font-size);
  height: 300px;
  display: flex;
  flex-wrap: nowrap;
  word-break: break-word;
`, [cM("disabled", [cB("transfer-list", [cB("transfer-list-header", [cE("title", `
          color: var(--n-header-text-color-disabled);
        `), cE("extra", `
          color: var(--n-header-extra-text-color-disabled);
        `)])])]), cB("transfer-list", `
    flex: 1;
    min-width: 0;
    height: inherit;
    display: flex;
    flex-direction: column;
    background-clip: padding-box;
    position: relative;
    transition: background-color .3s var(--n-bezier);
    background-color: var(--n-list-color);
  `, [cM("source", `
      border-top-left-radius: var(--n-border-radius);
      border-bottom-left-radius: var(--n-border-radius);
    `, [cE("border", "border-right: 1px solid var(--n-divider-color);")]), cM("target", `
      border-top-right-radius: var(--n-border-radius);
      border-bottom-right-radius: var(--n-border-radius);
    `, [cE("border", "border-left: none;")]), cE("border", `
      padding: 0 12px;
      border: 1px solid var(--n-border-color);
      transition: border-color .3s var(--n-bezier);
      pointer-events: none;
      border-radius: inherit;
      position: absolute;
      left: 0;
      right: 0;
      top: 0;
      bottom: 0;
    `), cB("transfer-list-header", `
      min-height: var(--n-header-height);
      box-sizing: border-box;
      display: flex;
      padding: 12px 12px 10px 12px;
      align-items: center;
      background-clip: padding-box;
      border-radius: inherit;
      border-bottom-left-radius: 0;
      border-bottom-right-radius: 0;
      line-height: 1.5;
      transition:
        border-color .3s var(--n-bezier),
        background-color .3s var(--n-bezier);
    `, [c$1("> *:not(:first-child)", `
        margin-left: 8px;
      `), cE("title", `
        flex: 1;
        min-width: 0;
        line-height: 1.5;
        font-size: var(--n-header-font-size);
        font-weight: var(--n-header-font-weight);
        transition: color .3s var(--n-bezier);
        color: var(--n-header-text-color);
      `), cE("button", `
        position: relative;
      `), cE("extra", `
        transition: color .3s var(--n-bezier);
        font-size: var(--n-extra-font-size);
        margin-right: 0;
        white-space: nowrap;
        color: var(--n-header-extra-text-color);
      `)]), cB("transfer-list-body", `
      flex-basis: 0;
      flex-grow: 1;
      box-sizing: border-box;
      position: relative;
      display: flex;
      flex-direction: column;
      border-radius: inherit;
      border-top-left-radius: 0;
      border-top-right-radius: 0;
    `, [cB("transfer-filter", `
        padding: 4px 12px 8px 12px;
        box-sizing: border-box;
        transition:
          border-color .3s var(--n-bezier),
          background-color .3s var(--n-bezier);
      `), cB("transfer-list-flex-container", `
        flex: 1;
        position: relative;
      `, [cB("scrollbar", `
          position: absolute;
          left: 0;
          right: 0;
          top: 0;
          bottom: 0;
          height: unset;
        `), cB("empty", `
          position: absolute;
          left: 50%;
          top: 50%;
          transform: translateY(-50%) translateX(-50%);
        `), cB("transfer-list-content", `
          padding: 0;
          margin: 0;
          position: relative;
        `, [cB("transfer-list-item", `
            padding: 0 12px;
            min-height: var(--n-item-height);
            display: flex;
            align-items: center;
            color: var(--n-item-text-color);
            position: relative;
            transition: color .3s var(--n-bezier);
          `, [cE("background", `
              position: absolute;
              left: 4px;
              right: 4px;
              top: 0;
              bottom: 0;
              border-radius: var(--n-border-radius);
              transition: background-color .3s var(--n-bezier);
            `), cE("checkbox", `
              position: relative;
              margin-right: 8px;
            `), cE("close", `
              opacity: 0;
              pointer-events: none;
              position: relative;
              transition:
                opacity .3s var(--n-bezier),
                background-color .3s var(--n-bezier),
                color .3s var(--n-bezier);
            `), cE("label", `
              position: relative;
              min-width: 0;
              flex-grow: 1;
            `), cM("source", "cursor: pointer;"), cM("disabled", `
              cursor: not-allowed;
              color: var(--n-item-text-color-disabled);
            `), cNotM("disabled", [c$1("&:hover", [cE("background", "background-color: var(--n-item-color-pending);"), cE("close", `
                  opacity: 1;
                  pointer-events: all;
                `)])])])])])])])]);

    const transferProps = {
      ...useTheme.props,
      value: Array,
      defaultValue: {
        type: Array,
        default: null
      },
      options: {
        type: Array,
        default: () => []
      },
      disabled: {
        type: Boolean,
        default: void 0
      },
      virtualScroll: Boolean,
      sourceTitle: String,
      targetTitle: String,
      filterable: {
        type: Boolean,
        default: void 0
      },
      sourceFilterable: Boolean,
      targetFilterable: Boolean,
      sourceFilterPlaceholder: String,
      targetFilterPlaceholder: String,
      filter: {
        type: Function,
        default: (pattern, option) => {
          if (!pattern)
            return true;
          return ~("" + option.label).toLowerCase().indexOf(("" + pattern).toLowerCase());
        }
      },
      size: String,
      renderSourceLabel: Function,
      renderTargetLabel: Function,
      renderSourceList: Function,
      "onUpdate:value": [Function, Array],
      onUpdateValue: [Function, Array],
      onChange: [Function, Array]
    };
    var Transfer = vue.defineComponent({
      name: "Transfer",
      props: transferProps,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.onChange !== void 0) {
              warnOnce(
                "transfer",
                "`on-change` is deprecated, please use `on-update:value` instead."
              );
            }
            if (props.filterable !== void 0) {
              warnOnce(
                "transfer",
                "`filterable` is deprecated, please use `source-filterable` or `target-filterable` instead."
              );
            }
          });
        }
        const { mergedClsPrefixRef } = useConfig(props);
        const themeRef = useTheme(
          "Transfer",
          "-transfer",
          style$b,
          transferLight$2,
          props,
          mergedClsPrefixRef
        );
        const formItem = useFormItem(props);
        const { mergedSizeRef, mergedDisabledRef } = formItem;
        const itemSizeRef = vue.computed(() => {
          const { value: size } = mergedSizeRef;
          const {
            self: { [createKey("itemHeight", size)]: itemSize }
          } = themeRef.value;
          return depx(itemSize);
        });
        const {
          uncontrolledValueRef,
          mergedValueRef,
          targetValueSetRef,
          valueSetForCheckAllRef,
          valueSetForUncheckAllRef,
          valueSetForClearRef,
          filteredTgtOptionsRef,
          filteredSrcOptionsRef,
          targetOptionsRef,
          canNotSelectAnythingRef,
          canBeClearedRef,
          allCheckedRef,
          srcPatternRef,
          tgtPatternRef,
          mergedSrcFilterableRef,
          handleSrcFilterUpdateValue,
          handleTgtFilterUpdateValue
        } = useTransferData(props);
        function doUpdateValue(value) {
          const {
            onUpdateValue,
            "onUpdate:value": _onUpdateValue,
            onChange
          } = props;
          const { nTriggerFormInput, nTriggerFormChange } = formItem;
          if (onUpdateValue)
            call(onUpdateValue, value);
          if (_onUpdateValue)
            call(_onUpdateValue, value);
          if (onChange)
            call(onChange, value);
          uncontrolledValueRef.value = value;
          nTriggerFormInput();
          nTriggerFormChange();
        }
        function handleSourceCheckAll() {
          doUpdateValue([...valueSetForCheckAllRef.value]);
        }
        function handleSourceUncheckAll() {
          doUpdateValue([...valueSetForUncheckAllRef.value]);
        }
        function handleTargetClearAll() {
          doUpdateValue([...valueSetForClearRef.value]);
        }
        function handleItemCheck(checked, optionValue) {
          if (checked) {
            doUpdateValue((mergedValueRef.value || []).concat(optionValue));
          } else {
            doUpdateValue(
              (mergedValueRef.value || []).filter((v) => v !== optionValue)
            );
          }
        }
        function handleChecked(optionValueList) {
          doUpdateValue(optionValueList);
        }
        vue.provide(transferInjectionKey, {
          targetValueSetRef,
          mergedClsPrefixRef,
          disabledRef: mergedDisabledRef,
          mergedThemeRef: themeRef,
          targetOptionsRef,
          canNotSelectAnythingRef,
          canBeClearedRef,
          allCheckedRef,
          srcOptionsLengthRef: vue.computed(() => props.options.length),
          handleItemCheck,
          renderSourceLabelRef: vue.toRef(props, "renderSourceLabel"),
          renderTargetLabelRef: vue.toRef(props, "renderTargetLabel")
        });
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          mergedDisabled: mergedDisabledRef,
          itemSize: itemSizeRef,
          isMounted: isMounted(),
          mergedTheme: themeRef,
          filteredSrcOpts: filteredSrcOptionsRef,
          filteredTgtOpts: filteredTgtOptionsRef,
          srcPattern: srcPatternRef,
          tgtPattern: tgtPatternRef,
          mergedSize: mergedSizeRef,
          mergedSrcFilterable: mergedSrcFilterableRef,
          handleSrcFilterUpdateValue,
          handleTgtFilterUpdateValue,
          handleSourceCheckAll,
          handleSourceUncheckAll,
          handleTargetClearAll,
          handleItemCheck,
          handleChecked,
          cssVars: vue.computed(() => {
            const { value: size } = mergedSizeRef;
            const {
              common: { cubicBezierEaseInOut },
              self: {
                borderRadius,
                borderColor,
                listColor,
                titleTextColor,
                titleTextColorDisabled,
                extraTextColor,
                itemTextColor,
                itemColorPending,
                itemTextColorDisabled,
                titleFontWeight,
                closeColorHover,
                closeColorPressed,
                closeIconColor,
                closeIconColorHover,
                closeIconColorPressed,
                closeIconSize,
                closeSize,
                dividerColor,
                extraTextColorDisabled,
                [createKey("extraFontSize", size)]: extraFontSize,
                [createKey("fontSize", size)]: fontSize,
                [createKey("titleFontSize", size)]: titleFontSize,
                [createKey("itemHeight", size)]: itemHeight,
                [createKey("headerHeight", size)]: headerHeight
              }
            } = themeRef.value;
            return {
              "--n-bezier": cubicBezierEaseInOut,
              "--n-border-color": borderColor,
              "--n-border-radius": borderRadius,
              "--n-extra-font-size": extraFontSize,
              "--n-font-size": fontSize,
              "--n-header-font-size": titleFontSize,
              "--n-header-extra-text-color": extraTextColor,
              "--n-header-extra-text-color-disabled": extraTextColorDisabled,
              "--n-header-font-weight": titleFontWeight,
              "--n-header-text-color": titleTextColor,
              "--n-header-text-color-disabled": titleTextColorDisabled,
              "--n-item-color-pending": itemColorPending,
              "--n-item-height": itemHeight,
              "--n-item-text-color": itemTextColor,
              "--n-item-text-color-disabled": itemTextColorDisabled,
              "--n-list-color": listColor,
              "--n-header-height": headerHeight,
              "--n-close-size": closeSize,
              "--n-close-icon-size": closeIconSize,
              "--n-close-color-hover": closeColorHover,
              "--n-close-color-pressed": closeColorPressed,
              "--n-close-icon-color": closeIconColor,
              "--n-close-icon-color-hover": closeIconColorHover,
              "--n-close-icon-color-pressed": closeIconColorPressed,
              "--n-divider-color": dividerColor
            };
          })
        };
      },
      render() {
        const {
          mergedClsPrefix,
          renderSourceList,
          mergedTheme,
          mergedSrcFilterable,
          targetFilterable
        } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-transfer`,
            this.mergedDisabled && `${mergedClsPrefix}-transfer--disabled`
          ],
          style: this.cssVars
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-transfer-list ${mergedClsPrefix}-transfer-list--source`
        }, /* @__PURE__ */ React.createElement(NTransferHeader, {
          source: true,
          title: this.sourceTitle,
          onCheckedAll: this.handleSourceCheckAll,
          onClearAll: this.handleSourceUncheckAll,
          size: this.mergedSize
        }), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-transfer-list-body`
        }, mergedSrcFilterable ? /* @__PURE__ */ React.createElement(NTransferFilter, {
          onUpdateValue: this.handleSrcFilterUpdateValue,
          value: this.srcPattern,
          disabled: this.mergedDisabled,
          placeholder: this.sourceFilterPlaceholder
        }) : null, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-transfer-list-flex-container`
        }, renderSourceList ? /* @__PURE__ */ React.createElement(NScrollbar, {
          theme: mergedTheme.peers.Scrollbar,
          themeOverrides: mergedTheme.peerOverrides.Scrollbar
        }, {
          default: () => renderSourceList({
            onCheck: this.handleChecked,
            checkedOptions: this.filteredTgtOpts,
            pattern: this.srcPattern
          })
        }) : /* @__PURE__ */ React.createElement(NTransferList, {
          source: true,
          options: this.filteredSrcOpts,
          disabled: this.mergedDisabled,
          virtualScroll: this.virtualScroll,
          itemSize: this.itemSize
        }))), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-transfer-list__border`
        })), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-transfer-list ${mergedClsPrefix}-transfer-list--target`
        }, /* @__PURE__ */ React.createElement(NTransferHeader, {
          onClearAll: this.handleTargetClearAll,
          size: this.mergedSize,
          title: this.targetTitle
        }), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-transfer-list-body`
        }, targetFilterable ? /* @__PURE__ */ React.createElement(NTransferFilter, {
          onUpdateValue: this.handleTgtFilterUpdateValue,
          value: this.tgtPattern,
          disabled: this.mergedDisabled,
          placeholder: this.sourceFilterPlaceholder
        }) : null, /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-transfer-list-flex-container`
        }, /* @__PURE__ */ React.createElement(NTransferList, {
          options: this.filteredTgtOpts,
          disabled: this.mergedDisabled,
          virtualScroll: this.virtualScroll,
          itemSize: this.itemSize
        }))), /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-transfer-list__border`
        })));
      }
    });

    const treeSelectInjectionKey = createInjectionKey("n-tree-select");

    const treeInjectionKey = createInjectionKey("n-tree");

    var NTreeNodeSwitcher = vue.defineComponent({
      name: "NTreeSwitcher",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        expanded: Boolean,
        hide: Boolean,
        loading: Boolean,
        onClick: Function
      },
      setup(props) {
        const { renderSwitcherIconRef } = vue.inject(treeInjectionKey, null);
        return () => {
          const { clsPrefix } = props;
          return /* @__PURE__ */ React.createElement("span", {
            "data-switcher": true,
            class: [
              `${clsPrefix}-tree-node-switcher`,
              {
                [`${clsPrefix}-tree-node-switcher--expanded`]: props.expanded,
                [`${clsPrefix}-tree-node-switcher--hide`]: props.hide
              }
            ],
            onClick: props.onClick
          }, /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-tree-node-switcher__icon`
          }, /* @__PURE__ */ React.createElement(NIconSwitchTransition, null, {
            default: () => {
              if (props.loading) {
                return /* @__PURE__ */ React.createElement(NBaseLoading, {
                  clsPrefix,
                  key: "loading",
                  radius: 85,
                  strokeWidth: 20
                });
              }
              const { value: renderSwitcherIcon } = renderSwitcherIconRef;
              return renderSwitcherIcon ? renderSwitcherIcon() : /* @__PURE__ */ React.createElement(NBaseIcon, {
                clsPrefix,
                key: "switcher"
              }, { default: () => /* @__PURE__ */ React.createElement(SwitcherIcon, null) });
            }
          })));
        };
      }
    });

    var NTreeNodeCheckbox = vue.defineComponent({
      name: "NTreeNodeCheckbox",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        right: Boolean,
        focusable: Boolean,
        disabled: Boolean,
        checked: Boolean,
        indeterminate: Boolean,
        onCheck: Function
      },
      setup(props) {
        const NTree = vue.inject(treeInjectionKey);
        function doCheck(value) {
          const { onCheck } = props;
          if (onCheck)
            return onCheck(value);
        }
        function handleUpdateValue(value) {
          if (props.indeterminate) {
            doCheck(false);
          } else {
            doCheck(value);
          }
        }
        return {
          handleUpdateValue,
          mergedTheme: NTree.mergedThemeRef
        };
      },
      render() {
        const {
          clsPrefix,
          mergedTheme,
          checked,
          indeterminate,
          disabled,
          focusable,
          handleUpdateValue
        } = this;
        return /* @__PURE__ */ React.createElement("span", {
          class: [
            `${clsPrefix}-tree-node-checkbox`,
            this.right && `${clsPrefix}-tree-node-checkbox--right`
          ],
          "data-checkbox": true
        }, /* @__PURE__ */ React.createElement(NCheckbox, {
          focusable,
          disabled,
          theme: mergedTheme.peers.Checkbox,
          themeOverrides: mergedTheme.peerOverrides.Checkbox,
          checked,
          indeterminate,
          onUpdateChecked: handleUpdateValue
        }));
      }
    });

    var NTreeNodeContent = vue.defineComponent({
      name: "TreeNodeContent",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        disabled: Boolean,
        checked: Boolean,
        selected: Boolean,
        onClick: Function,
        onDragstart: Function,
        tmNode: {
          type: Object,
          required: true
        },
        nodeProps: Object
      },
      setup(props) {
        const { renderLabelRef, renderPrefixRef, renderSuffixRef, labelFieldRef } = vue.inject(treeInjectionKey);
        const selfRef = vue.ref(null);
        function doClick(e) {
          const { onClick } = props;
          if (onClick)
            onClick(e);
        }
        function handleClick(e) {
          doClick(e);
        }
        return {
          selfRef,
          renderLabel: renderLabelRef,
          renderPrefix: renderPrefixRef,
          renderSuffix: renderSuffixRef,
          labelField: labelFieldRef,
          handleClick
        };
      },
      render() {
        const {
          clsPrefix,
          labelField,
          nodeProps,
          checked = false,
          selected = false,
          renderLabel,
          renderPrefix,
          renderSuffix,
          handleClick,
          onDragstart,
          tmNode: {
            rawNode,
            rawNode: { prefix, suffix, [labelField]: label }
          }
        } = this;
        return /* @__PURE__ */ React.createElement("span", {
          ...nodeProps,
          ref: "selfRef",
          class: [`${clsPrefix}-tree-node-content`, nodeProps?.class],
          onClick: handleClick,
          draggable: onDragstart === void 0 ? void 0 : true,
          onDragstart
        }, renderPrefix || prefix ? /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-tree-node-content__prefix`
        }, renderPrefix ? renderPrefix({
          option: rawNode,
          selected,
          checked
        }) : render$1(prefix)) : null, /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-tree-node-content__text`
        }, renderLabel ? renderLabel({
          option: rawNode,
          selected,
          checked
        }) : render$1(label)), renderSuffix || suffix ? /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-tree-node-content__suffix`
        }, renderSuffix ? renderSuffix({
          option: rawNode,
          selected,
          checked
        }) : render$1(suffix)) : null);
      }
    });

    function renderDropMark({
      position,
      offsetLevel,
      indent,
      el
    }) {
      const style = {
        position: "absolute",
        boxSizing: "border-box",
        right: 0
      };
      if (position === "inside") {
        style.left = 0;
        style.top = 0;
        style.bottom = 0;
        style.borderRadius = "inherit";
        style.boxShadow = "inset 0 0 0 2px var(--n-drop-mark-color)";
      } else {
        const cssPosition = position === "before" ? "top" : "bottom";
        style[cssPosition] = 0;
        style.left = `${el.offsetLeft + 6 - offsetLevel * indent}px`;
        style.height = "2px";
        style.backgroundColor = "var(--n-drop-mark-color)";
        style.transformOrigin = cssPosition;
        style.borderRadius = "1px";
        style.transform = position === "before" ? "translateY(-4px)" : "translateY(4px)";
      }
      return /* @__PURE__ */ React.createElement("div", {
        style
      });
    }
    function defaultAllowDrop({
      dropPosition,
      node
    }) {
      if (node.isLeaf === false)
        return true;
      if (node.children) {
        return true;
      }
      return dropPosition !== "inside";
    }

    const TreeNode = vue.defineComponent({
      name: "TreeNode",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        tmNode: {
          type: Object,
          required: true
        }
      },
      setup(props) {
        const NTree = vue.inject(treeInjectionKey);
        const {
          droppingNodeParentRef,
          droppingMouseNodeRef,
          draggingNodeRef,
          droppingPositionRef,
          droppingOffsetLevelRef,
          nodePropsRef,
          indentRef,
          blockLineRef,
          checkboxPlacementRef,
          checkOnClickRef
        } = NTree;
        const disabledRef = vue.computed(
          () => NTree.disabledRef.value || props.tmNode.disabled
        );
        const resolvedNodePropsRef = vue.computed(() => {
          const { value: nodeProps } = nodePropsRef;
          if (!nodeProps)
            return void 0;
          return nodeProps({ option: props.tmNode.rawNode });
        });
        const contentInstRef = vue.ref(null);
        const contentElRef = { value: null };
        vue.onMounted(() => {
          contentElRef.value = contentInstRef.value.$el;
        });
        function handleSwitcherClick() {
          const { tmNode } = props;
          if (!tmNode.isLeaf && !tmNode.shallowLoaded) {
            if (!NTree.loadingKeysRef.value.has(tmNode.key)) {
              NTree.loadingKeysRef.value.add(tmNode.key);
            } else {
              return;
            }
            const {
              onLoadRef: { value: onLoad }
            } = NTree;
            if (onLoad) {
              void onLoad(tmNode.rawNode).then(() => {
                NTree.handleSwitcherClick(tmNode);
              }).finally(() => {
                NTree.loadingKeysRef.value.delete(tmNode.key);
              });
            }
          } else {
            NTree.handleSwitcherClick(tmNode);
          }
        }
        const selectableRef = useMemo(
          () => !props.tmNode.disabled && NTree.selectableRef.value && (NTree.internalTreeSelect ? NTree.mergedCheckStrategyRef.value !== "child" || NTree.multipleRef.value && NTree.cascadeRef.value || props.tmNode.isLeaf : true)
        );
        const checkableRef = useMemo(
          () => NTree.checkableRef.value && (NTree.cascadeRef.value || NTree.mergedCheckStrategyRef.value !== "child" || props.tmNode.isLeaf)
        );
        const checkedRef = useMemo(
          () => NTree.displayedCheckedKeysRef.value.includes(props.tmNode.key)
        );
        const mergedCheckOnClickRef = useMemo(() => {
          const { value: checkable } = checkableRef;
          if (!checkable)
            return false;
          const { value: checkOnClick } = checkOnClickRef;
          if (typeof checkOnClick === "boolean") {
            return checkOnClick;
          }
          return checkOnClick(props.tmNode.rawNode);
        });
        function _handleClick(e) {
          const { value: expandOnClick } = NTree.expandOnClickRef;
          const { value: selectable } = selectableRef;
          const { value: mergedCheckOnClick } = mergedCheckOnClickRef;
          if (!selectable && !expandOnClick && !mergedCheckOnClick)
            return;
          if (happensIn(e, "checkbox") || happensIn(e, "switcher"))
            return;
          const { tmNode } = props;
          if (selectable) {
            NTree.handleSelect(tmNode);
          }
          if (expandOnClick && !tmNode.isLeaf) {
            handleSwitcherClick();
          }
          if (mergedCheckOnClick) {
            handleCheck(!checkedRef.value);
          }
        }
        function handleContentClick(e) {
          if (blockLineRef.value)
            return;
          if (!disabledRef.value)
            _handleClick(e);
          resolvedNodePropsRef.value?.onClick?.(e);
        }
        function handleLineClick(e) {
          if (!blockLineRef.value)
            return;
          if (!disabledRef.value) {
            _handleClick(e);
          }
          resolvedNodePropsRef.value?.onClick?.(e);
        }
        function handleCheck(checked) {
          NTree.handleCheck(props.tmNode, checked);
        }
        function handleDragStart(e) {
          NTree.handleDragStart({
            event: e,
            node: props.tmNode
          });
        }
        function handleDragEnter(e) {
          if (e.currentTarget !== e.target) {
            return;
          }
          NTree.handleDragEnter({
            event: e,
            node: props.tmNode
          });
        }
        function handleDragOver(e) {
          e.preventDefault();
          NTree.handleDragOver({
            event: e,
            node: props.tmNode
          });
        }
        function handleDragEnd(e) {
          NTree.handleDragEnd({
            event: e,
            node: props.tmNode
          });
        }
        function handleDragLeave(e) {
          if (e.currentTarget !== e.target) {
            return;
          }
          NTree.handleDragLeave({
            event: e,
            node: props.tmNode
          });
        }
        function handleDrop(e) {
          e.preventDefault();
          if (droppingPositionRef.value !== null) {
            NTree.handleDrop({
              event: e,
              node: props.tmNode,
              dropPosition: droppingPositionRef.value
            });
          }
        }
        return {
          showDropMark: useMemo(() => {
            const { value: draggingNode } = draggingNodeRef;
            if (!draggingNode)
              return;
            const { value: droppingPosition } = droppingPositionRef;
            if (!droppingPosition)
              return;
            const { value: droppingMouseNode } = droppingMouseNodeRef;
            if (!droppingMouseNode) {
              return;
            }
            const { tmNode } = props;
            if (tmNode.key === droppingMouseNode.key)
              return true;
            return false;
          }),
          showDropMarkAsParent: useMemo(() => {
            const { value: droppingNodeParent } = droppingNodeParentRef;
            if (!droppingNodeParent)
              return false;
            const { tmNode } = props;
            const { value: droppingPosition } = droppingPositionRef;
            if (droppingPosition === "before" || droppingPosition === "after") {
              return droppingNodeParent.key === tmNode.key;
            }
            return false;
          }),
          pending: useMemo(
            () => NTree.pendingNodeKeyRef.value === props.tmNode.key
          ),
          loading: useMemo(() => NTree.loadingKeysRef.value.has(props.tmNode.key)),
          highlight: useMemo(() => {
            return NTree.highlightKeySetRef.value?.has(props.tmNode.key);
          }),
          checked: checkedRef,
          indeterminate: useMemo(
            () => NTree.displayedIndeterminateKeysRef.value.includes(props.tmNode.key)
          ),
          selected: useMemo(
            () => NTree.mergedSelectedKeysRef.value.includes(props.tmNode.key)
          ),
          expanded: useMemo(
            () => NTree.mergedExpandedKeysRef.value.includes(props.tmNode.key)
          ),
          disabled: disabledRef,
          checkable: checkableRef,
          mergedCheckOnClick: mergedCheckOnClickRef,
          checkboxDisabled: vue.computed(() => !!props.tmNode.rawNode.checkboxDisabled),
          selectable: selectableRef,
          expandOnClick: NTree.expandOnClickRef,
          internalScrollable: NTree.internalScrollableRef,
          draggable: NTree.draggableRef,
          blockLine: blockLineRef,
          nodeProps: resolvedNodePropsRef,
          checkboxFocusable: NTree.internalCheckboxFocusableRef,
          droppingPosition: droppingPositionRef,
          droppingOffsetLevel: droppingOffsetLevelRef,
          indent: indentRef,
          checkboxPlacement: checkboxPlacementRef,
          contentInstRef,
          contentElRef,
          handleCheck,
          handleDrop,
          handleDragStart,
          handleDragEnter,
          handleDragOver,
          handleDragEnd,
          handleDragLeave,
          handleLineClick,
          handleContentClick,
          handleSwitcherClick
        };
      },
      render() {
        const {
          tmNode,
          clsPrefix,
          checkable,
          expandOnClick,
          selectable,
          selected,
          checked,
          highlight,
          draggable,
          blockLine,
          indent,
          disabled,
          pending,
          internalScrollable,
          nodeProps,
          checkboxPlacement
        } = this;
        const dragEventHandlers = draggable && !disabled ? {
          onDragenter: this.handleDragEnter,
          onDragleave: this.handleDragLeave,
          onDragend: this.handleDragEnd,
          onDrop: this.handleDrop,
          onDragover: this.handleDragOver
        } : void 0;
        const dataKey = internalScrollable ? createDataKey(tmNode.key) : void 0;
        const checkboxOnRight = checkboxPlacement === "right";
        const checkboxNode = checkable ? /* @__PURE__ */ React.createElement(NTreeNodeCheckbox, {
          right: checkboxOnRight,
          focusable: this.checkboxFocusable,
          disabled: disabled || this.checkboxDisabled,
          clsPrefix,
          checked: this.checked,
          indeterminate: this.indeterminate,
          onCheck: this.handleCheck
        }) : null;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-tree-node-wrapper`,
          ...dragEventHandlers
        }, /* @__PURE__ */ React.createElement("div", {
          ...blockLine ? nodeProps : void 0,
          class: [
            `${clsPrefix}-tree-node`,
            {
              [`${clsPrefix}-tree-node--selected`]: selected,
              [`${clsPrefix}-tree-node--checkable`]: checkable,
              [`${clsPrefix}-tree-node--highlight`]: highlight,
              [`${clsPrefix}-tree-node--pending`]: pending,
              [`${clsPrefix}-tree-node--disabled`]: disabled,
              [`${clsPrefix}-tree-node--selectable`]: selectable,
              [`${clsPrefix}-tree-node--clickable`]: selectable || expandOnClick || this.mergedCheckOnClick
            },
            nodeProps?.class
          ],
          "data-key": dataKey,
          draggable: draggable && blockLine,
          onClick: this.handleLineClick,
          onDragstart: draggable && blockLine && !disabled ? this.handleDragStart : void 0
        }, repeat(
          tmNode.level,
          /* @__PURE__ */ React.createElement("div", {
            class: `${clsPrefix}-tree-node-indent`
          }, /* @__PURE__ */ React.createElement("div", {
            style: { width: `${indent}px` }
          }))
        ), /* @__PURE__ */ React.createElement(NTreeNodeSwitcher, {
          clsPrefix,
          expanded: this.expanded,
          loading: this.loading,
          hide: tmNode.isLeaf,
          onClick: this.handleSwitcherClick
        }), !checkboxOnRight ? checkboxNode : null, /* @__PURE__ */ React.createElement(NTreeNodeContent, {
          ref: "contentInstRef",
          clsPrefix,
          checked,
          selected,
          onClick: this.handleContentClick,
          nodeProps: blockLine ? void 0 : nodeProps,
          onDragstart: draggable && !blockLine && !disabled ? this.handleDragStart : void 0,
          tmNode
        }), draggable ? this.showDropMark ? renderDropMark({
          el: this.contentElRef.value,
          position: this.droppingPosition,
          offsetLevel: this.droppingOffsetLevel,
          indent
        }) : this.showDropMarkAsParent ? renderDropMark({
          el: this.contentElRef.value,
          position: "inside",
          offsetLevel: this.droppingOffsetLevel,
          indent
        }) : null : null, checkboxOnRight ? checkboxNode : null));
      }
    });

    function traverse(nodes, childrenField, callback, callbackAfter) {
      nodes === null || nodes === void 0 ? void 0 : nodes.forEach(node => {
        callback(node);
        traverse(node[childrenField], childrenField, callback, callbackAfter);
        callbackAfter(node);
      });
    }

    function keysWithFilter(nodes, pattern, keyField, childrenField, filter) {
      const keys = /* @__PURE__ */new Set();
      const highlightKeySet = /* @__PURE__ */new Set();
      const path = [];
      traverse(nodes, childrenField, node => {
        path.push(node);

        if (filter(pattern, node)) {
          highlightKeySet.add(node[keyField]);

          for (let i = path.length - 2; i >= 0; --i) {
            if (!keys.has(path[i][keyField])) {
              keys.add(path[i][keyField]);
            } else {
              return;
            }
          }
        }
      }, () => {
        path.pop();
      });
      return {
        expandedKeys: Array.from(keys),
        highlightKeySet
      };
    }

    if (isBrowser$2 && Image) {
      const emptyImage2 = new Image();
      emptyImage2.src = "data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==";
    }
    function filterTree(tree, filter, pattern, keyField, childrenField) {
      const visitedTailKeys = /* @__PURE__ */new Set();
      const visitedNonTailKeys = /* @__PURE__ */new Set();
      const highlightKeySet = /* @__PURE__ */new Set();
      const expandedKeys = [];
      const filteredTree = [];
      const path = [];

      function visit(t) {
        t.forEach(n => {
          path.push(n);

          if (filter(pattern, n)) {
            visitedTailKeys.add(n[keyField]);
            highlightKeySet.add(n[keyField]);

            for (let i = path.length - 2; i >= 0; --i) {
              const key = path[i][keyField];

              if (!visitedNonTailKeys.has(key)) {
                visitedNonTailKeys.add(key);

                if (visitedTailKeys.has(key)) {
                  visitedTailKeys.delete(key);
                }
              } else {
                break;
              }
            }
          }

          const children = n[childrenField];

          if (children) {
            visit(children);
          }

          path.pop();
        });
      }

      visit(tree);

      function build(t, sibs) {
        t.forEach(n => {
          const key = n[keyField];
          const isVisitedTail = visitedTailKeys.has(key);
          const isVisitedNonTail = visitedNonTailKeys.has(key);
          if (!isVisitedTail && !isVisitedNonTail) return;
          const children = n[childrenField];

          if (children) {
            if (isVisitedTail) {
              sibs.push(n);
            } else {
              expandedKeys.push(key);
              const clonedNode = { ...n,
                [childrenField]: []
              };
              sibs.push(clonedNode);
              build(children, clonedNode[childrenField]);
            }
          } else {
            sibs.push(n);
          }
        });
      }

      build(tree, filteredTree);
      return {
        filteredTree,
        highlightKeySet,
        expandedKeys
      };
    }

    function useKeyboard({
      props,
      fNodesRef,
      mergedExpandedKeysRef,
      mergedSelectedKeysRef,
      handleSelect,
      handleSwitcherClick
    }) {
      const { value: mergedSelectedKeys } = mergedSelectedKeysRef;
      const treeSelectInjection = vue.inject(treeSelectInjectionKey, null);
      const pendingNodeKeyRef = treeSelectInjection ? treeSelectInjection.pendingNodeKeyRef : vue.ref(
        mergedSelectedKeys.length ? mergedSelectedKeys[mergedSelectedKeys.length - 1] : null
      );
      function handleKeydown(e) {
        if (!props.keyboard)
          return;
        const { value: pendingNodeKey } = pendingNodeKeyRef;
        if (pendingNodeKey === null) {
          if (e.key === "ArrowDown" || e.key === "ArrowUp") {
            e.preventDefault();
          }
          if (["ArrowDown", "ArrowUp", "ArrowLeft", "ArrowRight"].includes(e.key)) {
            if (pendingNodeKey === null) {
              const { value: fNodes } = fNodesRef;
              let fIndex = 0;
              while (fIndex < fNodes.length) {
                if (!fNodes[fIndex].disabled) {
                  pendingNodeKeyRef.value = fNodes[fIndex].key;
                  break;
                }
                fIndex += 1;
              }
            }
          }
        } else {
          const { value: fNodes } = fNodesRef;
          let fIndex = fNodes.findIndex((tmNode) => tmNode.key === pendingNodeKey);
          if (!~fIndex)
            return;
          if (e.key === "Enter") {
            handleSelect(fNodes[fIndex]);
          } else if (e.key === "ArrowDown") {
            e.preventDefault();
            fIndex += 1;
            while (fIndex < fNodes.length) {
              if (!fNodes[fIndex].disabled) {
                pendingNodeKeyRef.value = fNodes[fIndex].key;
                break;
              }
              fIndex += 1;
            }
          } else if (e.key === "ArrowUp") {
            e.preventDefault();
            fIndex -= 1;
            while (fIndex >= 0) {
              if (!fNodes[fIndex].disabled) {
                pendingNodeKeyRef.value = fNodes[fIndex].key;
                break;
              }
              fIndex -= 1;
            }
          } else if (e.key === "ArrowLeft") {
            const pendingNode = fNodes[fIndex];
            if (pendingNode.isLeaf || !mergedExpandedKeysRef.value.includes(pendingNodeKey)) {
              const parentTmNode = pendingNode.getParent();
              if (parentTmNode) {
                pendingNodeKeyRef.value = parentTmNode.key;
              }
            } else {
              handleSwitcherClick(pendingNode);
            }
          } else if (e.key === "ArrowRight") {
            const pendingNode = fNodes[fIndex];
            if (pendingNode.isLeaf)
              return;
            if (!mergedExpandedKeysRef.value.includes(pendingNodeKey)) {
              handleSwitcherClick(pendingNode);
            } else {
              fIndex += 1;
              while (fIndex < fNodes.length) {
                if (!fNodes[fIndex].disabled) {
                  pendingNodeKeyRef.value = fNodes[fIndex].key;
                  break;
                }
                fIndex += 1;
              }
            }
          }
        }
      }
      return {
        pendingNodeKeyRef,
        handleKeydown
      };
    }

    var MotionWrapper = vue.defineComponent({
      name: "TreeMotionWrapper",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        height: Number,
        nodes: {
          type: Array,
          required: true
        },
        mode: {
          type: String,
          required: true
        },
        onAfterEnter: {
          type: Function,
          required: true
        }
      },
      render() {
        const { clsPrefix } = this;
        return /* @__PURE__ */ React.createElement(NFadeInExpandTransition, {
          onAfterEnter: this.onAfterEnter,
          appear: true,
          reverse: this.mode === "collapse"
        }, {
          default: () => /* @__PURE__ */ React.createElement("div", {
            class: [
              `${clsPrefix}-tree-motion-wrapper`,
              `${clsPrefix}-tree-motion-wrapper--${this.mode}`
            ],
            style: {
              height: pxfy(this.height)
            }
          }, this.nodes.map((node) => /* @__PURE__ */ React.createElement(TreeNode, {
            clsPrefix,
            tmNode: node
          })))
        });
      }
    });

    var style$a = cB("tree", `
  font-size: var(--n-font-size);
  outline: none;
`, [c$1("ul, li", `
    margin: 0;
    padding: 0;
    list-style: none;
  `), c$1(">", [cB("tree-node", [c$1("&:first-child", {
      marginTop: 0
    })])]), cB("tree-node-indent", `
    flex-grow: 0;
    flex-shrink: 0;
    height: 0;
  `), cB("tree-motion-wrapper", [cM("expand", [fadeInHeightExpandTransition({
      duration: "0.2s"
    })]), cM("collapse", [fadeInHeightExpandTransition({
      duration: "0.2s",
      reverse: true
    })])]), cB("tree-node-wrapper", `
    box-sizing: border-box;
    padding: 3px 0;
  `), cB("tree-node", `
    position: relative;
    display: flex;
    border-radius: var(--n-node-border-radius);
    transition: background-color .3s var(--n-bezier);
  `, [cM("highlight", [cB("tree-node-content", [cE("text", {
      borderBottomColor: "var(--n-node-text-color-disabled)"
    })])]), cM("disabled", [cB("tree-node-content", `
        color: var(--n-node-text-color-disabled);
        cursor: not-allowed;
      `)]), cNotM("disabled", [cM("clickable", [cB("tree-node-content", `
          cursor: pointer;
        `)])])]), cM("block-node", [cB("tree-node-content", `
      flex: 1;
      min-width: 0;
    `)]), cNotM("block-line", [cB("tree-node", [cNotM("disabled", [cB("tree-node-content", [c$1("&:hover", {
      backgroundColor: "var(--n-node-color-hover)"
    })]), cM("selectable", [cB("tree-node-content", [c$1("&:active", {
      backgroundColor: "var(--n-node-color-pressed)"
    })])]), cM("pending", [cB("tree-node-content", `
            background-color: var(--n-node-color-hover);
          `)]), cM("selected", [cB("tree-node-content", {
      backgroundColor: "var(--n-node-color-active)"
    })])])])]), cM("block-line", [cB("tree-node", [cNotM("disabled", [c$1("&:hover", {
      backgroundColor: "var(--n-node-color-hover)"
    }), cM("pending", `
          background-color: var(--n-node-color-hover);
        `), cM("selectable", [cNotM("selected", [c$1("&:active", {
      backgroundColor: "var(--n-node-color-pressed)"
    })])]), cM("selected", {
      backgroundColor: "var(--n-node-color-active)"
    })]), cM("disabled", `
        cursor: not-allowed;
      `)])]), cB("tree-node-switcher", `
    cursor: pointer;
    display: inline-flex;
    flex-shrink: 0;
    height: 24px;
    width: 24px;
    align-items: center;
    justify-content: center;
    transition: transform .15s var(--n-bezier);
    vertical-align: bottom;
  `, [cE("icon", `
      position: relative;
      height: 14px;
      width: 14px;
      display: flex;
      color: var(--n-arrow-color);
      transition: color .3s var(--n-bezier);
      font-size: 14px;
    `, [cB("icon", [iconSwitchTransition()]), cB("base-loading", `
        color: var(--n-loading-color);
        position: absolute;
        left: 0;
        top: 0;
        right: 0;
        bottom: 0;
      `, [iconSwitchTransition()]), cB("base-icon", [iconSwitchTransition()])]), cM("hide", {
      visibility: "hidden"
    }), cM("expanded", {
      transform: "rotate(90deg)"
    })]), cB("tree-node-checkbox", `
    display: inline-flex;
    height: 24px;
    width: 16px;
    vertical-align: bottom;
    align-items: center;
    justify-content: center;
    margin-right: 4px;
  `, [cM("right", "margin-left: 4px;")]), cM("checkable", [cB("tree-node-content", `
      padding: 0 6px;
    `)]), cB("tree-node-content", `
    position: relative;
    display: inline-flex;
    align-items: center;
    min-height: 24px;
    box-sizing: border-box;
    line-height: 1.5;
    vertical-align: bottom;
    padding: 0 6px 0 4px;
    cursor: default;
    border-radius: var(--n-node-border-radius);
    text-decoration-color: #0000;
    text-decoration-line: underline;
    color: var(--n-node-text-color);
    transition:
      color .3s var(--n-bezier),
      text-decoration-color .3s var(--n-bezier),
      background-color .3s var(--n-bezier),
      border-color .3s var(--n-bezier);
  `, [c$1("&:last-child", {
      marginBottom: 0
    }), cE("prefix", `
      display: inline-flex;
      margin-right: 8px;
    `), cE("text", `
      border-bottom: 1px solid #0000;
      transition: border-color .3s var(--n-bezier);
      flex-grow: 1;
      max-width: 100%;
    `), cE("suffix", `
      display: inline-flex;
    `)]), cE("empty", "margin: auto;")]);

    const ITEM_SIZE = 30;
    function createTreeMateOptions(keyField, childrenField, disabledField) {
      return {
        getIsGroup() {
          return false;
        },
        getKey(node) {
          return node[keyField];
        },
        getChildren(node) {
          return node[childrenField];
        },
        getDisabled(node) {
          return !!(node[disabledField] || node.checkboxDisabled);
        }
      };
    }
    const treeSharedProps = {
      allowCheckingNotLoaded: Boolean,
      filter: Function,
      defaultExpandAll: Boolean,
      expandedKeys: Array,
      keyField: {
        type: String,
        default: "key"
      },
      labelField: {
        type: String,
        default: "label"
      },
      childrenField: {
        type: String,
        default: "children"
      },
      disabledField: {
        type: String,
        default: "disabled"
      },
      defaultExpandedKeys: {
        type: Array,
        default: () => []
      },
      indeterminateKeys: Array,
      renderSwitcherIcon: Function,
      onUpdateIndeterminateKeys: [Function, Array],
      "onUpdate:indeterminateKeys": [Function, Array],
      onUpdateExpandedKeys: [Function, Array],
      "onUpdate:expandedKeys": [Function, Array]
    };
    const treeProps = {
      ...useTheme.props,
      accordion: Boolean,
      showIrrelevantNodes: { type: Boolean, default: true },
      data: {
        type: Array,
        default: () => []
      },
      expandOnDragenter: {
        type: Boolean,
        default: true
      },
      expandOnClick: Boolean,
      checkOnClick: {
        type: [Boolean, Function],
        default: false
      },
      cancelable: {
        type: Boolean,
        default: true
      },
      checkable: Boolean,
      draggable: Boolean,
      blockNode: Boolean,
      blockLine: Boolean,
      disabled: Boolean,
      checkedKeys: Array,
      defaultCheckedKeys: {
        type: Array,
        default: () => []
      },
      selectedKeys: Array,
      defaultSelectedKeys: {
        type: Array,
        default: () => []
      },
      multiple: Boolean,
      pattern: {
        type: String,
        default: ""
      },
      onLoad: Function,
      cascade: Boolean,
      selectable: {
        type: Boolean,
        default: true
      },
      indent: {
        type: Number,
        default: 16
      },
      allowDrop: {
        type: Function,
        default: defaultAllowDrop
      },
      animated: {
        type: Boolean,
        default: true
      },
      checkboxPlacement: {
        type: String,
        default: "left"
      },
      virtualScroll: Boolean,
      watchProps: Array,
      renderLabel: Function,
      renderPrefix: Function,
      renderSuffix: Function,
      nodeProps: Function,
      keyboard: {
        type: Boolean,
        default: true
      },
      onDragenter: [Function, Array],
      onDragleave: [Function, Array],
      onDragend: [Function, Array],
      onDragstart: [Function, Array],
      onDragover: [Function, Array],
      onDrop: [Function, Array],
      onUpdateCheckedKeys: [Function, Array],
      "onUpdate:checkedKeys": [Function, Array],
      onUpdateSelectedKeys: [Function, Array],
      "onUpdate:selectedKeys": [Function, Array],
      ...treeSharedProps,
      internalTreeSelect: Boolean,
      internalScrollable: Boolean,
      internalScrollablePadding: String,
      internalRenderEmpty: Function,
      internalHighlightKeySet: Object,
      internalUnifySelectCheck: Boolean,
      internalCheckboxFocusable: {
        type: Boolean,
        default: true
      },
      internalFocusable: {
        type: Boolean,
        default: true
      },
      checkStrategy: {
        type: String,
        default: "all"
      },
      leafOnly: Boolean
    };
    var NTree = vue.defineComponent({
      name: "Tree",
      props: treeProps,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.leafOnly) {
              warnOnce(
                "tree",
                '`leaf-only` is deprecated, please use `check-strategy="child"` instead'
              );
            }
          });
        }
        const { mergedClsPrefixRef, inlineThemeDisabled, mergedRtlRef } = useConfig(props);
        const rtlEnabledRef = useRtl("Tree", mergedRtlRef, mergedClsPrefixRef);
        const themeRef = useTheme(
          "Tree",
          "-tree",
          style$a,
          treeLight$1,
          props,
          mergedClsPrefixRef
        );
        const selfElRef = vue.ref(null);
        const scrollbarInstRef = vue.ref(null);
        const virtualListInstRef = vue.ref(null);
        function getScrollContainer() {
          return virtualListInstRef.value?.listElRef;
        }
        function getScrollContent() {
          return virtualListInstRef.value?.itemsElRef;
        }
        const filteredTreeInfoRef = vue.computed(() => {
          const { pattern } = props;
          if (!pattern) {
            return {
              filteredTree: props.data,
              highlightKeySet: null,
              expandedKeys: void 0
            };
          }
          if (!pattern.length || !mergedFilterRef.value) {
            return {
              filteredTree: props.data,
              highlightKeySet: null,
              expandedKeys: void 0
            };
          }
          return filterTree(
            props.data,
            mergedFilterRef.value,
            pattern,
            props.keyField,
            props.childrenField
          );
        });
        const displayTreeMateRef = vue.computed(
          () => createTreeMate(
            props.showIrrelevantNodes ? props.data : filteredTreeInfoRef.value.filteredTree,
            createTreeMateOptions(
              props.keyField,
              props.childrenField,
              props.disabledField
            )
          )
        );
        const treeSelectInjection = vue.inject(treeSelectInjectionKey, null);
        const dataTreeMateRef = props.internalTreeSelect ? treeSelectInjection.dataTreeMate : displayTreeMateRef;
        const { watchProps } = props;
        const uncontrolledCheckedKeysRef = vue.ref([]);
        if (watchProps?.includes("defaultCheckedKeys")) {
          vue.watchEffect(() => {
            uncontrolledCheckedKeysRef.value = props.defaultCheckedKeys;
          });
        } else {
          uncontrolledCheckedKeysRef.value = props.defaultCheckedKeys;
        }
        const controlledCheckedKeysRef = vue.toRef(props, "checkedKeys");
        const mergedCheckedKeysRef = useMergedState(
          controlledCheckedKeysRef,
          uncontrolledCheckedKeysRef
        );
        const checkedStatusRef = vue.computed(() => {
          const value = dataTreeMateRef.value.getCheckedKeys(
            mergedCheckedKeysRef.value,
            {
              cascade: props.cascade,
              allowNotLoaded: props.allowCheckingNotLoaded
            }
          );
          return value;
        });
        const mergedCheckStrategyRef = vue.computed(
          () => props.leafOnly ? "child" : props.checkStrategy
        );
        const displayedCheckedKeysRef = vue.computed(() => {
          return checkedStatusRef.value.checkedKeys;
        });
        const displayedIndeterminateKeysRef = vue.computed(() => {
          const { indeterminateKeys } = props;
          if (indeterminateKeys !== void 0)
            return indeterminateKeys;
          return checkedStatusRef.value.indeterminateKeys;
        });
        const uncontrolledSelectedKeysRef = vue.ref([]);
        if (watchProps?.includes("defaultSelectedKeys")) {
          vue.watchEffect(() => {
            uncontrolledSelectedKeysRef.value = props.defaultSelectedKeys;
          });
        } else {
          uncontrolledSelectedKeysRef.value = props.defaultSelectedKeys;
        }
        const controlledSelectedKeysRef = vue.toRef(props, "selectedKeys");
        const mergedSelectedKeysRef = useMergedState(
          controlledSelectedKeysRef,
          uncontrolledSelectedKeysRef
        );
        const uncontrolledExpandedKeysRef = vue.ref([]);
        const initUncontrolledExpandedKeys = (keys) => {
          uncontrolledExpandedKeysRef.value = props.defaultExpandAll ? dataTreeMateRef.value.getNonLeafKeys() : keys === void 0 ? props.defaultExpandedKeys : keys;
        };
        if (watchProps?.includes("defaultExpandedKeys")) {
          vue.watchEffect(() => initUncontrolledExpandedKeys(void 0));
        } else {
          vue.watchEffect(() => initUncontrolledExpandedKeys(props.defaultExpandedKeys));
        }
        const controlledExpandedKeysRef = vue.toRef(props, "expandedKeys");
        const mergedExpandedKeysRef = useMergedState(
          controlledExpandedKeysRef,
          uncontrolledExpandedKeysRef
        );
        const fNodesRef = vue.computed(
          () => displayTreeMateRef.value.getFlattenedNodes(mergedExpandedKeysRef.value)
        );
        const { pendingNodeKeyRef, handleKeydown } = useKeyboard({
          props,
          mergedSelectedKeysRef,
          fNodesRef,
          mergedExpandedKeysRef,
          handleSelect,
          handleSwitcherClick
        });
        let expandTimerId = null;
        let nodeKeyToBeExpanded = null;
        const uncontrolledHighlightKeySetRef = vue.ref(/* @__PURE__ */ new Set());
        const controlledHighlightKeySetRef = vue.computed(() => {
          return props.internalHighlightKeySet || filteredTreeInfoRef.value.highlightKeySet;
        });
        const mergedHighlightKeySetRef = useMergedState(
          controlledHighlightKeySetRef,
          uncontrolledHighlightKeySetRef
        );
        const loadingKeysRef = vue.ref(/* @__PURE__ */ new Set());
        const expandedNonLoadingKeysRef = vue.computed(() => {
          return mergedExpandedKeysRef.value.filter(
            (key) => !loadingKeysRef.value.has(key)
          );
        });
        let dragStartX = 0;
        const draggingNodeRef = vue.ref(null);
        const droppingNodeRef = vue.ref(null);
        const droppingMouseNodeRef = vue.ref(null);
        const droppingPositionRef = vue.ref(null);
        const droppingOffsetLevelRef = vue.ref(0);
        const droppingNodeParentRef = vue.computed(() => {
          const { value: droppingNode } = droppingNodeRef;
          if (!droppingNode)
            return null;
          return droppingNode.parent;
        });
        const mergedFilterRef = vue.computed(() => {
          const { filter } = props;
          if (filter)
            return filter;
          const { labelField } = props;
          return (pattern, node) => {
            if (!pattern.length)
              return true;
            const label = node[labelField];
            if (typeof label === "string") {
              return label.toLowerCase().includes(pattern.toLowerCase());
            }
            return false;
          };
        });
        vue.watch(
          vue.toRef(props, "data"),
          () => {
            loadingKeysRef.value.clear();
            pendingNodeKeyRef.value = null;
            resetDndState();
          },
          {
            deep: false
          }
        );
        let memorizedExpandedKeys;
        vue.watch(vue.toRef(props, "pattern"), (value, oldValue) => {
          if (props.showIrrelevantNodes) {
            memorizedExpandedKeys = void 0;
            if (value) {
              const { expandedKeys: expandedKeysAfterChange, highlightKeySet } = keysWithFilter(
                props.data,
                props.pattern,
                props.keyField,
                props.childrenField,
                mergedFilterRef.value
              );
              uncontrolledHighlightKeySetRef.value = highlightKeySet;
              doUpdateExpandedKeys(
                expandedKeysAfterChange,
                getOptionsByKeys(expandedKeysAfterChange)
              );
            } else {
              uncontrolledHighlightKeySetRef.value = /* @__PURE__ */ new Set();
            }
          } else {
            if (!value.length) {
              if (memorizedExpandedKeys !== void 0) {
                doUpdateExpandedKeys(
                  memorizedExpandedKeys,
                  getOptionsByKeys(memorizedExpandedKeys)
                );
              }
            } else {
              if (!oldValue.length) {
                memorizedExpandedKeys = mergedExpandedKeysRef.value;
              }
              const { expandedKeys } = filteredTreeInfoRef.value;
              if (expandedKeys !== void 0) {
                doUpdateExpandedKeys(expandedKeys, getOptionsByKeys(expandedKeys));
              }
            }
          }
        });
        async function triggerLoading(node) {
          const { onLoad } = props;
          if (!onLoad) {
            {
              warn$2(
                "tree",
                "There is unloaded node in data but props.onLoad is not specified."
              );
            }
            return await Promise.resolve();
          }
          const { value: loadingKeys } = loadingKeysRef;
          return await new Promise((resolve) => {
            if (!loadingKeys.has(node.key)) {
              loadingKeys.add(node.key);
              onLoad(node.rawNode).then(() => {
                loadingKeys.delete(node.key);
                resolve();
              }).catch((loadError) => {
                console.error(loadError);
                resetDragExpandState();
              });
            }
          });
        }
        vue.watchEffect(() => {
          const { value: displayTreeMate } = displayTreeMateRef;
          if (!displayTreeMate)
            return;
          const { getNode } = displayTreeMate;
          mergedExpandedKeysRef.value?.forEach((key) => {
            const node = getNode(key);
            if (node && !node.shallowLoaded) {
              void triggerLoading(node);
            }
          });
        });
        const aipRef = vue.ref(false);
        const afNodesRef = vue.ref([]);
        vue.watch(expandedNonLoadingKeysRef, (value, prevValue) => {
          if (!props.animated) {
            void vue.nextTick(syncScrollbar);
            return;
          }
          const prevVSet = new Set(prevValue);
          let addedKey = null;
          let removedKey = null;
          for (const expandedKey of value) {
            if (!prevVSet.has(expandedKey)) {
              if (addedKey !== null)
                return;
              addedKey = expandedKey;
            }
          }
          const currentVSet = new Set(value);
          for (const expandedKey of prevValue) {
            if (!currentVSet.has(expandedKey)) {
              if (removedKey !== null)
                return;
              removedKey = expandedKey;
            }
          }
          if (addedKey === null && removedKey === null) {
            return;
          }
          const { virtualScroll } = props;
          const viewportHeight = (virtualScroll ? virtualListInstRef.value.listElRef : selfElRef.value).offsetHeight;
          const viewportItemCount = Math.ceil(viewportHeight / ITEM_SIZE) + 1;
          let baseExpandedKeys;
          if (addedKey !== null) {
            baseExpandedKeys = prevValue;
          }
          if (removedKey !== null) {
            if (baseExpandedKeys === void 0) {
              baseExpandedKeys = value;
            } else {
              baseExpandedKeys = baseExpandedKeys.filter(
                (key) => key !== removedKey
              );
            }
          }
          aipRef.value = true;
          afNodesRef.value = displayTreeMateRef.value.getFlattenedNodes(baseExpandedKeys);
          if (addedKey !== null) {
            const expandedNodeIndex = afNodesRef.value.findIndex(
              (node) => node.key === addedKey
            );
            if (~expandedNodeIndex) {
              const children = afNodesRef.value[expandedNodeIndex].children;
              if (children) {
                const expandedChildren = flatten$1(children, value);
                afNodesRef.value.splice(expandedNodeIndex + 1, 0, {
                  __motion: true,
                  mode: "expand",
                  height: virtualScroll ? expandedChildren.length * ITEM_SIZE : void 0,
                  nodes: virtualScroll ? expandedChildren.slice(0, viewportItemCount) : expandedChildren
                });
              }
            }
          }
          if (removedKey !== null) {
            const collapsedNodeIndex = afNodesRef.value.findIndex(
              (node) => node.key === removedKey
            );
            if (~collapsedNodeIndex) {
              const collapsedNodeChildren = afNodesRef.value[collapsedNodeIndex].children;
              if (!collapsedNodeChildren)
                return;
              aipRef.value = true;
              const collapsedChildren = flatten$1(collapsedNodeChildren, value);
              afNodesRef.value.splice(collapsedNodeIndex + 1, 0, {
                __motion: true,
                mode: "collapse",
                height: virtualScroll ? collapsedChildren.length * ITEM_SIZE : void 0,
                nodes: virtualScroll ? collapsedChildren.slice(0, viewportItemCount) : collapsedChildren
              });
            }
          }
        });
        const getFIndexRef = vue.computed(() => {
          return createIndexGetter(fNodesRef.value);
        });
        const mergedFNodesRef = vue.computed(() => {
          if (aipRef.value)
            return afNodesRef.value;
          else
            return fNodesRef.value;
        });
        function syncScrollbar() {
          const { value: scrollbarInst } = scrollbarInstRef;
          if (scrollbarInst)
            scrollbarInst.sync();
        }
        function handleAfterEnter() {
          aipRef.value = false;
          if (props.virtualScroll) {
            void vue.nextTick(syncScrollbar);
          }
        }
        function getOptionsByKeys(keys) {
          const { getNode } = dataTreeMateRef.value;
          return keys.map((key) => getNode(key)?.rawNode || null);
        }
        function doUpdateExpandedKeys(value, option) {
          const {
            "onUpdate:expandedKeys": _onUpdateExpandedKeys,
            onUpdateExpandedKeys
          } = props;
          uncontrolledExpandedKeysRef.value = value;
          if (_onUpdateExpandedKeys) {
            call(_onUpdateExpandedKeys, value, option);
          }
          if (onUpdateExpandedKeys) {
            call(onUpdateExpandedKeys, value, option);
          }
        }
        function doUpdateCheckedKeys(value, option) {
          const {
            "onUpdate:checkedKeys": _onUpdateCheckedKeys,
            onUpdateCheckedKeys
          } = props;
          uncontrolledCheckedKeysRef.value = value;
          if (onUpdateCheckedKeys) {
            call(onUpdateCheckedKeys, value, option);
          }
          if (_onUpdateCheckedKeys) {
            call(_onUpdateCheckedKeys, value, option);
          }
        }
        function doUpdateIndeterminateKeys(value, option) {
          const {
            "onUpdate:indeterminateKeys": _onUpdateIndeterminateKeys,
            onUpdateIndeterminateKeys
          } = props;
          if (_onUpdateIndeterminateKeys) {
            call(_onUpdateIndeterminateKeys, value, option);
          }
          if (onUpdateIndeterminateKeys) {
            call(onUpdateIndeterminateKeys, value, option);
          }
        }
        function doUpdateSelectedKeys(value, option) {
          const {
            "onUpdate:selectedKeys": _onUpdateSelectedKeys,
            onUpdateSelectedKeys
          } = props;
          uncontrolledSelectedKeysRef.value = value;
          if (onUpdateSelectedKeys) {
            call(onUpdateSelectedKeys, value, option);
          }
          if (_onUpdateSelectedKeys) {
            call(_onUpdateSelectedKeys, value, option);
          }
        }
        function doDragEnter(info) {
          const { onDragenter } = props;
          if (onDragenter)
            call(onDragenter, info);
        }
        function doDragLeave(info) {
          const { onDragleave } = props;
          if (onDragleave)
            call(onDragleave, info);
        }
        function doDragEnd(info) {
          const { onDragend } = props;
          if (onDragend)
            call(onDragend, info);
        }
        function doDragStart(info) {
          const { onDragstart } = props;
          if (onDragstart)
            call(onDragstart, info);
        }
        function doDragOver(info) {
          const { onDragover } = props;
          if (onDragover)
            call(onDragover, info);
        }
        function doDrop(info) {
          const { onDrop } = props;
          if (onDrop)
            call(onDrop, info);
        }
        function resetDndState() {
          resetDragState();
          resetDropState();
        }
        function resetDragState() {
          draggingNodeRef.value = null;
        }
        function resetDropState() {
          droppingOffsetLevelRef.value = 0;
          droppingNodeRef.value = null;
          droppingMouseNodeRef.value = null;
          droppingPositionRef.value = null;
          resetDragExpandState();
        }
        function resetDragExpandState() {
          if (expandTimerId) {
            window.clearTimeout(expandTimerId);
            expandTimerId = null;
          }
          nodeKeyToBeExpanded = null;
        }
        function handleCheck(node, checked) {
          if (props.disabled || node.disabled) {
            return;
          }
          if (props.internalUnifySelectCheck && !props.multiple) {
            handleSelect(node);
            return;
          }
          const { checkedKeys, indeterminateKeys } = dataTreeMateRef.value[checked ? "check" : "uncheck"](node.key, displayedCheckedKeysRef.value, {
            cascade: props.cascade,
            checkStrategy: mergedCheckStrategyRef.value,
            allowNotLoaded: props.allowCheckingNotLoaded
          });
          doUpdateCheckedKeys(checkedKeys, getOptionsByKeys(checkedKeys));
          doUpdateIndeterminateKeys(
            indeterminateKeys,
            getOptionsByKeys(indeterminateKeys)
          );
        }
        function toggleExpand(node) {
          if (props.disabled)
            return;
          const { key } = node;
          const { value: mergedExpandedKeys } = mergedExpandedKeysRef;
          const index = mergedExpandedKeys.findIndex(
            (expandNodeId) => expandNodeId === key
          );
          if (~index) {
            const expandedKeysAfterChange = Array.from(mergedExpandedKeys);
            expandedKeysAfterChange.splice(index, 1);
            doUpdateExpandedKeys(
              expandedKeysAfterChange,
              getOptionsByKeys(expandedKeysAfterChange)
            );
          } else {
            const nodeToBeExpanded = displayTreeMateRef.value.getNode(key);
            if (!nodeToBeExpanded || nodeToBeExpanded.isLeaf) {
              return;
            }
            let nextKeys;
            if (props.accordion) {
              const siblingKeySet = new Set(
                node.siblings.map(({ key: key2 }) => key2)
              );
              nextKeys = mergedExpandedKeys.filter((expandedKey) => {
                return !siblingKeySet.has(expandedKey);
              });
              nextKeys.push(key);
            } else {
              nextKeys = mergedExpandedKeys.concat(key);
            }
            doUpdateExpandedKeys(nextKeys, getOptionsByKeys(nextKeys));
          }
        }
        function handleSwitcherClick(node) {
          if (props.disabled || aipRef.value)
            return;
          toggleExpand(node);
        }
        function handleSelect(node) {
          if (props.disabled || !props.selectable) {
            return;
          }
          pendingNodeKeyRef.value = node.key;
          if (props.internalUnifySelectCheck) {
            const {
              value: { checkedKeys, indeterminateKeys }
            } = checkedStatusRef;
            if (props.multiple) {
              handleCheck(
                node,
                !(checkedKeys.includes(node.key) || indeterminateKeys.includes(node.key))
              );
            } else {
              doUpdateCheckedKeys([node.key], getOptionsByKeys([node.key]));
            }
          }
          if (props.multiple) {
            const selectedKeys = Array.from(mergedSelectedKeysRef.value);
            const index = selectedKeys.findIndex((key) => key === node.key);
            if (~index) {
              if (props.cancelable) {
                selectedKeys.splice(index, 1);
              }
            } else if (!~index) {
              selectedKeys.push(node.key);
            }
            doUpdateSelectedKeys(selectedKeys, getOptionsByKeys(selectedKeys));
          } else {
            const selectedKeys = mergedSelectedKeysRef.value;
            if (selectedKeys.includes(node.key)) {
              if (props.cancelable) {
                doUpdateSelectedKeys([], []);
              }
            } else {
              doUpdateSelectedKeys([node.key], getOptionsByKeys([node.key]));
            }
          }
        }
        function expandDragEnterNode(node) {
          if (expandTimerId) {
            window.clearTimeout(expandTimerId);
            expandTimerId = null;
          }
          if (node.isLeaf)
            return;
          nodeKeyToBeExpanded = node.key;
          const expand = () => {
            if (nodeKeyToBeExpanded !== node.key)
              return;
            const { value: droppingMouseNode } = droppingMouseNodeRef;
            if (droppingMouseNode && droppingMouseNode.key === node.key && !mergedExpandedKeysRef.value.includes(node.key)) {
              const nextKeys = mergedExpandedKeysRef.value.concat(node.key);
              doUpdateExpandedKeys(nextKeys, getOptionsByKeys(nextKeys));
            }
            expandTimerId = null;
            nodeKeyToBeExpanded = null;
          };
          if (!node.shallowLoaded) {
            expandTimerId = window.setTimeout(() => {
              void triggerLoading(node).then(() => {
                expand();
              });
            }, 1e3);
          } else {
            expandTimerId = window.setTimeout(() => {
              expand();
            }, 1e3);
          }
        }
        function handleDragEnter({ event, node }) {
          if (!props.draggable || props.disabled || node.disabled)
            return;
          handleDragOver({ event, node }, false);
          doDragEnter({ event, node: node.rawNode });
        }
        function handleDragLeave({ event, node }) {
          if (!props.draggable || props.disabled || node.disabled)
            return;
          doDragLeave({ event, node: node.rawNode });
        }
        function handleDragLeaveTree(e) {
          if (e.target !== e.currentTarget)
            return;
          resetDropState();
        }
        function handleDragEnd({ event, node }) {
          resetDndState();
          if (!props.draggable || props.disabled || node.disabled)
            return;
          doDragEnd({ event, node: node.rawNode });
        }
        function handleDragStart({ event, node }) {
          if (!props.draggable || props.disabled || node.disabled)
            return;
          dragStartX = event.clientX;
          draggingNodeRef.value = node;
          doDragStart({ event, node: node.rawNode });
        }
        function handleDragOver({ event, node }, emit = true) {
          if (!props.draggable || props.disabled || node.disabled)
            return;
          const { value: draggingNode } = draggingNodeRef;
          if (!draggingNode)
            return;
          const { allowDrop, indent } = props;
          if (emit)
            doDragOver({ event, node: node.rawNode });
          const el = event.currentTarget;
          const { height: elOffsetHeight, top: elClientTop } = el.getBoundingClientRect();
          const eventOffsetY = event.clientY - elClientTop;
          let mousePosition;
          const allowDropInside = allowDrop({
            node: node.rawNode,
            dropPosition: "inside",
            phase: "drag"
          });
          if (allowDropInside) {
            if (eventOffsetY <= 8) {
              mousePosition = "before";
            } else if (eventOffsetY >= elOffsetHeight - 8) {
              mousePosition = "after";
            } else {
              mousePosition = "inside";
            }
          } else {
            if (eventOffsetY <= elOffsetHeight / 2) {
              mousePosition = "before";
            } else {
              mousePosition = "after";
            }
          }
          const { value: getFindex } = getFIndexRef;
          let finalDropNode;
          let finalDropPosition;
          const hoverNodeFIndex = getFindex(node.key);
          if (hoverNodeFIndex === null) {
            resetDropState();
            return;
          }
          let mouseAtExpandedNonLeafNode = false;
          if (mousePosition === "inside") {
            finalDropNode = node;
            finalDropPosition = "inside";
          } else {
            if (mousePosition === "before") {
              if (node.isFirstChild) {
                finalDropNode = node;
                finalDropPosition = "before";
              } else {
                finalDropNode = fNodesRef.value[hoverNodeFIndex - 1];
                finalDropPosition = "after";
              }
            } else {
              finalDropNode = node;
              finalDropPosition = "after";
            }
          }
          if (!finalDropNode.isLeaf && mergedExpandedKeysRef.value.includes(finalDropNode.key)) {
            mouseAtExpandedNonLeafNode = true;
            if (finalDropPosition === "after") {
              finalDropNode = fNodesRef.value[hoverNodeFIndex + 1];
              if (!finalDropNode) {
                finalDropNode = node;
                finalDropPosition = "inside";
              } else {
                finalDropPosition = "before";
              }
            }
          }
          const droppingMouseNode = finalDropNode;
          droppingMouseNodeRef.value = droppingMouseNode;
          if (!mouseAtExpandedNonLeafNode && draggingNode.isLastChild && draggingNode.key === finalDropNode.key) {
            finalDropPosition = "after";
          }
          if (finalDropPosition === "after") {
            let offset = dragStartX - event.clientX;
            let offsetLevel = 0;
            while (offset >= indent / 2 && finalDropNode.parent !== null && finalDropNode.isLastChild && offsetLevel < 1) {
              offset -= indent;
              offsetLevel += 1;
              finalDropNode = finalDropNode.parent;
            }
            droppingOffsetLevelRef.value = offsetLevel;
          } else {
            droppingOffsetLevelRef.value = 0;
          }
          if (draggingNode.contains(finalDropNode) || finalDropPosition === "inside" && draggingNode.parent?.key === finalDropNode.key) {
            if (draggingNode.key === droppingMouseNode.key && draggingNode.key === finalDropNode.key) ; else {
              resetDropState();
              return;
            }
          }
          if (!allowDrop({
            node: finalDropNode.rawNode,
            dropPosition: finalDropPosition,
            phase: "drag"
          })) {
            resetDropState();
            return;
          }
          if (draggingNode.key === finalDropNode.key) {
            resetDragExpandState();
          } else {
            if (nodeKeyToBeExpanded !== finalDropNode.key) {
              if (finalDropPosition === "inside") {
                if (props.expandOnDragenter) {
                  expandDragEnterNode(finalDropNode);
                  if (!finalDropNode.shallowLoaded && nodeKeyToBeExpanded !== finalDropNode.key) {
                    resetDndState();
                    return;
                  }
                } else {
                  if (!finalDropNode.shallowLoaded) {
                    resetDndState();
                    return;
                  }
                }
              } else {
                resetDragExpandState();
              }
            } else {
              if (finalDropPosition !== "inside") {
                resetDragExpandState();
              }
            }
          }
          droppingPositionRef.value = finalDropPosition;
          droppingNodeRef.value = finalDropNode;
        }
        function handleDrop({ event, node, dropPosition }) {
          if (!props.draggable || props.disabled || node.disabled) {
            return;
          }
          const { value: draggingNode } = draggingNodeRef;
          const { value: droppingNode } = droppingNodeRef;
          const { value: droppingPosition } = droppingPositionRef;
          if (!draggingNode || !droppingNode || !droppingPosition) {
            return;
          }
          if (!props.allowDrop({
            node: droppingNode.rawNode,
            dropPosition: droppingPosition,
            phase: "drag"
          })) {
            return;
          }
          if (draggingNode.key === droppingNode.key) {
            return;
          }
          if (droppingPosition === "before") {
            const nextNode = draggingNode.getNext({ includeDisabled: true });
            if (nextNode) {
              if (nextNode.key === droppingNode.key) {
                resetDropState();
                return;
              }
            }
          }
          if (droppingPosition === "after") {
            const prevNode = draggingNode.getPrev({ includeDisabled: true });
            if (prevNode) {
              if (prevNode.key === droppingNode.key) {
                resetDropState();
                return;
              }
            }
          }
          doDrop({
            event,
            node: droppingNode.rawNode,
            dragNode: draggingNode.rawNode,
            dropPosition
          });
          resetDndState();
        }
        function handleScroll() {
          syncScrollbar();
        }
        function handleResize() {
          syncScrollbar();
        }
        function handleFocusout(e) {
          if (props.virtualScroll || props.internalScrollable) {
            const { value: scrollbarInst } = scrollbarInstRef;
            if (scrollbarInst?.containerRef?.contains(e.relatedTarget)) {
              return;
            }
            pendingNodeKeyRef.value = null;
          } else {
            const { value: selfEl } = selfElRef;
            if (selfEl?.contains(e.relatedTarget))
              return;
            pendingNodeKeyRef.value = null;
          }
        }
        vue.watch(pendingNodeKeyRef, (value) => {
          if (value === null)
            return;
          if (props.virtualScroll) {
            virtualListInstRef.value?.scrollTo({ key: value });
          } else if (props.internalScrollable) {
            const { value: scrollbarInst } = scrollbarInstRef;
            if (scrollbarInst === null)
              return;
            const targetEl = scrollbarInst.contentRef?.querySelector(
              `[data-key="${createDataKey(value)}"]`
            );
            if (!targetEl)
              return;
            scrollbarInst.scrollTo({
              el: targetEl
            });
          }
        });
        vue.provide(treeInjectionKey, {
          loadingKeysRef,
          highlightKeySetRef: mergedHighlightKeySetRef,
          displayedCheckedKeysRef,
          displayedIndeterminateKeysRef,
          mergedSelectedKeysRef,
          mergedExpandedKeysRef,
          mergedThemeRef: themeRef,
          mergedCheckStrategyRef,
          nodePropsRef: vue.toRef(props, "nodeProps"),
          disabledRef: vue.toRef(props, "disabled"),
          checkableRef: vue.toRef(props, "checkable"),
          selectableRef: vue.toRef(props, "selectable"),
          expandOnClickRef: vue.toRef(props, "expandOnClick"),
          onLoadRef: vue.toRef(props, "onLoad"),
          draggableRef: vue.toRef(props, "draggable"),
          blockLineRef: vue.toRef(props, "blockLine"),
          indentRef: vue.toRef(props, "indent"),
          cascadeRef: vue.toRef(props, "cascade"),
          checkOnClickRef: vue.toRef(props, "checkOnClick"),
          checkboxPlacementRef: props.checkboxPlacement,
          droppingMouseNodeRef,
          droppingNodeParentRef,
          draggingNodeRef,
          droppingPositionRef,
          droppingOffsetLevelRef,
          fNodesRef,
          pendingNodeKeyRef,
          internalScrollableRef: vue.toRef(props, "internalScrollable"),
          internalCheckboxFocusableRef: vue.toRef(props, "internalCheckboxFocusable"),
          internalTreeSelect: props.internalTreeSelect,
          renderLabelRef: vue.toRef(props, "renderLabel"),
          renderPrefixRef: vue.toRef(props, "renderPrefix"),
          renderSuffixRef: vue.toRef(props, "renderSuffix"),
          renderSwitcherIconRef: vue.toRef(props, "renderSwitcherIcon"),
          labelFieldRef: vue.toRef(props, "labelField"),
          multipleRef: vue.toRef(props, "multiple"),
          handleSwitcherClick,
          handleDragEnd,
          handleDragEnter,
          handleDragLeave,
          handleDragStart,
          handleDrop,
          handleDragOver,
          handleSelect,
          handleCheck
        });
        function scrollTo(options) {
          virtualListInstRef.value?.scrollTo(options);
        }
        const exposedMethods = {
          handleKeydown,
          scrollTo
        };
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self: {
              fontSize,
              nodeBorderRadius,
              nodeColorHover,
              nodeColorPressed,
              nodeColorActive,
              arrowColor,
              loadingColor,
              nodeTextColor,
              nodeTextColorDisabled,
              dropMarkColor
            }
          } = themeRef.value;
          return {
            "--n-arrow-color": arrowColor,
            "--n-loading-color": loadingColor,
            "--n-bezier": cubicBezierEaseInOut,
            "--n-font-size": fontSize,
            "--n-node-border-radius": nodeBorderRadius,
            "--n-node-color-active": nodeColorActive,
            "--n-node-color-hover": nodeColorHover,
            "--n-node-color-pressed": nodeColorPressed,
            "--n-node-text-color": nodeTextColor,
            "--n-node-text-color-disabled": nodeTextColorDisabled,
            "--n-drop-mark-color": dropMarkColor
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("tree", void 0, cssVarsRef, props) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          mergedTheme: themeRef,
          rtlEnabled: rtlEnabledRef,
          fNodes: mergedFNodesRef,
          aip: aipRef,
          selfElRef,
          virtualListInstRef,
          scrollbarInstRef,
          handleFocusout,
          handleDragLeaveTree,
          handleScroll,
          getScrollContainer,
          getScrollContent,
          handleAfterEnter,
          handleResize,
          handleKeydown: exposedMethods.handleKeydown,
          scrollTo: exposedMethods.scrollTo,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { fNodes, internalRenderEmpty } = this;
        if (!fNodes.length && internalRenderEmpty) {
          return internalRenderEmpty();
        }
        const {
          mergedClsPrefix,
          blockNode,
          blockLine,
          draggable,
          disabled,
          internalFocusable,
          checkable,
          handleKeydown,
          rtlEnabled,
          handleFocusout
        } = this;
        const mergedFocusable = internalFocusable && !disabled;
        const tabindex = mergedFocusable ? "0" : void 0;
        const treeClass = [
          `${mergedClsPrefix}-tree`,
          rtlEnabled && `${mergedClsPrefix}-tree--rtl`,
          checkable && `${mergedClsPrefix}-tree--checkable`,
          (blockLine || blockNode) && `${mergedClsPrefix}-tree--block-node`,
          blockLine && `${mergedClsPrefix}-tree--block-line`
        ];
        const createNode = (tmNode) => {
          return "__motion" in tmNode ? /* @__PURE__ */ React.createElement(MotionWrapper, {
            height: tmNode.height,
            nodes: tmNode.nodes,
            clsPrefix: mergedClsPrefix,
            mode: tmNode.mode,
            onAfterEnter: this.handleAfterEnter
          }) : /* @__PURE__ */ React.createElement(TreeNode, {
            key: tmNode.key,
            tmNode,
            clsPrefix: mergedClsPrefix
          });
        };
        if (this.virtualScroll) {
          const { mergedTheme, internalScrollablePadding } = this;
          const padding = getMargin(internalScrollablePadding || "0");
          return /* @__PURE__ */ React.createElement(XScrollbar, {
            ref: "scrollbarInstRef",
            onDragleave: draggable ? this.handleDragLeaveTree : void 0,
            container: this.getScrollContainer,
            content: this.getScrollContent,
            class: treeClass,
            theme: mergedTheme.peers.Scrollbar,
            themeOverrides: mergedTheme.peerOverrides.Scrollbar,
            tabindex,
            onKeydown: mergedFocusable ? handleKeydown : void 0,
            onFocusout: mergedFocusable ? handleFocusout : void 0
          }, {
            default: () => {
              this.onRender?.();
              return /* @__PURE__ */ React.createElement(VVirtualList, {
                ref: "virtualListInstRef",
                items: this.fNodes,
                itemSize: ITEM_SIZE,
                ignoreItemResize: this.aip,
                paddingTop: padding.top,
                paddingBottom: padding.bottom,
                class: this.themeClass,
                style: [
                  this.cssVars,
                  {
                    paddingLeft: padding.left,
                    paddingRight: padding.right
                  }
                ],
                onScroll: this.handleScroll,
                onResize: this.handleResize,
                showScrollbar: false,
                itemResizable: true
              }, {
                default: ({ item }) => createNode(item)
              });
            }
          });
        }
        const { internalScrollable } = this;
        treeClass.push(this.themeClass);
        this.onRender?.();
        if (internalScrollable) {
          return /* @__PURE__ */ React.createElement(XScrollbar, {
            class: treeClass,
            tabindex,
            onKeydown: mergedFocusable ? handleKeydown : void 0,
            onFocusout: mergedFocusable ? handleFocusout : void 0,
            style: this.cssVars,
            contentStyle: { padding: this.internalScrollablePadding }
          }, {
            default: () => /* @__PURE__ */ React.createElement("div", {
              onDragleave: draggable ? this.handleDragLeaveTree : void 0,
              ref: "selfElRef"
            }, this.fNodes.map(createNode))
          });
        } else {
          return /* @__PURE__ */ React.createElement("div", {
            class: treeClass,
            tabindex,
            ref: "selfElRef",
            style: this.cssVars,
            onKeydown: mergedFocusable ? handleKeydown : void 0,
            onFocusout: mergedFocusable ? handleFocusout : void 0,
            onDragleave: draggable ? this.handleDragLeaveTree : void 0
          }, !fNodes.length ? resolveSlot(this.$slots.empty, () => [
            /* @__PURE__ */ React.createElement(NEmpty, {
              class: `${mergedClsPrefix}-tree__empty`,
              theme: this.mergedTheme.peers.Empty,
              themeOverrides: this.mergedTheme.peerOverrides.Empty
            })
          ]) : fNodes.map(createNode));
        }
      }
    });

    function treeOption2SelectOption(tmNode, labelField) {
      const {
        rawNode
      } = tmNode;
      return { ...rawNode,
        label: rawNode[labelField],
        value: tmNode.key
      };
    }
    function treeOption2SelectOptionWithPath(tmNode, path, separator, labelField) {
      const {
        rawNode
      } = tmNode;
      return { ...rawNode,
        value: tmNode.key,
        label: path.map(v => v.rawNode[labelField]).join(separator)
      };
    }

    var style$9 = c$1([cB("tree-select", `
    z-index: auto;
    outline: none;
    width: 100%;
    position: relative;
  `), cB("tree-select-menu", `
    position: relative;
    overflow: hidden;
    margin: 4px 0;
    transition: box-shadow .3s var(--n-bezier), background-color .3s var(--n-bezier);
    border-radius: var(--n-menu-border-radius);
    box-shadow: var(--n-menu-box-shadow);
    background-color: var(--n-menu-color);
    outline: none;
  `, [cB("tree", "max-height: var(--n-menu-height);"), cE("empty", `
      display: flex;
      padding: 12px 32px;
      flex: 1;
      justify-content: center;
    `), cE("action", `
      padding: var(--n-action-padding);
      transition: 
        color .3s var(--n-bezier);
        border-color .3s var(--n-bezier);
      border-top: 1px solid var(--n-action-divider-color);
      color: var(--n-action-text-color);
    `), fadeInScaleUpTransition()])]);

    const treeSelectProps = {
      ...useTheme.props,
      bordered: {
        type: Boolean,
        default: true
      },
      cascade: Boolean,
      checkable: Boolean,
      clearable: Boolean,
      clearFilterAfterSelect: {
        type: Boolean,
        default: true
      },
      consistentMenuWidth: {
        type: Boolean,
        default: true
      },
      defaultShow: Boolean,
      defaultValue: {
        type: [String, Number, Array],
        default: null
      },
      disabled: {
        type: Boolean,
        default: void 0
      },
      filterable: Boolean,
      checkStrategy: {
        type: String,
        default: "all"
      },
      loading: Boolean,
      maxTagCount: [String, Number],
      multiple: Boolean,
      showPath: Boolean,
      separator: {
        type: String,
        default: " / "
      },
      options: {
        type: Array,
        default: () => []
      },
      placeholder: String,
      placement: {
        type: String,
        default: "bottom-start"
      },
      show: {
        type: Boolean,
        default: void 0
      },
      size: String,
      value: [String, Number, Array],
      to: useAdjustedTo.propTo,
      menuProps: Object,
      virtualScroll: {
        type: Boolean,
        default: true
      },
      status: String,
      renderTag: Function,
      ...treeSharedProps,
      renderLabel: Function,
      renderPrefix: Function,
      renderSuffix: Function,
      nodeProps: Function,
      onBlur: Function,
      onFocus: Function,
      onLoad: Function,
      onUpdateShow: [Function, Array],
      onUpdateValue: [Function, Array],
      "onUpdate:value": [Function, Array],
      "onUpdate:show": [Function, Array],
      leafOnly: Boolean
    };
    var TreeSelect = vue.defineComponent({
      name: "TreeSelect",
      props: treeSelectProps,
      setup(props) {
        {
          vue.watchEffect(() => {
            if (props.leafOnly) {
              warnOnce(
                "tree-select",
                '`leaf-only` is deprecated, please use `check-strategy="child"` instead.'
              );
            }
          });
        }
        const followerInstRef = vue.ref(null);
        const triggerInstRef = vue.ref(null);
        const treeInstRef = vue.ref(null);
        const menuElRef = vue.ref(null);
        const { mergedClsPrefixRef, namespaceRef, inlineThemeDisabled } = useConfig(props);
        const { localeRef } = useLocale("Select");
        const {
          mergedSizeRef,
          mergedDisabledRef,
          mergedStatusRef,
          nTriggerFormBlur,
          nTriggerFormChange,
          nTriggerFormFocus,
          nTriggerFormInput
        } = useFormItem(props);
        const uncontrolledValueRef = vue.ref(props.defaultValue);
        const controlledValueRef = vue.toRef(props, "value");
        const mergedValueRef = useMergedState(
          controlledValueRef,
          uncontrolledValueRef
        );
        const uncontrolledShowRef = vue.ref(props.defaultShow);
        const controlledShowRef = vue.toRef(props, "show");
        const mergedShowRef = useMergedState(controlledShowRef, uncontrolledShowRef);
        const patternRef = vue.ref("");
        const mergedFilterRef = vue.computed(() => {
          const { filter } = props;
          if (filter)
            return filter;
          const { labelField } = props;
          return (pattern, node) => {
            if (!pattern.length)
              return true;
            return node[labelField].toLowerCase().includes(pattern.toLowerCase());
          };
        });
        const dataTreeMateRef = vue.computed(
          () => createTreeMate(
            props.options,
            createTreeMateOptions(
              props.keyField,
              props.childrenField,
              props.disabledField
            )
          )
        );
        const { value: initMergedValue } = mergedValueRef;
        const pendingNodeKeyRef = vue.ref(
          props.checkable ? null : Array.isArray(initMergedValue) && initMergedValue.length ? initMergedValue[initMergedValue.length - 1] : null
        );
        const mergedCascadeRef = vue.computed(() => {
          return props.multiple && props.cascade && props.checkable;
        });
        const uncontrolledExpandedKeysRef = vue.ref(
          props.defaultExpandAll ? void 0 : props.defaultExpandedKeys || props.expandedKeys
        );
        const controlledExpandedKeysRef = vue.toRef(props, "expandedKeys");
        const mergedExpandedKeysRef = useMergedState(
          controlledExpandedKeysRef,
          uncontrolledExpandedKeysRef
        );
        const focusedRef = vue.ref(false);
        const mergedPlaceholderRef = vue.computed(() => {
          const { placeholder } = props;
          if (placeholder !== void 0)
            return placeholder;
          return localeRef.value.placeholder;
        });
        const treeSelectedKeysRef = vue.computed(() => {
          if (props.checkable)
            return [];
          return treeCheckedKeysRef.value;
        });
        const treeCheckedKeysRef = vue.computed(() => {
          const { value: mergedValue } = mergedValueRef;
          if (props.multiple) {
            if (Array.isArray(mergedValue))
              return mergedValue;
            else
              return [];
          } else {
            if (mergedValue === null || Array.isArray(mergedValue))
              return [];
            else
              return [mergedValue];
          }
        });
        const selectedOptionRef = vue.computed(() => {
          const { multiple, showPath, separator, labelField } = props;
          if (multiple)
            return null;
          const { value: mergedValue } = mergedValueRef;
          if (!Array.isArray(mergedValue) && mergedValue !== null) {
            const { value: treeMate } = dataTreeMateRef;
            const tmNode = treeMate.getNode(mergedValue);
            if (tmNode !== null) {
              return showPath ? treeOption2SelectOptionWithPath(
                tmNode,
                treeMate.getPath(mergedValue).treeNodePath,
                separator,
                labelField
              ) : treeOption2SelectOption(tmNode, labelField);
            }
          }
          return null;
        });
        const selectedOptionsRef = vue.computed(() => {
          const { multiple, showPath, separator } = props;
          if (!multiple)
            return null;
          const { value: mergedValue } = mergedValueRef;
          if (Array.isArray(mergedValue)) {
            const res = [];
            const { value: treeMate } = dataTreeMateRef;
            const { checkedKeys } = treeMate.getCheckedKeys(mergedValue, {
              checkStrategy: props.checkStrategy,
              cascade: mergedCascadeRef.value,
              allowNotLoaded: props.allowCheckingNotLoaded
            });
            const { labelField } = props;
            checkedKeys.forEach((value) => {
              const tmNode = treeMate.getNode(value);
              if (tmNode !== null) {
                res.push(
                  showPath ? treeOption2SelectOptionWithPath(
                    tmNode,
                    treeMate.getPath(value).treeNodePath,
                    separator,
                    labelField
                  ) : treeOption2SelectOption(tmNode, labelField)
                );
              }
            });
            return res;
          }
          return [];
        });
        const menuPaddingRef = vue.computed(() => {
          const {
            self: { menuPadding }
          } = themeRef.value;
          return menuPadding;
        });
        function focusSelection() {
          triggerInstRef.value?.focus();
        }
        function focusSelectionInput() {
          triggerInstRef.value?.focusInput();
        }
        function doUpdateShow(value) {
          const { onUpdateShow, "onUpdate:show": _onUpdateShow } = props;
          if (onUpdateShow)
            call(onUpdateShow, value);
          if (_onUpdateShow)
            call(_onUpdateShow, value);
          uncontrolledShowRef.value = value;
        }
        function doUpdateValue(value, option) {
          const { onUpdateValue, "onUpdate:value": _onUpdateValue } = props;
          if (onUpdateValue)
            call(onUpdateValue, value, option);
          if (_onUpdateValue) {
            call(_onUpdateValue, value, option);
          }
          uncontrolledValueRef.value = value;
          nTriggerFormInput();
          nTriggerFormChange();
        }
        function doUpdateIndeterminateKeys(value, option) {
          const {
            onUpdateIndeterminateKeys,
            "onUpdate:indeterminateKeys": _onUpdateIndeterminateKeys
          } = props;
          if (onUpdateIndeterminateKeys) {
            call(onUpdateIndeterminateKeys, value, option);
          }
          if (_onUpdateIndeterminateKeys) {
            call(_onUpdateIndeterminateKeys, value, option);
          }
        }
        function doUpdateExpandedKeys(keys, option) {
          const {
            onUpdateExpandedKeys,
            "onUpdate:expandedKeys": _onUpdateExpandedKeys
          } = props;
          if (onUpdateExpandedKeys) {
            call(onUpdateExpandedKeys, keys, option);
          }
          if (_onUpdateExpandedKeys) {
            call(_onUpdateExpandedKeys, keys, option);
          }
          uncontrolledExpandedKeysRef.value = keys;
        }
        function doFocus(e) {
          const { onFocus } = props;
          if (onFocus)
            onFocus(e);
          nTriggerFormFocus();
        }
        function doBlur(e) {
          closeMenu();
          const { onBlur } = props;
          if (onBlur)
            onBlur(e);
          nTriggerFormBlur();
        }
        function closeMenu() {
          doUpdateShow(false);
        }
        function openMenu() {
          if (!mergedDisabledRef.value) {
            patternRef.value = "";
            doUpdateShow(true);
            if (props.filterable) {
              focusSelectionInput();
            }
          }
        }
        function handleMenuLeave() {
          patternRef.value = "";
        }
        function handleMenuClickoutside(e) {
          if (mergedShowRef.value) {
            if (!triggerInstRef.value?.$el.contains(
              getPreciseEventTarget(e)
            )) {
              closeMenu();
            }
          }
        }
        function handleTriggerClick() {
          if (mergedDisabledRef.value)
            return;
          if (!mergedShowRef.value) {
            openMenu();
          } else {
            if (!props.filterable) {
              closeMenu();
            }
          }
        }
        function getOptionsByKeys(keys) {
          const {
            value: { getNode }
          } = dataTreeMateRef;
          return keys.map((key) => getNode(key)?.rawNode || null);
        }
        function handleUpdateCheckedKeys(keys) {
          const options = getOptionsByKeys(keys);
          if (props.multiple) {
            doUpdateValue(keys, options);
          } else {
            keys.length ? doUpdateValue(keys[0], options[0] || null) : doUpdateValue(null, null);
            closeMenu();
            if (!props.filterable) {
              focusSelection();
            }
          }
          if (props.filterable) {
            focusSelectionInput();
            if (props.clearFilterAfterSelect)
              patternRef.value = "";
          }
        }
        function handleUpdateIndeterminateKeys(keys) {
          if (props.checkable) {
            doUpdateIndeterminateKeys(keys, getOptionsByKeys(keys));
          }
        }
        function handleTriggerFocus(e) {
          if (menuElRef.value?.contains(e.relatedTarget))
            return;
          focusedRef.value = true;
          doFocus(e);
        }
        function handleTriggerBlur(e) {
          if (menuElRef.value?.contains(e.relatedTarget))
            return;
          focusedRef.value = false;
          doBlur(e);
        }
        function handleMenuFocusin(e) {
          if (menuElRef.value?.contains(e.relatedTarget) || triggerInstRef.value?.$el?.contains(e.relatedTarget)) {
            return;
          }
          focusedRef.value = true;
          doFocus(e);
        }
        function handleMenuFocusout(e) {
          if (menuElRef.value?.contains(e.relatedTarget) || triggerInstRef.value?.$el?.contains(e.relatedTarget)) {
            return;
          }
          focusedRef.value = false;
          doBlur(e);
        }
        function handleClear(e) {
          e.stopPropagation();
          const { multiple } = props;
          if (!multiple && props.filterable) {
            closeMenu();
          }
          if (multiple) {
            doUpdateValue([], []);
          } else {
            doUpdateValue(null, null);
          }
        }
        function handleDeleteOption(option) {
          const { value: mergedValue } = mergedValueRef;
          if (Array.isArray(mergedValue)) {
            const { value: treeMate } = dataTreeMateRef;
            const { checkedKeys: checkedKeysValue } = treeMate.getCheckedKeys(
              mergedValue,
              {
                cascade: mergedCascadeRef.value,
                allowNotLoaded: props.allowCheckingNotLoaded
              }
            );
            const index = checkedKeysValue.findIndex((key) => key === option.value);
            if (~index) {
              if (props.checkable) {
                const { checkedKeys } = treeMate.uncheck(
                  option.value,
                  checkedKeysValue,
                  {
                    checkStrategy: props.checkStrategy,
                    cascade: mergedCascadeRef.value,
                    allowNotLoaded: props.allowCheckingNotLoaded
                  }
                );
                doUpdateValue(checkedKeys, getOptionsByKeys(checkedKeys));
              } else {
                const nextValue = Array.from(checkedKeysValue);
                nextValue.splice(index, 1);
                doUpdateValue(nextValue, getOptionsByKeys(nextValue));
              }
            }
          }
        }
        function handlePatternInput(e) {
          const { value } = e.target;
          patternRef.value = value;
        }
        function treeHandleKeydown(e) {
          const { value: treeInst } = treeInstRef;
          if (treeInst) {
            treeInst.handleKeydown(e);
          }
        }
        function handleKeydown(e) {
          if (e.key === "Enter") {
            if (mergedShowRef.value) {
              treeHandleKeydown(e);
              if (!props.multiple) {
                closeMenu();
                focusSelection();
              }
            } else {
              openMenu();
            }
            e.preventDefault();
          } else if (e.key === "Escape") {
            if (mergedShowRef.value) {
              markEventEffectPerformed(e);
              closeMenu();
              focusSelection();
            }
          } else {
            if (mergedShowRef.value) {
              treeHandleKeydown(e);
            } else if (e.key === "ArrowDown") {
              openMenu();
            }
          }
        }
        function handleTabOut() {
          closeMenu();
          focusSelection();
        }
        function handleMenuMousedown(e) {
          if (!happensIn(e, "action"))
            e.preventDefault();
        }
        const selectionRenderTagRef = vue.computed(() => {
          const { renderTag } = props;
          if (!renderTag)
            return void 0;
          return function selectionRenderTag({
            option,
            handleClose
          }) {
            const { value } = option;
            if (value !== void 0) {
              const treeOption = dataTreeMateRef.value.getNode(value);
              if (treeOption) {
                return renderTag({ option: treeOption.rawNode, handleClose });
              }
            }
            return value;
          };
        });
        vue.provide(treeSelectInjectionKey, {
          pendingNodeKeyRef,
          dataTreeMate: dataTreeMateRef
        });
        function handleTriggerOrMenuResize() {
          if (!mergedShowRef.value)
            return;
          followerInstRef.value?.syncPosition();
        }
        useOnResize(menuElRef, handleTriggerOrMenuResize);
        const themeRef = useTheme(
          "TreeSelect",
          "-tree-select",
          style$9,
          treeSelectLight$1,
          props,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self: {
              menuBoxShadow,
              menuBorderRadius,
              menuColor,
              menuHeight,
              actionPadding,
              actionDividerColor,
              actionTextColor
            }
          } = themeRef.value;
          return {
            "--n-menu-box-shadow": menuBoxShadow,
            "--n-menu-border-radius": menuBorderRadius,
            "--n-menu-color": menuColor,
            "--n-menu-height": menuHeight,
            "--n-bezier": cubicBezierEaseInOut,
            "--n-action-padding": actionPadding,
            "--n-action-text-color": actionTextColor,
            "--n-action-divider-color": actionDividerColor
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("tree-select", void 0, cssVarsRef, props) : void 0;
        return {
          menuElRef,
          mergedStatus: mergedStatusRef,
          triggerInstRef,
          followerInstRef,
          treeInstRef,
          mergedClsPrefix: mergedClsPrefixRef,
          mergedValue: mergedValueRef,
          mergedShow: mergedShowRef,
          namespace: namespaceRef,
          adjustedTo: useAdjustedTo(props),
          isMounted: isMounted(),
          focused: focusedRef,
          menuPadding: menuPaddingRef,
          mergedPlaceholder: mergedPlaceholderRef,
          mergedExpandedKeys: mergedExpandedKeysRef,
          treeSelectedKeys: treeSelectedKeysRef,
          treeCheckedKeys: treeCheckedKeysRef,
          mergedSize: mergedSizeRef,
          mergedDisabled: mergedDisabledRef,
          selectedOption: selectedOptionRef,
          selectedOptions: selectedOptionsRef,
          pattern: patternRef,
          pendingNodeKey: pendingNodeKeyRef,
          mergedCascade: mergedCascadeRef,
          mergedFilter: mergedFilterRef,
          selectionRenderTag: selectionRenderTagRef,
          handleTriggerOrMenuResize,
          doUpdateExpandedKeys,
          handleMenuLeave,
          handleTriggerClick,
          handleMenuClickoutside,
          handleUpdateCheckedKeys,
          handleUpdateIndeterminateKeys,
          handleTriggerFocus,
          handleTriggerBlur,
          handleMenuFocusin,
          handleMenuFocusout,
          handleClear,
          handleDeleteOption,
          handlePatternInput,
          handleKeydown,
          handleTabOut,
          handleMenuMousedown,
          mergedTheme: themeRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedTheme, mergedClsPrefix, $slots } = this;
        return /* @__PURE__ */ React.createElement("div", {
          class: `${mergedClsPrefix}-tree-select`
        }, /* @__PURE__ */ React.createElement(VBinder, null, {
          default: () => [
            /* @__PURE__ */ React.createElement(VTarget, null, {
              default: () => /* @__PURE__ */ React.createElement(NInternalSelection, {
                ref: "triggerInstRef",
                onResize: this.handleTriggerOrMenuResize,
                status: this.mergedStatus,
                focused: this.focused,
                clsPrefix: mergedClsPrefix,
                theme: mergedTheme.peers.InternalSelection,
                themeOverrides: mergedTheme.peerOverrides.InternalSelection,
                renderTag: this.selectionRenderTag,
                selectedOption: this.selectedOption,
                selectedOptions: this.selectedOptions,
                size: this.mergedSize,
                bordered: this.bordered,
                placeholder: this.mergedPlaceholder,
                disabled: this.mergedDisabled,
                active: this.mergedShow,
                loading: this.loading,
                multiple: this.multiple,
                maxTagCount: this.maxTagCount,
                showArrow: true,
                filterable: this.filterable,
                clearable: this.clearable,
                pattern: this.pattern,
                onPatternInput: this.handlePatternInput,
                onClear: this.handleClear,
                onClick: this.handleTriggerClick,
                onFocus: this.handleTriggerFocus,
                onBlur: this.handleTriggerBlur,
                onDeleteOption: this.handleDeleteOption,
                onKeydown: this.handleKeydown
              }, {
                arrow: () => [this.$slots.arrow?.()]
              })
            }),
            /* @__PURE__ */ React.createElement(VFollower, {
              ref: "followerInstRef",
              show: this.mergedShow,
              placement: this.placement,
              to: this.adjustedTo,
              teleportDisabled: this.adjustedTo === useAdjustedTo.tdkey,
              containerClass: this.namespace,
              width: this.consistentMenuWidth ? "target" : void 0,
              minWidth: "target"
            }, {
              default: () => /* @__PURE__ */ React.createElement(vue.Transition, {
                name: "fade-in-scale-up-transition",
                appear: this.isMounted,
                onLeave: this.handleMenuLeave
              }, {
                default: () => {
                  if (!this.mergedShow)
                    return null;
                  const {
                    mergedClsPrefix: mergedClsPrefix2,
                    checkable,
                    multiple,
                    menuProps,
                    options
                  } = this;
                  this.onRender?.();
                  return vue.withDirectives(
                    /* @__PURE__ */ React.createElement("div", {
                      ...menuProps,
                      class: [
                        `${mergedClsPrefix2}-tree-select-menu`,
                        menuProps?.class,
                        this.themeClass
                      ],
                      ref: "menuElRef",
                      style: [
                        menuProps?.style || "",
                        this.cssVars
                      ],
                      tabindex: 0,
                      onMousedown: this.handleMenuMousedown,
                      onKeydown: this.handleKeydown,
                      onFocusin: this.handleMenuFocusin,
                      onFocusout: this.handleMenuFocusout
                    }, /* @__PURE__ */ React.createElement(NTree, {
                      ref: "treeInstRef",
                      blockLine: true,
                      allowCheckingNotLoaded: this.allowCheckingNotLoaded,
                      showIrrelevantNodes: false,
                      animated: false,
                      pattern: this.pattern,
                      filter: this.mergedFilter,
                      data: options,
                      cancelable: multiple,
                      labelField: this.labelField,
                      keyField: this.keyField,
                      disabledField: this.disabledField,
                      childrenField: this.childrenField,
                      theme: mergedTheme.peers.Tree,
                      themeOverrides: mergedTheme.peerOverrides.Tree,
                      defaultExpandAll: this.defaultExpandAll,
                      defaultExpandedKeys: this.defaultExpandedKeys,
                      expandedKeys: this.mergedExpandedKeys,
                      checkedKeys: this.treeCheckedKeys,
                      selectedKeys: this.treeSelectedKeys,
                      checkable,
                      checkStrategy: this.checkStrategy,
                      cascade: this.mergedCascade,
                      leafOnly: this.leafOnly,
                      multiple: this.multiple,
                      renderLabel: this.renderLabel,
                      renderPrefix: this.renderPrefix,
                      renderSuffix: this.renderSuffix,
                      renderSwitcherIcon: this.renderSwitcherIcon,
                      nodeProps: this.nodeProps,
                      virtualScroll: this.consistentMenuWidth && this.virtualScroll,
                      internalTreeSelect: true,
                      internalUnifySelectCheck: true,
                      internalScrollable: true,
                      internalScrollablePadding: this.menuPadding,
                      internalFocusable: false,
                      internalCheckboxFocusable: false,
                      internalRenderEmpty: () => /* @__PURE__ */ React.createElement("div", {
                        class: `${mergedClsPrefix2}-tree-select-menu__empty`
                      }, resolveSlot($slots.empty, () => [
                        /* @__PURE__ */ React.createElement(NEmpty, {
                          theme: mergedTheme.peers.Empty,
                          themeOverrides: mergedTheme.peerOverrides.Empty
                        })
                      ])),
                      onLoad: this.onLoad,
                      onUpdateCheckedKeys: this.handleUpdateCheckedKeys,
                      onUpdateIndeterminateKeys: this.handleUpdateIndeterminateKeys,
                      onUpdateExpandedKeys: this.doUpdateExpandedKeys
                    }), resolveWrappedSlot($slots.action, (children) => {
                      return children ? /* @__PURE__ */ React.createElement("div", {
                        class: `${mergedClsPrefix2}-tree-select-menu__action`,
                        "data-action": true
                      }, children) : null;
                    }), /* @__PURE__ */ React.createElement(FocusDetector, {
                      onFocus: this.handleTabOut
                    })),
                    [
                      [
                        clickoutside$1,
                        this.handleMenuClickoutside,
                        void 0,
                        { capture: true }
                      ]
                    ]
                  );
                }
              })
            })
          ]
        }));
      }
    });

    var style$8 = cB("h", `
  font-size: var(--n-font-size);
  font-weight: var(--n-font-weight);
  margin: var(--n-margin);
  transition: color .3s var(--n-bezier);
  color: var(--n-text-color);
`, [c$1("&:first-child", {
      marginTop: 0
    }), cM("prefix-bar", {
      position: "relative",
      paddingLeft: "var(--n-prefix-width)"
    }, [cM("align-text", {
      paddingLeft: 0
    }, [c$1("&::before", {
      left: "calc(-1 * var(--n-prefix-width))"
    })]), c$1("&::before", `
      content: "";
      width: var(--n-bar-width);
      border-radius: calc(var(--n-bar-width) / 2);
      transition: background-color .3s var(--n-bezier);
      left: 0;
      top: 0;
      bottom: 0;
      position: absolute;
    `), c$1("&::before", {
      backgroundColor: "var(--n-bar-color)"
    })])]);

    const headerProps = { ...useTheme.props,
      type: {
        type: String,
        default: "default"
      },
      prefix: String,
      alignText: Boolean
    };
    var createHeader = (level => vue.defineComponent({
      name: `H${level}`,
      props: headerProps,

      setup(props) {
        const {
          mergedClsPrefixRef,
          inlineThemeDisabled
        } = useConfig(props);
        const themeRef = useTheme("Typography", "-h", style$8, typographyLight$1, props, mergedClsPrefixRef);
        const cssVarsRef = vue.computed(() => {
          const {
            type
          } = props;
          const {
            common: {
              cubicBezierEaseInOut
            },
            self: {
              headerFontWeight,
              headerTextColor,
              [createKey("headerPrefixWidth", level)]: prefixWidth,
              [createKey("headerFontSize", level)]: fontSize,
              [createKey("headerMargin", level)]: margin,
              [createKey("headerBarWidth", level)]: barWidth,
              [createKey("headerBarColor", type)]: barColor
            }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-font-size": fontSize,
            "--n-margin": margin,
            "--n-bar-color": barColor,
            "--n-bar-width": barWidth,
            "--n-font-weight": headerFontWeight,
            "--n-text-color": headerTextColor,
            "--n-prefix-width": prefixWidth
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(`h${level}`, vue.computed(() => props.type[0]), cssVarsRef, props) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle === null || themeClassHandle === void 0 ? void 0 : themeClassHandle.themeClass,
          onRender: themeClassHandle === null || themeClassHandle === void 0 ? void 0 : themeClassHandle.onRender
        };
      },

      render() {
        var _this$onRender;

        const {
          prefix,
          alignText,
          mergedClsPrefix,
          cssVars,
          $slots
        } = this;
        (_this$onRender = this.onRender) === null || _this$onRender === void 0 ? void 0 : _this$onRender.call(this);
        return vue.h(`h${level}`, {
          class: [`${mergedClsPrefix}-h`, `${mergedClsPrefix}-h${level}`, this.themeClass, {
            [`${mergedClsPrefix}-h--prefix-bar`]: prefix,
            [`${mergedClsPrefix}-h--align-text`]: alignText
          }],
          style: cssVars
        }, $slots);
      }

    }));

    const NH1 = createHeader("1");
    const NH2 = createHeader("2");
    const NH3 = createHeader("3");
    const NH4 = createHeader("4");
    const NH5 = createHeader("5");
    const NH6 = createHeader("6");

    var style$7 = cB("a", `
  cursor: pointer;
  transition:
    color .3s var(--n-bezier),
    text-decoration-color .3s var(--n-bezier);
  text-decoration-color: var(--n-text-color);
  color: var(--n-text-color);
`);

    const aProps = {
      ...useTheme.props
    };
    var a = vue.defineComponent({
      name: "A",
      props: aProps,
      setup(props) {
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Typography",
          "-a",
          style$7,
          typographyLight$1,
          props,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self: { aTextColor }
          } = themeRef.value;
          return {
            "--n-text-color": aTextColor,
            "--n-bezier": cubicBezierEaseInOut
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("a", void 0, cssVarsRef, props) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        this.onRender?.();
        return /* @__PURE__ */ React.createElement("a", {
          class: [`${this.mergedClsPrefix}-a`, this.themeClass],
          style: this.cssVars
        }, this.$slots);
      }
    });

    var style$6 = cB("p", `
  box-sizing: border-box;
  transition: color .3s var(--n-bezier);
  margin: var(--n-margin);
  font-size:  var(--n-font-size);
  line-height: var(--n-line-height);
  color: var(--n-text-color);
`, [c$1("&:first-child", "margin-top: 0;"), c$1("&:last-child", "margin-bottom: 0;")]);

    const pProps = {
      ...useTheme.props,
      depth: [String, Number]
    };
    var p = vue.defineComponent({
      name: "P",
      props: pProps,
      setup(props) {
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Typography",
          "-p",
          style$6,
          typographyLight$1,
          props,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const { depth } = props;
          const typeSafeDepth = depth || "1";
          const {
            common: { cubicBezierEaseInOut },
            self: {
              pFontSize,
              pLineHeight,
              pMargin,
              pTextColor,
              [`pTextColor${typeSafeDepth}Depth`]: depthTextColor
            }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-font-size": pFontSize,
            "--n-line-height": pLineHeight,
            "--n-margin": pMargin,
            "--n-text-color": depth === void 0 ? pTextColor : depthTextColor
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "p",
          vue.computed(() => `${props.depth || ""}`),
          cssVarsRef,
          props
        ) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        this.onRender?.();
        return /* @__PURE__ */ React.createElement("p", {
          class: [`${this.mergedClsPrefix}-p`, this.themeClass],
          style: this.cssVars
        }, this.$slots);
      }
    });

    var style$5 = cB("blockquote", `
  font-size: var(--n-font-size);
  line-height: var(--n-line-height);
  margin: 0;
  margin-top: 12px;
  margin-bottom: 12px;
  box-sizing: border-box;
  padding-left: 12px;
  border-left: 4px solid var(--n-prefix-color);
  color: var(--n-text-color);
  transition:
    color .3s var(--n-bezier),
    border-color .3s var(--n-bezier);
`, [c$1("&:first-child", {
      marginTop: 0
    }), c$1("&:last-child", {
      marginBottom: 0
    }), cM("align-text", {
      marginLeft: "-16px"
    })]);

    const blockquoteProps = {
      ...useTheme.props,
      alignText: Boolean
    };
    var blockquote = vue.defineComponent({
      name: "Blockquote",
      props: blockquoteProps,
      setup(props) {
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Typography",
          "-blockquote",
          style$5,
          typographyLight$1,
          props,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self: {
              blockquoteTextColor,
              blockquotePrefixColor,
              blockquoteLineHeight,
              blockquoteFontSize
            }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-font-size": blockquoteFontSize,
            "--n-line-height": blockquoteLineHeight,
            "--n-prefix-color": blockquotePrefixColor,
            "--n-text-color": blockquoteTextColor
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("blockquote", void 0, cssVarsRef, props) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedClsPrefix } = this;
        this.onRender?.();
        return /* @__PURE__ */ React.createElement("blockquote", {
          class: [
            `${mergedClsPrefix}-blockquote`,
            this.themeClass,
            this.alignText && `${mergedClsPrefix}-blockquote--align-text`
          ],
          style: this.cssVars
        }, this.$slots);
      }
    });

    var style$4 = cB("hr", `
  margin: 12px 0;
  transition: border-color .3s var(--n-bezier);
  border-left: none;
  border-right: none;
  border-bottom: none;
  border-top: 1px solid var(--n-color);
`);

    var hr = vue.defineComponent({
      name: "Hr",
      props: {
        ...useTheme.props
      },
      setup(props) {
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Typography",
          "-hr",
          style$4,
          typographyLight$1,
          props,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self: { hrColor }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-color": hrColor
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("hr", void 0, cssVarsRef, props) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        this.onRender?.();
        return /* @__PURE__ */ React.createElement("hr", {
          class: [`${this.mergedClsPrefix}-hr`, this.themeClass],
          style: this.cssVars
        });
      }
    });

    const liStyle = c$1("li", {
      transition: "color .3s var(--n-bezier)",
      lineHeight: "var(--n-line-height)",
      margin: "var(--n-li-margin)",
      marginBottom: 0,
      color: "var(--n-text-color)"
    });
    const childStyle = [c$1("&:first-child", `
    margin-top: 0;
  `), c$1("&:last-child", `
    margin-bottom: 0;
  `)];
    var style$3 = c$1([cB("ol", {
      fontSize: "var(--n-font-size)",
      padding: "var(--n-ol-padding)"
    }, [cM("align-text", {
      paddingLeft: 0
    }), liStyle, childStyle]), cB("ul", {
      fontSize: "var(--n-font-size)",
      padding: "var(--n-ul-padding)"
    }, [cM("align-text", {
      paddingLeft: 0
    }), liStyle, childStyle])]);

    const ulProps = {
      ...useTheme.props,
      alignText: Boolean
    };
    var ul = vue.defineComponent({
      name: "Ul",
      props: ulProps,
      setup(props) {
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Typography",
          "-xl",
          style$3,
          typographyLight$1,
          props,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self: {
              olPadding,
              ulPadding,
              liMargin,
              liTextColor,
              liLineHeight,
              liFontSize
            }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-font-size": liFontSize,
            "--n-line-height": liLineHeight,
            "--n-text-color": liTextColor,
            "--n-li-margin": liMargin,
            "--n-ol-padding": olPadding,
            "--n-ul-padding": ulPadding
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("ul", void 0, cssVarsRef, props) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedClsPrefix } = this;
        this.onRender?.();
        return /* @__PURE__ */ React.createElement("ul", {
          class: [
            `${mergedClsPrefix}-ul`,
            this.themeClass,
            this.alignText && `${mergedClsPrefix}-ul--align-text`
          ],
          style: this.cssVars
        }, this.$slots);
      }
    });

    const olProps = {
      ...useTheme.props,
      alignText: Boolean
    };
    var ol = vue.defineComponent({
      name: "Ol",
      props: olProps,
      setup(props) {
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Typography",
          "-xl",
          style$3,
          typographyLight$1,
          props,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self: {
              olPadding,
              ulPadding,
              liMargin,
              liTextColor,
              liLineHeight,
              liFontSize
            }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-font-size": liFontSize,
            "--n-line-height": liLineHeight,
            "--n-text-color": liTextColor,
            "--n-li-margin": liMargin,
            "--n-ol-padding": olPadding,
            "--n-ul-padding": ulPadding
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("ol", void 0, cssVarsRef, props) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedClsPrefix } = this;
        this.onRender?.();
        return /* @__PURE__ */ React.createElement("ol", {
          class: [
            `${mergedClsPrefix}-ol`,
            this.themeClass,
            this.alignText && `${mergedClsPrefix}-ol--align-text`
          ],
          style: this.cssVars
        }, this.$slots);
      }
    });

    var li = vue.defineComponent({
      name: "Li",
      render() {
        return /* @__PURE__ */ React.createElement("li", null, this.$slots);
      }
    });

    var style$2 = cB("text", `
  transition: color .3s var(--n-bezier);
  color: var(--n-text-color);
`, [cM("strong", `
    font-weight: var(--n-font-weight-strong);
  `), cM("italic", {
      fontStyle: "italic"
    }), cM("underline", {
      textDecoration: "underline"
    }), cM("code", `
    line-height: 1.4;
    display: inline-block;
    font-family: var(--n-font-famliy-mono);
    transition: 
      color .3s var(--n-bezier),
      border-color .3s var(--n-bezier),
      background-color .3s var(--n-bezier);
    box-sizing: border-box;
    padding: .05em .35em 0 .35em;
    border-radius: var(--n-code-border-radius);
    font-size: .9em;
    color: var(--n-code-text-color);
    background-color: var(--n-code-color);
    border: var(--n-code-border);
  `)]);

    const textProps = {
      ...useTheme.props,
      code: Boolean,
      type: {
        type: String,
        default: "default"
      },
      delete: Boolean,
      strong: Boolean,
      italic: Boolean,
      underline: Boolean,
      depth: [String, Number],
      tag: String,
      as: {
        type: String,
        validator: () => {
          {
            warn$2("text", "`as` is deprecated, please use `tag` instead.");
          }
          return true;
        },
        default: void 0
      }
    };
    var text = vue.defineComponent({
      name: "Text",
      props: textProps,
      setup(props) {
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Typography",
          "-text",
          style$2,
          typographyLight$1,
          props,
          mergedClsPrefixRef
        );
        const cssVarsRef = vue.computed(() => {
          const { depth, type } = props;
          const textColorKey = type === "default" ? depth === void 0 ? "textColor" : `textColor${depth}Depth` : createKey("textColor", type);
          const {
            common: { fontWeightStrong, fontFamilyMono, cubicBezierEaseInOut },
            self: {
              codeTextColor,
              codeBorderRadius,
              codeColor,
              codeBorder,
              [textColorKey]: textColor
            }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-text-color": textColor,
            "--n-font-weight-strong": fontWeightStrong,
            "--n-font-famliy-mono": fontFamilyMono,
            "--n-code-border-radius": codeBorderRadius,
            "--n-code-text-color": codeTextColor,
            "--n-code-color": codeColor,
            "--n-code-border": codeBorder
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass(
          "text",
          vue.computed(() => `${props.type[0]}${props.depth || ""}`),
          cssVarsRef,
          props
        ) : void 0;
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          compitableTag: useCompitable(props, ["as", "tag"]),
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender
        };
      },
      render() {
        const { mergedClsPrefix } = this;
        this.onRender?.();
        const textClass = [
          `${mergedClsPrefix}-text`,
          this.themeClass,
          {
            [`${mergedClsPrefix}-text--code`]: this.code,
            [`${mergedClsPrefix}-text--delete`]: this.delete,
            [`${mergedClsPrefix}-text--strong`]: this.strong,
            [`${mergedClsPrefix}-text--italic`]: this.italic,
            [`${mergedClsPrefix}-text--underline`]: this.underline
          }
        ];
        const children = this.$slots.default?.();
        return this.code ? /* @__PURE__ */ React.createElement("code", {
          class: textClass,
          style: this.cssVars
        }, this.delete ? /* @__PURE__ */ React.createElement("del", null, children) : children) : this.delete ? /* @__PURE__ */ React.createElement("del", {
          class: textClass,
          style: this.cssVars
        }, children) : vue.h(
          this.compitableTag || "span",
          { class: textClass, style: this.cssVars },
          children
        );
      }
    });

    const uploadInjectionKey = createInjectionKey("n-upload");

    const uploadDraggerKey = "__UPLOAD_DRAGGER__";
    var NUploadDragger = vue.defineComponent({
      name: "UploadDragger",
      [uploadDraggerKey]: true,
      setup(_, { slots }) {
        const NUpload = vue.inject(uploadInjectionKey, null);
        if (!NUpload) {
          throwError(
            "upload-dragger",
            "`n-upload-dragger` must be placed inside `n-upload`."
          );
        }
        return () => {
          const {
            mergedClsPrefixRef: { value: mergedClsPrefix },
            mergedDisabledRef: { value: mergedDisabled },
            maxReachedRef: { value: maxReached }
          } = NUpload;
          return /* @__PURE__ */ React.createElement("div", {
            class: [
              `${mergedClsPrefix}-upload-dragger`,
              (mergedDisabled || maxReached) && `${mergedClsPrefix}-upload-dragger--disabled`
            ]
          }, slots);
        };
      }
    });

    const isImageFileType = type => type.includes("image/");

    const getExtname = function () {
      let url = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "";
      const temp = url.split("/");
      const filename = temp[temp.length - 1];
      const filenameWithoutSuffix = filename.split(/#|\?/)[0];
      return (/\.[^./\\]*$/.exec(filenameWithoutSuffix) || [""])[0];
    };

    const isImageFile = file => {
      if (file.type) {
        return isImageFileType(file.type);
      }

      const url = file.thumbnailUrl || file.url || "";
      const extension = getExtname(url);

      if (/^data:image\//.test(url) || /(webp|svg|png|gif|jpg|jpeg|jfif|bmp|dpg|ico)$/i.test(extension)) {
        return true;
      }

      if (/^data:/.test(url)) {
        return false;
      }

      if (extension) {
        return false;
      }

      return true;
    };
    async function createImageDataUrl(file) {
      return await new Promise(resolve => {
        if (!file.type || !isImageFileType(file.type)) {
          resolve("");
          return;
        }

        resolve(window.URL.createObjectURL(file));
      });
    }
    const environmentSupportFile = isBrowser$2 && window.FileReader && window.File;
    function isFileSystemDirectoryEntry(item) {
      return item.isDirectory;
    }
    function isFileSystemFileEntry(item) {
      return item.isFile;
    }
    async function getFilesFromEntries(entries, directory) {
      const fileAndEntries = [];

      let _resolve;

      let requestCallbackCount = 0;

      function lock() {
        requestCallbackCount++;
      }

      function unlock() {
        requestCallbackCount--;

        if (!requestCallbackCount) {
          _resolve(fileAndEntries);
        }
      }

      function _getFilesFromEntries(entries2) {
        entries2.forEach(entry => {
          if (!entry) return;
          lock();

          if (directory && isFileSystemDirectoryEntry(entry)) {
            const directoryReader = entry.createReader();
            lock();
            directoryReader.readEntries(entries3 => {
              _getFilesFromEntries(entries3);

              unlock();
            }, () => {
              unlock();
            });
          } else if (isFileSystemFileEntry(entry)) {
            lock();
            entry.file(file => {
              fileAndEntries.push({
                file,
                entry,
                source: "dnd"
              });
              unlock();
            }, () => {
              unlock();
            });
          }

          unlock();
        });
      }

      await new Promise(resolve => {
        _resolve = resolve;

        _getFilesFromEntries(entries);
      });
      return fileAndEntries;
    }
    function createSettledFileInfo(fileInfo) {
      const {
        id,
        name,
        percentage,
        status,
        url,
        file,
        thumbnailUrl,
        type,
        fullPath,
        batchId
      } = fileInfo;
      return {
        id,
        name,
        percentage: percentage ?? null,
        status,
        url: url ?? null,
        file: file ?? null,
        thumbnailUrl: thumbnailUrl ?? null,
        type: type ?? null,
        fullPath: fullPath ?? null,
        batchId: batchId ?? null
      };
    }
    function matchType(name, mimeType, accept) {
      name = name.toLowerCase();
      mimeType = mimeType.toLocaleLowerCase();
      accept = accept.toLocaleLowerCase();
      const acceptAtoms = accept.split(",").map(acceptAtom => acceptAtom.trim()).filter(Boolean);
      return acceptAtoms.some(acceptAtom => {
        if (acceptAtom.startsWith(".")) {
          if (name.endsWith(acceptAtom)) return true;
        } else if (acceptAtom.includes("/")) {
          const [type, subtype] = mimeType.split("/");
          const [acceptType, acceptSubtype] = acceptAtom.split("/");

          if (acceptType === "*" || type && acceptType && acceptType === type) {
            if (acceptSubtype === "*" || subtype && acceptSubtype && acceptSubtype === subtype) {
              return true;
            }
          }
        } else {
          return true;
        }

        return false;
      });
    }
    const download = (url, name) => {
      if (!url) return;
      const a = document.createElement("a");
      a.href = url;

      if (name !== void 0) {
        a.download = name;
      }

      document.body.appendChild(a);
      a.click();
      document.body.removeChild(a);
    };

    var NUploadTrigger = vue.defineComponent({
      name: "UploadTrigger",
      props: {
        abstract: Boolean
      },
      setup(props, { slots }) {
        const NUpload = vue.inject(uploadInjectionKey, null);
        if (!NUpload) {
          throwError(
            "upload-trigger",
            "`n-upload-trigger` must be placed inside `n-upload`."
          );
        }
        const {
          mergedClsPrefixRef,
          mergedDisabledRef,
          maxReachedRef,
          listTypeRef,
          dragOverRef,
          openOpenFileDialog,
          draggerInsideRef,
          handleFileAddition,
          mergedDirectoryDndRef,
          triggerStyleRef
        } = NUpload;
        const isImageCardTypeRef = vue.computed(
          () => listTypeRef.value === "image-card"
        );
        function handleTriggerClick() {
          if (mergedDisabledRef.value || maxReachedRef.value)
            return;
          openOpenFileDialog();
        }
        function handleTriggerDragOver(e) {
          e.preventDefault();
          dragOverRef.value = true;
        }
        function handleTriggerDragEnter(e) {
          e.preventDefault();
          dragOverRef.value = true;
        }
        function handleTriggerDragLeave(e) {
          e.preventDefault();
          dragOverRef.value = false;
        }
        function handleTriggerDrop(e) {
          e.preventDefault();
          if (!draggerInsideRef.value || mergedDisabledRef.value || maxReachedRef.value) {
            dragOverRef.value = false;
            return;
          }
          const dataTransferItems = e.dataTransfer?.items;
          if (dataTransferItems?.length) {
            void getFilesFromEntries(
              Array.from(dataTransferItems).map((item) => item.webkitGetAsEntry()),
              mergedDirectoryDndRef.value
            ).then((files) => {
              handleFileAddition(files);
            }).finally(() => {
              dragOverRef.value = false;
            });
          } else {
            dragOverRef.value = false;
          }
        }
        return () => {
          const { value: mergedClsPrefix } = mergedClsPrefixRef;
          return props.abstract ? slots.default?.({
            handleClick: handleTriggerClick,
            handleDrop: handleTriggerDrop,
            handleDragOver: handleTriggerDragOver,
            handleDragEnter: handleTriggerDragEnter,
            handleDragLeave: handleTriggerDragLeave
          }) : /* @__PURE__ */ React.createElement("div", {
            class: [
              `${mergedClsPrefix}-upload-trigger`,
              (mergedDisabledRef.value || maxReachedRef.value) && `${mergedClsPrefix}-upload-trigger--disabled`,
              isImageCardTypeRef.value && `${mergedClsPrefix}-upload-trigger--image-card`
            ],
            style: triggerStyleRef.value,
            onClick: handleTriggerClick,
            onDrop: handleTriggerDrop,
            onDragover: handleTriggerDragOver,
            onDragenter: handleTriggerDragEnter,
            onDragleave: handleTriggerDragLeave
          }, isImageCardTypeRef.value ? /* @__PURE__ */ React.createElement(NUploadDragger, null, {
            default: () => resolveSlot(slots.default, () => [
              /* @__PURE__ */ React.createElement(NBaseIcon, {
                clsPrefix: mergedClsPrefix
              }, { default: () => /* @__PURE__ */ React.createElement(AddIcon, null) })
            ])
          }) : slots);
        };
      }
    });

    var NUploadProgress = vue.defineComponent({
      name: "UploadProgress",
      props: {
        show: Boolean,
        percentage: {
          type: Number,
          required: true
        },
        status: {
          type: String,
          required: true
        }
      },
      setup() {
        const NUpload = vue.inject(uploadInjectionKey);
        return {
          mergedTheme: NUpload.mergedThemeRef
        };
      },
      render() {
        return /* @__PURE__ */ React.createElement(NFadeInExpandTransition, null, {
          default: () => this.show ? /* @__PURE__ */ React.createElement(NProgress, {
            type: "line",
            showIndicator: false,
            percentage: this.percentage,
            status: this.status,
            height: 2,
            theme: this.mergedTheme.peers.Progress,
            themeOverrides: this.mergedTheme.peerOverrides.Progress
          }) : null
        });
      }
    });

    const imageIcon = /* @__PURE__ */ React.createElement("svg", {
      xmlns: "http://www.w3.org/2000/svg",
      viewBox: "0 0 28 28"
    }, /* @__PURE__ */ React.createElement("g", {
      fill: "none"
    }, /* @__PURE__ */ React.createElement("path", {
      d: "M21.75 3A3.25 3.25 0 0 1 25 6.25v15.5A3.25 3.25 0 0 1 21.75 25H6.25A3.25 3.25 0 0 1 3 21.75V6.25A3.25 3.25 0 0 1 6.25 3h15.5zm.583 20.4l-7.807-7.68a.75.75 0 0 0-.968-.07l-.084.07l-7.808 7.68c.183.065.38.1.584.1h15.5c.204 0 .4-.035.583-.1l-7.807-7.68l7.807 7.68zM21.75 4.5H6.25A1.75 1.75 0 0 0 4.5 6.25v15.5c0 .208.036.408.103.593l7.82-7.692a2.25 2.25 0 0 1 3.026-.117l.129.117l7.82 7.692c.066-.185.102-.385.102-.593V6.25a1.75 1.75 0 0 0-1.75-1.75zm-3.25 3a2.5 2.5 0 1 1 0 5a2.5 2.5 0 0 1 0-5zm0 1.5a1 1 0 1 0 0 2a1 1 0 0 0 0-2z",
      fill: "currentColor"
    })));
    const documentIcon = /* @__PURE__ */ React.createElement("svg", {
      xmlns: "http://www.w3.org/2000/svg",
      viewBox: "0 0 28 28"
    }, /* @__PURE__ */ React.createElement("g", {
      fill: "none"
    }, /* @__PURE__ */ React.createElement("path", {
      d: "M6.4 2A2.4 2.4 0 0 0 4 4.4v19.2A2.4 2.4 0 0 0 6.4 26h15.2a2.4 2.4 0 0 0 2.4-2.4V11.578c0-.729-.29-1.428-.805-1.944l-6.931-6.931A2.4 2.4 0 0 0 14.567 2H6.4zm-.9 2.4a.9.9 0 0 1 .9-.9H14V10a2 2 0 0 0 2 2h6.5v11.6a.9.9 0 0 1-.9.9H6.4a.9.9 0 0 1-.9-.9V4.4zm16.44 6.1H16a.5.5 0 0 1-.5-.5V4.06l6.44 6.44z",
      fill: "currentColor"
    })));

    const buttonThemeOverrides = {
      paddingMedium: "0 3px",
      heightMedium: "24px",
      iconSizeMedium: "18px"
    };
    var NUploadFile = vue.defineComponent({
      name: "UploadFile",
      props: {
        clsPrefix: {
          type: String,
          required: true
        },
        file: {
          type: Object,
          required: true
        },
        listType: {
          type: String,
          required: true
        }
      },
      setup(props) {
        const NUpload = vue.inject(uploadInjectionKey);
        const imageRef = vue.ref(null);
        const thumbnailUrlRef = vue.ref("");
        const progressStatusRef = vue.computed(() => {
          const { file } = props;
          if (file.status === "finished")
            return "success";
          if (file.status === "error")
            return "error";
          return "info";
        });
        const buttonTypeRef = vue.computed(() => {
          const { file } = props;
          if (file.status === "error")
            return "error";
          return void 0;
        });
        const showProgressRef = vue.computed(() => {
          const { file } = props;
          return file.status === "uploading";
        });
        const showCancelButtonRef = vue.computed(() => {
          if (!NUpload.showCancelButtonRef.value)
            return false;
          const { file } = props;
          return ["uploading", "pending", "error"].includes(file.status);
        });
        const showRemoveButtonRef = vue.computed(() => {
          if (!NUpload.showRemoveButtonRef.value)
            return false;
          const { file } = props;
          return ["finished"].includes(file.status);
        });
        const showDownloadButtonRef = vue.computed(() => {
          if (!NUpload.showDownloadButtonRef.value)
            return false;
          const { file } = props;
          return ["finished"].includes(file.status);
        });
        const showRetryButtonRef = vue.computed(() => {
          if (!NUpload.showRetryButtonRef.value)
            return false;
          const { file } = props;
          return ["error"].includes(file.status);
        });
        const mergedThumbnailUrlRef = useMemo(() => {
          return thumbnailUrlRef.value || props.file.thumbnailUrl || props.file.url;
        });
        const showPreviewButtonRef = vue.computed(() => {
          if (!NUpload.showPreviewButtonRef.value)
            return false;
          const {
            file: { status },
            listType
          } = props;
          return ["finished"].includes(status) && mergedThumbnailUrlRef.value && listType === "image-card";
        });
        function handleRetryClick() {
          NUpload.submit(props.file.id);
        }
        function handleRemoveOrCancelClick(e) {
          e.preventDefault();
          const { file } = props;
          if (["finished", "pending", "error"].includes(file.status)) {
            handleRemove(file);
          } else if (["uploading"].includes(file.status)) {
            handleAbort(file);
          } else {
            warn$2("upload", "The button clicked type is unknown.");
          }
        }
        function handleDownloadClick(e) {
          e.preventDefault();
          handleDownload(props.file);
        }
        function handleRemove(file) {
          const {
            xhrMap,
            doChange,
            onRemoveRef: { value: onRemove },
            mergedFileListRef: { value: mergedFileList }
          } = NUpload;
          void Promise.resolve(
            onRemove ? onRemove({
              file: Object.assign({}, file),
              fileList: mergedFileList
            }) : true
          ).then((result) => {
            if (result === false)
              return;
            const fileAfterChange = Object.assign({}, file, {
              status: "removed"
            });
            xhrMap.delete(file.id);
            doChange(fileAfterChange, void 0, {
              remove: true
            });
          });
        }
        function handleDownload(file) {
          const {
            onDownloadRef: { value: onDownload }
          } = NUpload;
          void Promise.resolve(
            onDownload ? onDownload(Object.assign({}, file)) : true
          ).then((res) => {
            if (res !== false) {
              download(file.url, file.name);
            }
          });
        }
        function handleAbort(file) {
          const { xhrMap } = NUpload;
          const xhr = xhrMap.get(file.id);
          xhr?.abort();
          handleRemove(Object.assign({}, file));
        }
        function handlePreviewClick() {
          const {
            onPreviewRef: { value: onPreview }
          } = NUpload;
          if (onPreview) {
            onPreview(props.file);
          } else if (props.listType === "image-card") {
            const { value } = imageRef;
            if (!value)
              return;
            value.click();
          }
        }
        const deriveFileThumbnailUrl = async () => {
          const { listType } = props;
          if (listType !== "image" && listType !== "image-card") {
            return;
          }
          if (!environmentSupportFile || !(props.file.file instanceof File)) {
            return;
          }
          thumbnailUrlRef.value = await NUpload.getFileThumbnailUrl(props.file);
        };
        vue.watchEffect(() => {
          void deriveFileThumbnailUrl();
        });
        return {
          mergedTheme: NUpload.mergedThemeRef,
          progressStatus: progressStatusRef,
          buttonType: buttonTypeRef,
          showProgress: showProgressRef,
          disabled: NUpload.mergedDisabledRef,
          showCancelButton: showCancelButtonRef,
          showRemoveButton: showRemoveButtonRef,
          showDownloadButton: showDownloadButtonRef,
          showRetryButton: showRetryButtonRef,
          showPreviewButton: showPreviewButtonRef,
          mergedThumbnailUrl: mergedThumbnailUrlRef,
          imageRef,
          handleRemoveOrCancelClick,
          handleDownloadClick,
          handleRetryClick,
          handlePreviewClick
        };
      },
      render() {
        const { clsPrefix, mergedTheme, listType, file } = this;
        let icon;
        const isImageType = listType === "image";
        const isImageCardType = listType === "image-card";
        if (isImageType || isImageCardType) {
          icon = !isImageFile(file) ? /* @__PURE__ */ React.createElement("span", {
            class: `${clsPrefix}-upload-file-info__thumbnail`
          }, /* @__PURE__ */ React.createElement(NBaseIcon, {
            clsPrefix
          }, { default: () => documentIcon })) : this.mergedThumbnailUrl && file.status !== "error" ? /* @__PURE__ */ React.createElement("a", {
            rel: "noopener noreferer",
            target: "_blank",
            href: file.url || void 0,
            class: `${clsPrefix}-upload-file-info__thumbnail`,
            onClick: this.handlePreviewClick
          }, listType === "image-card" ? /* @__PURE__ */ React.createElement(NImage, {
            src: this.mergedThumbnailUrl || void 0,
            previewSrc: file.url || void 0,
            alt: file.name,
            ref: "imageRef"
          }) : /* @__PURE__ */ React.createElement("img", {
            src: this.mergedThumbnailUrl || void 0,
            alt: file.name
          })) : /* @__PURE__ */ React.createElement("span", {
            class: `${clsPrefix}-upload-file-info__thumbnail`
          }, /* @__PURE__ */ React.createElement(NBaseIcon, {
            clsPrefix
          }, { default: () => imageIcon }));
        } else {
          icon = /* @__PURE__ */ React.createElement("span", {
            class: `${clsPrefix}-upload-file-info__thumbnail`
          }, /* @__PURE__ */ React.createElement(NBaseIcon, {
            clsPrefix
          }, { default: () => /* @__PURE__ */ React.createElement(AttachIcon, null) }));
        }
        const progress = /* @__PURE__ */ React.createElement(NUploadProgress, {
          show: this.showProgress,
          percentage: file.percentage || 0,
          status: this.progressStatus
        });
        const showName = listType === "text" || listType === "image";
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${clsPrefix}-upload-file`,
            `${clsPrefix}-upload-file--${this.progressStatus}-status`,
            file.url && file.status !== "error" && listType !== "image-card" && `${clsPrefix}-upload-file--with-url`,
            `${clsPrefix}-upload-file--${listType}-type`
          ]
        }, /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-upload-file-info`
        }, icon, /* @__PURE__ */ React.createElement("div", {
          class: `${clsPrefix}-upload-file-info__name`
        }, showName && (file.url && file.status !== "error" ? /* @__PURE__ */ React.createElement("a", {
          rel: "noopener noreferer",
          target: "_blank",
          href: file.url || void 0,
          onClick: this.handlePreviewClick
        }, file.name) : /* @__PURE__ */ React.createElement("span", {
          onClick: this.handlePreviewClick
        }, file.name)), isImageType && progress), /* @__PURE__ */ React.createElement("div", {
          class: [
            `${clsPrefix}-upload-file-info__action`,
            `${clsPrefix}-upload-file-info__action--${listType}-type`
          ]
        }, this.showPreviewButton ? /* @__PURE__ */ React.createElement(NButton, {
          key: "preview",
          quaternary: true,
          type: this.buttonType,
          onClick: this.handlePreviewClick,
          theme: mergedTheme.peers.Button,
          themeOverrides: mergedTheme.peerOverrides.Button,
          builtinThemeOverrides: buttonThemeOverrides
        }, {
          icon: () => /* @__PURE__ */ React.createElement(NBaseIcon, {
            clsPrefix
          }, { default: () => /* @__PURE__ */ React.createElement(EyeIcon, null) })
        }) : null, (this.showRemoveButton || this.showCancelButton) && !this.disabled && /* @__PURE__ */ React.createElement(NButton, {
          key: "cancelOrTrash",
          theme: mergedTheme.peers.Button,
          themeOverrides: mergedTheme.peerOverrides.Button,
          quaternary: true,
          builtinThemeOverrides: buttonThemeOverrides,
          type: this.buttonType,
          onClick: this.handleRemoveOrCancelClick
        }, {
          icon: () => /* @__PURE__ */ React.createElement(NIconSwitchTransition, null, {
            default: () => this.showRemoveButton ? /* @__PURE__ */ React.createElement(NBaseIcon, {
              clsPrefix,
              key: "trash"
            }, { default: () => /* @__PURE__ */ React.createElement(TrashIcon, null) }) : /* @__PURE__ */ React.createElement(NBaseIcon, {
              clsPrefix,
              key: "cancel"
            }, { default: () => /* @__PURE__ */ React.createElement(CancelIcon, null) })
          })
        }), this.showRetryButton && !this.disabled && /* @__PURE__ */ React.createElement(NButton, {
          key: "retry",
          quaternary: true,
          type: this.buttonType,
          onClick: this.handleRetryClick,
          theme: mergedTheme.peers.Button,
          themeOverrides: mergedTheme.peerOverrides.Button,
          builtinThemeOverrides: buttonThemeOverrides
        }, {
          icon: () => /* @__PURE__ */ React.createElement(NBaseIcon, {
            clsPrefix
          }, { default: () => /* @__PURE__ */ React.createElement(RetryIcon, null) })
        }), this.showDownloadButton ? /* @__PURE__ */ React.createElement(NButton, {
          key: "download",
          quaternary: true,
          type: this.buttonType,
          onClick: this.handleDownloadClick,
          theme: mergedTheme.peers.Button,
          themeOverrides: mergedTheme.peerOverrides.Button,
          builtinThemeOverrides: buttonThemeOverrides
        }, {
          icon: () => /* @__PURE__ */ React.createElement(NBaseIcon, {
            clsPrefix
          }, { default: () => /* @__PURE__ */ React.createElement(DownloadIcon, null) })
        }) : null)), !isImageType && progress);
      }
    });

    var NUploadFileList = vue.defineComponent({
      name: "UploadFileList",
      setup(_, { slots }) {
        const NUpload = vue.inject(uploadInjectionKey, null);
        if (!NUpload) {
          throwError(
            "upload-file-list",
            "`n-upload-file-list` must be placed inside `n-upload`."
          );
        }
        const {
          abstractRef,
          mergedClsPrefixRef,
          listTypeRef,
          mergedFileListRef,
          fileListStyleRef,
          cssVarsRef,
          themeClassRef,
          maxReachedRef,
          showTriggerRef,
          imageGroupPropsRef
        } = NUpload;
        const isImageCardTypeRef = vue.computed(
          () => listTypeRef.value === "image-card"
        );
        const renderFileList = () => mergedFileListRef.value.map((file) => /* @__PURE__ */ React.createElement(NUploadFile, {
          clsPrefix: mergedClsPrefixRef.value,
          key: file.id,
          file,
          listType: listTypeRef.value
        }));
        const renderUploadFileList = () => isImageCardTypeRef.value ? /* @__PURE__ */ React.createElement(NImageGroup, {
          ...imageGroupPropsRef.value
        }, { default: renderFileList }) : /* @__PURE__ */ React.createElement(NFadeInExpandTransition, {
          group: true
        }, {
          default: renderFileList
        });
        return () => {
          const { value: mergedClsPrefix } = mergedClsPrefixRef;
          const { value: abstract } = abstractRef;
          return /* @__PURE__ */ React.createElement("div", {
            class: [
              `${mergedClsPrefix}-upload-file-list`,
              isImageCardTypeRef.value && `${mergedClsPrefix}-upload-file-list--grid`,
              abstract ? themeClassRef?.value : void 0
            ],
            style: [
              abstract && cssVarsRef ? cssVarsRef.value : "",
              fileListStyleRef.value
            ]
          }, renderUploadFileList(), showTriggerRef.value && !maxReachedRef.value && isImageCardTypeRef.value && /* @__PURE__ */ React.createElement(NUploadTrigger, null, slots));
        };
      }
    });

    var style$1 = c$1([cB("upload", "width: 100%;", [cM("dragger-inside", [cB("upload-trigger", `
        display: block;
      `)]), cM("drag-over", [cB("upload-dragger", `
        border: var(--n-dragger-border-hover);
      `)])]), cB("upload-dragger", `
    cursor: pointer;
    box-sizing: border-box;
    width: 100%;
    text-align: center;
    border-radius: var(--n-border-radius);
    padding: 24px;
    opacity: 1;
    transition:
      opacity .3s var(--n-bezier),
      border-color .3s var(--n-bezier),
      background-color .3s var(--n-bezier);
    background-color: var(--n-dragger-color);
    border: var(--n-dragger-border);
  `, [c$1("&:hover", `
      border: var(--n-dragger-border-hover);
    `), cM("disabled", `
      cursor: not-allowed;
    `)]), cB("upload-trigger", `
    display: inline-block;
    box-sizing: border-box;
    opacity: 1;
    transition: opacity .3s var(--n-bezier);
  `, [c$1("+", [cB("upload-file-list", "margin-top: 8px;")]), cM("disabled", `
      opacity: var(--n-item-disabled-opacity);
      cursor: not-allowed;
    `), cM("image-card", `
      width: 96px;
      height: 96px;
    `, [cB("base-icon", `
        font-size: 24px;
      `), cB("upload-dragger", `
        padding: 0;
        height: 100%;
        width: 100%;
        display: flex;
        align-items: center;
        justify-content: center;
      `)])]), cB("upload-file-list", `
    line-height: var(--n-line-height);
    opacity: 1;
    transition: opacity .3s var(--n-bezier);
  `, [c$1("a, img", "outline: none;"), cM("disabled", `
      opacity: var(--n-item-disabled-opacity);
      cursor: not-allowed;
    `, [cB("upload-file", "cursor: not-allowed;")]), cM("grid", `
      display: grid;
      grid-template-columns: repeat(auto-fill, 96px);
      grid-gap: 8px;
      margin-top: 0;
    `), cB("upload-file", `
      display: block;
      box-sizing: border-box;
      cursor: default;
      padding: 0px 12px 0 6px;
      transition: background-color .3s  var(--n-bezier);
      border-radius: var(--n-border-radius);
    `, [fadeInHeightExpandTransition(), cB("progress", [fadeInHeightExpandTransition({
      foldPadding: true
    })]), c$1("&:hover", `
        background-color: var(--n-item-color-hover);
      `, [cB("upload-file-info", [cE("action", `
            opacity: 1;
          `)])]), cM("image-type", `
        border-radius: var(--n-border-radius);
        text-decoration: underline;
        text-decoration-color: #0000;
      `, [cB("upload-file-info", `
          padding-top: 0px;
          padding-bottom: 0px;
          width: 100%;
          height: 100%;
          display: flex;
          justify-content: space-between;
          align-items: center;
          padding: 6px 0;
        `, [cB("progress", `
            padding: 2px 0;
            margin-bottom: 0;
          `), cE("name", `
            padding: 0 8px;
          `), cE("thumbnail", `
            width: 32px;
            height: 32px;
            font-size: 28px;
            display: flex;
            justify-content: center;
            align-items: center;
          `, [c$1("img", `
              width: 100%;
            `)])])]), cM("text-type", [cB("progress", `
          box-sizing: border-box;
          padding-bottom: 6px;
          margin-bottom: 6px;
        `)]), cM("image-card-type", `
        position: relative;
        width: 96px;
        height: 96px;
        border: var(--n-item-border-image-card);
        border-radius: var(--n-border-radius);
        padding: 0;
        display: flex;
        align-items: center;
        justify-content: center;
        transition: border-color .3s var(--n-bezier), background-color .3s var(--n-bezier);
        border-radius: var(--n-border-radius);
        overflow: hidden;
      `, [cB("progress", `
          position: absolute;
          left: 8px;
          bottom: 8px;
          right: 8px;
          width: unset;
        `), cB("upload-file-info", `
          padding: 0;
          width: 100%;
          height: 100%;
        `, [cE("thumbnail", `
            width: 100%;
            height: 100%;
            display: flex;
            flex-direction: column;
            align-items: center;
            justify-content: center;
            font-size: 36px;
          `, [c$1("img", `
              width: 100%;
            `)])]), c$1("&::before", `
          position: absolute;
          z-index: 1;
          left: 0;
          right: 0;
          top: 0;
          bottom: 0;
          border-radius: inherit;
          opacity: 0;
          transition: opacity .2s var(--n-bezier);
          content: "";
        `), c$1("&:hover", [c$1("&::before", "opacity: 1;"), cB("upload-file-info", [cE("thumbnail", "opacity: .12;")])])]), cM("error-status", [c$1("&:hover", `
          background-color: var(--n-item-color-hover-error);
        `), cB("upload-file-info", [cE("name", "color: var(--n-item-text-color-error);"), cE("thumbnail", "color: var(--n-item-text-color-error);")]), cM("image-card-type", `
          border: var(--n-item-border-image-card-error);
        `)]), cM("with-url", `
        cursor: pointer;
      `, [cB("upload-file-info", [cE("name", `
            color: var(--n-item-text-color-success);
            text-decoration-color: var(--n-item-text-color-success);
          `, [c$1("a", `
              text-decoration: underline;
            `)])])]), cB("upload-file-info", `
        position: relative;
        padding-top: 6px;
        padding-bottom: 6px;
        display: flex;
        flex-wrap: nowrap;
      `, [cE("thumbnail", `
          font-size: 18px;
          opacity: 1;
          transition: opacity .2s var(--n-bezier);
          color: var(--n-item-icon-color);
        `, [cB("base-icon", `
            margin-right: 2px;
            vertical-align: middle;
            transition: color .3s var(--n-bezier);
          `)]), cE("action", `
          padding-top: inherit;
          padding-bottom: inherit;
          position: absolute;
          right: 0;
          top: 0;
          bottom: 0;
          width: 80px;
          display: flex;
          align-items: center;
          transition: opacity .2s var(--n-bezier);
          justify-content: flex-end;
          opacity: 0;
        `, [cB("button", [c$1("&:not(:last-child)", {
      marginRight: "4px"
    }), cB("base-icon", [c$1("svg", [iconSwitchTransition()])])]), cM("image-type", `
            position: relative;
            max-width: 80px;
            width: auto;
          `), cM("image-card-type", `
            z-index: 2;
            position: absolute;
            width: 100%;
            height: 100%;
            left: 0;
            right: 0;
            bottom: 0;
            top: 0;
            display: flex;
            justify-content: center;
            align-items: center;
          `)]), cE("name", `
          color: var(--n-item-text-color);
          flex: 1;
          display: flex;
          justify-content: center;
          text-overflow: ellipsis;
          overflow: hidden;
          flex-direction: column;
          text-decoration-color: #0000;
          font-size: var(--n-font-size);
          transition:
            color .3s var(--n-bezier),
            text-decoration-color .3s var(--n-bezier); 
        `, [c$1("a", `
            color: inherit;
            text-decoration: underline;
          `)])])])]), cB("upload-file-input", `
    display: block;
    width: 0;
    height: 0;
    opacity: 0;
  `)]);

    function createXhrHandlers(inst, file, xhr) {
      const { doChange, xhrMap } = inst;
      let percentage = 0;
      function handleXHRError(e) {
        let fileAfterChange = Object.assign({}, file, {
          status: "error",
          percentage
        });
        xhrMap.delete(file.id);
        fileAfterChange = createSettledFileInfo(
          inst.onError?.({ file: fileAfterChange, event: e }) || fileAfterChange
        );
        doChange(fileAfterChange, e);
      }
      function handleXHRLoad(e) {
        if (inst.isErrorState) {
          if (inst.isErrorState(xhr)) {
            handleXHRError(e);
            return;
          }
        } else {
          if (xhr.status < 200 || xhr.status >= 300) {
            handleXHRError(e);
            return;
          }
        }
        let fileAfterChange = Object.assign({}, file, {
          status: "finished",
          percentage,
          file: null
        });
        xhrMap.delete(file.id);
        fileAfterChange = createSettledFileInfo(
          inst.onFinish?.({ file: fileAfterChange, event: e }) || fileAfterChange
        );
        doChange(fileAfterChange, e);
      }
      return {
        handleXHRLoad,
        handleXHRError,
        handleXHRAbort(e) {
          const fileAfterChange = Object.assign({}, file, {
            status: "removed",
            file: null,
            percentage
          });
          xhrMap.delete(file.id);
          doChange(fileAfterChange, e);
        },
        handleXHRProgress(e) {
          const fileAfterChange = Object.assign({}, file, {
            status: "uploading"
          });
          if (e.lengthComputable) {
            const progress = Math.ceil(e.loaded / e.total * 100);
            fileAfterChange.percentage = progress;
            percentage = progress;
          }
          doChange(fileAfterChange, e);
        }
      };
    }
    function customSubmitImpl(options) {
      const { inst, file, data, headers, withCredentials, action, customRequest } = options;
      const { doChange } = options.inst;
      let percentage = 0;
      customRequest({
        file,
        data,
        headers,
        withCredentials,
        action,
        onProgress(event) {
          const fileAfterChange = Object.assign({}, file, {
            status: "uploading"
          });
          const progress = event.percent;
          fileAfterChange.percentage = progress;
          percentage = progress;
          doChange(fileAfterChange);
        },
        onFinish() {
          let fileAfterChange = Object.assign({}, file, {
            status: "finished",
            percentage,
            file: null
          });
          fileAfterChange = createSettledFileInfo(
            inst.onFinish?.({ file: fileAfterChange }) || fileAfterChange
          );
          doChange(fileAfterChange);
        },
        onError() {
          let fileAfterChange = Object.assign({}, file, {
            status: "error",
            percentage
          });
          fileAfterChange = createSettledFileInfo(
            inst.onError?.({ file: fileAfterChange }) || fileAfterChange
          );
          doChange(fileAfterChange);
        }
      });
    }
    function registerHandler(inst, file, request) {
      const handlers = createXhrHandlers(inst, file, request);
      request.onabort = handlers.handleXHRAbort;
      request.onerror = handlers.handleXHRError;
      request.onload = handlers.handleXHRLoad;
      if (request.upload) {
        request.upload.onprogress = handlers.handleXHRProgress;
      }
    }
    function unwrapFunctionValue(data, file) {
      if (typeof data === "function") {
        return data({ file });
      }
      if (data)
        return data;
      return {};
    }
    function setHeaders(request, headers, file) {
      const headersObject = unwrapFunctionValue(headers, file);
      if (!headersObject)
        return;
      Object.keys(headersObject).forEach((key) => {
        request.setRequestHeader(key, headersObject[key]);
      });
    }
    function appendData(formData, data, file) {
      const dataObject = unwrapFunctionValue(data, file);
      if (!dataObject)
        return;
      Object.keys(dataObject).forEach((key) => {
        formData.append(key, dataObject[key]);
      });
    }
    function submitImpl(inst, fieldName, file, {
      method,
      action,
      withCredentials,
      headers,
      data
    }) {
      const request = new XMLHttpRequest();
      inst.xhrMap.set(file.id, request);
      request.withCredentials = withCredentials;
      const formData = new FormData();
      appendData(formData, data, file);
      formData.append(fieldName, file.file);
      registerHandler(inst, file, request);
      if (action !== void 0) {
        request.open(method.toUpperCase(), action);
        setHeaders(request, headers, file);
        request.send(formData);
        const fileAfterChange = Object.assign({}, file, {
          status: "uploading"
        });
        inst.doChange(fileAfterChange);
      }
    }
    const uploadProps = {
      ...useTheme.props,
      name: {
        type: String,
        default: "file"
      },
      accept: String,
      action: String,
      customRequest: Function,
      directory: Boolean,
      directoryDnd: { type: Boolean, default: void 0 },
      method: {
        type: String,
        default: "POST"
      },
      multiple: Boolean,
      showFileList: {
        type: Boolean,
        default: true
      },
      data: [Object, Function],
      headers: [Object, Function],
      withCredentials: Boolean,
      disabled: {
        type: Boolean,
        default: void 0
      },
      onChange: Function,
      onRemove: Function,
      onFinish: Function,
      onError: Function,
      onBeforeUpload: Function,
      isErrorState: Function,
      onDownload: Function,
      defaultUpload: {
        type: Boolean,
        default: true
      },
      fileList: Array,
      "onUpdate:fileList": [Function, Array],
      onUpdateFileList: [Function, Array],
      fileListStyle: [String, Object],
      defaultFileList: {
        type: Array,
        default: () => []
      },
      showCancelButton: {
        type: Boolean,
        default: true
      },
      showRemoveButton: {
        type: Boolean,
        default: true
      },
      showDownloadButton: Boolean,
      showRetryButton: {
        type: Boolean,
        default: true
      },
      showPreviewButton: {
        type: Boolean,
        default: true
      },
      listType: {
        type: String,
        default: "text"
      },
      onPreview: Function,
      createThumbnailUrl: Function,
      abstract: Boolean,
      max: Number,
      showTrigger: {
        type: Boolean,
        default: true
      },
      imageGroupProps: Object,
      inputProps: Object,
      triggerStyle: [String, Object]
    };
    var Upload = vue.defineComponent({
      name: "Upload",
      props: uploadProps,
      setup(props) {
        if (props.abstract && props.listType === "image-card") {
          throwError(
            "upload",
            "when the list-type is image-card, abstract is not supported."
          );
        }
        const { mergedClsPrefixRef, inlineThemeDisabled } = useConfig(props);
        const themeRef = useTheme(
          "Upload",
          "-upload",
          style$1,
          uploadLight$1,
          props,
          mergedClsPrefixRef
        );
        const formItem = useFormItem(props);
        const maxReachedRef = vue.computed(() => {
          const { max } = props;
          if (max !== void 0) {
            return mergedFileListRef.value.length >= max;
          }
          return false;
        });
        const uncontrolledFileListRef = vue.ref(props.defaultFileList);
        const controlledFileListRef = vue.toRef(props, "fileList");
        const inputElRef = vue.ref(null);
        const draggerInsideRef = {
          value: false
        };
        const dragOverRef = vue.ref(false);
        const xhrMap = /* @__PURE__ */ new Map();
        const _mergedFileListRef = useMergedState(
          controlledFileListRef,
          uncontrolledFileListRef
        );
        const mergedFileListRef = vue.computed(
          () => _mergedFileListRef.value.map(createSettledFileInfo)
        );
        function openOpenFileDialog() {
          inputElRef.value?.click();
        }
        function handleFileInputChange(e) {
          const target = e.target;
          handleFileAddition(
            target.files ? Array.from(target.files).map((file) => ({
              file,
              entry: null,
              source: "input"
            })) : null,
            e
          );
          target.value = "";
        }
        function doUpdateFileList(files) {
          const { "onUpdate:fileList": _onUpdateFileList, onUpdateFileList } = props;
          if (_onUpdateFileList)
            call(_onUpdateFileList, files);
          if (onUpdateFileList)
            call(onUpdateFileList, files);
          uncontrolledFileListRef.value = files;
        }
        const mergedMultipleRef = vue.computed(() => props.multiple || props.directory);
        function handleFileAddition(fileAndEntries, e) {
          if (!fileAndEntries || fileAndEntries.length === 0)
            return;
          const { onBeforeUpload } = props;
          fileAndEntries = mergedMultipleRef.value ? fileAndEntries : [fileAndEntries[0]];
          const { max, accept } = props;
          fileAndEntries = fileAndEntries.filter(({ file, source }) => {
            if (source === "dnd" && accept?.trim()) {
              return matchType(file.name, file.type, accept);
            } else {
              return true;
            }
          });
          if (max) {
            fileAndEntries = fileAndEntries.slice(
              0,
              max - mergedFileListRef.value.length
            );
          }
          const batchId = createId();
          void Promise.all(
            fileAndEntries.map(async ({ file, entry }) => {
              const fileInfo = {
                id: createId(),
                batchId,
                name: file.name,
                status: "pending",
                percentage: 0,
                file,
                url: null,
                type: file.type,
                thumbnailUrl: null,
                fullPath: entry?.fullPath ?? `/${file.webkitRelativePath || file.name}`
              };
              if (!onBeforeUpload || await onBeforeUpload({
                file: fileInfo,
                fileList: mergedFileListRef.value
              }) !== false) {
                return fileInfo;
              }
              return null;
            })
          ).then(async (fileInfos) => {
            let nextTickChain = Promise.resolve();
            fileInfos.forEach((fileInfo) => {
              nextTickChain = nextTickChain.then(vue.nextTick).then(() => {
                fileInfo && doChange(fileInfo, e, {
                  append: true
                });
              });
            });
            return await nextTickChain;
          }).then(() => {
            if (props.defaultUpload) {
              submit();
            }
          });
        }
        function submit(fileId) {
          const {
            method,
            action,
            withCredentials,
            headers,
            data,
            name: fieldName
          } = props;
          const filesToUpload = fileId !== void 0 ? mergedFileListRef.value.filter((file) => file.id === fileId) : mergedFileListRef.value;
          const shouldReupload = fileId !== void 0;
          filesToUpload.forEach((file) => {
            const { status } = file;
            if (status === "pending" || status === "error" && shouldReupload) {
              if (props.customRequest) {
                customSubmitImpl({
                  inst: {
                    doChange,
                    xhrMap,
                    onFinish: props.onFinish,
                    onError: props.onError
                  },
                  file,
                  action,
                  withCredentials,
                  headers,
                  data,
                  customRequest: props.customRequest
                });
              } else {
                submitImpl(
                  {
                    doChange,
                    xhrMap,
                    onFinish: props.onFinish,
                    onError: props.onError,
                    isErrorState: props.isErrorState
                  },
                  fieldName,
                  file,
                  {
                    method,
                    action,
                    withCredentials,
                    headers,
                    data
                  }
                );
              }
            }
          });
        }
        const doChange = (fileAfterChange, event, options = {
          append: false,
          remove: false
        }) => {
          const { append, remove } = options;
          const fileListAfterChange = Array.from(mergedFileListRef.value);
          const fileIndex = fileListAfterChange.findIndex(
            (file) => file.id === fileAfterChange.id
          );
          if (append || remove || ~fileIndex) {
            if (append) {
              fileListAfterChange.push(fileAfterChange);
            } else if (remove) {
              fileListAfterChange.splice(fileIndex, 1);
            } else {
              fileListAfterChange.splice(fileIndex, 1, fileAfterChange);
            }
            const { onChange } = props;
            if (onChange) {
              onChange({
                file: fileAfterChange,
                fileList: fileListAfterChange,
                event
              });
            }
            doUpdateFileList(fileListAfterChange);
          } else {
            warn$2("upload", "File has no corresponding id in current file list.");
          }
        };
        async function getFileThumbnailUrl(file) {
          const { createThumbnailUrl } = props;
          return createThumbnailUrl ? await createThumbnailUrl(file.file) : await createImageDataUrl(file.file);
        }
        const cssVarsRef = vue.computed(() => {
          const {
            common: { cubicBezierEaseInOut },
            self: {
              draggerColor,
              draggerBorder,
              draggerBorderHover,
              itemColorHover,
              itemColorHoverError,
              itemTextColorError,
              itemTextColorSuccess,
              itemTextColor,
              itemIconColor,
              itemDisabledOpacity,
              lineHeight,
              borderRadius,
              fontSize,
              itemBorderImageCardError,
              itemBorderImageCard
            }
          } = themeRef.value;
          return {
            "--n-bezier": cubicBezierEaseInOut,
            "--n-border-radius": borderRadius,
            "--n-dragger-border": draggerBorder,
            "--n-dragger-border-hover": draggerBorderHover,
            "--n-dragger-color": draggerColor,
            "--n-font-size": fontSize,
            "--n-item-color-hover": itemColorHover,
            "--n-item-color-hover-error": itemColorHoverError,
            "--n-item-disabled-opacity": itemDisabledOpacity,
            "--n-item-icon-color": itemIconColor,
            "--n-item-text-color": itemTextColor,
            "--n-item-text-color-error": itemTextColorError,
            "--n-item-text-color-success": itemTextColorSuccess,
            "--n-line-height": lineHeight,
            "--n-item-border-image-card-error": itemBorderImageCardError,
            "--n-item-border-image-card": itemBorderImageCard
          };
        });
        const themeClassHandle = inlineThemeDisabled ? useThemeClass("upload", void 0, cssVarsRef, props) : void 0;
        vue.provide(uploadInjectionKey, {
          mergedClsPrefixRef,
          mergedThemeRef: themeRef,
          showCancelButtonRef: vue.toRef(props, "showCancelButton"),
          showDownloadButtonRef: vue.toRef(props, "showDownloadButton"),
          showRemoveButtonRef: vue.toRef(props, "showRemoveButton"),
          showRetryButtonRef: vue.toRef(props, "showRetryButton"),
          onRemoveRef: vue.toRef(props, "onRemove"),
          onDownloadRef: vue.toRef(props, "onDownload"),
          mergedFileListRef,
          triggerStyleRef: vue.toRef(props, "triggerStyle"),
          xhrMap,
          submit,
          doChange,
          showPreviewButtonRef: vue.toRef(props, "showPreviewButton"),
          onPreviewRef: vue.toRef(props, "onPreview"),
          getFileThumbnailUrl,
          listTypeRef: vue.toRef(props, "listType"),
          dragOverRef,
          openOpenFileDialog,
          draggerInsideRef,
          handleFileAddition,
          mergedDisabledRef: formItem.mergedDisabledRef,
          maxReachedRef,
          fileListStyleRef: vue.toRef(props, "fileListStyle"),
          abstractRef: vue.toRef(props, "abstract"),
          acceptRef: vue.toRef(props, "accept"),
          cssVarsRef: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClassRef: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender,
          showTriggerRef: vue.toRef(props, "showTrigger"),
          imageGroupPropsRef: vue.toRef(props, "imageGroupProps"),
          mergedDirectoryDndRef: vue.computed(() => {
            return props.directoryDnd ?? props.directory;
          })
        });
        const exposedMethods = {
          clear: () => {
            uncontrolledFileListRef.value = [];
          },
          submit,
          openOpenFileDialog
        };
        return {
          mergedClsPrefix: mergedClsPrefixRef,
          draggerInsideRef,
          inputElRef,
          mergedTheme: themeRef,
          dragOver: dragOverRef,
          mergedMultiple: mergedMultipleRef,
          cssVars: inlineThemeDisabled ? void 0 : cssVarsRef,
          themeClass: themeClassHandle?.themeClass,
          onRender: themeClassHandle?.onRender,
          handleFileInputChange,
          ...exposedMethods
        };
      },
      render() {
        const { draggerInsideRef, mergedClsPrefix, $slots, directory, onRender } = this;
        if ($slots.default && !this.abstract) {
          const firstChild = $slots.default()[0];
          if (firstChild?.type?.[uploadDraggerKey]) {
            draggerInsideRef.value = true;
          }
        }
        const inputNode = /* @__PURE__ */ React.createElement("input", {
          ...this.inputProps,
          ref: "inputElRef",
          type: "file",
          class: `${mergedClsPrefix}-upload-file-input`,
          accept: this.accept,
          multiple: this.mergedMultiple,
          onChange: this.handleFileInputChange,
          webkitdirectory: directory,
          directory
        });
        if (this.abstract) {
          return /* @__PURE__ */ React.createElement(React.Fragment, null, $slots.default?.(), /* @__PURE__ */ React.createElement(vue.Teleport, {
            to: "body"
          }, inputNode));
        }
        onRender?.();
        return /* @__PURE__ */ React.createElement("div", {
          class: [
            `${mergedClsPrefix}-upload`,
            draggerInsideRef.value && `${mergedClsPrefix}-upload--dragger-inside`,
            this.dragOver && `${mergedClsPrefix}-upload--drag-over`,
            this.themeClass
          ],
          style: this.cssVars
        }, inputNode, this.showTrigger && this.listType !== "image-card" && /* @__PURE__ */ React.createElement(NUploadTrigger, null, $slots), this.showFileList && /* @__PURE__ */ React.createElement(NUploadFileList, null, $slots));
      }
    });

    var style = c$1([cB("watermark-container", `
    position: relative;
  `, [cNotM("selectable", `
      user-select: none;
      -webkit-user-select: none;
    `), cM("global-rotate", `
      overflow: hidden;
    `), cM("fullscreen", `
      top: 0;
      left: 0;
      width: 100%;
      height: 100%;
      pointer-events: none;
      position: fixed;
    `)]), cB("watermark", `
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    pointer-events: none;
    background-repeat: repeat;
  `, [cM("fullscreen", `
      position: fixed;
    `), cM("global-rotate", `
      position: absolute;
      height: max(284vh, 284vw);
      width: max(284vh, 284vw);
    `)])]);

    function getRatio(context) {
      if (!context) {
        return 1;
      }
      const backingStore = context.backingStorePixelRatio || context.webkitBackingStorePixelRatio || context.mozBackingStorePixelRatio || context.msBackingStorePixelRatio || context.oBackingStorePixelRatio || context.backingStorePixelRatio || 1;
      return (window.devicePixelRatio || 1) / backingStore;
    }
    const watermarkProps = {
      ...useTheme.props,
      debug: Boolean,
      cross: Boolean,
      fullscreen: Boolean,
      width: {
        type: Number,
        default: 32
      },
      height: {
        type: Number,
        default: 32
      },
      zIndex: {
        type: Number,
        default: 10
      },
      xGap: {
        type: Number,
        default: 0
      },
      yGap: {
        type: Number,
        default: 0
      },
      yOffset: {
        type: Number,
        default: 0
      },
      xOffset: {
        type: Number,
        default: 0
      },
      rotate: {
        type: Number,
        default: 0
      },
      image: String,
      imageOpacity: { type: Number, default: 1 },
      imageHeight: Number,
      imageWidth: Number,
      content: String,
      selectable: {
        type: Boolean,
        default: true
      },
      fontSize: {
        type: Number,
        default: 14
      },
      fontFamily: String,
      fontStyle: {
        type: String,
        default: "normal"
      },
      fontVariant: {
        type: String,
        default: ""
      },
      fontWeight: {
        type: Number,
        default: 400
      },
      fontColor: {
        type: String,
        default: "rgba(128, 128, 128, .3)"
      },
      fontStretch: {
        type: String,
        default: ""
      },
      lineHeight: {
        type: Number,
        default: 14
      },
      globalRotate: {
        type: Number,
        default: 0
      }
    };
    var Watermark = vue.defineComponent({
      name: "Watermark",
      props: watermarkProps,
      setup(props, { slots }) {
        const { mergedClsPrefixRef } = useConfig(props);
        const themeRef = useTheme(
          "Watermark",
          "-watermark",
          style,
          watermarkLight$1,
          props,
          mergedClsPrefixRef
        );
        const base64UrlRef = vue.ref("");
        const canvas = isBrowser$2 ? document.createElement("canvas") : null;
        const ctx = canvas ? canvas.getContext("2d") : null;
        const fontsReadyRef = vue.ref(false);
        onFontsReady(() => fontsReadyRef.value = true);
        vue.watchEffect(() => {
          if (!canvas)
            return;
          void fontsReadyRef.value;
          const ratio = getRatio(ctx);
          const {
            xGap,
            yGap,
            width,
            height,
            yOffset,
            xOffset,
            rotate,
            image,
            content,
            fontColor,
            fontStyle,
            fontVariant,
            fontStretch,
            fontWeight,
            fontFamily,
            fontSize,
            lineHeight,
            debug
          } = props;
          const canvasWidth = (xGap + width) * ratio;
          const canvasHeight = (yGap + height) * ratio;
          const canvasOffsetLeft = xOffset * ratio;
          const canvasOffsetTop = yOffset * ratio;
          canvas.width = canvasWidth;
          canvas.height = canvasHeight;
          if (ctx) {
            ctx.translate(0, 0);
            const markWidth = width * ratio;
            const markHeight = height * ratio;
            if (debug) {
              ctx.strokeStyle = "grey";
              ctx.strokeRect(0, 0, markWidth, markHeight);
            }
            ctx.rotate(rotate * (Math.PI / 180));
            if (image) {
              const img = new Image();
              img.crossOrigin = "anonymous";
              img.referrerPolicy = "no-referrer";
              img.src = image;
              img.onload = () => {
                ctx.globalAlpha = props.imageOpacity;
                const { imageWidth, imageHeight } = props;
                ctx.drawImage(
                  img,
                  canvasOffsetLeft,
                  canvasOffsetTop,
                  (props.imageWidth || (imageHeight ? img.width * imageHeight / img.height : img.width)) * ratio,
                  (props.imageHeight || (imageWidth ? img.height * imageWidth / img.width : img.height)) * ratio
                );
                base64UrlRef.value = canvas.toDataURL();
              };
            } else if (content) {
              if (debug) {
                ctx.strokeStyle = "green";
                ctx.strokeRect(0, 0, markWidth, markHeight);
              }
              ctx.font = `${fontStyle} ${fontVariant} ${fontWeight} ${fontStretch} ${fontSize * ratio}px/${lineHeight * ratio}px ${fontFamily || themeRef.value.self.fontFamily}`;
              ctx.fillStyle = fontColor;
              ctx.fillText(
                content,
                canvasOffsetLeft,
                canvasOffsetTop + lineHeight * ratio
              );
              base64UrlRef.value = canvas.toDataURL();
            }
          } else {
            warnOnce("watermark", "Canvas is not supported in the browser.");
          }
        });
        return () => {
          const { globalRotate, fullscreen, zIndex } = props;
          const mergedClsPrefix = mergedClsPrefixRef.value;
          const isFullScreenGlobalRotate = globalRotate !== 0 && fullscreen;
          const rotatedImageOffset = "max(142vh, 142vw)";
          const watermarkNode = /* @__PURE__ */ React.createElement("div", {
            class: [
              `${mergedClsPrefix}-watermark`,
              globalRotate !== 0 && `${mergedClsPrefix}-watermark--global-rotate`,
              fullscreen && `${mergedClsPrefix}-watermark--fullscreen`
            ],
            style: {
              transform: globalRotate ? `translateX(-50%) translateY(-50%) rotate(${globalRotate}deg)` : void 0,
              zIndex: isFullScreenGlobalRotate ? void 0 : zIndex,
              backgroundSize: `${props.xGap + props.width}px`,
              backgroundPosition: globalRotate === 0 ? props.cross ? `${props.width / 2}px ${props.height / 2}px, 0 0` : "" : props.cross ? `calc(${rotatedImageOffset} + ${props.width / 2}px) calc(${rotatedImageOffset} + ${props.height / 2}px), ${rotatedImageOffset} ${rotatedImageOffset}` : rotatedImageOffset,
              backgroundImage: props.cross ? `url(${base64UrlRef.value}), url(${base64UrlRef.value})` : `url(${base64UrlRef.value})`
            }
          });
          if (props.fullscreen && !globalRotate)
            return watermarkNode;
          return /* @__PURE__ */ React.createElement("div", {
            class: [
              `${mergedClsPrefix}-watermark-container`,
              globalRotate !== 0 && `${mergedClsPrefix}-watermark-container--global-rotate`,
              fullscreen && `${mergedClsPrefix}-watermark-container--fullscreen`,
              props.selectable && `${mergedClsPrefix}-watermark-container--selectable`
            ],
            style: {
              zIndex: isFullScreenGlobalRotate ? zIndex : void 0
            }
          }, slots.default?.(), watermarkNode);
        };
      }
    });

    const NInjectionExtractor = vue.defineComponent({
      name: "InjectionExtractor",
      props: {
        onSetup: Function
      },
      setup(props, { slots }) {
        props.onSetup?.();
        return () => slots.default?.();
      }
    });

    const injectionFactoryMap = {
      message: useMessage,
      notification: useNotification,
      loadingBar: useLoadingBar,
      dialog: useDialog
    };
    function createDiscreteApp(_ref) {
      let {
        providersAndProps,
        configProviderProps
      } = _ref;
      const extractedApi = {};

      const App2 = () => {
        return vue.h(NConfigProvider, vue.unref(configProviderProps), {
          default: () => providersAndProps.map(_ref2 => {
            let {
              type,
              Provider,
              props
            } = _ref2;
            return vue.h(Provider, vue.unref(props), {
              default: () => vue.h(NInjectionExtractor, {
                onSetup: () => extractedApi[type] = injectionFactoryMap[type]()
              })
            });
          })
        });
      };

      let app = vue.createApp(App2);
      let hostEl = document.createElement("div");
      document.body.appendChild(hostEl);
      app.mount(hostEl);

      const unmount = () => {
        var _hostEl$parentNode;

        if (app === null || hostEl === null) {
          warn$2("discrete", "unmount call no need because discrete app has been unmounted");
          return;
        }

        app.unmount();
        (_hostEl$parentNode = hostEl.parentNode) === null || _hostEl$parentNode === void 0 ? void 0 : _hostEl$parentNode.removeChild(hostEl);
        hostEl = null;
        app = null;
      };

      return {
        unmount,
        ...extractedApi
      };
    }

    function createDiscreteApi(includes) {
      let {
        configProviderProps,
        messageProviderProps,
        dialogProviderProps,
        notificationProviderProps,
        loadingBarProviderProps
      } = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      const providersAndProps = [];
      includes.forEach(type => {
        switch (type) {
          case "message":
            providersAndProps.push({
              type,
              Provider: NMessageProvider,
              props: messageProviderProps
            });
            break;

          case "notification":
            providersAndProps.push({
              type,
              Provider: NNotificationProvider,
              props: notificationProviderProps
            });
            break;

          case "dialog":
            providersAndProps.push({
              type,
              Provider: NDialogProvider,
              props: dialogProviderProps
            });
            break;

          case "loadingBar":
            providersAndProps.push({
              type,
              Provider: NLoadingBarProvider,
              props: loadingBarProviderProps
            });
            break;
        }
      });
      const discreteApp = createDiscreteApp({
        providersAndProps,
        configProviderProps
      });
      return discreteApp;
    }

    var components = /*#__PURE__*/Object.freeze({
        __proto__: null,
        NAffix: NAffix,
        affixProps: affixProps,
        NAlert: Alert,
        alertProps: alertProps,
        NAnchor: AnchorAdapter,
        anchorProps: anchorProps,
        NAnchorLink: Link,
        anchorLinkProps: anchorLinkProps,
        NAutoComplete: AutoComplete,
        autoCompleteProps: autoCompleteProps,
        NAvatar: NAvatar,
        avatarProps: avatarProps,
        NAvatarGroup: AvatarGroup,
        avatarGroupProps: avatarGroupProps,
        NBackTop: BackTop,
        backTopProps: backTopProps,
        NBadge: Badge,
        badgeProps: badgeProps,
        NBreadcrumb: Breadcrumb,
        breadcrumbProps: breadcrumbProps,
        NBreadcrumbItem: BreadcrumbItem,
        breadcrumbItemProps: breadcrumbItemProps,
        NButton: NButton,
        NxButton: XButton,
        buttonProps: buttonProps,
        NButtonGroup: NButtonGroup,
        buttonGroupProps: buttonGroupProps,
        NCalendar: Calendar,
        calendarProps: calendarProps,
        NColorPicker: NColorPicker,
        colorPickerProps: colorPickerProps,
        NCard: NCard,
        cardProps: cardProps,
        NCarousel: Carousel,
        carouselProps: carouselProps,
        NCarouselItem: NCarouselItem,
        NCascader: Cascader,
        cascaderProps: cascaderProps,
        NCheckbox: NCheckbox,
        checkboxProps: checkboxProps,
        NCheckboxGroup: NCheckboxGroup,
        checkboxGroupProps: checkboxGroupProps,
        NCode: NCode,
        codeProps: codeProps,
        NCollapse: NCollapse,
        collapseProps: collapseProps,
        NCollapseItem: NCollapseItem,
        collapseItemProps: collapseItemProps,
        NCollapseTransition: CollapseTransition,
        collapseTransitionProps: collapseTransitionProps,
        NConfigProvider: NConfigProvider,
        configProviderProps: configProviderProps,
        NCountdown: Countdown,
        countdownProps: countdownProps,
        NNumberAnimation: NumberAnimation,
        numberAnimationProps: numberAnimationProps,
        NDataTable: DataTable,
        dataTableProps: dataTableProps,
        NDatePicker: DatePicker,
        datePickerProps: datePickerProps,
        NDescriptions: Descriptions,
        descriptionsProps: descriptionsProps,
        NDescriptionsItem: DescriptionsItem,
        descriptionsItemProps: descriptionsItemProps,
        NDialog: NDialog,
        dialogProps: dialogProps,
        NDialogProvider: NDialogProvider,
        dialogProviderProps: dialogProviderProps,
        useDialog: useDialog,
        useDialogReactiveList: useDialogReactiveList,
        NDivider: NDivider,
        dividerProps: dividerProps,
        NDrawer: Drawer,
        drawerProps: drawerProps,
        NDrawerContent: DrawerContent,
        drawerContentProps: drawerContentProps,
        NDropdown: NDropdown,
        dropdownProps: dropdownProps,
        NDynamicInput: DynamicInput,
        dynamicInputProps: dynamicInputProps,
        NDynamicTags: DynamicTags,
        dynamicTagsProps: dynamicTagsProps,
        NElement: NElement,
        elementProps: elementProps,
        NEl: NElement,
        NEllipsis: NEllipsis,
        ellipsisProps: ellipsisProps,
        NEmpty: NEmpty,
        emptyProps: emptyProps,
        NForm: Form,
        formProps: formProps,
        NFormItem: NFormItem,
        formItemProps: formItemProps,
        NFormItemGridItem: FormItemGridItem,
        NFormItemGi: FormItemGridItem,
        formItemGiProps: formItemGiProps,
        formItemGridItemProps: formItemGiProps,
        NFormItemCol: NFormItemCol,
        NFormItemRow: FormItemRow,
        NGlobalStyle: GlobalStyle,
        NGradientText: GradientText,
        gradientTextProps: gradientTextProps,
        NGrid: Grid,
        gridProps: gridProps,
        NGridItem: NGridItem,
        gridItemProps: gridItemProps,
        NGi: NGridItem,
        giProps: gridItemProps,
        NIcon: NIcon,
        iconProps: iconProps,
        NIconWrapper: NIconWrapper,
        iconWrapperProps: iconWrapperProps,
        NImage: NImage,
        imageProps: imageProps,
        NImageGroup: NImageGroup,
        imageGroupProps: imageGroupProps,
        NInput: NInput,
        inputProps: inputProps,
        NInputGroup: NInputGroup,
        inputGroupProps: inputGroupProps,
        NInputGroupLabel: InputGroupLabel,
        inputGroupLabelProps: inputGroupLabelProps,
        NInputNumber: InputNumber,
        inputNumberProps: inputNumberProps,
        NLayout: Layout,
        layoutProps: layoutProps,
        layoutContentProps: layoutProps,
        NLayoutContent: LayoutContent,
        NLayoutHeader: LayoutHeader,
        layoutHeaderProps: headerProps$1,
        NLayoutFooter: LayoutFooter,
        layoutFooterProps: layoutFooterProps,
        NLayoutSider: LayoutSider,
        layoutSiderProps: layoutSiderProps,
        NRow: NRow,
        rowProps: rowProps,
        NCol: NCol,
        colProps: colProps,
        NLegacyTransfer: Transfer$1,
        legacyTransferProps: transferProps$1,
        NList: List,
        listProps: listProps,
        NListItem: ListItem,
        NLoadingBarProvider: NLoadingBarProvider,
        loadingBarProviderProps: loadingBarProviderProps,
        useLoadingBar: useLoadingBar,
        NLog: Log,
        logProps: logProps,
        NMenu: Menu,
        menuProps: menuProps,
        NMention: Mention,
        mentionProps: mentionProps,
        NMessageProvider: NMessageProvider,
        messageProviderProps: messageProviderProps,
        useMessage: useMessage,
        NModal: NModal,
        modalProps: modalProps,
        NNotificationProvider: NNotificationProvider,
        notificationProviderProps: notificationProviderProps,
        useNotification: useNotification,
        NPageHeader: PageHeader,
        pageHeaderProps: pageHeaderProps,
        NPagination: NPagination,
        paginationProps: paginationProps,
        NPopconfirm: Popconfirm,
        popconfirmProps: popconfirmProps,
        NPopover: NPopover,
        popoverProps: popoverProps,
        NPopselect: NPopselect,
        popselectProps: popselectProps,
        NProgress: NProgress,
        progressProps: progressProps,
        NRadio: NRadio,
        radioProps: radioProps,
        NRadioGroup: NRadioGroup,
        radioGroupProps: radioGroupProps,
        NRadioButton: RadioButton,
        radioButtonProps: radioButtonProps,
        NRate: Rate,
        rateProps: rateProps,
        NResult: Result,
        resultProps: resultProps,
        NScrollbar: Scrollbar$1,
        scrollbarProps: scrollbarProps,
        NSelect: NSelect,
        selectProps: selectProps,
        NSkeleton: Skeleton,
        skeletonProps: skeletonProps,
        NSlider: Slider,
        sliderProps: sliderProps,
        NSpace: NSpace,
        spaceProps: spaceProps,
        NSpin: Spin,
        spinProps: spinProps,
        NStatistic: Statistic,
        statisticProps: statisticProps,
        NSteps: Steps,
        stepsProps: stepsProps,
        NStep: Step,
        stepProps: stepProps,
        NSwitch: Switch,
        switchProps: switchProps,
        NTable: Table,
        tableProps: tableProps,
        NTh: Th,
        NTr: Tr,
        NTd: Td,
        NThead: Thead,
        NTbody: Tbody,
        NTabs: Tabs,
        tabsProps: tabsProps,
        NTabPane: TabPane,
        tabPaneProps: tabPaneProps,
        NTab: Tab,
        tabProps: tabProps,
        NTag: NTag,
        tagProps: tagProps,
        NThing: Thing,
        thingProps: thingProps,
        NTime: Time,
        timeProps: timeProps,
        NTimePicker: NTimePicker,
        timePickerProps: timePickerProps,
        NTimeline: Timeline,
        timelineProps: timelineProps,
        NTimelineItem: TimelineItem,
        timelineItemProps: timelineItemProps,
        NTooltip: NTooltip,
        tooltipProps: tooltipProps,
        NTransfer: Transfer,
        transferProps: transferProps,
        NTree: NTree,
        treeProps: treeProps,
        NTreeSelect: TreeSelect,
        treeSelectProps: treeSelectProps,
        NH1: NH1,
        NH2: NH2,
        NH3: NH3,
        NH4: NH4,
        NH5: NH5,
        NH6: NH6,
        h1Props: headerProps,
        h2Props: headerProps,
        h3Props: headerProps,
        h4Props: headerProps,
        h5Props: headerProps,
        h6Props: headerProps,
        NA: a,
        aProps: aProps,
        NP: p,
        pProps: pProps,
        NBlockquote: blockquote,
        blockquoteProps: blockquoteProps,
        NHr: hr,
        NUl: ul,
        ulProps: ulProps,
        NOl: ol,
        olProps: olProps,
        NLi: li,
        NText: text,
        textProps: textProps,
        NUpload: Upload,
        uploadProps: uploadProps,
        NUploadDragger: NUploadDragger,
        NUploadTrigger: NUploadTrigger,
        NUploadFileList: NUploadFileList,
        NWatermark: Watermark,
        watermarkProps: watermarkProps,
        createDiscreteApi: createDiscreteApi
    });

    var version = "2.33.0";

    function create() {
      let {
        componentPrefix = "N",
        components = []
      } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      const installTargets = [];

      function registerComponent(app, name, component) {
        const registered = app.component(componentPrefix + name);

        if (!registered) {
          app.component(componentPrefix + name, component);
        }
      }

      function install(app) {
        if (installTargets.includes(app)) return;
        installTargets.push(app);
        components.forEach(component => {
          const {
            name,
            alias
          } = component;
          registerComponent(app, name, component);

          if (alias) {
            alias.forEach(aliasName => {
              registerComponent(app, aliasName, component);
            });
          }
        });
      }

      return {
        version,
        componentPrefix,
        install
      };
    }

    const naive = create({
      components: Object.keys(components).map(key => components[key])
    });
    var naive$1 = naive;
    const install = naive.install;

    function useThemeVars() {
      const configProviderInjection = vue.inject(configProviderInjectionKey, null);
      return vue.computed(() => {
        if (configProviderInjection === null) return commonLight;
        const {
          mergedThemeRef: {
            value: mergedTheme
          },
          mergedThemeOverridesRef: {
            value: mergedThemeOverrides
          }
        } = configProviderInjection;
        const currentThemeVars = (mergedTheme === null || mergedTheme === void 0 ? void 0 : mergedTheme.common) || commonLight;

        if (mergedThemeOverrides !== null && mergedThemeOverrides !== void 0 && mergedThemeOverrides.common) {
          return Object.assign({}, currentThemeVars, mergedThemeOverrides.common);
        } else {
          return currentThemeVars;
        }
      });
    }

    const darkTheme = {
      name: "dark",
      common: commonDark,
      Alert: alertDark$1,
      Anchor: anchorDark$1,
      AutoComplete: autoCompleteDark$1,
      Avatar: avatarDark$1,
      AvatarGroup: avatarGroupDark$1,
      BackTop: backTopDark$1,
      Badge: badgeDark$1,
      Breadcrumb: breadcrumbDark$1,
      Button: buttonDark$1,
      ButtonGroup: buttonGroupDark$1,
      Calendar: calendarDark$1,
      Card: cardDark$1,
      Carousel: carouselDark$1,
      Cascader: cascaderDark$1,
      Checkbox: checkboxDark$1,
      Code: codeDark$1,
      Collapse: collapseDark$1,
      CollapseTransition: collapseTransitionDark$1,
      ColorPicker: colorPickerDark$1,
      DataTable: dataTableDark$1,
      DatePicker: datePickerDark$1,
      Descriptions: descriptionsDark$1,
      Dialog: dialogDark$1,
      Divider: dividerDark$1,
      Drawer: drawerDark$1,
      Dropdown: dropdownDark$1,
      DynamicInput: dynamicInputDark$1,
      DynamicTags: dynamicTagsDark$1,
      Element: elementDark$1,
      Empty: emptyDark$1,
      Ellipsis: ellipsisDark$1,
      Form: formDark,
      GradientText: gradientTextDark$1,
      Icon: iconDark$2,
      IconWrapper: iconWrapperDark,
      Image: imageDark,
      Input: inputDark$1,
      InputNumber: inputNumberDark$1,
      LegacyTransfer: legacyTransferDark,
      Layout: layoutDark$1,
      List: listDark$2,
      LoadingBar: loadingBarDark$1,
      Log: logDark$1,
      Menu: menuDark$1,
      Mention: mentionDark,
      Message: messageDark$1,
      Modal: modalDark$1,
      Notification: notificationDark$1,
      PageHeader: pageHeaderDark,
      Pagination: paginationDark$1,
      Popconfirm: popconfirmDark$1,
      Popover: popoverDark$1,
      Popselect: popselectDark,
      Progress: progressDark$1,
      Radio: radioDark$1,
      Rate: rateDark$1,
      Result: resultDark$1,
      Row: rowDark$1,
      Scrollbar: scrollbarDark$1,
      Select: selectDark$1,
      Skeleton: skeletonDark,
      Slider: sliderDark$1,
      Space: spaceDark$1,
      Spin: spinDark$1,
      Statistic: statisticDark$1,
      Steps: stepsDark$1,
      Switch: switchDark$1,
      Table: tableDark$1,
      Tabs: tabsDark$1,
      Tag: tagDark$1,
      Thing: thingDark$1,
      TimePicker: timePickerDark$1,
      Timeline: timelineDark$1,
      Tooltip: tooltipDark$1,
      Transfer: transferDark$2,
      Tree: treeDark$1,
      TreeSelect: treeSelectDark$1,
      Typography: typographyDark$1,
      Upload: uploadDark$1,
      Watermark: watermarkDark$1
    };

    const lightTheme = {
      name: "light",
      common: commonLight,
      Alert: alertLight$1,
      Anchor: anchorLight$1,
      AutoComplete: autoCompleteLight$1,
      Avatar: avatarLight$1,
      AvatarGroup: avatarGroupLight$1,
      BackTop: backTopLight$1,
      Badge: badgeLight$1,
      Breadcrumb: breadcrumbLight$1,
      Button: buttonLight$1,
      ButtonGroup: buttonGroupLight$1,
      Calendar: calendarLight$1,
      Card: cardLight$1,
      Carousel: carouselLight$1,
      Cascader: cascaderLight$1,
      Checkbox: checkboxLight$1,
      Code: codeLight$1,
      Collapse: collapseLight$1,
      CollapseTransition: collapseTransitionLight$1,
      ColorPicker: colorPickerLight$1,
      DataTable: dataTableLight$1,
      DatePicker: datePickerLight$1,
      Descriptions: descriptionsLight$1,
      Dialog: dialogLight$1,
      Divider: dividerLight$1,
      Drawer: drawerLight$1,
      Dropdown: dropdownLight$1,
      DynamicInput: dynamicInputLight$1,
      DynamicTags: dynamicTagsLight$1,
      Element: elementLight$1,
      Empty: emptyLight$1,
      Ellipsis: ellipsisLight$1,
      Form: formLight$1,
      GradientText: gradientTextLight$1,
      Icon: iconLight$1,
      IconWrapper: iconWrapperLight$1,
      Image: imageLight,
      Input: inputLight$1,
      InputNumber: inputNumberLight$1,
      Layout: layoutLight$1,
      LegacyTransfer: legacyTransferLight,
      List: listLight$1,
      LoadingBar: loadingBarLight$1,
      Log: logLight$1,
      Menu: menuLight$1,
      Mention: mentionLight$1,
      Message: messageLight$1,
      Modal: modalLight$1,
      Notification: notificationLight$1,
      PageHeader: pageHeaderLight,
      Pagination: paginationLight$1,
      Popconfirm: popconfirmLight$1,
      Popover: popoverLight$1,
      Popselect: popselectLight$1,
      Progress: progressLight$1,
      Radio: radioLight$1,
      Rate: rateLight,
      Row: rowLight$1,
      Result: resultLight$1,
      Scrollbar: scrollbarLight$1,
      Skeleton: skeletonLight,
      Select: selectLight$1,
      Slider: sliderLight$1,
      Space: spaceLight$1,
      Spin: spinLight$1,
      Statistic: statisticLight$1,
      Steps: stepsLight$1,
      Switch: switchLight$1,
      Table: tableLight$1,
      Tabs: tabsLight$1,
      Tag: tagLight$1,
      Thing: thingLight$1,
      TimePicker: timePickerLight$1,
      Timeline: timelineLight$1,
      Tooltip: tooltipLight$1,
      Transfer: transferLight$2,
      Tree: treeLight$1,
      TreeSelect: treeSelectLight$1,
      Typography: typographyLight$1,
      Upload: uploadLight$1,
      Watermark: watermarkLight$1
    };

    function createTheme(name, componentThemes) {
      const nameIsString = typeof name === "string";
      const theme = {
        name: nameIsString ? name : "customized-theme"
      };

      if (nameIsString) {
        if (componentThemes) {
          for (const cTheme of componentThemes) {
            theme[cTheme.name] = cTheme;
          }
        }
      } else {
        for (const cTheme of name) {
          theme[cTheme.name] = cTheme;
        }
      }

      return theme;
    }

    const _hoisted_1$kP = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kP = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 112a56 56 0 1 1 56-56a56.06 56.06 0 0 1-56 56z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hR = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M432 112.8l-.45.12l-.42.13c-1 .28-2 .58-3 .89c-18.61 5.46-108.93 30.92-172.56 30.92c-59.13 0-141.28-22-167.56-29.47a73.79 73.79 0 0 0-8-2.58c-19-5-32 14.3-32 31.94c0 17.47 15.7 25.79 31.55 31.76v.28l95.22 29.74c9.73 3.73 12.33 7.54 13.6 10.84c4.13 10.59.83 31.56-.34 38.88l-5.8 45l-32.19 176.19q-.15.72-.27 1.47l-.23 1.27c-2.32 16.15 9.54 31.82 32 31.82c19.6 0 28.25-13.53 32-31.94s28-157.57 42-157.57s42.84 157.57 42.84 157.57c3.75 18.41 12.4 31.94 32 31.94c22.52 0 34.38-15.74 32-31.94a57.17 57.17 0 0 0-.76-4.06L329 301.27l-5.79-45c-4.19-26.21-.82-34.87.32-36.9a1.09 1.09 0 0 0 .08-.15c1.08-2 6-6.48 17.48-10.79l89.28-31.21a16.9 16.9 0 0 0 1.62-.52c16-6 32-14.3 32-31.93S451 107.81 432 112.8z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$at = [_hoisted_2$kP, _hoisted_3$hR];
    vue.defineComponent({
      name: 'Accessibility',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kP, _hoisted_4$at);
      }
    });

    const _hoisted_1$kO = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kO = /*#__PURE__*/vue.createElementVNode('circle', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      cx: '256',
      cy: '56',
      r: '40'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hQ = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M204.23 274.44c2.9-18.06 4.2-35.52-.5-47.59c-4-10.38-12.7-16.19-23.2-20.15L88 176.76c-12-4-23.21-10.7-24-23.94c-1-17 14-28 29-24c0 0 88 31.14 163 31.14s162-31 162-31c18-5 30 9 30 23.79c0 14.21-11 19.21-24 23.94l-88 31.91c-8 3-21 9-26 18.18c-6 10.75-5 29.53-2.1 47.59l5.9 29.63l37.41 163.9c2.8 13.15-6.3 25.44-19.4 27.74S308 489 304.12 476.28l-37.56-115.93q-2.71-8.34-4.8-16.87L256 320l-5.3 21.65q-2.52 10.35-5.8 20.48L208 476.18c-4 12.85-14.5 21.75-27.6 19.46s-22.4-15.59-19.46-27.74l37.39-163.83z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$as = [_hoisted_2$kO, _hoisted_3$hQ];
    vue.defineComponent({
      name: 'AccessibilityOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kO, _hoisted_4$as);
      }
    });

    const _hoisted_1$kN = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kN = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 112c-66.82 17.92-119.55 32-192 32s-125.18-14.08-192-32l-16 51c48 20.53 96.71 35.16 147.2 53.2L144 496l56.4 16L246 336h20l45.6 176l56.4-16l-51.2-279.8C367.26 199.93 416 183.53 464 164z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hP = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 112a56 56 0 1 1 56-56a56.06 56.06 0 0 1-56 56z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$ar = [_hoisted_2$kN, _hoisted_3$hP];
    vue.defineComponent({
      name: 'AccessibilitySharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kN, _hoisted_4$ar);
      }
    });

    const _hoisted_1$kM = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kM = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 112v288'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hO = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M400 256H112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$aq = [_hoisted_2$kM, _hoisted_3$hO];
    vue.defineComponent({
      name: 'Add',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kM, _hoisted_4$aq);
      }
    });

    const _hoisted_1$kL = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kL = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm80 224h-64v64a16 16 0 0 1-32 0v-64h-64a16 16 0 0 1 0-32h64v-64a16 16 0 0 1 32 0v64h64a16 16 0 0 1 0 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hN = [_hoisted_2$kL];
    vue.defineComponent({
      name: 'AddCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kL, _hoisted_3$hN);
      }
    });

    const _hoisted_1$kK = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kK = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hM = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 176v160'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$ap = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M336 256H176'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4T = [_hoisted_2$kK, _hoisted_3$hM, _hoisted_4$ap];
    vue.defineComponent({
      name: 'AddCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kK, _hoisted_5$4T);
      }
    });

    const _hoisted_1$kJ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kJ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm96 224h-80v80h-32v-80h-80v-32h80v-80h32v80h80z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hL = [_hoisted_2$kJ];
    vue.defineComponent({
      name: 'AddCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kJ, _hoisted_3$hL);
      }
    });

    const _hoisted_1$kI = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kI = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 112v288'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hK = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M400 256H112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$ao = [_hoisted_2$kI, _hoisted_3$hK];
    vue.defineComponent({
      name: 'AddOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kI, _hoisted_4$ao);
      }
    });

    const _hoisted_1$kH = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kH = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 112v288'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hJ = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M400 256H112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$an = [_hoisted_2$kH, _hoisted_3$hJ];
    vue.defineComponent({
      name: 'AddSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kH, _hoisted_4$an);
      }
    });

    const _hoisted_1$kG = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kG = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M186.62 464H160a16 16 0 0 1-14.57-22.6l64.46-142.25L113.1 297l-35.3 42.77C71.07 348.23 65.7 352 52 352H34.08a17.66 17.66 0 0 1-14.7-7.06c-2.38-3.21-4.72-8.65-2.44-16.41l19.82-71c.15-.53.33-1.06.53-1.58a.38.38 0 0 0 0-.15a14.82 14.82 0 0 1-.53-1.59l-19.84-71.45c-2.15-7.61.2-12.93 2.56-16.06a16.83 16.83 0 0 1 13.6-6.7H52c10.23 0 20.16 4.59 26 12l34.57 42.05l97.32-1.44l-64.44-142A16 16 0 0 1 160 48h26.91a25 25 0 0 1 19.35 9.8l125.05 152l57.77-1.52c4.23-.23 15.95-.31 18.66-.31C463 208 496 225.94 496 256c0 9.46-3.78 27-29.07 38.16c-14.93 6.6-34.85 9.94-59.21 9.94c-2.68 0-14.37-.08-18.66-.31l-57.76-1.54l-125.36 152a25 25 0 0 1-19.32 9.75z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hI = [_hoisted_2$kG];
    vue.defineComponent({
      name: 'Airplane',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kG, _hoisted_3$hI);
      }
    });

    const _hoisted_1$kF = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kF = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M407.72 224c-3.4 0-14.79.1-18 .3l-64.9 1.7a1.83 1.83 0 0 1-1.69-.9L193.55 67.56a9 9 0 0 0-6.66-3.56H160l73 161a2.35 2.35 0 0 1-2.26 3.35l-121.69 1.8a8.06 8.06 0 0 1-6.6-3.1l-37-45c-3-3.9-8.62-6-13.51-6H33.08c-1.29 0-1.1 1.21-.75 2.43l19.84 71.42a16.3 16.3 0 0 1 0 11.9L32.31 333c-.59 1.95-.52 3 1.77 3H52c8.14 0 9.25-1.06 13.41-6.3l37.7-45.7a8.19 8.19 0 0 1 6.6-3.1l120.68 2.7a2.7 2.7 0 0 1 2.43 3.74L160 448h26.64a9 9 0 0 0 6.65-3.55L323.14 287c.39-.6 2-.9 2.69-.9l63.9 1.7c3.3.2 14.59.3 18 .3C452 288.1 480 275.93 480 256s-27.88-32-72.28-32z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hH = [_hoisted_2$kF];
    vue.defineComponent({
      name: 'AirplaneOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kF, _hoisted_3$hH);
      }
    });

    const _hoisted_1$kE = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kE = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M407.72 208c-2.72 0-14.44.08-18.67.31l-57.77 1.52L198.06 48h-62.81l74.59 164.61l-97.31 1.44L68.25 160H16.14l20.61 94.18c.15.54.33 1.07.53 1.59a.26.26 0 0 1 0 .15a15.42 15.42 0 0 0-.53 1.58L15.86 352h51.78l45.45-55l96.77 2.17L135.24 464h63l133-161.75l57.77 1.54c4.29.23 16 .31 18.66.31c24.35 0 44.27-3.34 59.21-9.94C492.22 283 496 265.46 496 256c0-30.06-33-48-88.28-48zm-71.29 87.9z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hG = [_hoisted_2$kE];
    vue.defineComponent({
      name: 'AirplaneSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kE, _hoisted_3$hG);
      }
    });

    const _hoisted_1$kD = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kD = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M153.59 110.46A21.41 21.41 0 0 0 152.48 79A62.67 62.67 0 0 0 112 64l-3.27.09h-.48C74.4 66.15 48 95.55 48.07 131c0 19 8 29.06 14.32 37.11a20.61 20.61 0 0 0 14.7 7.8c.26 0 .7.05 2 .05a19.06 19.06 0 0 0 13.75-5.89z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hF = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M403.79 64.11l-3.27-.1H400a62.67 62.67 0 0 0-40.52 15a21.41 21.41 0 0 0-1.11 31.44l60.77 59.65a19.06 19.06 0 0 0 13.79 5.9c1.28 0 1.72 0 2-.05a20.61 20.61 0 0 0 14.69-7.8c6.36-8.05 14.28-18.08 14.32-37.11c.06-35.49-26.34-64.89-60.15-66.93z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$am = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256.07 96c-97 0-176 78.95-176 176a175.23 175.23 0 0 0 40.81 112.56l-36.12 36.13a16 16 0 1 0 22.63 22.62l36.12-36.12a175.63 175.63 0 0 0 225.12 0l36.13 36.12a16 16 0 1 0 22.63-22.62l-36.13-36.13A175.17 175.17 0 0 0 432.07 272c0-97-78.95-176-176-176zm16 176a16 16 0 0 1-16 16h-80a16 16 0 0 1 0-32h64v-96a16 16 0 0 1 32 0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4S = [_hoisted_2$kD, _hoisted_3$hF, _hoisted_4$am];
    vue.defineComponent({
      name: 'Alarm',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kD, _hoisted_5$4S);
      }
    });

    const _hoisted_1$kC = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kC = /*#__PURE__*/vue.createStaticVNode('<path d="M416.07 272a160 160 0 1 0-160 160a160 160 0 0 0 160-160z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path d="M142.12 91.21A46.67 46.67 0 0 0 112 80l-2.79.08C83.66 81.62 64 104 64.07 131c0 13.21 4.66 19.37 10.88 27.23a4.55 4.55 0 0 0 3.24 1.77h.88a3.23 3.23 0 0 0 2.54-1.31L142.38 99a5.38 5.38 0 0 0 1.55-4a5.26 5.26 0 0 0-1.81-3.79z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path d="M369.88 91.21A46.67 46.67 0 0 1 400 80l2.79.08C428.34 81.62 448 104 447.93 131c0 13.21-4.66 19.37-10.88 27.23a4.55 4.55 0 0 1-3.24 1.76h-.88a3.23 3.23 0 0 1-2.54-1.31L369.62 99a5.38 5.38 0 0 1-1.55-4a5.26 5.26 0 0 1 1.81-3.79z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256.07 160v112h-80"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M416.07 432l-40-40"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M96.07 432l40-40"></path>', 6);

    const _hoisted_8$E = [_hoisted_2$kC];
    vue.defineComponent({
      name: 'AlarmOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kC, _hoisted_8$E);
      }
    });

    const _hoisted_1$kB = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kB = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M403.79 64.11l-3.27-.1H400c-14.73 0-28.55 5.91-40.52 15S344 96 344 96l88 86s11.25-5.71 17.61-13.85s14.28-18.08 14.32-37.11c.07-35.49-26.33-64.89-60.14-66.93z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hE = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M108.21 64.11l3.27-.1h.52c14.73 0 28.55 5.91 40.52 15S168 96 168 96l-88 86s-11.25-5.71-17.61-13.85S48.11 150.07 48.07 131C48 95.55 74.4 66.15 108.21 64.11z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$al = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M391.3 384.6a.06.06 0 0 1 0-.08C425 344 441 288.24 427 229.23c-13.64-57.52-72.67-115.69-130.34-128.66C182 74.79 80.07 161.71 80.07 272a175.15 175.15 0 0 0 40.78 112.52a.06.06 0 0 1 0 .08L73 432a.06.06 0 0 0 0 .08l23 22.51a.06.06 0 0 0 .08 0l47.43-47.37a.06.06 0 0 1 .08 0a175.64 175.64 0 0 0 225.05 0h.07L416 454.59a.06.06 0 0 0 .08 0L440 432zM272.07 288h-112h-.07v-31.9l.05-.05h80V144h32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4R = [_hoisted_2$kB, _hoisted_3$hE, _hoisted_4$al];
    vue.defineComponent({
      name: 'AlarmSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kB, _hoisted_5$4R);
      }
    });

    const _hoisted_1$kA = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kA = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M368 96H144a16 16 0 0 1 0-32h224a16 16 0 0 1 0 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hD = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400 144H112a16 16 0 0 1 0-32h288a16 16 0 0 1 0 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$ak = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M419.13 448H92.87A44.92 44.92 0 0 1 48 403.13V204.87A44.92 44.92 0 0 1 92.87 160h326.26A44.92 44.92 0 0 1 464 204.87v198.26A44.92 44.92 0 0 1 419.13 448z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4Q = [_hoisted_2$kA, _hoisted_3$hD, _hoisted_4$ak];
    vue.defineComponent({
      name: 'Albums',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kA, _hoisted_5$4Q);
      }
    });

    const _hoisted_1$kz = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kz = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '64',
      y: '176',
      width: '384',
      height: '256',
      rx: '28.87',
      ry: '28.87',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hC = /*#__PURE__*/vue.createElementVNode('path', {
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M144 80h224',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$aj = /*#__PURE__*/vue.createElementVNode('path', {
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M112 128h288',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4P = [_hoisted_2$kz, _hoisted_3$hC, _hoisted_4$aj];
    vue.defineComponent({
      name: 'AlbumsOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kz, _hoisted_5$4P);
      }
    });

    const _hoisted_1$ky = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ky = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M128 64h256v32H128z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hB = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M96 112h320v32H96z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$ai = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 448H48V160h416z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4O = [_hoisted_2$ky, _hoisted_3$hB, _hoisted_4$ai];
    vue.defineComponent({
      name: 'AlbumsSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ky, _hoisted_5$4O);
      }
    });

    const _hoisted_1$kx = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kx = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 80c-8.66 0-16.58 7.36-16 16l8 216a8 8 0 0 0 8 8h0a8 8 0 0 0 8-8l8-216c.58-8.64-7.34-16-16-16z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hA = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '416',
      r: '16',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$ah = [_hoisted_2$kx, _hoisted_3$hA];
    vue.defineComponent({
      name: 'Alert',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kx, _hoisted_4$ah);
      }
    });

    const _hoisted_1$kw = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kw = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm0 319.91a20 20 0 1 1 20-20a20 20 0 0 1-20 20zm21.72-201.15l-5.74 122a16 16 0 0 1-32 0l-5.74-121.94v-.05a21.74 21.74 0 1 1 43.44 0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hz = [_hoisted_2$kw];
    vue.defineComponent({
      name: 'AlertCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kw, _hoisted_3$hz);
      }
    });

    const _hoisted_1$kv = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kv = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hy = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M250.26 166.05L256 288l5.73-121.95a5.74 5.74 0 0 0-5.79-6h0a5.74 5.74 0 0 0-5.68 6z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$ag = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 367.91a20 20 0 1 1 20-20a20 20 0 0 1-20 20z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4N = [_hoisted_2$kv, _hoisted_3$hy, _hoisted_4$ag];
    vue.defineComponent({
      name: 'AlertCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kv, _hoisted_5$4N);
      }
    });

    const _hoisted_1$ku = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ku = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      d: 'M240 304h32l6-160h-44l6 160z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hx = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm20 319.91h-40v-40h40zM272 304h-32l-6-160h44z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$af = [_hoisted_2$ku, _hoisted_3$hx];
    vue.defineComponent({
      name: 'AlertCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ku, _hoisted_4$af);
      }
    });

    const _hoisted_1$kt = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kt = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 80c-8.66 0-16.58 7.36-16 16l8 216a8 8 0 0 0 8 8h0a8 8 0 0 0 8-8l8-216c.58-8.64-7.34-16-16-16z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hw = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '416',
      r: '16',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$ae = [_hoisted_2$kt, _hoisted_3$hw];
    vue.defineComponent({
      name: 'AlertOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kt, _hoisted_4$ae);
      }
    });

    const _hoisted_1$ks = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ks = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M240 80l8 240h16l8-240h-32z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hv = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M240 400h32v32h-32z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$ad = [_hoisted_2$ks, _hoisted_3$hv];
    vue.defineComponent({
      name: 'AlertSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ks, _hoisted_4$ad);
      }
    });

    const _hoisted_1$kr = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kr = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M122.06 122.06c-44.37 44.37-66.71 100.61-78 145.28l200.6 200.56c44.67-11.25 100.91-33.59 145.28-78s66.71-100.61 78-145.28L267.34 44.1c-44.67 11.25-100.91 33.59-145.28 77.96zm256.73 256.72zM300.65 189L323 166.71A15.78 15.78 0 0 1 345.29 189L323 211.35l11.16 11.17a15.78 15.78 0 0 1-22.32 22.32l-11.16-11.16L278.32 256l11.16 11.16a15.78 15.78 0 1 1-22.32 22.32L256 278.32l-22.32 22.33l11.16 11.16a15.78 15.78 0 1 1-22.32 22.32L211.35 323L189 345.29A15.78 15.78 0 0 1 166.71 323L189 300.65l-11.16-11.17a15.78 15.78 0 0 1 22.32-22.32l11.16 11.16L233.68 256l-11.16-11.16a15.78 15.78 0 1 1 22.32-22.32L256 233.68l22.32-22.33l-11.16-11.16a15.78 15.78 0 0 1 22.32-22.32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hu = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M476.57 199.63c7.31-54.53 4-120.26-20-144.21s-89.68-27.3-144.21-20c-2.51.34-5.16.72-7.91 1.15l171 171c.4-2.78.78-5.43 1.12-7.94z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$ac = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M35.43 312.37c-7.31 54.53-4 120.26 20 144.21C72.17 473.33 109.34 480 148.84 480a387 387 0 0 0 50.79-3.43c2.51-.34 5.16-.72 7.91-1.15l-171-171c-.39 2.79-.77 5.44-1.11 7.95z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4M = [_hoisted_2$kr, _hoisted_3$hu, _hoisted_4$ac];
    vue.defineComponent({
      name: 'AmericanFootball',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kr, _hoisted_5$4M);
      }
    });

    const _hoisted_1$kq = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kq = /*#__PURE__*/vue.createStaticVNode('<ellipse cx="256" cy="256" rx="267.57" ry="173.44" transform="rotate(-45 256 256.002)" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></ellipse><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M334.04 177.96L177.96 334.04"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M278.3 278.3l-44.6-44.6"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M322.89 233.7l-44.59-44.59"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M456.68 211.4L300.6 55.32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M211.4 456.68L55.32 300.6"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M233.7 322.89l-44.59-44.59"></path>', 7);

    const _hoisted_9$l = [_hoisted_2$kq];
    vue.defineComponent({
      name: 'AmericanFootballOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kq, _hoisted_9$l);
      }
    });

    const _hoisted_1$kp = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kp = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M120.9 120.51c-44.75 44.56-67.29 101.05-78.64 145.9l202.31 201.44c45.05-11.3 101.78-33.74 146.53-78.3s67.29-101.05 78.64-145.91L267.43 42.21C222.38 53.51 165.65 76 120.9 120.51zm259 257.83zm-45-224.2l22.52 22.42l-33.78 33.63l22.52 22.42L323.55 255L301 232.61L278.52 255L301 277.45l-22.51 22.42L256 277.45l-22.52 22.42L256 322.29l-22.52 22.42L211 322.29l-33.78 33.63l-22.55-22.42l33.78-33.63l-22.52-22.42L188.45 255L211 277.45L233.48 255L211 232.61l22.51-22.42L256 232.61l22.52-22.42L256 187.77l22.52-22.42L301 187.77z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ht = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M478.48 198.41C485.85 143.65 464 48.05 464 48.05s-96.14-21.88-151.14-14.54c-2.54.33-5.21.72-8 1.14l172.47 171.71c.43-2.76.81-5.42 1.15-7.95z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$ab = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M33.52 311.65C26.15 366.41 48.05 464 48.05 464s60 16 99.86 16a391.92 391.92 0 0 0 51.23-3.45c2.54-.33 5.21-.72 8-1.15L34.67 303.7c-.43 2.76-.81 5.42-1.15 7.95z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4L = [_hoisted_2$kp, _hoisted_3$ht, _hoisted_4$ab];
    vue.defineComponent({
      name: 'AmericanFootballSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kp, _hoisted_5$4L);
      }
    });

    const _hoisted_1$ko = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ko = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M456 128a40 40 0 0 0-37.23 54.6l-84.17 84.17a39.86 39.86 0 0 0-29.2 0l-60.17-60.17a40 40 0 1 0-74.46 0L70.6 306.77a40 40 0 1 0 22.63 22.63L193.4 229.23a39.86 39.86 0 0 0 29.2 0l60.17 60.17a40 40 0 1 0 74.46 0l84.17-84.17A40 40 0 1 0 456 128z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hs = [_hoisted_2$ko];
    vue.defineComponent({
      name: 'Analytics',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ko, _hoisted_3$hs);
      }
    });

    const _hoisted_1$kn = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kn = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M344 280l88-88"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M232 216l64 64"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M80 320l104-104"></path><circle cx="456" cy="168" r="24" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><circle cx="320" cy="304" r="24" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><circle cx="208" cy="192" r="24" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><circle cx="56" cy="344" r="24" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle>', 7);

    const _hoisted_9$k = [_hoisted_2$kn];
    vue.defineComponent({
      name: 'AnalyticsOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kn, _hoisted_9$k);
      }
    });

    const _hoisted_1$km = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$km = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M450 128a46 46 0 0 0-44.11 59l-71.37 71.36a45.88 45.88 0 0 0-29 0l-52.91-52.91a46 46 0 1 0-89.12 0L75 293.88A46.08 46.08 0 1 0 106.11 325l87.37-87.36a45.85 45.85 0 0 0 29 0l52.92 52.92a46 46 0 1 0 89.12 0L437 218.12A46 46 0 1 0 450 128z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hr = [_hoisted_2$km];
    vue.defineComponent({
      name: 'AnalyticsSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$km, _hoisted_3$hr);
      }
    });

    const _hoisted_1$kl = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kl = /*#__PURE__*/vue.createStaticVNode('<path d="M250.54 129.17l-67.8-67.8A209.65 209.65 0 0 0 86.32 136h161.4a4 4 0 0 0 2.82-6.83z" fill="currentColor"></path><path d="M167.72 168H67.63a207.34 207.34 0 0 0-16.15 125.9l119.06-119.07a4 4 0 0 0-2.82-6.83z" fill="currentColor"></path><path d="M344 167.72V67.56a207.82 207.82 0 0 0-125.89-16.08l119.06 119.06a4 4 0 0 0 6.83-2.82z" fill="currentColor"></path><path d="M460.52 218.1L341.46 337.17a4 4 0 0 0 2.82 6.83h100.09a207.34 207.34 0 0 0 16.15-125.9z" fill="currentColor"></path><path d="M382.83 250.54l67.83-67.82A209.08 209.08 0 0 0 376 86.2v161.52a4 4 0 0 0 6.83 2.82z" fill="currentColor"></path><path d="M221.68 341.77a8 8 0 0 0 5.54 2.23h59.66a8 8 0 0 0 5.7-2.39l49.18-50a8 8 0 0 0 2.3-5.62l-.06-60.81a8 8 0 0 0-2.38-5.69l-50-49.25a8 8 0 0 0-5.63-2.3l-60.84.06a8 8 0 0 0-5.69 2.38l-49.25 50a8 8 0 0 0-2.3 5.63l.06 60.78a8 8 0 0 0 2.45 5.76z" fill="currentColor"></path><path d="M261.46 382.83l67.8 67.8A209.65 209.65 0 0 0 425.68 376h-161.4a4 4 0 0 0-2.82 6.83z" fill="currentColor"></path><path d="M168 344.28v100.16a207.82 207.82 0 0 0 125.89 16.08L174.83 341.46a4 4 0 0 0-6.83 2.82z" fill="currentColor"></path><path d="M129.17 261.46l-67.83 67.83A209.1 209.1 0 0 0 136 425.8V264.28a4 4 0 0 0-6.83-2.82z" fill="currentColor"></path>', 9);

    const _hoisted_11$f = [_hoisted_2$kl];
    vue.defineComponent({
      name: 'Aperture',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kl, _hoisted_11$f);
      }
    });

    const _hoisted_1$kk = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kk = /*#__PURE__*/vue.createStaticVNode('<path d="M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M360 94.59V296"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M443.13 212.87L296 360"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M417.41 360H216"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M299.13 443.13l-144-144"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M152 416V216"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M68.87 299.13l144-144"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M94.59 152H288"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M212.87 68.87L360 216"></path>', 9);

    const _hoisted_11$e = [_hoisted_2$kk];
    vue.defineComponent({
      name: 'ApertureOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kk, _hoisted_11$e);
      }
    });

    const _hoisted_1$kj = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kj = /*#__PURE__*/vue.createStaticVNode('<path d="M216 48l129.49 128.18V48H216z" fill="currentColor"></path><path d="M181.47 58.38L80 134h176l-74.53-75.62z" fill="currentColor"></path><path d="M336 344h128V216L336 344z" fill="currentColor"></path><path d="M454 182L378 80v176l76-74z" fill="currentColor"></path><path d="M48 166v128l128-128H48z" fill="currentColor"></path><path d="M330 454l102-76H256l74 76z" fill="currentColor"></path><path d="M58 330l76 102V256l-76 74z" fill="currentColor"></path><path d="M345.49 222.12l-55.55-55.46h-67.88l-55.55 55.46v67.76l55.62 55.52c.44 0 .88-.06 1.33-.06h66.48l55.55-55.46z" fill="currentColor"></path><path d="M165.98 336.09L166 464h128L165.98 336.09z" fill="currentColor"></path>', 9);

    const _hoisted_11$d = [_hoisted_2$kj];
    vue.defineComponent({
      name: 'ApertureSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kj, _hoisted_11$d);
      }
    });

    const _hoisted_1$ki = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ki = /*#__PURE__*/vue.createStaticVNode('<path d="M104 160a56 56 0 1 1 56-56a56.06 56.06 0 0 1-56 56z" fill="currentColor"></path><path d="M256 160a56 56 0 1 1 56-56a56.06 56.06 0 0 1-56 56z" fill="currentColor"></path><path d="M408 160a56 56 0 1 1 56-56a56.06 56.06 0 0 1-56 56z" fill="currentColor"></path><path d="M104 312a56 56 0 1 1 56-56a56.06 56.06 0 0 1-56 56z" fill="currentColor"></path><path d="M256 312a56 56 0 1 1 56-56a56.06 56.06 0 0 1-56 56z" fill="currentColor"></path><path d="M408 312a56 56 0 1 1 56-56a56.06 56.06 0 0 1-56 56z" fill="currentColor"></path><path d="M104 464a56 56 0 1 1 56-56a56.06 56.06 0 0 1-56 56z" fill="currentColor"></path><path d="M256 464a56 56 0 1 1 56-56a56.06 56.06 0 0 1-56 56z" fill="currentColor"></path><path d="M408 464a56 56 0 1 1 56-56a56.06 56.06 0 0 1-56 56z" fill="currentColor"></path>', 9);

    const _hoisted_11$c = [_hoisted_2$ki];
    vue.defineComponent({
      name: 'Apps',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ki, _hoisted_11$c);
      }
    });

    const _hoisted_1$kh = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kh = /*#__PURE__*/vue.createStaticVNode('<rect x="64" y="64" width="80" height="80" rx="40" ry="40" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></rect><rect x="216" y="64" width="80" height="80" rx="40" ry="40" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></rect><rect x="368" y="64" width="80" height="80" rx="40" ry="40" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></rect><rect x="64" y="216" width="80" height="80" rx="40" ry="40" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></rect><rect x="216" y="216" width="80" height="80" rx="40" ry="40" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></rect><rect x="368" y="216" width="80" height="80" rx="40" ry="40" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></rect><rect x="64" y="368" width="80" height="80" rx="40" ry="40" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></rect><rect x="216" y="368" width="80" height="80" rx="40" ry="40" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></rect><rect x="368" y="368" width="80" height="80" rx="40" ry="40" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></rect>', 9);

    const _hoisted_11$b = [_hoisted_2$kh];
    vue.defineComponent({
      name: 'AppsOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kh, _hoisted_11$b);
      }
    });

    const _hoisted_1$kg = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kg = /*#__PURE__*/vue.createStaticVNode('<rect x="48" y="48" width="112" height="112" rx="8" ry="8" fill="currentColor"></rect><rect x="200" y="48" width="112" height="112" rx="8" ry="8" fill="currentColor"></rect><rect x="352" y="48" width="112" height="112" rx="8" ry="8" fill="currentColor"></rect><rect x="48" y="200" width="112" height="112" rx="8" ry="8" fill="currentColor"></rect><rect x="200" y="200" width="112" height="112" rx="8" ry="8" fill="currentColor"></rect><rect x="352" y="200" width="112" height="112" rx="8" ry="8" fill="currentColor"></rect><rect x="48" y="352" width="112" height="112" rx="8" ry="8" fill="currentColor"></rect><rect x="200" y="352" width="112" height="112" rx="8" ry="8" fill="currentColor"></rect><rect x="352" y="352" width="112" height="112" rx="8" ry="8" fill="currentColor"></rect>', 9);

    const _hoisted_11$a = [_hoisted_2$kg];
    vue.defineComponent({
      name: 'AppsSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kg, _hoisted_11$a);
      }
    });

    const _hoisted_1$kf = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kf = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M64 164v244a56 56 0 0 0 56 56h272a56 56 0 0 0 56-56V164a4 4 0 0 0-4-4H68a4 4 0 0 0-4 4zm267 151.63l-63.69 63.68a16 16 0 0 1-22.62 0L181 315.63c-6.09-6.09-6.65-16-.85-22.38a16 16 0 0 1 23.16-.56L240 329.37V224.45c0-8.61 6.62-16 15.23-16.43A16 16 0 0 1 272 224v105.37l36.69-36.68a16 16 0 0 1 23.16.56c5.8 6.37 5.24 16.29-.85 22.38z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hq = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '32',
      y: '48',
      width: '448',
      height: '80',
      rx: '32',
      ry: '32',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$aa = [_hoisted_2$kf, _hoisted_3$hq];
    vue.defineComponent({
      name: 'Archive',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kf, _hoisted_4$aa);
      }
    });

    const _hoisted_1$ke = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ke = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M80 152v256a40.12 40.12 0 0 0 40 40h272a40.12 40.12 0 0 0 40-40V152',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hp = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '48',
      y: '64',
      width: '416',
      height: '80',
      rx: '28',
      ry: '28',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$a9 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M320 304l-64 64l-64-64'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4K = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 345.89V224'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1Z = [_hoisted_2$ke, _hoisted_3$hp, _hoisted_4$a9, _hoisted_5$4K];
    vue.defineComponent({
      name: 'ArchiveOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ke, _hoisted_6$1Z);
      }
    });

    const _hoisted_1$kd = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kd = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '32',
      y: '48',
      width: '448',
      height: '80',
      rx: '12',
      ry: '12',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ho = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M64 160v280a24 24 0 0 0 24 24h336a24 24 0 0 0 24-24V160zm192 230.63L169.32 304L192 281.32l48 48.05V208h32v121.37l48.07-48.07l22.61 22.64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$a8 = [_hoisted_2$kd, _hoisted_3$ho];
    vue.defineComponent({
      name: 'ArchiveSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kd, _hoisted_4$a8);
      }
    });

    const _hoisted_1$kc = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kc = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M244 400L100 256l144-144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hn = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M120 256h292'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$a7 = [_hoisted_2$kc, _hoisted_3$hn];
    vue.defineComponent({
      name: 'ArrowBack',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kc, _hoisted_4$a7);
      }
    });

    const _hoisted_1$kb = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$kb = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 256c0 114.87 93.13 208 208 208s208-93.13 208-208S370.87 48 256 48S48 141.13 48 256zm212.65-91.36a16 16 0 0 1 .09 22.63L208.42 240H342a16 16 0 0 1 0 32H208.42l52.32 52.73A16 16 0 1 1 238 347.27l-79.39-80a16 16 0 0 1 0-22.54l79.39-80a16 16 0 0 1 22.65-.09z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hm = [_hoisted_2$kb];
    vue.defineComponent({
      name: 'ArrowBackCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$kb, _hoisted_3$hm);
      }
    });

    const _hoisted_1$ka = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ka = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M249.38 336L170 256l79.38-80'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hl = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M181.03 256H342'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$a6 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4J = [_hoisted_2$ka, _hoisted_3$hl, _hoisted_4$a6];
    vue.defineComponent({
      name: 'ArrowBackCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ka, _hoisted_5$4J);
      }
    });

    const _hoisted_1$k9 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$k9 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 256c0 114.87 93.13 208 208 208s208-93.13 208-208S370.87 48 256 48S48 141.13 48 256zm224-80.09L208.42 240H358v32H208.42L272 336.09l-22.7 22.54L147.46 256L249.3 153.37z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hk = [_hoisted_2$k9];
    vue.defineComponent({
      name: 'ArrowBackCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$k9, _hoisted_3$hk);
      }
    });

    const _hoisted_1$k8 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$k8 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M244 400L100 256l144-144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hj = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M120 256h292'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$a5 = [_hoisted_2$k8, _hoisted_3$hj];
    vue.defineComponent({
      name: 'ArrowBackOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$k8, _hoisted_4$a5);
      }
    });

    const _hoisted_1$k7 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$k7 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '48',
      d: 'M244 400L100 256l144-144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hi = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '48',
      d: 'M120 256h292'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$a4 = [_hoisted_2$k7, _hoisted_3$hi];
    vue.defineComponent({
      name: 'ArrowBackSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$k7, _hoisted_4$a4);
      }
    });

    const _hoisted_1$k6 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$k6 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M112 268l144 144l144-144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hh = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M256 392V100'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$a3 = [_hoisted_2$k6, _hoisted_3$hh];
    vue.defineComponent({
      name: 'ArrowDown',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$k6, _hoisted_4$a3);
      }
    });

    const _hoisted_1$k5 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$k5 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 464c114.87 0 208-93.13 208-208S370.87 48 256 48S48 141.13 48 256s93.13 208 208 208zm-91.36-212.65a16 16 0 0 1 22.63-.09L240 303.58V170a16 16 0 0 1 32 0v133.58l52.73-52.32A16 16 0 1 1 347.27 274l-80 79.39a16 16 0 0 1-22.54 0l-80-79.39a16 16 0 0 1-.09-22.65z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hg = [_hoisted_2$k5];
    vue.defineComponent({
      name: 'ArrowDownCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$k5, _hoisted_3$hg);
      }
    });

    const _hoisted_1$k4 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$k4 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M176 262.62L256 342l80-79.38'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hf = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 330.97V170'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$a2 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 64C150 64 64 150 64 256s86 192 192 192s192-86 192-192S362 64 256 64z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4I = [_hoisted_2$k4, _hoisted_3$hf, _hoisted_4$a2];
    vue.defineComponent({
      name: 'ArrowDownCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$k4, _hoisted_5$4I);
      }
    });

    const _hoisted_1$k3 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$k3 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 464c114.87 0 208-93.13 208-208S370.87 48 256 48S48 141.13 48 256s93.13 208 208 208zm-80.09-224L240 303.58V154h32v149.58L336.09 240l22.54 22.71L256 364.54L153.37 262.7z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$he = [_hoisted_2$k3];
    vue.defineComponent({
      name: 'ArrowDownCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$k3, _hoisted_3$he);
      }
    });

    const _hoisted_1$k2 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$k2 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M112 268l144 144l144-144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hd = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M256 392V100'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$a1 = [_hoisted_2$k2, _hoisted_3$hd];
    vue.defineComponent({
      name: 'ArrowDownOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$k2, _hoisted_4$a1);
      }
    });

    const _hoisted_1$k1 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$k1 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '48',
      d: 'M112 268l144 144l144-144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hc = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '48',
      d: 'M256 392V100'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$a0 = [_hoisted_2$k1, _hoisted_3$hc];
    vue.defineComponent({
      name: 'ArrowDownSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$k1, _hoisted_4$a0);
      }
    });

    const _hoisted_1$k0 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$k0 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M268 112l144 144l-144 144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$hb = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M392 256H100'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9$ = [_hoisted_2$k0, _hoisted_3$hb];
    vue.defineComponent({
      name: 'ArrowForward',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$k0, _hoisted_4$9$);
      }
    });

    const _hoisted_1$j$ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$j$ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 256c0-114.87-93.13-208-208-208S48 141.13 48 256s93.13 208 208 208s208-93.13 208-208zm-212.65 91.36a16 16 0 0 1-.09-22.63L303.58 272H170a16 16 0 0 1 0-32h133.58l-52.32-52.73A16 16 0 1 1 274 164.73l79.39 80a16 16 0 0 1 0 22.54l-79.39 80a16 16 0 0 1-22.65.09z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ha = [_hoisted_2$j$];
    vue.defineComponent({
      name: 'ArrowForwardCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$j$, _hoisted_3$ha);
      }
    });

    const _hoisted_1$j_ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$j_ = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M262.62 336L342 256l-79.38-80'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$h9 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M330.97 256H170'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9_ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 448c106 0 192-86 192-192S362 64 256 64S64 150 64 256s86 192 192 192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4H = [_hoisted_2$j_, _hoisted_3$h9, _hoisted_4$9_];
    vue.defineComponent({
      name: 'ArrowForwardCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$j_, _hoisted_5$4H);
      }
    });

    const _hoisted_1$jZ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jZ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 256c0-114.87-93.13-208-208-208S48 141.13 48 256s93.13 208 208 208s208-93.13 208-208zm-224 80.09L303.58 272H154v-32h149.58L240 175.91l22.71-22.54L364.54 256L262.7 358.63z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$h8 = [_hoisted_2$jZ];
    vue.defineComponent({
      name: 'ArrowForwardCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jZ, _hoisted_3$h8);
      }
    });

    const _hoisted_1$jY = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jY = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M268 112l144 144l-144 144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$h7 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M392 256H100'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9Z = [_hoisted_2$jY, _hoisted_3$h7];
    vue.defineComponent({
      name: 'ArrowForwardOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jY, _hoisted_4$9Z);
      }
    });

    const _hoisted_1$jX = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jX = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '48',
      d: 'M268 112l144 144l-144 144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$h6 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '48',
      d: 'M392 256H100'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9Y = [_hoisted_2$jX, _hoisted_3$h6];
    vue.defineComponent({
      name: 'ArrowForwardSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jX, _hoisted_4$9Y);
      }
    });

    const _hoisted_1$jW = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jW = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M58.79 439.13A16 16 0 0 1 48 424c0-73.1 14.68-131.56 43.65-173.77c35-51 90.21-78.46 164.35-81.87V88a16 16 0 0 1 27.05-11.57l176 168a16 16 0 0 1 0 23.14l-176 168A16 16 0 0 1 256 424v-79.77c-45 1.36-79 8.65-106.07 22.64c-29.25 15.12-50.46 37.71-73.32 67a16 16 0 0 1-17.82 5.28z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$h5 = [_hoisted_2$jW];
    vue.defineComponent({
      name: 'ArrowRedo',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jW, _hoisted_3$h5);
      }
    });

    const _hoisted_1$jV = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jV = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 256c0 114.87 93.13 208 208 208s208-93.13 208-208S370.87 48 256 48S48 141.13 48 256zm96 66.67c5.45-61.45 34.14-117.09 122.87-117.09v-37.32a8.32 8.32 0 0 1 14-6L365.42 242a8.2 8.2 0 0 1 0 11.94L281 333.71a8.32 8.32 0 0 1-14-6v-37.29c-57.07 0-84.51 13.47-108.58 38.68c-5.49 5.65-15.07 1.32-14.42-6.43z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$h4 = [_hoisted_2$jV];
    vue.defineComponent({
      name: 'ArrowRedoCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jV, _hoisted_3$h4);
      }
    });

    const _hoisted_1$jU = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jU = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M266.91 327.74v-37.32c-57.07 0-84.51 13.47-108.58 38.68c-5.4 5.65-15 1.32-14.29-6.43c5.45-61.45 34.14-117.09 122.87-117.09v-37.32a8.32 8.32 0 0 1 14-6L365.42 242a8.2 8.2 0 0 1 0 11.94L281 333.71a8.32 8.32 0 0 1-14.09-5.97z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$h3 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M64 256c0 106 86 192 192 192s192-86 192-192S362 64 256 64S64 150 64 256z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9X = [_hoisted_2$jU, _hoisted_3$h3];
    vue.defineComponent({
      name: 'ArrowRedoCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jU, _hoisted_4$9X);
      }
    });

    const _hoisted_1$jT = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jT = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 256c0 114.87 93.13 208 208 208s208-93.13 208-208S370.87 48 256 48S48 141.13 48 256zm98 88c0-68.13 22.67-137.14 119.17-137.14V152L366 248l-100.83 96v-54.86c-66.69 0-91.32 19.29-119.17 54.86z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$h2 = [_hoisted_2$jT];
    vue.defineComponent({
      name: 'ArrowRedoCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jT, _hoisted_3$h2);
      }
    });

    const _hoisted_1$jS = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jS = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256L272 88v96C103.57 184 64 304.77 64 424c48.61-62.24 91.6-96 208-96v96z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$h1 = [_hoisted_2$jS];
    vue.defineComponent({
      name: 'ArrowRedoOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jS, _hoisted_3$h1);
      }
    });

    const _hoisted_1$jR = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jR = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 399.26C48 335.19 62.44 284 90.91 247c34.38-44.67 88.68-68.77 161.56-71.75V72L464 252L252.47 432V329.35c-44.25 1.19-77.66 7.58-104.27 19.84c-28.75 13.25-49.6 33.05-72.08 58.7L48 440z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$h0 = [_hoisted_2$jR];
    vue.defineComponent({
      name: 'ArrowRedoSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jR, _hoisted_3$h0);
      }
    });

    const _hoisted_1$jQ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jQ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 440a16 16 0 0 1-12.61-6.15c-22.86-29.27-44.07-51.86-73.32-67C335 352.88 301 345.59 256 344.23V424a16 16 0 0 1-27 11.57l-176-168a16 16 0 0 1 0-23.14l176-168A16 16 0 0 1 256 88v80.36c74.14 3.41 129.38 30.91 164.35 81.87C449.32 292.44 464 350.9 464 424a16 16 0 0 1-16 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$g$ = [_hoisted_2$jQ];
    vue.defineComponent({
      name: 'ArrowUndo',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jQ, _hoisted_3$g$);
      }
    });

    const _hoisted_1$jP = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jP = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.13 48 48 141.13 48 256s93.13 208 208 208s208-93.13 208-208S370.87 48 256 48zm97.67 281.1c-24.07-25.21-51.51-38.68-108.58-38.68v37.32a8.32 8.32 0 0 1-14.05 6L146.58 254a8.2 8.2 0 0 1 0-11.94L231 162.29a8.32 8.32 0 0 1 14.05 6v37.32c88.73 0 117.42 55.64 122.87 117.09c.73 7.72-8.85 12.05-14.25 6.4z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$g_ = [_hoisted_2$jP];
    vue.defineComponent({
      name: 'ArrowUndoCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jP, _hoisted_3$g_);
      }
    });

    const _hoisted_1$jO = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jO = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M245.09 327.74v-37.32c57.07 0 84.51 13.47 108.58 38.68c5.4 5.65 15 1.32 14.29-6.43c-5.45-61.45-34.14-117.09-122.87-117.09v-37.32a8.32 8.32 0 0 0-14.05-6L146.58 242a8.2 8.2 0 0 0 0 11.94L231 333.71a8.32 8.32 0 0 0 14.09-5.97z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gZ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 64C150 64 64 150 64 256s86 192 192 192s192-86 192-192S362 64 256 64z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9W = [_hoisted_2$jO, _hoisted_3$gZ];
    vue.defineComponent({
      name: 'ArrowUndoCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jO, _hoisted_4$9W);
      }
    });

    const _hoisted_1$jN = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jN = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.13 48 48 141.13 48 256s93.13 208 208 208s208-93.13 208-208S370.87 48 256 48zm-9.17 241.14V344L146 248l100.83-96v54.86c96.5 0 119.17 69 119.17 137.14c-27.85-35.57-52.48-54.86-119.17-54.86z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gY = [_hoisted_2$jN];
    vue.defineComponent({
      name: 'ArrowUndoCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jN, _hoisted_3$gY);
      }
    });

    const _hoisted_1$jM = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jM = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M240 424v-96c116.4 0 159.39 33.76 208 96c0-119.23-39.57-240-208-240V88L64 256z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gX = [_hoisted_2$jM];
    vue.defineComponent({
      name: 'ArrowUndoOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jM, _hoisted_3$gX);
      }
    });

    const _hoisted_1$jL = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jL = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 440l-28.12-32.11c-22.48-25.65-43.33-45.45-72.08-58.7c-26.61-12.26-60-18.65-104.27-19.84V432L48 252L259.53 72v103.21c72.88 3 127.18 27.08 161.56 71.75C449.56 284 464 335.19 464 399.26z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gW = [_hoisted_2$jL];
    vue.defineComponent({
      name: 'ArrowUndoSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jL, _hoisted_3$gW);
      }
    });

    const _hoisted_1$jK = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jK = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M112 244l144-144l144 144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gV = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M256 120v292'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9V = [_hoisted_2$jK, _hoisted_3$gV];
    vue.defineComponent({
      name: 'ArrowUp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jK, _hoisted_4$9V);
      }
    });

    const _hoisted_1$jJ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jJ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.13 48 48 141.13 48 256s93.13 208 208 208s208-93.13 208-208S370.87 48 256 48zm91.36 212.65a16 16 0 0 1-22.63.09L272 208.42V342a16 16 0 0 1-32 0V208.42l-52.73 52.32A16 16 0 1 1 164.73 238l80-79.39a16 16 0 0 1 22.54 0l80 79.39a16 16 0 0 1 .09 22.65z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gU = [_hoisted_2$jJ];
    vue.defineComponent({
      name: 'ArrowUpCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jJ, _hoisted_3$gU);
      }
    });

    const _hoisted_1$jI = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jI = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M176 249.38L256 170l80 79.38'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gT = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 181.03V342'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9U = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4G = [_hoisted_2$jI, _hoisted_3$gT, _hoisted_4$9U];
    vue.defineComponent({
      name: 'ArrowUpCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jI, _hoisted_5$4G);
      }
    });

    const _hoisted_1$jH = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jH = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.13 48 48 141.13 48 256s93.13 208 208 208s208-93.13 208-208S370.87 48 256 48zm80.09 224L272 208.42V358h-32V208.42L175.91 272l-22.54-22.7L256 147.46L358.63 249.3z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gS = [_hoisted_2$jH];
    vue.defineComponent({
      name: 'ArrowUpCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jH, _hoisted_3$gS);
      }
    });

    const _hoisted_1$jG = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jG = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M112 244l144-144l144 144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gR = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M256 120v292'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9T = [_hoisted_2$jG, _hoisted_3$gR];
    vue.defineComponent({
      name: 'ArrowUpOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jG, _hoisted_4$9T);
      }
    });

    const _hoisted_1$jF = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jF = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '48',
      d: 'M112 244l144-144l144 144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gQ = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '48',
      d: 'M256 120v292'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9S = [_hoisted_2$jF, _hoisted_3$gQ];
    vue.defineComponent({
      name: 'ArrowUpSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jF, _hoisted_4$9S);
      }
    });

    const _hoisted_1$jE = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jE = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 254.27c-4.5 51-40.12 80-80.55 80s-67.34-35.82-63.45-80s37.12-80 77.55-80s70.33 36 66.45 80z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gP = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M319.77 415.77c-28.56 12-47.28 14.5-79.28 14.5c-97.2 0-169-78.8-160.49-176s94.31-176 191.51-176C381 78.27 441.19 150 432.73 246c-6.31 71.67-52.11 92.32-76.09 88.07c-22.56-4-41.18-24.42-37.74-63.5l8.48-96.25',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9R = [_hoisted_2$jE, _hoisted_3$gP];
    vue.defineComponent({
      name: 'At',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jE, _hoisted_4$9R);
      }
    });

    const _hoisted_1$jD = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jD = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M255.46 48.74c-114.84 0-208 93.11-208 208s93.12 208 208 208s208-93.12 208-208s-93.15-208-208-208zM380.28 252c-2.85 32.63-16.79 49.7-28 58.26S327.61 322.58 316 320.5a41.61 41.61 0 0 1-26.82-17.19a62.06 62.06 0 0 1-44 17.57a51.66 51.66 0 0 1-38.55-16.83c-11.38-12.42-17-30.36-15.32-49.23c3-35 30.91-57.39 56.87-61.48c27.2-4.29 52.23 6.54 62.9 19.46l3.85 4.66l-6.34 50.38c-1.19 14.34 3.28 23.48 12.29 25.1c2.39.42 8.1-.13 14.37-4.93c6.72-5.15 15.14-16 17.1-38.47c2.35-26.54-4.35-49.19-19.25-65.49c-15.49-16.9-39.09-25.84-68.23-25.84c-54 0-101.81 44.43-106.58 99c-2.28 26.2 5.67 50.68 22.4 68.93c16.36 17.86 39.31 27.74 64.66 27.74c19 0 30.61-2.05 49.48-8.78a14 14 0 0 1 9.4 26.38c-21.82 7.77-36.68 10.4-58.88 10.4c-33.28 0-63.57-13.06-85.3-36.77C138 321 127.42 288.94 130.4 254.82c2.91-33.33 18.45-64.63 43.77-88.12s57.57-36.49 90.7-36.49c37.2 0 67.93 12.08 88.87 34.93c20.09 21.91 29.51 52.75 26.54 86.86z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gO = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M252.57 221c-14.83 2.33-31.56 15.84-33.34 36.26c-1 11.06 2 21.22 8.07 27.87a23.65 23.65 0 0 0 17.91 7.75c20.31 0 34.73-14.94 36.75-38.06a14 14 0 0 1 .34-2.07l3.2-25.45a49.61 49.61 0 0 0-32.93-6.3z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9Q = [_hoisted_2$jD, _hoisted_3$gO];
    vue.defineComponent({
      name: 'AtCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jD, _hoisted_4$9Q);
      }
    });

    const _hoisted_1$jC = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jC = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448.08 256.08c0-106-86-192-192-192s-192 86-192 192s86 192 192 192s192-85.97 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gN = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M300.81 358.29c-20.83 7.42-34.05 9.59-54.19 9.59c-61.17 0-106.39-50.07-101-111.84S205 144.21 266.14 144.21c68.92 0 106.79 45.55 101.47 106.55c-4 45.54-32.8 58.66-47.89 56c-14.2-2.55-25.92-15.52-23.75-40.35l5.62-44.66c-7.58-9.17-28.11-18-49.93-14.54C231.77 210.3 209 228 206.56 256s14.49 50.84 39.93 50.84s47.86-18.39 50.69-50.84',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '28'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9P = [_hoisted_2$jC, _hoisted_3$gN];
    vue.defineComponent({
      name: 'AtCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jC, _hoisted_4$9P);
      }
    });

    const _hoisted_1$jB = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jB = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256.41 48.74c-114.85 0-208 93.11-208 208s93.12 208 208 208s208-93.12 208-208s-93.16-208-208-208zM381.22 252c-2.85 32.63-16.78 49.7-28 58.26s-24.69 12.34-36.33 10.26a41.63 41.63 0 0 1-27-17.52a60.84 60.84 0 0 1-43.72 17.9a51.65 51.65 0 0 1-38.55-16.83c-11.39-12.42-17-30.36-15.33-49.23c3.05-35 30.92-57.39 56.87-61.48c27.21-4.29 52.24 6.54 62.91 19.46l3.84 4.66l-6.34 50.38c-1.19 14.34 3.29 23.48 12.29 25.1c2.39.42 8.11-.13 14.38-4.93c6.72-5.15 15.14-16 17.1-38.47c2.32-26.55-4.35-49.19-19.28-65.49c-15.5-16.9-39.1-25.84-68.24-25.84c-54 0-101.81 44.43-106.57 99c-2.29 26.2 5.66 50.68 22.39 68.93C198 344 221 353.88 246.29 353.88c19 0 30.61-2.05 49.49-8.78l13.22-4.69l9.39 26.37l-13.19 4.7c-21.82 7.77-36.68 10.4-58.88 10.4c-33.28 0-63.57-13.06-85.3-36.77c-22.09-24.11-32.62-56.17-29.65-90.29c2.91-33.33 18.46-64.63 43.77-88.12s57.57-36.49 90.7-36.49c37.2 0 67.94 12.08 88.88 34.93c20.05 21.91 29.48 52.75 26.5 86.86z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gM = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M253.51 221c-14.83 2.33-31.55 15.84-33.34 36.26c-1 11.06 2 21.22 8.08 27.87a23.63 23.63 0 0 0 17.91 7.75c19.7 0 33.8-14.79 36.8-38.59l1.75-13.89h.09l1.65-13.11a49.63 49.63 0 0 0-32.94-6.3z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9O = [_hoisted_2$jB, _hoisted_3$gM];
    vue.defineComponent({
      name: 'AtCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jB, _hoisted_4$9O);
      }
    });

    const _hoisted_1$jA = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jA = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 254.27c-4.5 51-40.12 80-80.55 80s-67.34-35.82-63.45-80s37.12-80 77.55-80s70.33 36 66.45 80z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gL = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M319.77 415.77c-28.56 12-47.28 14.5-79.28 14.5c-97.2 0-169-78.8-160.49-176s94.31-176 191.51-176C381 78.27 441.19 150 432.73 246c-6.31 71.67-52.11 92.32-76.09 88.07c-22.56-4-41.18-24.42-37.74-63.5l8.48-96.25',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9N = [_hoisted_2$jA, _hoisted_3$gL];
    vue.defineComponent({
      name: 'AtOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jA, _hoisted_4$9N);
      }
    });

    const _hoisted_1$jz = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jz = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M407.6 115.78c-32.07-35-79.47-53.51-137.09-53.51c-51 0-100.69 19.8-139.82 55.76s-63.13 83.84-67.63 134.83c-4.55 51.67 11.41 100.29 44.94 136.9c33.37 36.44 80.07 56.51 131.49 56.51c32.52 0 53.61-2.36 85.48-15.75l14.75-6.2l-12.4-29.5l-14.75 6.18c-27.15 11.4-43.78 13.25-73.08 13.25c-42.34 0-80.65-16.38-107.89-46.12c-27.4-29.92-40.42-69.86-36.66-112.48c7.84-89 86.6-161.4 175.57-161.4c48.4 0 87.65 14.91 113.49 43.13c24.61 26.87 35.6 63.92 31.79 107.15c-3.29 37.35-17.76 55.74-29.32 64.6c-11 8.44-22 10.18-28 9.11c-17.68-3.13-26.87-20.46-24.59-46.29l9.93-109.12L311.9 160l-2 22.29a79.69 79.69 0 0 0-57.32-24c-23.8 0-46.54 10.07-64 28.37c-16.77 17.53-27.23 41.05-29.45 66.22c-2.45 27.87 5.75 54.34 22.51 72.64a76.14 76.14 0 0 0 56.88 24.77A93 93 0 0 0 310 318a60 60 0 0 0 42.88 31.81c16.89 3 36.73-2.69 53.08-15.21c30.19-23.13 39.36-60.19 41.74-87.2c4.52-51.7-9.7-98.4-40.1-131.62zm-126.34 186a62.19 62.19 0 0 1-42.81 16.53a43.94 43.94 0 0 1-33.28-14.38c-10.71-11.7-15.9-29.27-14.23-48.22c3.23-36.68 30.29-65.4 61.61-65.4a48.16 48.16 0 0 1 35.88 15.82c10.87 11.87 16.2 28.87 14.63 46.73c-1.78 20.28-9.33 37.14-21.8 48.88z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gK = [_hoisted_2$jz];
    vue.defineComponent({
      name: 'AtSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jz, _hoisted_3$gK);
      }
    });

    const _hoisted_1$jy = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jy = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M216.08 192v143.85a40.08 40.08 0 0 0 80.15 0l.13-188.55a67.94 67.94 0 1 0-135.87 0v189.82a95.51 95.51 0 1 0 191 0V159.74',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gJ = [_hoisted_2$jy];
    vue.defineComponent({
      name: 'Attach',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jy, _hoisted_3$gJ);
      }
    });

    const _hoisted_1$jx = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jx = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M216.08 192v143.85a40.08 40.08 0 0 0 80.15 0l.13-188.55a67.94 67.94 0 1 0-135.87 0v189.82a95.51 95.51 0 1 0 191 0V159.74',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gI = [_hoisted_2$jx];
    vue.defineComponent({
      name: 'AttachOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jx, _hoisted_3$gI);
      }
    });

    const _hoisted_1$jw = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jw = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M216.08 192v143.55a40.08 40.08 0 0 0 80.15 0l.13-188.55a67.94 67.94 0 1 0-135.87 0v189.82a95.51 95.51 0 0 0 191 0V159.44',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gH = [_hoisted_2$jw];
    vue.defineComponent({
      name: 'AttachSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jw, _hoisted_3$gH);
      }
    });

    const _hoisted_1$jv = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jv = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M403.13 96H156.87a44.9 44.9 0 0 0-33.68 15.27a15.88 15.88 0 0 0-1.91 2.7L32 247.75a16 16 0 0 0 0 16.5l89.15 133.57a16.24 16.24 0 0 0 2 2.88a44.89 44.89 0 0 0 33.7 15.3h246.28A44.92 44.92 0 0 0 448 371.13V140.87A44.92 44.92 0 0 0 403.13 96zM348 311a16 16 0 1 1-22.63 22.62L271.67 280L218 333.65A16 16 0 0 1 195.35 311L249 257.33l-53.69-53.69A16 16 0 0 1 218 181l53.69 53.7l53.67-53.7A16 16 0 0 1 348 203.64l-53.7 53.69z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gG = [_hoisted_2$jv];
    vue.defineComponent({
      name: 'Backspace',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jv, _hoisted_3$gG);
      }
    });

    const _hoisted_1$ju = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ju = /*#__PURE__*/vue.createStaticVNode('<path d="M135.19 390.14a28.79 28.79 0 0 0 21.68 9.86h246.26A29 29 0 0 0 432 371.13V140.87A29 29 0 0 0 403.13 112H156.87a28.84 28.84 0 0 0-21.67 9.84v0L46.33 256l88.86 134.11z" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M336.67 192.33L206.66 322.34"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M336.67 322.34L206.66 192.33"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M336.67 192.33L206.66 322.34"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M336.67 322.34L206.66 192.33"></path>', 5);

    const _hoisted_7$11 = [_hoisted_2$ju];
    vue.defineComponent({
      name: 'BackspaceOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ju, _hoisted_7$11);
      }
    });

    const _hoisted_1$jt = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jt = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M144 96L32 256l112 160h304V96zm215.3 226.34L336.67 345l-65-65l-65 65L184 322.34l65-65l-65-65l22.63-22.63l65 65l65-65l22.63 22.63l-65 65z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gF = [_hoisted_2$jt];
    vue.defineComponent({
      name: 'BackspaceSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jt, _hoisted_3$gF);
      }
    });

    const _hoisted_1$js = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$js = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M454.65 169.4A31.82 31.82 0 0 0 432 160h-64v-16a112 112 0 0 0-224 0v16H80a32 32 0 0 0-32 32v216c0 39 33 72 72 72h272a72.22 72.22 0 0 0 50.48-20.55a69.48 69.48 0 0 0 21.52-50.2V192a31.75 31.75 0 0 0-9.35-22.6zM176 144a80 80 0 0 1 160 0v16H176z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gE = [_hoisted_2$js];
    vue.defineComponent({
      name: 'Bag',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$js, _hoisted_3$gE);
      }
    });

    const _hoisted_1$jr = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jr = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M454.66 169.4A31.86 31.86 0 0 0 432 160h-64v-16a112 112 0 0 0-224 0v16H80a32 32 0 0 0-32 32v216c0 39 33 72 72 72h272a72.22 72.22 0 0 0 50.48-20.55a69.48 69.48 0 0 0 21.52-50.2V192a31.78 31.78 0 0 0-9.34-22.6zM320 336h-48v48a16 16 0 0 1-32 0v-48h-48a16 16 0 0 1 0-32h48v-48a16 16 0 0 1 32 0v48h48a16 16 0 0 1 0 32zm16-176H176v-16a80 80 0 0 1 160 0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gD = [_hoisted_2$jr];
    vue.defineComponent({
      name: 'BagAdd',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jr, _hoisted_3$gD);
      }
    });

    const _hoisted_1$jq = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jq = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 256v128'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gC = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M320 320H192'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9M = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M80 176a16 16 0 0 0-16 16v216c0 30.24 25.76 56 56 56h272c30.24 0 56-24.51 56-54.75V192a16 16 0 0 0-16-16z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4F = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M160 176v-32a96 96 0 0 1 96-96h0a96 96 0 0 1 96 96v32',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1Y = [_hoisted_2$jq, _hoisted_3$gC, _hoisted_4$9M, _hoisted_5$4F];
    vue.defineComponent({
      name: 'BagAddOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jq, _hoisted_6$1Y);
      }
    });

    const _hoisted_1$jp = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jp = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M460 160h-88v-12A116.13 116.13 0 0 0 258.89 32h-5.78A116.13 116.13 0 0 0 140 148v12H52a4 4 0 0 0-4 4v300a16 16 0 0 0 16 16h384a16 16 0 0 0 16-16V164a4 4 0 0 0-4-4zm-280-11c0-41.84 33.41-76.56 75.25-77A76.08 76.08 0 0 1 332 148v12H180zm156 187h-64v64h-32v-64h-64v-32h64v-64h32v64h64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gB = [_hoisted_2$jp];
    vue.defineComponent({
      name: 'BagAddSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jp, _hoisted_3$gB);
      }
    });

    const _hoisted_1$jo = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jo = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M454.65 169.4A31.82 31.82 0 0 0 432 160h-64v-16a112 112 0 0 0-224 0v16H80a32 32 0 0 0-32 32v216c0 39 33 72 72 72h272a72.22 72.22 0 0 0 50.48-20.55a69.48 69.48 0 0 0 21.52-50.2V192a31.75 31.75 0 0 0-9.35-22.6zM332.49 274l-89.6 112a16 16 0 0 1-12.23 6h-.26a16 16 0 0 1-12.16-5.6l-38.4-44.88a16 16 0 1 1 24.32-20.8L230 350.91L307.51 254a16 16 0 0 1 25 20zM336 160H176v-16a80 80 0 0 1 160 0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gA = [_hoisted_2$jo];
    vue.defineComponent({
      name: 'BagCheck',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jo, _hoisted_3$gA);
      }
    });

    const _hoisted_1$jn = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jn = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M320 264l-89.6 112l-38.4-44.88'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gz = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M80 176a16 16 0 0 0-16 16v216c0 30.24 25.76 56 56 56h272c30.24 0 56-24.51 56-54.75V192a16 16 0 0 0-16-16z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9L = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M160 176v-32a96 96 0 0 1 96-96h0a96 96 0 0 1 96 96v32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4E = [_hoisted_2$jn, _hoisted_3$gz, _hoisted_4$9L];
    vue.defineComponent({
      name: 'BagCheckOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jn, _hoisted_5$4E);
      }
    });

    const _hoisted_1$jm = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jm = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M460 160h-88v-12A116.13 116.13 0 0 0 258.89 32h-5.78A116.13 116.13 0 0 0 140 148v12H52a4 4 0 0 0-4 4v300a16 16 0 0 0 16 16h384a16 16 0 0 0 16-16V164a4 4 0 0 0-4-4zm-280-11c0-41.84 33.41-76.56 75.25-77A76.08 76.08 0 0 1 332 148v12H180zm50.81 252.12l-61.37-71.72l24.31-20.81L230 350.91l87.51-109.4l25 20z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gy = [_hoisted_2$jm];
    vue.defineComponent({
      name: 'BagCheckSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jm, _hoisted_3$gy);
      }
    });

    const _hoisted_1$jl = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jl = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M454.65 169.4A31.82 31.82 0 0 0 432 160h-64v-16a112 112 0 0 0-224 0v16H80a32 32 0 0 0-32 32v216c0 39 33 72 72 72h272a72.22 72.22 0 0 0 50.48-20.55a69.48 69.48 0 0 0 21.52-50.2V192a31.75 31.75 0 0 0-9.35-22.6zM176 144a80 80 0 0 1 160 0v16H176zm192 96a112 112 0 0 1-224 0v-16a16 16 0 0 1 32 0v16a80 80 0 0 0 160 0v-16a16 16 0 0 1 32 0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gx = [_hoisted_2$jl];
    vue.defineComponent({
      name: 'BagHandle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jl, _hoisted_3$gx);
      }
    });

    const _hoisted_1$jk = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jk = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M80 176a16 16 0 0 0-16 16v216c0 30.24 25.76 56 56 56h272c30.24 0 56-24.51 56-54.75V192a16 16 0 0 0-16-16z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gw = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M160 176v-32a96 96 0 0 1 96-96h0a96 96 0 0 1 96 96v32',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9K = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M160 224v16a96 96 0 0 0 96 96h0a96 96 0 0 0 96-96v-16',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4D = [_hoisted_2$jk, _hoisted_3$gw, _hoisted_4$9K];
    vue.defineComponent({
      name: 'BagHandleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jk, _hoisted_5$4D);
      }
    });

    const _hoisted_1$jj = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jj = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M460 160h-88v-12A116.13 116.13 0 0 0 258.89 32h-5.78A116.13 116.13 0 0 0 140 148v12H52a4 4 0 0 0-4 4v300a16 16 0 0 0 16 16h384a16 16 0 0 0 16-16V164a4 4 0 0 0-4-4zm-280-11c0-41.84 33.41-76.56 75.25-77A76.08 76.08 0 0 1 332 148v12H180zm188 91a112 112 0 0 1-224 0v-32h32v32a80 80 0 0 0 160 0v-32h32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gv = [_hoisted_2$jj];
    vue.defineComponent({
      name: 'BagHandleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jj, _hoisted_3$gv);
      }
    });

    const _hoisted_1$ji = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ji = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M80 176a16 16 0 0 0-16 16v216c0 30.24 25.76 56 56 56h272c30.24 0 56-24.51 56-54.75V192a16 16 0 0 0-16-16z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gu = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M160 176v-32a96 96 0 0 1 96-96h0a96 96 0 0 1 96 96v32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9J = [_hoisted_2$ji, _hoisted_3$gu];
    vue.defineComponent({
      name: 'BagOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ji, _hoisted_4$9J);
      }
    });

    const _hoisted_1$jh = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jh = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M454.66 169.4A31.86 31.86 0 0 0 432 160h-64v-16a112 112 0 0 0-224 0v16H80a32 32 0 0 0-32 32v216c0 39 33 72 72 72h272a72.22 72.22 0 0 0 50.48-20.55a69.48 69.48 0 0 0 21.52-50.2V192a31.78 31.78 0 0 0-9.34-22.6zM320 336H192a16 16 0 0 1 0-32h128a16 16 0 0 1 0 32zm16-176H176v-16a80 80 0 0 1 160 0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gt = [_hoisted_2$jh];
    vue.defineComponent({
      name: 'BagRemove',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jh, _hoisted_3$gt);
      }
    });

    const _hoisted_1$jg = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jg = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M320 320H192'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gs = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M80 176a16 16 0 0 0-16 16v216c0 30.24 25.76 56 56 56h272c30.24 0 56-24.51 56-54.75V192a16 16 0 0 0-16-16z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9I = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M160 176v-32a96 96 0 0 1 96-96h0a96 96 0 0 1 96 96v32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4C = [_hoisted_2$jg, _hoisted_3$gs, _hoisted_4$9I];
    vue.defineComponent({
      name: 'BagRemoveOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jg, _hoisted_5$4C);
      }
    });

    const _hoisted_1$jf = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jf = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M460 160h-88v-12A116.13 116.13 0 0 0 258.89 32h-5.78A116.13 116.13 0 0 0 140 148v12H52a4 4 0 0 0-4 4v300a16 16 0 0 0 16 16h384a16 16 0 0 0 16-16V164a4 4 0 0 0-4-4zm-280-11c0-41.84 33.41-76.56 75.25-77A76.08 76.08 0 0 1 332 148v12H180zm156 187H176v-32h160z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gr = [_hoisted_2$jf];
    vue.defineComponent({
      name: 'BagRemoveSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jf, _hoisted_3$gr);
      }
    });

    const _hoisted_1$je = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$je = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M372 160v-12A116.13 116.13 0 0 0 258.89 32h-5.78A116.13 116.13 0 0 0 140 148v12H52a4 4 0 0 0-4 4v300a16 16 0 0 0 16 16h384a16 16 0 0 0 16-16V164a4 4 0 0 0-4-4zm-40 0H180v-11c0-41.84 33.41-76.56 75.25-77A76.08 76.08 0 0 1 332 148z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gq = [_hoisted_2$je];
    vue.defineComponent({
      name: 'BagSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$je, _hoisted_3$gq);
      }
    });

    const _hoisted_1$jd = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jd = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M391 307.27c32.75-46.35 46.59-101.63 39-155.68A175.82 175.82 0 0 0 231.38 2c-96 13.49-163.14 102.58-149.65 198.58c7.57 53.89 36.12 103.16 80.37 138.74c24.58 19.68 52.31 33.5 78.62 39.68a8 8 0 0 1 6 9.22l-4.87 26.38a16.29 16.29 0 0 0 1.48 10.57a16 16 0 0 0 14.2 8.61a15.21 15.21 0 0 0 2.23-.16l17.81-2.5a2 2 0 0 1 2.09 1.14c16.72 36.31 45.46 63.85 82.15 78.36a16 16 0 0 0 21-9.65c2.83-8.18-1.64-17.07-9.68-20.28a118.57 118.57 0 0 1-59.3-51.88a2 2 0 0 1 1.45-3l7.4-1a16.54 16.54 0 0 0 10.08-5.23a16 16 0 0 0 2.39-17.8l-12.06-24.23a8 8 0 0 1 3.26-10.55c23.59-13.17 46.45-34 64.65-59.73zm-154.9 16.78a16 16 0 0 1-5.88-1.12c-41.26-16.32-76.3-52.7-91.45-94.94a16 16 0 1 1 30.12-10.8c14.5 40.44 47.27 65.77 73.1 76a16 16 0 0 1-5.89 30.88z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gp = [_hoisted_2$jd];
    vue.defineComponent({
      name: 'Balloon',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jd, _hoisted_3$gp);
      }
    });

    const _hoisted_1$jc = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jc = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M414.11 153.82C429.66 264.4 345.85 357.09 282.54 366s-169.48-57.5-185-167.68a159.82 159.82 0 1 1 316.53-44.49z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$go = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M236.06 308.05c-32.83-13-67.08-43.1-82.27-85.46',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9H = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M367.7 495.78c-32.83-13-63.31-40.06-78.5-82.41',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4B = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M266.71 368.21l-9.17 49.61l63.31-8.9l-22.49-45.16l-31.65 4.45z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1X = [_hoisted_2$jc, _hoisted_3$go, _hoisted_4$9H, _hoisted_5$4B];
    vue.defineComponent({
      name: 'BalloonOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jc, _hoisted_6$1X);
      }
    });

    const _hoisted_1$jb = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$jb = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M391 307.27c32.75-46.35 46.59-101.63 39-155.68C416.47 55.59 327.38-11.54 231.38 2S68.24 104.53 81.73 200.53c7.57 53.89 36.12 103.16 80.37 138.74c26.91 21.64 57.59 36.1 86.05 41.33l-8.36 45.23a8 8 0 0 0 9 9.38L279 431c15.9 35.87 41.65 60.48 78.41 75l14.88 5.88l11.77-29.75l-14.88-5.89c-26.35-10.42-44.48-26.16-57-49.92l21.84-3.07a8 8 0 0 0 6.05-11.49l-20.49-41.16c25.98-12.87 51.49-35.18 71.42-63.33zm-160.82 15.66c-41.26-16.32-76.3-52.7-91.45-94.94l-5.4-15.06l30.12-10.8l5.4 15.06c14.5 40.44 47.27 65.77 73.1 76l14.88 5.88l-11.77 29.76z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gn = [_hoisted_2$jb];
    vue.defineComponent({
      name: 'BalloonSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$jb, _hoisted_3$gn);
      }
    });

    const _hoisted_1$ja = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ja = /*#__PURE__*/vue.createElementVNode('circle', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '48',
      cx: '256',
      cy: '256',
      r: '200'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gm = /*#__PURE__*/vue.createElementVNode('path', {
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '48',
      d: 'M114.58 114.58l282.84 282.84',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9G = [_hoisted_2$ja, _hoisted_3$gm];
    vue.defineComponent({
      name: 'Ban',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ja, _hoisted_4$9G);
      }
    });

    const _hoisted_1$j9 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$j9 = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '208',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gl = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M108.92 108.92l294.16 294.16'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9F = [_hoisted_2$j9, _hoisted_3$gl];
    vue.defineComponent({
      name: 'BanOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$j9, _hoisted_4$9F);
      }
    });

    const _hoisted_1$j8 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$j8 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M414.39 97.61A224 224 0 1 0 97.61 414.39A224 224 0 1 0 414.39 97.61zM432 256a175.09 175.09 0 0 1-35.8 106.26L149.74 115.8A175.09 175.09 0 0 1 256 80c97.05 0 176 79 176 176zm-352 0a175.09 175.09 0 0 1 35.8-106.26L362.26 396.2A175.09 175.09 0 0 1 256 432c-97 0-176-78.95-176-176z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gk = [_hoisted_2$j8];
    vue.defineComponent({
      name: 'BanSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$j8, _hoisted_3$gk);
      }
    });

    const _hoisted_1$j7 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$j7 = /*#__PURE__*/vue.createStaticVNode('<path d="M275.8 157a16 16 0 0 0-22.63 0l-93.34 93.34a16 16 0 0 0 0 22.63l79.2 79.2a16 16 0 0 0 22.63 0L355 258.83a16 16 0 0 0 0-22.63z" fill="none"></path><path d="M137.21 295.6a47.81 47.81 0 0 1-9.43-13.38L69 341a72.2 72.2 0 0 0 0 102a72.37 72.37 0 0 0 102 0l58.77-58.76a47.81 47.81 0 0 1-13.38-9.43z" fill="none"></path><path d="M392 48a71.55 71.55 0 0 0-51 21l-55.92 55.91a48.05 48.05 0 0 1 13.36 9.45l79.19 79.19a48.05 48.05 0 0 1 9.45 13.36L443 171a72 72 0 0 0-51-123z" fill="none"></path><path d="M275.8 157a16 16 0 0 0-22.63 0l-93.34 93.34a16 16 0 0 0 0 22.63l79.2 79.2a16 16 0 0 0 22.63 0L355 258.83a16 16 0 0 0 0-22.63zm-56.49 110.31a16 16 0 1 1 0-22.62a16 16 0 0 1 0 22.62zm48 48a16 16 0 1 1 0-22.62a16 16 0 0 1 0 22.62zm0-96a16 16 0 1 1 0-22.62a16 16 0 0 1 0 22.62zm48 48a16 16 0 1 1 0-22.62a16 16 0 0 1 0 22.62z" fill="currentColor"></path><path d="M465.61 46.39a104.38 104.38 0 0 0-147.25 0l-69.76 69.89a4 4 0 0 0 4.2 6.58a35.74 35.74 0 0 1 11.69-2.54a47.7 47.7 0 0 1 33.94 14.06l79.19 79.19a47.7 47.7 0 0 1 14.06 33.94a35.68 35.68 0 0 1-2.54 11.69a4 4 0 0 0 6.58 4.2l69.89-69.76a104.38 104.38 0 0 0 0-147.25z" fill="currentColor"></path><path d="M254.34 386.83a47.91 47.91 0 0 1-33.94-14l-79.19-79.23a47.81 47.81 0 0 1-9.43-13.38c-4.59-9.7-1.39-25 2.48-36.9a4 4 0 0 0-6.64-4l-77.23 77.04a104.12 104.12 0 0 0 147.25 147.25l72.75-72.88a4 4 0 0 0-4.21-6.58c-4.18 1.58-8.4 2.68-11.84 2.68z" fill="currentColor"></path>', 6);

    const _hoisted_8$D = [_hoisted_2$j7];
    vue.defineComponent({
      name: 'Bandage',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$j7, _hoisted_8$D);
      }
    });

    const _hoisted_1$j6 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$j6 = /*#__PURE__*/vue.createStaticVNode('<rect x="-24.43" y="167.88" width="560.87" height="176.25" rx="88.12" ry="88.12" transform="rotate(-45 256 256.002)" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></rect><rect x="169.41" y="156.59" width="176" height="196" rx="32" ry="32" transform="rotate(45 257.409 254.582)" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></rect><circle cx="256" cy="208" r="16" fill="currentColor"></circle><circle cx="304" cy="256" r="16" fill="currentColor"></circle><circle cx="208" cy="256" r="16" fill="currentColor"></circle><circle cx="256" cy="304" r="16" fill="currentColor"></circle>', 6);

    const _hoisted_8$C = [_hoisted_2$j6];
    vue.defineComponent({
      name: 'BandageOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$j6, _hoisted_8$C);
      }
    });

    const _hoisted_1$j5 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$j5 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M27.71 337.1a40 40 0 0 0 0 56.54l90.65 90.65a40 40 0 0 0 56.54 0l75.1-75.1L102.81 262z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gj = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M496 147.1a39.87 39.87 0 0 0-11.75-28.38l-91-91a40.14 40.14 0 0 0-56.75 0L264 100.28L411.72 248l72.53-72.53A39.85 39.85 0 0 0 496 147.1z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9E = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M273.06 386.19l116-116L241.77 123l-116 116zm19.63-141.5a16 16 0 1 1 0 22.62a16 16 0 0 1 0-22.62zm-48-48a16 16 0 1 1 0 22.62a16 16 0 0 1 0-22.62zm0 96a16 16 0 1 1 0 22.62a16 16 0 0 1 0-22.62zm-25.38-48a16 16 0 1 1-22.62 0a16 16 0 0 1 22.62 0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4A = [_hoisted_2$j5, _hoisted_3$gj, _hoisted_4$9E];
    vue.defineComponent({
      name: 'BandageSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$j5, _hoisted_5$4A);
      }
    });

    const _hoisted_1$j4 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$j4 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 496H48a32 32 0 0 1-32-32V32a16 16 0 0 1 32 0v432h432a16 16 0 0 1 0 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gi = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M156 432h-40a36 36 0 0 1-36-36V244a36 36 0 0 1 36-36h40a36 36 0 0 1 36 36v152a36 36 0 0 1-36 36z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9D = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M300 432h-40a36 36 0 0 1-36-36V196a36 36 0 0 1 36-36h40a36 36 0 0 1 36 36v200a36 36 0 0 1-36 36z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M443.64 432h-40a36 36 0 0 1-36-36V132a36 36 0 0 1 36-36h40a36 36 0 0 1 36 36v264a36 36 0 0 1-36 36z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1W = [_hoisted_2$j4, _hoisted_3$gi, _hoisted_4$9D, _hoisted_5$4z];
    vue.defineComponent({
      name: 'BarChart',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$j4, _hoisted_6$1W);
      }
    });

    const _hoisted_1$j3 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$j3 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M32 32v432a16 16 0 0 0 16 16h432',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gh = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '96',
      y: '224',
      width: '80',
      height: '192',
      rx: '20',
      ry: '20',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9C = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '240',
      y: '176',
      width: '80',
      height: '240',
      rx: '20',
      ry: '20',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4y = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '383.64',
      y: '112',
      width: '80',
      height: '304',
      rx: '20',
      ry: '20',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1V = [_hoisted_2$j3, _hoisted_3$gh, _hoisted_4$9C, _hoisted_5$4y];
    vue.defineComponent({
      name: 'BarChartOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$j3, _hoisted_6$1V);
      }
    });

    const _hoisted_1$j2 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$j2 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M496 496H16V16h32v448h448v32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gg = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M192 432H80V208h112z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9B = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 432H224V160h112z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4x = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M479.64 432h-112V96h112z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1U = [_hoisted_2$j2, _hoisted_3$gg, _hoisted_4$9B, _hoisted_5$4x];
    vue.defineComponent({
      name: 'BarChartSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$j2, _hoisted_6$1U);
      }
    });

    const _hoisted_1$j1 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$j1 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M467 176a29.94 29.94 0 0 0-25.32 12.5a2 2 0 0 1-3.64-1.14v-36.65c0-20.75-16.34-38.21-37.08-38.7A38 38 0 0 0 362 150v82a2 2 0 0 1-2 2H152a2 2 0 0 1-2-2v-81.29c0-20.75-16.34-38.21-37.08-38.7A38 38 0 0 0 74 150v37.38a2 2 0 0 1-3.64 1.14A29.94 29.94 0 0 0 45 176c-16.3.51-29 14.31-29 30.62v98.72c0 16.31 12.74 30.11 29 30.62a29.94 29.94 0 0 0 25.32-12.5a2 2 0 0 1 3.68 1.16v36.67C74 382 90.34 399.5 111.08 400A38 38 0 0 0 150 362v-82a2 2 0 0 1 2-2h208a2 2 0 0 1 2 2v81.29c0 20.75 16.34 38.21 37.08 38.7A38 38 0 0 0 438 362v-37.38a2 2 0 0 1 3.64-1.14A29.94 29.94 0 0 0 467 336c16.3-.51 29-14.31 29-30.62v-98.74c0-16.31-12.74-30.11-29-30.64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gf = [_hoisted_2$j1];
    vue.defineComponent({
      name: 'Barbell',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$j1, _hoisted_3$gf);
      }
    });

    const _hoisted_1$j0 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$j0 = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M48 256h416"></path><rect x="384" y="128" width="32" height="256" rx="16" ry="16" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></rect><rect x="96" y="128" width="32" height="256" rx="16" ry="16" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></rect><rect x="32" y="192" width="16" height="128" rx="8" ry="8" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></rect><rect x="464" y="192" width="16" height="128" rx="8" ry="8" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></rect>', 5);

    const _hoisted_7$10 = [_hoisted_2$j0];
    vue.defineComponent({
      name: 'BarbellOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$j0, _hoisted_7$10);
      }
    });

    const _hoisted_1$i$ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$i$ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M496 176h-58v-64h-76v122H150V112H74v64H16v160h58v64h76V278h212v122h76v-64h58V176z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ge = [_hoisted_2$i$];
    vue.defineComponent({
      name: 'BarbellSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$i$, _hoisted_3$ge);
      }
    });

    const _hoisted_1$i_ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$i_ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M419.13 96H419l-35.05.33L128 96h-.16l-36.74.33C66.93 96.38 48 116.07 48 141.2v230.27c0 25.15 19 44.86 43.2 44.86h.15l36.71-.33l255.92.33h.17l35.07-.33A44.91 44.91 0 0 0 464 371.13V140.87A44.92 44.92 0 0 0 419.13 96zM144 320a16 16 0 0 1-32 0V192a16 16 0 0 1 32 0zm64 32a16 16 0 0 1-32 0V160a16 16 0 0 1 32 0zm64-16a16 16 0 0 1-32 0V176a16 16 0 0 1 32 0zm64 16a16 16 0 0 1-32 0V160a16 16 0 0 1 32 0zm64-32a16 16 0 0 1-32 0V192a16 16 0 0 1 32 0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gd = [_hoisted_2$i_];
    vue.defineComponent({
      name: 'Barcode',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$i_, _hoisted_3$gd);
      }
    });

    const _hoisted_1$iZ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iZ = /*#__PURE__*/vue.createStaticVNode('<path d="M384 400.33l35.13-.33A29 29 0 0 0 448 371.13V140.87A29 29 0 0 0 419.13 112l-35.13.33" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M128 112l-36.8.33c-15.88 0-27.2 13-27.2 28.87v230.27c0 15.87 11.32 28.86 27.2 28.86L128 400" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M384 192v128"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M320 160v192"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 176v160"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M192 160v192"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M128 192v128"></path>', 7);

    const _hoisted_9$j = [_hoisted_2$iZ];
    vue.defineComponent({
      name: 'BarcodeOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iZ, _hoisted_9$j);
      }
    });

    const _hoisted_1$iY = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iY = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="square" stroke-linejoin="round" stroke-width="32" d="M400 400.33l48-.33V112l-48 .33"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-linejoin="round" stroke-width="32" d="M112 112l-48 .33v288l48-.33"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-linejoin="round" stroke-width="32" d="M384 192v128"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-linejoin="round" stroke-width="32" d="M320 160v192"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-linejoin="round" stroke-width="32" d="M256 176v160"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-linejoin="round" stroke-width="32" d="M192 160v192"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-linejoin="round" stroke-width="32" d="M128 192v128"></path>', 7);

    const _hoisted_9$i = [_hoisted_2$iY];
    vue.defineComponent({
      name: 'BarcodeSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iY, _hoisted_9$i);
      }
    });

    const _hoisted_1$iX = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iX = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M444 295.67l-.47-26.07a205.42 205.42 0 0 1-39.27-4.73l-5 17.35a14 14 0 1 1-26.88-7.81l5-17.38a206.47 206.47 0 0 1-36.05-17.35l-10.44 14.77a14 14 0 0 1-22.87-16.16l10.41-14.73a204.8 204.8 0 0 1-30-30L273.71 204a14 14 0 0 1-16.16-22.87l14.74-10.42a205.3 205.3 0 0 1-17.38-36.06l-17.32 5a14 14 0 1 1-7.81-26.89l17.3-5a205.88 205.88 0 0 1-4.43-32.59q-.17-3-.24-6l-18.22-.33a14 14 0 0 1-13.74-14A208 208 0 0 0 55 202.42a16 16 0 0 1 15 15.66l.44 24.43c1.58.05 3.16.11 4.73.2a205.88 205.88 0 0 1 32.59 4.43l5-17.3a14 14 0 0 1 26.89 7.81l-5 17.32a205.21 205.21 0 0 1 36 17.38L181 257.61a14 14 0 0 1 22.87 16.16l-10.39 14.73a205.65 205.65 0 0 1 15.79 14.23a203.79 203.79 0 0 1 14.23 15.79l14.73-10.41A14 14 0 0 1 254.39 331l-14.76 10.43A206.86 206.86 0 0 1 257 377.47l17.38-5.05a14 14 0 0 1 7.81 26.89l-17.35 5a205.89 205.89 0 0 1 4.7 38.28l18.27.33a16 16 0 0 1 15.71 16.28a11.69 11.69 0 0 1-.08 1.19a208 208 0 0 0 153.39-151.03A14 14 0 0 1 444 295.67z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gc = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M301.49 56.2A14 14 0 0 1 287.5 70h-.25l-16.81-.3c.05 1.31.1 2.62.17 3.93a178.83 178.83 0 0 0 3.44 26.31l16.29-4.74a14 14 0 0 1 7.81 26.8l-16.27 4.73a178.06 178.06 0 0 0 13.33 27.69l13.84-9.78a14 14 0 1 1 16.16 22.87l-13.86 9.79q5.25 6.33 11.12 12.19c3.9 3.91 8 7.6 12.2 11.1l9.78-13.84A14 14 0 1 1 367.32 203l-9.76 13.8a178.83 178.83 0 0 0 27.68 13.33l4.76-16.28a14 14 0 0 1 26.89 7.81l-4.73 16.26a177.72 177.72 0 0 0 30.95 3.65l-.16-9a14 14 0 0 1 13.75-14.24h.25a14.67 14.67 0 0 1 2.59.25a208 208 0 0 0-158-163.51c-.06.4-.04.76-.05 1.13z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9A = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M208.44 457.55a16 16 0 0 1 16.28-15.71l16.76.29a178.49 178.49 0 0 0-3.62-29.95l-16.26 4.72a14 14 0 1 1-7.81-26.9l16.21-4.7a177.92 177.92 0 0 0-13.33-27.68l-13.8 9.76a14 14 0 1 1-16.16-22.87l13.84-9.78c-3.5-4.22-7.19-8.3-11.1-12.2s-8-7.62-12.19-11.12l-9.79 13.86a14 14 0 1 1-22.87-16.16l9.78-13.84a177.16 177.16 0 0 0-27.69-13.33L122 298.21a14 14 0 1 1-26.9-7.81l4.73-16.29a177.32 177.32 0 0 0-26.31-3.44c-.89-.05-1.79-.08-2.68-.12l.16 10.59a16 16 0 0 1-15.71 16.28H55a16 16 0 0 1-3.94-.51a208 208 0 0 0 157.65 163.87a15.72 15.72 0 0 1-.27-3.23z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4w = [_hoisted_2$iX, _hoisted_3$gc, _hoisted_4$9A];
    vue.defineComponent({
      name: 'Baseball',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iX, _hoisted_5$4w);
      }
    });

    const _hoisted_1$iW = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iW = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M294.25 108.6l-60.57 17.59"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M317.13 156.11l-51.5 36.4"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M355.89 194.87l-36.4 51.5"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M403.4 217.75l-17.59 60.57"></path><circle cx="256" cy="256" r="192" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><path d="M432.94 255.05a192 192 0 0 1-176.31-180.7" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M108.54 294.31l17.59-60.57"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M156.05 317.19l36.4-51.5"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M194.81 355.95l51.5-36.4"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M217.69 403.46l60.57-17.59"></path><path d="M255 433.61A192 192 0 0 0 74.29 256.69" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 11);

    const _hoisted_13$3 = [_hoisted_2$iW];
    vue.defineComponent({
      name: 'BaseballOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iW, _hoisted_13$3);
      }
    });

    const _hoisted_1$iV = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iV = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M302.16 56.2a13.88 13.88 0 0 1-3.42 8.91l-.11 5.13l-27.71-.57c0 1.3.09 2.61.16 3.91a177.33 177.33 0 0 0 3.45 26.31l24.72-7.18l7.81 26.88l-24.71 7.18a177.21 177.21 0 0 0 13.34 27.69l21.27-15l16.16 22.86l-21.29 15.05q5.25 6.33 11.11 12.19c3.91 3.91 8 7.6 12.2 11.1l15.71-22.22l22.86 16.16L358 216.75a178.78 178.78 0 0 0 27.68 13.32l7.49-25.8l26.89 7.81l-7.5 25.83a177.8 177.8 0 0 0 31 3.67l-.41-24.67l17.41-.29A208 208 0 0 0 301.82 52.93a13.65 13.65 0 0 1 .34 3.27z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$gb = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M214 441.64l27.91.49a177.46 177.46 0 0 0-3.62-29.95l-24.14 7l-7.81-26.88l24.11-7a177.92 177.92 0 0 0-13.33-27.68L196.79 372l-16.16-22.86L201 334.73c-3.49-4.22-7.19-8.3-11.09-12.2s-8-7.62-12.19-11.12l-13.91 19.68L141 314.93l13.9-19.66a177.26 177.26 0 0 0-27.7-13.33l-6.37 21.94l-26.89-7.81l6.38-22a177.32 177.32 0 0 0-26.32-3.4c-1.59-.09-3.18-.16-4.78-.2l.4 22.34l-17.71.32a207.88 207.88 0 0 0 161.81 166.48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M444.65 302.67l-.55-33.06a206 206 0 0 1-39.33-4.74L397 291.8l-26.94-7.8l7.83-27a206.91 206.91 0 0 1-36.06-17.35l-16.36 23.15l-22.86-16.16l16.33-23.11a204.21 204.21 0 0 1-30-30l-22.19 15.67l-16.16-22.87l22.17-15.67a206 206 0 0 1-17.38-36.06l-25.75 7.48l-7.81-26.89l25.73-7.47q-2-9.21-3.18-18.64h-.47l-.78-14l-.33-6l-17.94-.32a13.38 13.38 0 0 1-1.79-.16l-6.35-.13l.06-2.47a14 14 0 0 1-5.66-11.49a13.27 13.27 0 0 1 .13-1.67A208 208 0 0 0 52.16 217.43l16.1-.28l.45 25.18l6.83.38l14 .77v.48q9.42 1.17 18.64 3.18l6.68-23L141.7 232l-6.7 23a205.3 205.3 0 0 1 36.06 17.38l14.53-20.56L208.47 268L194 288.5a203.5 203.5 0 0 1 30 30l21.3-15l16.16 22.86l-21.36 15.05a206.86 206.86 0 0 1 17.34 36.06l25.27-7.33l7.81 26.86l-25.24 7.33a205.9 205.9 0 0 1 4.72 38.3l29.42.53l-.29 16.48a207.94 207.94 0 0 0 160-157.21z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4v = [_hoisted_2$iV, _hoisted_3$gb, _hoisted_4$9z];
    vue.defineComponent({
      name: 'BaseballSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iV, _hoisted_5$4v);
      }
    });

    const _hoisted_1$iU = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iU = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M424.11 192H360L268.8 70.4a16 16 0 0 0-25.6 0L152 192H87.89a32.57 32.57 0 0 0-32.62 32.44a30.3 30.3 0 0 0 1.31 9l46.27 163.14a50.72 50.72 0 0 0 48.84 36.91h208.62a51.21 51.21 0 0 0 49-36.86l46.33-163.36a15.62 15.62 0 0 0 .46-2.36l.53-4.93a13.3 13.3 0 0 0 .09-1.55A32.57 32.57 0 0 0 424.11 192zM256 106.67L320 192H192zm0 245a37.7 37.7 0 1 1 37.88-37.7A37.87 37.87 0 0 1 256 351.63z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ga = [_hoisted_2$iU];
    vue.defineComponent({
      name: 'Basket',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iU, _hoisted_3$ga);
      }
    });

    const _hoisted_1$iT = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iT = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M68.4 192A20.38 20.38 0 0 0 48 212.2a17.87 17.87 0 0 0 .8 5.5L100.5 400a40.46 40.46 0 0 0 39.1 29.5h232.8a40.88 40.88 0 0 0 39.3-29.5l51.7-182.3l.6-5.5a20.38 20.38 0 0 0-20.4-20.2H68.4zm193.32 160.07A42.07 42.07 0 1 1 304 310a42.27 42.27 0 0 1-42.28 42.07z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$g9 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M160 192l96-128l96 128'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9y = [_hoisted_2$iT, _hoisted_3$g9];
    vue.defineComponent({
      name: 'BasketOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iT, _hoisted_4$9y);
      }
    });

    const _hoisted_1$iS = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iS = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M339.2 217.6L256 106.67L172.8 217.6l-25.6-19.2l96-128a16 16 0 0 1 25.6 0l96 128z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$g8 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M441.59 192H70.41a12 12 0 0 0-11.68 14.77L112.59 434h286.82l53.86-227.23A12 12 0 0 0 441.59 192zM256 351.66A37.71 37.71 0 1 1 293.89 314A37.88 37.88 0 0 1 256 351.66z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9x = [_hoisted_2$iS, _hoisted_3$g8];
    vue.defineComponent({
      name: 'BasketSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iS, _hoisted_4$9x);
      }
    });

    const _hoisted_1$iR = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iR = /*#__PURE__*/vue.createStaticVNode('<path d="M256 233.37l34.45-34.45a207.08 207.08 0 0 1-50.12-135.25c0-5 .19-10.05.54-15A207.09 207.09 0 0 0 120.67 98z" fill="currentColor"></path><path d="M313.14 176.23L391.33 98A207.07 207.07 0 0 0 273 48.8c-.41 4.9-.64 9.86-.64 14.87a175.25 175.25 0 0 0 40.78 112.56z" fill="currentColor"></path><path d="M335.77 198.86a175.25 175.25 0 0 0 112.56 40.81c5 0 10-.23 14.87-.64A207.07 207.07 0 0 0 414 120.67z" fill="currentColor"></path><path d="M176.23 313.14a175.23 175.23 0 0 0-112.56-40.81q-7.52 0-14.87.64A207.07 207.07 0 0 0 98 391.33z" fill="currentColor"></path><path d="M256 278.63l-34.45 34.45a207.08 207.08 0 0 1 50.12 135.25c0 5-.19 10.05-.54 15A207.06 207.06 0 0 0 391.33 414z" fill="currentColor"></path><path d="M448.33 271.67a207.08 207.08 0 0 1-135.25-50.12L278.63 256L414 391.33a207.09 207.09 0 0 0 49.39-120.2c-5.01.35-10.02.54-15.06.54z" fill="currentColor"></path><path d="M233.37 256L98 120.67a207.06 207.06 0 0 0-49.39 120.2c5-.35 10-.54 15-.54a207.08 207.08 0 0 1 135.25 50.12z" fill="currentColor"></path><path d="M120.67 414A207.07 207.07 0 0 0 239 463.2q.63-7.35.64-14.87a175.23 175.23 0 0 0-40.81-112.56z" fill="currentColor"></path>', 8);

    const _hoisted_10$p = [_hoisted_2$iR];
    vue.defineComponent({
      name: 'Basketball',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iR, _hoisted_10$p);
      }
    });

    const _hoisted_1$iQ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iQ = /*#__PURE__*/vue.createStaticVNode('<circle cx="256" cy="256" r="192" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><path d="M432.94 255.05a192 192 0 0 1-176.31-180.7" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M255 433.61A192 192 0 0 0 74.29 256.69" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M120.24 120.24l271.52 271.52"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M120.24 391.76l271.52-271.52"></path>', 5);

    const _hoisted_7$$ = [_hoisted_2$iQ];
    vue.defineComponent({
      name: 'BasketballOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iQ, _hoisted_7$$);
      }
    });

    const _hoisted_1$iP = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iP = /*#__PURE__*/vue.createStaticVNode('<path d="M256 233.37l34.45-34.45a207.08 207.08 0 0 1-50.12-135.25c0-5 .19-10.05.54-15A207.09 207.09 0 0 0 120.67 98z" fill="currentColor"></path><path d="M313.14 176.23L391.33 98A207.07 207.07 0 0 0 273 48.8c-.41 4.9-.64 9.86-.64 14.87a175.25 175.25 0 0 0 40.78 112.56z" fill="currentColor"></path><path d="M335.77 198.86a175.25 175.25 0 0 0 112.56 40.81c5 0 10-.23 14.87-.64A207.07 207.07 0 0 0 414 120.67z" fill="currentColor"></path><path d="M176.23 313.14a175.23 175.23 0 0 0-112.56-40.81q-7.52 0-14.87.64A207.07 207.07 0 0 0 98 391.33z" fill="currentColor"></path><path d="M256 278.63l-34.45 34.45a207.08 207.08 0 0 1 50.12 135.25c0 5-.19 10.05-.54 15A207.06 207.06 0 0 0 391.33 414z" fill="currentColor"></path><path d="M448.33 271.67a207.08 207.08 0 0 1-135.25-50.12L278.63 256L414 391.33a207.09 207.09 0 0 0 49.39-120.2c-5.01.35-10.02.54-15.06.54z" fill="currentColor"></path><path d="M233.37 256L98 120.67a207.06 207.06 0 0 0-49.39 120.2c5-.35 10-.54 15-.54a207.08 207.08 0 0 1 135.25 50.12z" fill="currentColor"></path><path d="M120.67 414A207.07 207.07 0 0 0 239 463.2q.63-7.35.64-14.87a175.23 175.23 0 0 0-40.81-112.56z" fill="currentColor"></path>', 8);

    const _hoisted_10$o = [_hoisted_2$iP];
    vue.defineComponent({
      name: 'BasketballSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iP, _hoisted_10$o);
      }
    });

    const _hoisted_1$iO = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iO = /*#__PURE__*/vue.createStaticVNode('<path d="M48 322.3V189.7A29.74 29.74 0 0 1 77.7 160h137.44l24.4-32H77.7A61.77 61.77 0 0 0 16 189.7v132.6A61.77 61.77 0 0 0 77.7 384h96.85a22.57 22.57 0 0 1 .26-7.32l.15-.75l.21-.73l6.5-23.2H77.7A29.74 29.74 0 0 1 48 322.3z" fill="currentColor"></path><path d="M386.3 128h-98.64a22.69 22.69 0 0 1-.27 7.2l-.15.74l-.21.73l-6.54 23.33H386.3a29.74 29.74 0 0 1 29.7 29.7v132.6a29.74 29.74 0 0 1-29.7 29.7H247l-24.42 32H386.3a61.77 61.77 0 0 0 61.7-61.7V189.7a61.77 61.77 0 0 0-61.7-61.7z" fill="currentColor"></path><path d="M162.65 294.16a24.37 24.37 0 0 1-21.56-13a25 25 0 0 1 1.42-25.83l.31-.46l.33-.44L197.62 183H89.69a20 20 0 0 0-20 20v106a20 20 0 0 0 20 20h98.42l9.78-34.86z" fill="currentColor"></path><path d="M276.07 280.89l27.07-35.49a5.2 5.2 0 0 0 .77-1.91a5 5 0 0 0 .08-.66a5 5 0 0 0-.08-1.29a5.11 5.11 0 0 0-.68-1.75a4.76 4.76 0 0 0-.78-.95a3.48 3.48 0 0 0-.48-.38a4 4 0 0 0-1.11-.55a4.28 4.28 0 0 0-1.31-.2h-61.62l12.12-43.21l3.23-11.5l6.21-22.16l.51-1.84l7.79-27.76a3.51 3.51 0 0 0 .05-.55v-.16c0-.05 0-.26-.05-.38s0-.09 0-.14a2.2 2.2 0 0 0-.17-.45a3.77 3.77 0 0 0-.26-.39l-.09-.1a2.73 2.73 0 0 0-.25-.23l-.1-.08a3.14 3.14 0 0 0-.39-.24a2 2 0 0 0-.41-.14H265.53a2.3 2.3 0 0 0-.45 0a1.9 1.9 0 0 0-.42.15l-.13.07l-.3.21l-.11.1a2.4 2.4 0 0 0-.36.41l-18 23.63l-13.14 17.22l-9.85 12.83l-63.71 83.55a5.72 5.72 0 0 0-.44.8a4.78 4.78 0 0 0-.35 1.09a4.7 4.7 0 0 0-.08 1.29a4.86 4.86 0 0 0 2 3.71a4.74 4.74 0 0 0 .54.31a4.31 4.31 0 0 0 1.89.43h61.62L194.42 380.6a3.64 3.64 0 0 0 0 .56v.15a2.32 2.32 0 0 0 .06.38a.58.58 0 0 0 0 .14a2.2 2.2 0 0 0 .17.45a3.62 3.62 0 0 0 .26.38l.09.1l.25.24a.39.39 0 0 1 .1.08a2.22 2.22 0 0 0 .39.23a2.83 2.83 0 0 0 .41.14h.13a1.86 1.86 0 0 0 .33 0h.13a2.32 2.32 0 0 0 .45-.06a2.05 2.05 0 0 0 .41-.16l.13-.07l.3-.21l.11-.09a2.4 2.4 0 0 0 .36-.41L221.82 352l17.53-23z" fill="currentColor"></path><path d="M319.5 256.93l-.46.6L264.51 329h109.8a20 20 0 0 0 20-20V203a20 20 0 0 0-20-20H274.05l-9.74 34.73h35.24A24.35 24.35 0 0 1 321 230.5a25.21 25.21 0 0 1-1 25.79z" fill="currentColor"></path><path d="M480 202.67a16 16 0 0 0-16 16v74.66a16 16 0 0 0 32 0v-74.66a16 16 0 0 0-16-16z" fill="currentColor"></path>', 6);

    const _hoisted_8$B = [_hoisted_2$iO];
    vue.defineComponent({
      name: 'BatteryCharging',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iO, _hoisted_8$B);
      }
    });

    const _hoisted_1$iN = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iN = /*#__PURE__*/vue.createStaticVNode('<path d="M48 322.3V189.7A29.74 29.74 0 0 1 77.7 160h137.44l24.4-32H77.7A61.77 61.77 0 0 0 16 189.7v132.6A61.77 61.77 0 0 0 77.7 384h96.85a22.57 22.57 0 0 1 .26-7.32l.15-.75l.21-.73l6.5-23.2H77.7A29.74 29.74 0 0 1 48 322.3z" fill="currentColor"></path><path d="M386.3 128h-98.64a22.69 22.69 0 0 1-.27 7.2l-.15.74l-.21.73l-6.54 23.33H386.3a29.74 29.74 0 0 1 29.7 29.7v132.6a29.74 29.74 0 0 1-29.7 29.7H247l-24.42 32H386.3a61.77 61.77 0 0 0 61.7-61.7V189.7a61.77 61.77 0 0 0-61.7-61.7z" fill="currentColor"></path><path d="M162.65 294.16a24.37 24.37 0 0 1-21.56-13a25 25 0 0 1 1.42-25.83l.31-.46l.33-.44L197.62 183H89.69a20 20 0 0 0-20 20v106a20 20 0 0 0 20 20h98.42l9.78-34.86z" fill="currentColor"></path><path d="M276.07 280.89l27.07-35.49a5.2 5.2 0 0 0 .77-1.91a5 5 0 0 0 .08-.66a5 5 0 0 0-.08-1.29a5.11 5.11 0 0 0-.68-1.75a4.76 4.76 0 0 0-.78-.95a3.48 3.48 0 0 0-.48-.38a4 4 0 0 0-1.11-.55a4.28 4.28 0 0 0-1.31-.2h-61.62l12.12-43.21l3.23-11.5l6.21-22.16l.51-1.84l7.79-27.76a3.51 3.51 0 0 0 .05-.55v-.16c0-.05 0-.26-.05-.38s0-.09 0-.14a2.2 2.2 0 0 0-.17-.45a3.77 3.77 0 0 0-.26-.39l-.09-.1a2.73 2.73 0 0 0-.25-.23l-.1-.08a3.14 3.14 0 0 0-.39-.24a2 2 0 0 0-.41-.14H265.53a2.3 2.3 0 0 0-.45 0a1.9 1.9 0 0 0-.42.15l-.13.07l-.3.21l-.11.1a2.4 2.4 0 0 0-.36.41l-18 23.63l-13.14 17.22l-9.85 12.83l-63.71 83.55a5.72 5.72 0 0 0-.44.8a4.78 4.78 0 0 0-.35 1.09a4.7 4.7 0 0 0-.08 1.29a4.86 4.86 0 0 0 2 3.71a4.74 4.74 0 0 0 .54.31a4.31 4.31 0 0 0 1.89.43h61.62L194.42 380.6a3.64 3.64 0 0 0 0 .56v.15a2.32 2.32 0 0 0 .06.38a.58.58 0 0 0 0 .14a2.2 2.2 0 0 0 .17.45a3.62 3.62 0 0 0 .26.38l.09.1l.25.24a.39.39 0 0 1 .1.08a2.22 2.22 0 0 0 .39.23a2.83 2.83 0 0 0 .41.14h.13a1.86 1.86 0 0 0 .33 0h.13a2.32 2.32 0 0 0 .45-.06a2.05 2.05 0 0 0 .41-.16l.13-.07l.3-.21l.11-.09a2.4 2.4 0 0 0 .36-.41L221.82 352l17.53-23z" fill="currentColor"></path><path d="M319.5 256.93l-.46.6L264.51 329h109.8a20 20 0 0 0 20-20V203a20 20 0 0 0-20-20H274.05l-9.74 34.73h35.24A24.35 24.35 0 0 1 321 230.5a25.21 25.21 0 0 1-1 25.79z" fill="currentColor"></path><path d="M480 202.67a16 16 0 0 0-16 16v74.66a16 16 0 0 0 32 0v-74.66a16 16 0 0 0-16-16z" fill="currentColor"></path>', 6);

    const _hoisted_8$A = [_hoisted_2$iN];
    vue.defineComponent({
      name: 'BatteryChargingOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iN, _hoisted_8$A);
      }
    });

    const _hoisted_1$iM = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iM = /*#__PURE__*/vue.createStaticVNode('<path d="M306.68 237.62h-66.5l15.33-54.7l6.43-22.92l3.94-14l4.29-15.33a3.56 3.56 0 0 0 .06-.44v-.19a1.85 1.85 0 0 0 0-.23a2 2 0 0 0 0-.24v-.14c0-.1-.07-.19-.11-.29v-.05a2.33 2.33 0 0 0-2-1.35h-.1a2.25 2.25 0 0 0-1.8 1l-12.5 17.15l-18.82 25.55l-8.36 11.48l-35.41 48.6L160 274.26h66.44l-30 107a3.93 3.93 0 0 0-.06.48v.1a1.94 1.94 0 0 0 0 .34a.29.29 0 0 0 0 .09a3 3 0 0 0 .07.32v.06a1.83 1.83 0 0 0 .14.32a2.38 2.38 0 0 0 1.52 1.16H198.68a2.1 2.1 0 0 0 1.31-.5l.06-.05a2.6 2.6 0 0 0 .42-.45L223.3 352l13-17.82z" fill="currentColor"></path><path d="M289.78 134.55l-.14.74l-.21.73l-6.72 24H417V352H248.05l-23.33 32H449V128H290.13a22.62 22.62 0 0 1-.35 6.55z" fill="currentColor"></path><path d="M49 160h169.49l23.31-32H17v256h159.49a22.73 22.73 0 0 1 .34-6.67l.15-.75l.2-.73l6.69-23.85H49z" fill="currentColor"></path><path d="M264.76 329.08h130.55V182.92H276.28l-9.73 34.7H346l-23.16 31.78l-58.08 79.68z" fill="currentColor"></path><path d="M160 294.26h-39.31l23.15-31.78l57.95-79.56H70.69v146.16h119.6l9.77-34.82H160z" fill="currentColor"></path><path d="M465 202.67h32v106.67h-32z" fill="currentColor"></path>', 6);

    const _hoisted_8$z = [_hoisted_2$iM];
    vue.defineComponent({
      name: 'BatteryChargingSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iM, _hoisted_8$z);
      }
    });

    const _hoisted_1$iL = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iL = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '31',
      y: '144',
      width: '400',
      height: '224',
      rx: '45.7',
      ry: '45.7',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$g7 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M479 218.67v74.66'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9w = [_hoisted_2$iL, _hoisted_3$g7];
    vue.defineComponent({
      name: 'BatteryDead',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iL, _hoisted_4$9w);
      }
    });

    const _hoisted_1$iK = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iK = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '31',
      y: '144',
      width: '400',
      height: '224',
      rx: '45.7',
      ry: '45.7',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$g6 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M479 218.67v74.66'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9v = [_hoisted_2$iK, _hoisted_3$g6];
    vue.defineComponent({
      name: 'BatteryDeadOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iK, _hoisted_4$9v);
      }
    });

    const _hoisted_1$iJ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iJ = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M32 144h400v224H32z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$g5 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M480 218.67v74.66'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9u = [_hoisted_2$iJ, _hoisted_3$g5];
    vue.defineComponent({
      name: 'BatteryDeadSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iJ, _hoisted_4$9u);
      }
    });

    const _hoisted_1$iI = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iI = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '32',
      y: '144',
      width: '400',
      height: '224',
      rx: '45.7',
      ry: '45.7',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$g4 = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '85.69',
      y: '198.93',
      width: '292.63',
      height: '114.14',
      rx: '4',
      ry: '4',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9t = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M480 218.67v74.66'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4u = [_hoisted_2$iI, _hoisted_3$g4, _hoisted_4$9t];
    vue.defineComponent({
      name: 'BatteryFull',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iI, _hoisted_5$4u);
      }
    });

    const _hoisted_1$iH = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iH = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '32',
      y: '144',
      width: '400',
      height: '224',
      rx: '45.7',
      ry: '45.7',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$g3 = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '85.69',
      y: '198.93',
      width: '292.63',
      height: '114.14',
      rx: '4',
      ry: '4',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9s = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M480 218.67v74.66'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4t = [_hoisted_2$iH, _hoisted_3$g3, _hoisted_4$9s];
    vue.defineComponent({
      name: 'BatteryFullOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iH, _hoisted_5$4t);
      }
    });

    const _hoisted_1$iG = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iG = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M17 384h432V128H17zm32-224h368v192H49z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$g2 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M70.69 182.94h324.63v146.13H70.69z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9r = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M465 202.67h32v106.67h-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4s = [_hoisted_2$iG, _hoisted_3$g2, _hoisted_4$9r];
    vue.defineComponent({
      name: 'BatteryFullSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iG, _hoisted_5$4s);
      }
    });

    const _hoisted_1$iF = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iF = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '32',
      y: '144',
      width: '400',
      height: '224',
      rx: '45.7',
      ry: '45.7',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$g1 = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '85.69',
      y: '198.93',
      width: '154.31',
      height: '114.13',
      rx: '4',
      ry: '4',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9q = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M480 218.67v74.66'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4r = [_hoisted_2$iF, _hoisted_3$g1, _hoisted_4$9q];
    vue.defineComponent({
      name: 'BatteryHalf',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iF, _hoisted_5$4r);
      }
    });

    const _hoisted_1$iE = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iE = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '32',
      y: '144',
      width: '400',
      height: '224',
      rx: '45.7',
      ry: '45.7',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$g0 = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '85.69',
      y: '198.93',
      width: '154.31',
      height: '114.13',
      rx: '4',
      ry: '4',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9p = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M480 218.67v74.66'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4q = [_hoisted_2$iE, _hoisted_3$g0, _hoisted_4$9p];
    vue.defineComponent({
      name: 'BatteryHalfOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iE, _hoisted_5$4q);
      }
    });

    const _hoisted_1$iD = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iD = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M17 384h432V128H17zm32-224h368v192H49z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$f$ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M70.69 182.92H256v146.16H70.69z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9o = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M465 202.67h32v106.67h-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4p = [_hoisted_2$iD, _hoisted_3$f$, _hoisted_4$9o];
    vue.defineComponent({
      name: 'BatteryHalfSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iD, _hoisted_5$4p);
      }
    });

    const _hoisted_1$iC = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iC = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M444 32H128c-19.38 0-45.9 4.34-64.11 24.77C52.17 69.92 48 85.66 48 96a16 16 0 0 0 13.8 15.85C91.7 116 96 117.79 96 136v264a80.07 80.07 0 0 0 80 80h192a80.11 80.11 0 0 0 80-80V96c0-12.55 7.46-27.25 10-31.36l.1-.14c.22-.35.5-.72.78-1.1c2-2.79 5.09-7 5.09-12.95C464 39.79 454.89 32 444 32zM84.11 83.08c5.24-8.87 17.17-19 44.29-19h294.43C419.3 72.87 416 84.27 416 96v64H128v-24c0-37.32-21.35-48.14-43.89-52.92z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$f_ = [_hoisted_2$iC];
    vue.defineComponent({
      name: 'Beaker',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iC, _hoisted_3$f_);
      }
    });

    const _hoisted_1$iB = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iB = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M445.2 48.05L398 48H128c-54.3 0-64 35.7-64 48c30.3 4.2 48 8 48 40v264a64 64 0 0 0 64 64h192a64 64 0 0 0 64-64V96c0-19 11.5-38.35 12.6-40c1.2-1.9 3.4-4.4 3.4-5.5s-.3-2.45-2.8-2.45z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fZ = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M112 176h320'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9n = [_hoisted_2$iB, _hoisted_3$fZ];
    vue.defineComponent({
      name: 'BeakerOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iB, _hoisted_4$9n);
      }
    });

    const _hoisted_1$iA = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iA = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M453.55 54.7L464 32H128.4c-27.74 0-49 6.57-63.31 19.51C54.39 61.27 48 74.89 48 88v24h16c31 0 32 16.79 32 35v313a20 20 0 0 0 20 20h312a20 20 0 0 0 20-20V96c0-17.16 2.28-34.14 5.55-41.3zM416 96v64H128v-22c0-36.15-21-51-41.77-53.46C89 70 105.7 64.05 128.4 64.05h289.92A221.83 221.83 0 0 0 416 96z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fY = [_hoisted_2$iA];
    vue.defineComponent({
      name: 'BeakerSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iA, _hoisted_3$fY);
      }
    });

    const _hoisted_1$iz = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iz = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M432 230.7a79.44 79.44 0 0 0-32-6.7H112a79.51 79.51 0 0 0-32 6.69A80.09 80.09 0 0 0 32 304v112a16 16 0 0 0 32 0v-8a8.1 8.1 0 0 1 8-8h368a8.1 8.1 0 0 1 8 8v8a16 16 0 0 0 32 0V304a80.09 80.09 0 0 0-48-73.3z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fX = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M376 80H136a56 56 0 0 0-56 56v72a4 4 0 0 0 5.11 3.84A95.5 95.5 0 0 1 112 208h4.23a4 4 0 0 0 4-3.55A32 32 0 0 1 152 176h56a32 32 0 0 1 31.8 28.45a4 4 0 0 0 4 3.55h24.46a4 4 0 0 0 4-3.55A32 32 0 0 1 304 176h56a32 32 0 0 1 31.8 28.45a4 4 0 0 0 4 3.55h4.2a95.51 95.51 0 0 1 26.89 3.85A4 4 0 0 0 432 208v-72a56 56 0 0 0-56-56z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9m = [_hoisted_2$iz, _hoisted_3$fX];
    vue.defineComponent({
      name: 'Bed',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iz, _hoisted_4$9m);
      }
    });

    const _hoisted_1$iy = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iy = /*#__PURE__*/vue.createStaticVNode('<path d="M384 240H96V136a40.12 40.12 0 0 1 40-40h240a40.12 40.12 0 0 1 40 40v104z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M48 416V304a64.19 64.19 0 0 1 64-64h288a64.19 64.19 0 0 1 64 64v112" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M48 416v-8a24.07 24.07 0 0 1 24-24h368a24.07 24.07 0 0 1 24 24v8" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M112 240v-16a32.09 32.09 0 0 1 32-32h80a32.09 32.09 0 0 1 32 32v16" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M256 240v-16a32.09 32.09 0 0 1 32-32h80a32.09 32.09 0 0 1 32 32v16" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 5);

    const _hoisted_7$_ = [_hoisted_2$iy];
    vue.defineComponent({
      name: 'BedOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iy, _hoisted_7$_);
      }
    });

    const _hoisted_1$ix = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ix = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M432 224V96a16 16 0 0 0-16-16H96a16 16 0 0 0-16 16v128a48 48 0 0 0-48 48v160h36v-32h376v32h36V272a48 48 0 0 0-48-48zm-192 0H120v-32a16 16 0 0 1 16-16h88a16 16 0 0 1 16 16zm32-32a16 16 0 0 1 16-16h88a16 16 0 0 1 16 16v32H272z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fW = [_hoisted_2$ix];
    vue.defineComponent({
      name: 'BedSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ix, _hoisted_3$fW);
      }
    });

    const _hoisted_1$iw = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iw = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M392 208h-24v-5.74A63.93 63.93 0 0 0 321.65 96a111 111 0 0 0-27.59-47.29A108.62 108.62 0 0 0 216 16c-29.91 0-57.78 12.28-79 34.68a56 56 0 0 0-67.51 77.54A63.91 63.91 0 0 0 80 231.39V440a56.06 56.06 0 0 0 56 56h176a56.06 56.06 0 0 0 56-56v-8h24a72.08 72.08 0 0 0 72-72v-80a72.08 72.08 0 0 0-72-72zM176 416a16 16 0 0 1-32 0V256a16 16 0 0 1 32 0zm64 0a16 16 0 0 1-32 0V256a16 16 0 0 1 32 0zm64 0a16 16 0 0 1-32 0V256a16 16 0 0 1 32 0zm16-224c-8.33 0-20.55-5.18-26.69-11.31A16 16 0 0 0 282 176H160a16 16 0 0 0-15 10.53c-6.83 18.68-23.6 21.47-33 21.47a32 32 0 0 1 0-64c.09 0 9.12.34 16.4 5.8a16 16 0 1 0 19.2-25.6A63.69 63.69 0 0 0 112 112a63.55 63.55 0 0 0-14 1.57A24 24 0 0 1 120 80a23.78 23.78 0 0 1 19.38 9.84a51.35 51.35 0 0 1 4.71 7.9A16 16 0 0 0 176 96c0-6.77-3.61-15.17-10.76-25c-.46-.63-1-1.25-1.45-1.86C178.39 55.44 196.64 48 216 48a76.86 76.86 0 0 1 55.23 23.18A80.2 80.2 0 0 1 292.61 142a16 16 0 0 0 12.73 18.71a16.29 16.29 0 0 0 3 .28a16 16 0 0 0 15.7-13a111.78 111.78 0 0 0 1.96-19.42a32 32 0 0 1-6 63.43zm112 168a40 40 0 0 1-40 40h-24V240h24a40 40 0 0 1 40 40z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fV = [_hoisted_2$iw];
    vue.defineComponent({
      name: 'Beer',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iw, _hoisted_3$fV);
      }
    });

    const _hoisted_1$iv = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iv = /*#__PURE__*/vue.createStaticVNode('<path d="M352 200v240a40.12 40.12 0 0 1-40 40H136a40.12 40.12 0 0 1-40-40V224" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M352 224h40a56.16 56.16 0 0 1 56 56v80a56.16 56.16 0 0 1-56 56h-40" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M224 256v160"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M288 256v160"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M160 256v160"></path><path d="M320 112a48 48 0 0 1 0 96c-13.25 0-29.31-7.31-38-16H160c-8 22-27 32-48 32a48 48 0 0 1 0-96a47.91 47.91 0 0 1 26 9" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M91.86 132.43a40 40 0 1 1 60.46-52S160 91 160 96" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><path d="M145.83 64.71C163.22 44.89 187.57 32 216 32c52.38 0 94 42.84 94 95.21a95 95 0 0 1-1.67 17.79" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path>', 8);

    const _hoisted_10$n = [_hoisted_2$iv];
    vue.defineComponent({
      name: 'BeerOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iv, _hoisted_10$n);
      }
    });

    const _hoisted_1$iu = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iu = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 208h-80v-5.74A63.93 63.93 0 0 0 321.65 96a111 111 0 0 0-27.59-47.29A108.62 108.62 0 0 0 216 16c-29.91 0-57.78 12.28-79 34.67a56 56 0 0 0-67.51 77.51c-1 .86-1.91 1.74-2.83 2.66A63.56 63.56 0 0 0 48 176.26a62.65 62.65 0 0 0 20.77 46.54A65 65 0 0 0 80 231v249a16 16 0 0 0 16 16h256a16 16 0 0 0 16-16v-48h80a16 16 0 0 0 16-16V224a16 16 0 0 0-16-16zM176 432h-32V240h32zm64 0h-32V240h32zm64 0h-32V240h32zm16-240c-8.33 0-20.55-5.18-26.69-11.31l-4.68-4.69H148.79L145 186.53c-5.81 16-18.83 20.41-28.73 21.29a34.08 34.08 0 0 1-25.91-8.67a31 31 0 0 1-10.32-23a31.8 31.8 0 0 1 9.33-22.71c.16-.17.33-.32.5-.49A31.78 31.78 0 0 1 112 144c.09 0 9.12.34 16.4 5.8l12.8 9.6l19.2-25.6l-12.8-9.6A63.69 63.69 0 0 0 112 112a64.79 64.79 0 0 0-14 1.55a24 24 0 0 1 41.4-23.68l.23.35l.4.46a35.78 35.78 0 0 1 5 8.94l5.62 15l30-11.24l-5.62-15a68.2 68.2 0 0 0-10-17.74c-.38-.52-.79-1-1.19-1.51C178.38 55.45 196.64 48 216 48a76.86 76.86 0 0 1 55.23 23.18A80.2 80.2 0 0 1 292.61 142l-3 15.72l31.43 6l3-15.72a111.78 111.78 0 0 0 1.96-19.43a32 32 0 0 1-6 63.43zm112 208h-64V240h64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fU = [_hoisted_2$iu];
    vue.defineComponent({
      name: 'BeerSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iu, _hoisted_3$fU);
      }
    });

    const _hoisted_1$it = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$it = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M388 448a92 92 0 1 1 92-92a92.1 92.1 0 0 1-92 92zm0-152a60 60 0 1 0 60 60a60.07 60.07 0 0 0-60-60z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fT = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M124 448a92 92 0 1 1 92-92a92.1 92.1 0 0 1-92 92zm0-152a60 60 0 1 0 60 60a60.07 60.07 0 0 0-60-60z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9l = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 128a31.89 31.89 0 0 0 32-32.1A31.55 31.55 0 0 0 320.2 64a32 32 0 1 0-.2 64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4o = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M367.55 192h-43.76a4 4 0 0 1-3.51-2.08l-31.74-58.17a31 31 0 0 0-49.38-7.75l-69.86 70.4a32.56 32.56 0 0 0-9.3 22.4c0 17.4 12.6 23.6 18.5 27.1c28.5 16.42 48.57 28.43 59.58 35.1a4 4 0 0 1 1.92 3.41v69.12c0 8.61 6.62 16 15.23 16.43A16 16 0 0 0 272 352v-86a16 16 0 0 0-6.66-13l-37-26.61a4 4 0 0 1-.58-6l42-44.79a4 4 0 0 1 6.42.79L298 215.77a16 16 0 0 0 14 8.23h56a16 16 0 0 0 16-16.77c-.42-8.61-7.84-15.23-16.45-15.23z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1T = [_hoisted_2$it, _hoisted_3$fT, _hoisted_4$9l, _hoisted_5$4o];
    vue.defineComponent({
      name: 'Bicycle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$it, _hoisted_6$1T);
      }
    });

    const _hoisted_1$is = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$is = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M388 288a76 76 0 1 0 76 76a76.24 76.24 0 0 0-76-76z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fS = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M124 288a76 76 0 1 0 76 76a76.24 76.24 0 0 0-76-76z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9k = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 360v-86l-64-42l80-88l40 72h56'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4n = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 136a31.89 31.89 0 0 0 32-32.1A31.55 31.55 0 0 0 320.2 72a32 32 0 1 0-.2 64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1S = [_hoisted_2$is, _hoisted_3$fS, _hoisted_4$9k, _hoisted_5$4n];
    vue.defineComponent({
      name: 'BicycleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$is, _hoisted_6$1S);
      }
    });

    const _hoisted_1$ir = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ir = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 192l-29.5-60.1C284.32 118 284.32 118 264 118c-13.26 0-14.76 0-23 7.3l-71.7 69.1c-8.3 8.45-9.3 9.45-9.3 26.6c0 12.67 3.78 14.61 18.51 22.9L240 278v90h32V254s-29-17-48.3-30l48.9-51.5c18.7 28.5 27.3 51.5 38 51.5H384v-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fR = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M388 448a92 92 0 1 1 92-92a92.1 92.1 0 0 1-92 92zm0-152a60 60 0 1 0 60 60a60.07 60.07 0 0 0-60-60z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9j = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M124 448a92 92 0 1 1 92-92a92.1 92.1 0 0 1-92 92zm0-152a60 60 0 1 0 60 60a60.07 60.07 0 0 0-60-60z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4m = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 128a31.89 31.89 0 0 0 32-32.1A31.55 31.55 0 0 0 320.2 64a32 32 0 1 0-.2 64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1R = [_hoisted_2$ir, _hoisted_3$fR, _hoisted_4$9j, _hoisted_5$4m];
    vue.defineComponent({
      name: 'BicycleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ir, _hoisted_6$1R);
      }
    });

    const _hoisted_1$iq = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$iq = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M388 160.77a20 20 0 0 0-5.85-14.91l-112-112A20 20 0 0 0 236 48v164.52l-79-67.71a20 20 0 0 0-26 30.38L225.27 256L131 336.81a20 20 0 1 0 26 30.38l79-67.71V464a20 20 0 0 0 34.14 14.14l112-112a20 20 0 0 0-1.14-29.33L286.73 256L381 175.19a20 20 0 0 0 7-14.42zm-49.42 192.36L276 415.72V299.49zM276 212.52V96.28l62.59 62.59z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fQ = [_hoisted_2$iq];
    vue.defineComponent({
      name: 'Bluetooth',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$iq, _hoisted_3$fQ);
      }
    });

    const _hoisted_1$ip = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ip = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M144 352l224-192L256 48v416l112-112l-224-192'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fP = [_hoisted_2$ip];
    vue.defineComponent({
      name: 'BluetoothOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ip, _hoisted_3$fP);
      }
    });

    const _hoisted_1$io = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$io = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M397.41 161.13L236-.28v212.8l-94.17-80.72l-26 30.37L225.27 256L115.8 349.83l26 30.37l94.2-80.72v212.8l161.41-161.41L286.73 256zM276 96.28l62.59 62.59L276 212.52zm62.58 256.85L276 415.72V299.48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fO = [_hoisted_2$io];
    vue.defineComponent({
      name: 'BluetoothSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$io, _hoisted_3$fO);
      }
    });

    const _hoisted_1$in = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$in = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 473.14a6.83 6.83 0 0 0-3.57-6c-27.07-14.55-51.76-36.82-62.62-48a10.05 10.05 0 0 0-12.72-1.51c-50.33 32.42-111.61 32.44-161.95.05a10.09 10.09 0 0 0-12.82 1.56c-10.77 11.28-35.19 33.3-62.43 47.75a7.11 7.11 0 0 0-3.89 5.73a6.73 6.73 0 0 0 7.92 7.15c20.85-4.18 41-13.68 60.2-23.83a8.71 8.71 0 0 1 8-.06a185.14 185.14 0 0 0 167.81 0a8.82 8.82 0 0 1 8.09.06c19.1 10 39.22 19.59 60 23.8a6.73 6.73 0 0 0 8-6.71z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fN = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M476.71 246.91c-3.49-8.39-10.9-14.89-20.9-18.35L432 219.08V136a64 64 0 0 0-64-64h-32v-8a40 40 0 0 0-40-40h-80a40 40 0 0 0-40 40v8h-32a64 64 0 0 0-64 64v83.15l-23.58 9.39c-9.94 3.3-17.63 10-21.15 18.44c-2.45 5.89-5.25 15-1.3 26.46l.1.3l46.66 119.44A23.33 23.33 0 0 0 102.58 408c.5 0 1 0 1.53-.05c31.32-2 56-17.27 72.6-31.61C200.42 396.81 228.31 408 256 408s55.43-11.2 79.14-31.7c16.59 14.36 41.3 29.67 72.61 31.65a23.36 23.36 0 0 0 23.37-14.74l46.65-119c3.28-8.09 2.9-17.76-1.06-27.3zM269 154.21l-1.14-.4a39.53 39.53 0 0 0-23.73 0l-.58.18l-126.07 50.23a4 4 0 0 1-5.48-3.72V136a32 32 0 0 1 32-32h224a32 32 0 0 1 32 32v64.44a4 4 0 0 1-5.48 3.72z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9i = [_hoisted_2$in, _hoisted_3$fN];
    vue.defineComponent({
      name: 'Boat',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$in, _hoisted_4$9i);
      }
    });

    const _hoisted_1$im = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$im = /*#__PURE__*/vue.createStaticVNode('<path d="M461.93 261.05c-2-4.76-6.71-7.83-11.67-9.49l-187.18-74.48a23.78 23.78 0 0 0-14.17 0l-187 74.52c-5 1.56-9.83 4.77-11.81 9.53s-2.94 9.37-1 15.08l46.53 119.15a7.46 7.46 0 0 0 7.47 4.64c26.69-1.68 50.31-15.23 68.38-32.5a7.66 7.66 0 0 1 10.49 0C201.29 386 227 400 256 400s54.56-14 73.88-32.54a7.67 7.67 0 0 1 10.5 0c18.07 17.28 41.69 30.86 68.38 32.54a7.45 7.45 0 0 0 7.46-4.61l46.7-119.16c1.98-4.78.99-10.41-.99-15.18z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path d="M416 473.14a6.84 6.84 0 0 0-3.56-6c-27.08-14.55-51.77-36.82-62.63-48a10.05 10.05 0 0 0-12.72-1.51c-50.33 32.42-111.61 32.44-161.95.05a10.09 10.09 0 0 0-12.82 1.56c-10.77 11.28-35.19 33.3-62.43 47.75a7.15 7.15 0 0 0-3.89 5.73a6.73 6.73 0 0 0 7.92 7.15c20.85-4.18 41-13.68 60.2-23.83a8.71 8.71 0 0 1 8-.06A185.14 185.14 0 0 0 340 456a8.82 8.82 0 0 1 8.09.06c19.1 10 39.22 19.59 60 23.8a6.72 6.72 0 0 0 7.95-6.71z" fill="currentColor"></path><path d="M320 96V72a24.07 24.07 0 0 0-24-24h-80a24.07 24.07 0 0 0-24 24v24" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M416 233v-89a48.14 48.14 0 0 0-48-48H144a48.14 48.14 0 0 0-48 48v92" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 183.6v212.85"></path>', 5);

    const _hoisted_7$Z = [_hoisted_2$im];
    vue.defineComponent({
      name: 'BoatOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$im, _hoisted_7$Z);
      }
    });

    const _hoisted_1$il = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$il = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M477.77 246.42c-2.13-6-7.23-9.55-12.56-11.95L432 221.38V92a20 20 0 0 0-20-20h-76V40a16 16 0 0 0-16-16H192a16 16 0 0 0-16 16v32h-76a20 20 0 0 0-20 20v129.46l-33.08 13.06c-5.33 2.4-10.58 6-12.72 12s-3.16 11.81-1 19L84.25 415.7h1.06c34.12 0 64-17.41 85.31-43.82c21.32 26.41 51.18 42.12 85.3 42.12s64-15.76 85.31-42.17c21.32 26.41 51.18 43.87 85.3 43.87h1.06l51.25-150.17c2.16-6 1.07-13.1-1.07-19.11zM256 152l-144 56.83V108a4 4 0 0 1 4-4h280a4 4 0 0 1 4 4v100.76z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fM = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M345.22 407c-52.25 36.26-126.35 36.25-178.6 0c0 0-45.64 63-94.64 63l13.33 1c29.86 0 58.65-11.73 85.31-25.59a185.33 185.33 0 0 0 170.6 0c26.66 13.87 55.45 25.6 85.31 25.6l13.33-1C392.21 470 345.22 407 345.22 407z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9h = [_hoisted_2$il, _hoisted_3$fM];
    vue.defineComponent({
      name: 'BoatSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$il, _hoisted_4$9h);
      }
    });

    const _hoisted_1$ik = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ik = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '56',
      r: '56',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fL = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M437 128H75a27 27 0 0 0 0 54h101.88c6.91 0 15 3.09 19.58 15c5.35 13.83 2.73 40.54-.57 61.23l-4.32 24.45a.42.42 0 0 1-.12.35l-34.6 196.81A27.43 27.43 0 0 0 179 511.58a27.06 27.06 0 0 0 31.42-22.29l23.91-136.8S242 320 256 320c14.23 0 21.74 32.49 21.74 32.49l23.91 136.92a27.24 27.24 0 1 0 53.62-9.6L320.66 283a.45.45 0 0 0-.11-.35l-4.33-24.45c-3.3-20.69-5.92-47.4-.57-61.23c4.56-11.88 12.91-15 19.28-15H437a27 27 0 0 0 0-54z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9g = [_hoisted_2$ik, _hoisted_3$fL];
    vue.defineComponent({
      name: 'Body',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ik, _hoisted_4$9g);
      }
    });

    const _hoisted_1$ij = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ij = /*#__PURE__*/vue.createElementVNode('circle', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      cx: '256',
      cy: '56',
      r: '40'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fK = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M199.3 295.62h0l-30.4 172.2a24 24 0 0 0 19.5 27.8a23.76 23.76 0 0 0 27.6-19.5l21-119.9v.2s5.2-32.5 17.5-32.5h3.1c12.5 0 17.5 32.5 17.5 32.5v-.1l21 119.9a23.92 23.92 0 1 0 47.1-8.4l-30.4-172.2l-4.9-29.7c-2.9-18.1-4.2-47.6.5-59.7c4-10.4 14.13-14.2 23.2-14.2H424a24 24 0 0 0 0-48H88a24 24 0 0 0 0 48h92.5c9.23 0 19.2 3.8 23.2 14.2c4.7 12.1 3.4 41.6.5 59.7z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9f = [_hoisted_2$ij, _hoisted_3$fK];
    vue.defineComponent({
      name: 'BodyOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ij, _hoisted_4$9f);
      }
    });

    const _hoisted_1$ii = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ii = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '56',
      r: '56',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fJ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 128H48v52h144l-32 325.13l51 6.87l21.65-192h47.02L301 512l51-6.98L320 180h144v-52z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9e = [_hoisted_2$ii, _hoisted_3$fJ];
    vue.defineComponent({
      name: 'BodySharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ii, _hoisted_4$9e);
      }
    });

    const _hoisted_1$ih = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ih = /*#__PURE__*/vue.createStaticVNode('<path d="M273.38 368.37c-.81-9.23-8.86-16.44-18.55-16.44a18.63 18.63 0 0 0-18.2 14.07l-18.2 88.36a35.59 35.59 0 0 0-.93 7.87c0 19.93 16.68 33.77 37.33 33.77s37.34-13.84 37.34-33.77a36.16 36.16 0 0 0-1.29-9.45z" fill="currentColor"></path><path d="M411.05 407.89a42.66 42.66 0 0 0-5.95-4.36L335.57 355c-6.77-4.24-14-4.13-19.25 1a13.52 13.52 0 0 0-2 17.19l52.5 69a38 38 0 0 0 4 4.69c9.1 10.16 29.28 10.72 40.37 0c10.94-10.96 10.81-30.39-.14-38.99z" fill="currentColor"></path><path d="M463.3 335.93h-70.42c-4.55 0-8.88 3.35-8.88 8.15s2.95 7.85 6.92 9.16l66.43 20.55C467 376 480 367.44 480 356.71c0-13.63-7.6-20.78-16.7-20.78z" fill="currentColor"></path><path d="M128.22 344.08c0-4.95-4.55-8.15-9.45-8.15H48.35c-8.87 0-16.35 9.58-16.35 20.31S44.62 376 54.3 373.79l67.43-20.55c4.39-1.31 6.49-4.24 6.49-9.16z" fill="currentColor"></path><path d="M176.55 355.05L107 403.41a32.29 32.29 0 0 0-6 4.34a26.33 26.33 0 0 0 0 38.56a29.41 29.41 0 0 0 40.36 0a30.75 30.75 0 0 0 4-4.68L197.9 373c3.5-5.57 2.92-12.48-2-17a15 15 0 0 0-19.35-.95z" fill="currentColor"></path><path d="M293.46 242.39c10-5.42 19.45-10.54 28.31-16.16c42.46-26.92 62.23-59 62.23-101c0-64.66-56.07-104.4-108.82-109c-6.49-.57-15-.42-19.91 3.88s-5.88 12.56-6.15 19.1c-1.38 33.61-28.38 59-57 85.86c-28 26.3-56.93 53.49-62.71 91c-8.41 54.68 21.74 86.71 40.46 100.93a31.88 31.88 0 0 0 19.3 6.51a32.32 32.32 0 0 0 7.41-.87a31.75 31.75 0 0 0 21.27-16.95c14.91-30.39 45.77-47.12 75.61-63.3z" fill="currentColor"></path><path d="M139.82 156.57c12.22-15.76 27-29.68 41.37-43.15c19.92-18.72 37.81-35.58 46.5-53.86c-12.24-7.37-27.36-11.36-46.51-11.36c-17.79 0-20.39 5.18-20.39 19.06c0 12.56-6.53 20.54-14.34 30.65C137.8 109.1 128 121.77 128 140.84c0 10.23 1.29 18.77 4.2 26.37q3.5-5.32 7.62-10.64z" fill="currentColor"></path><path d="M330.34 239.74c-9.33 5.92-19 11.16-29.25 16.71c-28.91 15.68-56.21 30.48-68.88 56.28a62.6 62.6 0 0 1-1.88 3.61a8 8 0 0 0 3.89 11.3c12.31 5.1 25.13 8.27 38.91 8.27a111.42 111.42 0 0 0 78.24-31.37A107.45 107.45 0 0 0 384 226.85a86.56 86.56 0 0 0-1.33-15a8 8 0 0 0-13.8-4c-10.18 11.47-22.93 22-38.53 31.89z" fill="currentColor"></path>', 8);

    const _hoisted_10$m = [_hoisted_2$ih];
    vue.defineComponent({
      name: 'Bonfire',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ih, _hoisted_10$m);
      }
    });

    const _hoisted_1$ig = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ig = /*#__PURE__*/vue.createStaticVNode('<path d="M273.38 368.33c-.81-9.23-8.86-16.44-18.55-16.44a18.63 18.63 0 0 0-18.2 14.11l-18.2 88.38a35.75 35.75 0 0 0-.93 7.88c0 19.93 16.68 33.78 37.33 33.78s37.34-13.85 37.34-33.78a36.16 36.16 0 0 0-1.29-9.45z" fill="currentColor"></path><path d="M411.05 407.86a41.78 41.78 0 0 0-5.95-4.35l-69.53-48.59c-6.77-4.25-14-4.13-19.25 1a13.53 13.53 0 0 0-2 17.2l52.5 69a36.57 36.57 0 0 0 4 4.69c9.1 10.17 29.28 10.73 40.37 0c10.94-10.91 10.81-30.35-.14-38.95z" fill="currentColor"></path><path d="M463.3 335.88h-70.42c-4.55 0-8.88 3.35-8.88 8.16s2.95 7.85 6.92 9.16l66.43 20.55C467 376 480 367.4 480 356.66c0-13.66-7.6-20.78-16.7-20.78z" fill="currentColor"></path><path d="M128.22 344c0-5-4.55-8.16-9.45-8.16H48.35c-8.87 0-16.35 9.58-16.35 20.32S44.62 376 54.3 373.75l67.43-20.55c4.39-1.31 6.49-4.2 6.49-9.2z" fill="currentColor"></path><path d="M176.55 355L107 403.38a32.34 32.34 0 0 0-6 4.35a26.33 26.33 0 0 0 0 38.56a29.39 29.39 0 0 0 40.36 0a30.75 30.75 0 0 0 4-4.68L197.9 373c3.5-5.58 2.92-12.49-2-17.06a15 15 0 0 0-19.35-.94z" fill="currentColor"></path><path d="M368 125.09c0-55.7-49.22-89.16-94.2-93.06a8 8 0 0 0-8.69 7.71c-3.12 76-109.38 110.69-119.87 178.68c-7 45.4 16.65 72.37 34.31 85.78a15.94 15.94 0 0 0 23.93-5.62c22.5-45.86 74.33-63.49 109.72-85.94c42.88-27.2 54.8-56.44 54.8-87.55z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><path d="M240 95.7c-12.82-23-30.51-31-59.16-31.63a3.86 3.86 0 0 0-4.06 3.51c-.95 34.22-32.78 44.85-32.78 73.15c0 19.37 5.39 29 17.16 39.28" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><path d="M352.45 178.76c8.6 14.31 15.55 30.08 15.55 48c0 52.52-42.47 93.1-94.86 93.1a94.42 94.42 0 0 1-65.14-26" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path>', 8);

    const _hoisted_10$l = [_hoisted_2$ig];
    vue.defineComponent({
      name: 'BonfireOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ig, _hoisted_10$l);
      }
    });

    const _hoisted_1$if = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$if = /*#__PURE__*/vue.createStaticVNode('<path d="M199.89 336l-15.25-5.62a100.35 100.35 0 0 1-32-23.08c-13.93-14.9-29.29-40.71-23.38-79.11c5.2-33.73 44.2-74.21 69.34-97.87c27.24-25.62 66-65.85 64.15-99.15L262 16h15.18C328.53 16 384 53.62 384 114.41c0 45.57-22 77.61-68.91 106.9c-8 5-16.44 9.66-25.42 14.53c-30.63 16.62-75.29 49.83-85.73 85.32z" fill="currentColor"></path><path d="M181.19 113.59C201 95 218.91 78.15 227.62 59.79q-2.76-1.68-5.7-3.09c-11.87-5.69-26.1-8.34-44.76-8.34h-16.94l.56 16.49c.47 14.06-6.06 22.51-14.33 33.21C137.8 109.26 128 121.94 128 141c0 10.23 1.29 18.76 4.2 26.36q3.5-5.31 7.61-10.63c12.19-15.73 27.05-29.68 41.38-43.14z" fill="currentColor"></path><path d="M330.34 239.85c-9.31 5.9-19 11.14-29.25 16.71c-32.65 17.69-63.48 34.44-73.23 67.44l-.6 2a110.5 110.5 0 0 0 45.87 10c29.66 0 57.45-11.13 78.24-31.36A107.38 107.38 0 0 0 384 227a92.39 92.39 0 0 0-5.59-31c-11.35 16.18-27.14 30.58-48.07 43.85z" fill="currentColor"></path><path d="M268.72 360h-25.44a4 4 0 0 0-3.92 3.22l-25.36 128a4 4 0 0 0 3.92 4.78h76.26a4 4 0 0 0 3.92-4.78l-25.41-128a4 4 0 0 0-3.97-3.22z" fill="currentColor"></path><path d="M325.68 354.32l-11.36 11.36a4 4 0 0 0-.5 5.05l59.47 89.21a4 4 0 0 0 6.16.61l41.1-41.1a4 4 0 0 0-.61-6.16l-89.21-59.47a4 4 0 0 0-5.05.5z" fill="currentColor"></path><path d="M388 336a4 4 0 0 0-4 4v8.61a4 4 0 0 0 3.34 3.95l88 14.66a4 4 0 0 0 4.66-3.94V340a4 4 0 0 0-4-4z" fill="currentColor"></path><path d="M186.32 354.32l11.36 11.36a4 4 0 0 1 .5 5.05l-59.47 89.21a4 4 0 0 1-6.16.61l-41.1-41.1a4 4 0 0 1 .61-6.16l89.21-59.47a4 4 0 0 1 5.05.5z" fill="currentColor"></path><path d="M124 336H36a4 4 0 0 0-4 4v23.28a4 4 0 0 0 4.66 3.94l88-14.66a4 4 0 0 0 3.34-3.95V340a4 4 0 0 0-4-4z" fill="currentColor"></path>', 8);

    const _hoisted_10$k = [_hoisted_2$if];
    vue.defineComponent({
      name: 'BonfireSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$if, _hoisted_10$k);
      }
    });

    const _hoisted_1$ie = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ie = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M202.24 74C166.11 56.75 115.61 48.3 48 48a31.36 31.36 0 0 0-17.92 5.33A32 32 0 0 0 16 79.9V366c0 19.34 13.76 33.93 32 33.93c71.07 0 142.36 6.64 185.06 47a4.11 4.11 0 0 0 6.94-3V106.82a15.89 15.89 0 0 0-5.46-12A143 143 0 0 0 202.24 74z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fI = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M481.92 53.3A31.33 31.33 0 0 0 464 48c-67.61.3-118.11 8.71-154.24 26a143.31 143.31 0 0 0-32.31 20.78a15.93 15.93 0 0 0-5.45 12v337.13a3.93 3.93 0 0 0 6.68 2.81c25.67-25.5 70.72-46.82 185.36-46.81a32 32 0 0 0 32-32v-288a32 32 0 0 0-14.12-26.61z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9d = [_hoisted_2$ie, _hoisted_3$fI];
    vue.defineComponent({
      name: 'Book',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ie, _hoisted_4$9d);
      }
    });

    const _hoisted_1$id = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$id = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 160c16-63.16 76.43-95.41 208-96a15.94 15.94 0 0 1 16 16v288a16 16 0 0 1-16 16c-128 0-177.45 25.81-208 64c-30.37-38-80-64-208-64c-9.88 0-16-8.05-16-17.93V80a15.94 15.94 0 0 1 16-16c131.57.59 192 32.84 208 96z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fH = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 160v288'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9c = [_hoisted_2$id, _hoisted_3$fH];
    vue.defineComponent({
      name: 'BookOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$id, _hoisted_4$9c);
      }
    });

    const _hoisted_1$ic = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ic = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 48c-67.61.29-117.87 9.6-154.24 25.69c-27.14 12-37.76 21.08-37.76 51.84V448c41.57-37.5 78.46-48 224-48V48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fG = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 48c67.61.29 117.87 9.6 154.24 25.69c27.14 12 37.76 21.08 37.76 51.84V448c-41.57-37.5-78.46-48-224-48V48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9b = [_hoisted_2$ic, _hoisted_3$fG];
    vue.defineComponent({
      name: 'BookSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ic, _hoisted_4$9b);
      }
    });

    const _hoisted_1$ib = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ib = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400 480a16 16 0 0 1-10.63-4L256 357.41L122.63 476A16 16 0 0 1 96 464V96a64.07 64.07 0 0 1 64-64h192a64.07 64.07 0 0 1 64 64v368a16 16 0 0 1-16 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fF = [_hoisted_2$ib];
    vue.defineComponent({
      name: 'Bookmark',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ib, _hoisted_3$fF);
      }
    });

    const _hoisted_1$ia = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ia = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M352 48H160a48 48 0 0 0-48 48v368l144-128l144 128V96a48 48 0 0 0-48-48z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fE = [_hoisted_2$ia];
    vue.defineComponent({
      name: 'BookmarkOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ia, _hoisted_3$fE);
      }
    });

    const _hoisted_1$i9 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$i9 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 480L256 357.41L96 480V32h320z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fD = [_hoisted_2$i9];
    vue.defineComponent({
      name: 'BookmarkSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$i9, _hoisted_3$fD);
      }
    });

    const _hoisted_1$i8 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$i8 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400 0H176a64.11 64.11 0 0 0-62 48h228a74 74 0 0 1 74 74v304.89l22 17.6a16 16 0 0 0 19.34.5a16.41 16.41 0 0 0 6.66-13.42V64a64 64 0 0 0-64-64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fC = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 80H112a64 64 0 0 0-64 64v351.62A16.36 16.36 0 0 0 54.6 509a16 16 0 0 0 19.71-.71L216 388.92l141.69 119.32a16 16 0 0 0 19.6.79a16.4 16.4 0 0 0 6.71-13.44V144a64 64 0 0 0-64-64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9a = [_hoisted_2$i8, _hoisted_3$fC];
    vue.defineComponent({
      name: 'Bookmarks',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$i8, _hoisted_4$9a);
      }
    });

    const _hoisted_1$i7 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$i7 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M128 80V64a48.14 48.14 0 0 1 48-48h224a48.14 48.14 0 0 1 48 48v368l-80-64',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fB = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 96H112a48.14 48.14 0 0 0-48 48v352l152-128l152 128V144a48.14 48.14 0 0 0-48-48z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$99 = [_hoisted_2$i7, _hoisted_3$fB];
    vue.defineComponent({
      name: 'BookmarksOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$i7, _hoisted_4$99);
      }
    });

    const _hoisted_1$i6 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$i6 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M112 0v48h304v368l48 32V0H112z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fA = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 80v432l168-124l168 124V80H48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$98 = [_hoisted_2$i6, _hoisted_3$fA];
    vue.defineComponent({
      name: 'BookmarksSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$i6, _hoisted_4$98);
      }
    });

    const _hoisted_1$i5 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$i5 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M414.39 97.61A224 224 0 1 0 97.61 414.39A224 224 0 1 0 414.39 97.61zM288 224a24 24 0 1 1 24-24a24 24 0 0 1-24 24zm8-72a24 24 0 1 1 24-24a24 24 0 0 1-24 24zm64 40a24 24 0 1 1 24-24a24 24 0 0 1-24 24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fz = [_hoisted_2$i5];
    vue.defineComponent({
      name: 'BowlingBall',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$i5, _hoisted_3$fz);
      }
    });

    const _hoisted_1$i4 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$i4 = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '208',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fy = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '288',
      cy: '200',
      r: '24',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$97 = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '296',
      cy: '128',
      r: '24',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4l = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '360',
      cy: '168',
      r: '24',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1Q = [_hoisted_2$i4, _hoisted_3$fy, _hoisted_4$97, _hoisted_5$4l];
    vue.defineComponent({
      name: 'BowlingBallOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$i4, _hoisted_6$1Q);
      }
    });

    const _hoisted_1$i3 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$i3 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M414.39 97.61A224 224 0 1 0 97.61 414.39A224 224 0 1 0 414.39 97.61zM286 230a28 28 0 1 1 28-28a28 28 0 0 1-28 28zm8-76a28 28 0 1 1 28-28a28 28 0 0 1-28 28zm68 44a28 28 0 1 1 28-28a28 28 0 0 1-28 28z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fx = [_hoisted_2$i3];
    vue.defineComponent({
      name: 'BowlingBallSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$i3, _hoisted_3$fx);
      }
    });

    const _hoisted_1$i2 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$i2 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 80H176a16 16 0 0 0-16 16v16h192V96a16 16 0 0 0-16-16z',
      fill: 'none'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fw = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M496 176a64.07 64.07 0 0 0-64-64h-48V96a48.05 48.05 0 0 0-48-48H176a48.05 48.05 0 0 0-48 48v16H80a64.07 64.07 0 0 0-64 64v48h480zm-144-64H160V96a16 16 0 0 1 16-16h160a16 16 0 0 1 16 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$96 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 264a24 24 0 0 1-24 24H200a24 24 0 0 1-24-24v-4a4 4 0 0 0-4-4H16v144a64 64 0 0 0 64 64h352a64 64 0 0 0 64-64V256H340a4 4 0 0 0-4 4z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4k = [_hoisted_2$i2, _hoisted_3$fw, _hoisted_4$96];
    vue.defineComponent({
      name: 'Briefcase',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$i2, _hoisted_5$4k);
      }
    });

    const _hoisted_1$i1 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$i1 = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '32',
      y: '128',
      width: '448',
      height: '320',
      rx: '48',
      ry: '48',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fv = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M144 128V96a32 32 0 0 1 32-32h160a32 32 0 0 1 32 32v32',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$95 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M480 240H32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4j = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 240v24a8 8 0 0 1-8 8H200a8 8 0 0 1-8-8v-24',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1P = [_hoisted_2$i1, _hoisted_3$fv, _hoisted_4$95, _hoisted_5$4j];
    vue.defineComponent({
      name: 'BriefcaseOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$i1, _hoisted_6$1P);
      }
    });

    const _hoisted_1$i0 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$i0 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 288H176v-32H16v196a12 12 0 0 0 12 12h456a12 12 0 0 0 12-12V256H336z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fu = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M496 124a12 12 0 0 0-12-12H384V56a8 8 0 0 0-8-8H136a8 8 0 0 0-8 8v56H28a12 12 0 0 0-12 12v100h480zm-152-12H168V88h176z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$94 = [_hoisted_2$i0, _hoisted_3$fu];
    vue.defineComponent({
      name: 'BriefcaseSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$i0, _hoisted_4$94);
      }
    });

    const _hoisted_1$h$ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$h$ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 48H96a64 64 0 0 0-64 64v288a64 64 0 0 0 64 64h320a64 64 0 0 0 64-64V112a64 64 0 0 0-64-64zm24 96H72a8 8 0 0 1-8-8v-24a32.09 32.09 0 0 1 32-32h320a32.09 32.09 0 0 1 32 32v24a8 8 0 0 1-8 8z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ft = [_hoisted_2$h$];
    vue.defineComponent({
      name: 'Browsers',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$h$, _hoisted_3$ft);
      }
    });

    const _hoisted_1$h_ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$h_ = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '48',
      y: '64',
      width: '416',
      height: '384',
      rx: '48',
      ry: '48',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fs = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M397.82 64H114.18C77.69 64 48 94.15 48 131.2V176h16c0-16 16-32 32-32h320c16 0 32 16 32 32h16v-44.8c0-37.05-29.69-67.2-66.18-67.2z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$93 = [_hoisted_2$h_, _hoisted_3$fs];
    vue.defineComponent({
      name: 'BrowsersOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$h_, _hoisted_4$93);
      }
    });

    const _hoisted_1$hZ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hZ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M32 64v384a16 16 0 0 0 16 16h416a16 16 0 0 0 16-16V64a16 16 0 0 0-16-16H48a16 16 0 0 0-16 16zm408 364H72a4 4 0 0 1-4-4V152a4 4 0 0 1 4-4h368a4 4 0 0 1 4 4v272a4 4 0 0 1-4 4z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fr = [_hoisted_2$hZ];
    vue.defineComponent({
      name: 'BrowsersSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hZ, _hoisted_3$fr);
      }
    });

    const _hoisted_1$hY = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hY = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M233.15 360.11a15.7 15.7 0 0 1-4.92-.77a16 16 0 0 1-10.92-13c-2.15-15-19.95-32.46-36.62-35.85a16 16 0 0 1-8.69-26.33l211.09-235.1c.19-.22.39-.43.59-.63a56.57 56.57 0 0 1 79.89 0a56.51 56.51 0 0 1 .11 79.78l-219 227a16 16 0 0 1-11.53 4.9z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fq = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M119.89 480.11c-32.14 0-65.45-16.89-84.85-43a16 16 0 0 1 12.85-25.54c5.34 0 20-4.87 20-20.57c0-39.07 31.4-70.86 70-70.86s70 31.79 70 70.86c0 49.12-39.48 89.11-88 89.11z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$92 = [_hoisted_2$hY, _hoisted_3$fq];
    vue.defineComponent({
      name: 'Brush',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hY, _hoisted_4$92);
      }
    });

    const _hoisted_1$hX = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hX = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M452.37 59.63h0a40.49 40.49 0 0 0-57.26 0L184 294.74c23.08 4.7 46.12 27.29 49.26 49.26l219.11-227.11a40.49 40.49 0 0 0 0-57.26z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fp = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M138 336c-29.88 0-54 24.5-54 54.86c0 23.95-20.88 36.57-36 36.57C64.56 449.74 92.82 464 120 464c39.78 0 72-32.73 72-73.14c0-30.36-24.12-54.86-54-54.86z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$91 = [_hoisted_2$hX, _hoisted_3$fp];
    vue.defineComponent({
      name: 'BrushOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hX, _hoisted_4$91);
      }
    });

    const _hoisted_1$hW = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hW = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 96l-64-64l-244 260l64 64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fo = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M142 320c-36.52 0-66 30.63-66 68.57c0 25.43-31 45.72-44 45.72C52.24 462.17 86.78 480 120 480c48.62 0 88-40.91 88-91.43c0-37.94-29.48-68.57-66-68.57z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$90 = [_hoisted_2$hW, _hoisted_3$fo];
    vue.defineComponent({
      name: 'BrushSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hW, _hoisted_4$90);
      }
    });

    const _hoisted_1$hV = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hV = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M463.55 272.13H400v-48.2q0-4.32-.27-8.47c29.57-27.88 32.25-64.63 32.27-103c0-8.61-6.64-16-15.25-16.41A16 16 0 0 0 400 112c0 28-1.86 48.15-9.9 63.84c-19.22-41.15-65.78-63.91-134.1-63.91c-39.8 0-74.19 9.13-99.43 26.39c-14.9 10.19-26.2 22.91-33.7 37.72C114 160.65 112 141 112 112.46c0-8.61-6.6-16-15.2-16.44A16 16 0 0 0 80 112c0 37.63 2.61 73.73 32.44 101.63q-.43 5.06-.44 10.3v48.2H48.45c-8.61 0-16 6.62-16.43 15.23a16 16 0 0 0 16 16.77h64V320a143.32 143.32 0 0 0 10.39 53.69C96.74 396.64 80.18 422 80 463.34c0 8.74 6.62 16.3 15.36 16.65A16 16 0 0 0 112 464c0-27.66 9.1-44.71 26.17-61.32A144.37 144.37 0 0 0 220 459.42a16 16 0 0 0 20-15.49V192.45c0-8.61 6.62-16 15.23-16.43A16 16 0 0 1 272 192v251.93a16 16 0 0 0 20 15.49a144.4 144.4 0 0 0 81.82-56.74c17 16.54 26.09 33.52 26.17 60.95a16.27 16.27 0 0 0 15.1 16.37A16 16 0 0 0 432 464c0-41.68-16.6-67.23-42.39-90.31A143.32 143.32 0 0 0 400 320v-15.87h64a16 16 0 0 0 16-16.77c-.42-8.61-7.84-15.23-16.45-15.23z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fn = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M321.39 104l.32.09c13.57 3.8 25.07-10.55 18.2-22.85A95.86 95.86 0 0 0 256.21 32h-.42a95.87 95.87 0 0 0-84.19 50.13c-6.84 12.58 5.14 27 18.84 22.86c19.71-6 41.79-9.06 65.56-9.06c24.09 0 46.09 2.72 65.39 8.07z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8$ = [_hoisted_2$hV, _hoisted_3$fn];
    vue.defineComponent({
      name: 'Bug',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hV, _hoisted_4$8$);
      }
    });

    const _hoisted_1$hU = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hU = /*#__PURE__*/vue.createStaticVNode('<path d="M370 378c28.89 23.52 46 46.07 46 86" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M142 378c-28.89 23.52-46 46.06-46 86" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M384 208c28.89-23.52 32-56.07 32-96" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M128 206c-28.89-23.52-32-54.06-32-94" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M464 288.13h-80"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M128 288.13H48"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 192v256"></path><path d="M256 448h0c-70.4 0-128-57.6-128-128v-96.07c0-65.07 57.6-96 128-96h0c70.4 0 128 25.6 128 96V320c0 70.4-57.6 128-128 128z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M179.43 143.52a49.08 49.08 0 0 1-3.43-15.73A80 80 0 0 1 255.79 48h.42A80 80 0 0 1 336 127.79a41.91 41.91 0 0 1-3.12 14.3" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 9);

    const _hoisted_11$9 = [_hoisted_2$hU];
    vue.defineComponent({
      name: 'BugOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hU, _hoisted_11$9);
      }
    });

    const _hoisted_1$hT = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hT = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 304.13v-32h-80V215.2c29.42-27.95 32-64.76 32-103.2V96h-32v16c0 28-1.86 48.15-9.9 63.84C368 128 324.32 112 256 112c-39.8 0-75.19 7.06-100.43 24.32c-14.9 10.19-25.2 24.91-32.7 39.72C114 160.57 112 140.82 112 112V96H80v16c0 37.44 2.59 73.36 32 101.2v58.93H32v32l80-.13c0 19 3.7 53.09 10.39 69.69C96.6 396.76 80 422.31 80 464v16h32v-16c0-27.66 9.1-44.71 26.17-61.32C160 448 177 464 240 464V176h32v288c65 0 80-16 101.83-61.32C390.9 419.29 400 436.35 400 464v16h32v-16c0-41.68-16.6-67.23-42.39-90.31C396.3 357.09 400 323 400 304z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fm = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 32c-48.06 0-96 0-96 84c26.12-14 59.35-20 96-20c24.09 0 46.09 2.65 65.39 8c10.75 3 24.66 8.71 30.61 12c0-84-47.94-84-96-84z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8_ = [_hoisted_2$hT, _hoisted_3$fm];
    vue.defineComponent({
      name: 'BugSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hT, _hoisted_4$8_);
      }
    });

    const _hoisted_1$hS = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hS = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M469.54 120.52a16 16 0 0 0-25.54-4L382.56 178a16.12 16.12 0 0 1-22.63 0l-26.56-26.6a16 16 0 0 1 0-22.63l61.18-61.19a16 16 0 0 0-4.78-25.92C343.56 21 285.88 31.78 249.51 67.88c-30.9 30.68-40.11 78.62-25.25 131.53a15.89 15.89 0 0 1-4.49 16L53.29 367.46a64.17 64.17 0 1 0 90.6 90.64l153.68-166.85a15.9 15.9 0 0 1 15.77-4.57a179.3 179.3 0 0 0 46.22 6.37c33.4 0 62.71-10.81 83.85-31.64c39.15-38.57 45.12-103.99 26.13-140.89zM99.48 447.15a32 32 0 1 1 28.34-28.35a32 32 0 0 1-28.34 28.35z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fl = [_hoisted_2$hS];
    vue.defineComponent({
      name: 'Build',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hS, _hoisted_3$fl);
      }
    });

    const _hoisted_1$hR = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hR = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M393.87 190a32.1 32.1 0 0 1-45.25 0l-26.57-26.57a32.09 32.09 0 0 1 0-45.26L382.19 58a1 1 0 0 0-.3-1.64c-38.82-16.64-89.15-8.16-121.11 23.57c-30.58 30.35-32.32 76-21.12 115.84a31.93 31.93 0 0 1-9.06 32.08L64 380a48.17 48.17 0 1 0 68 68l153.86-167a31.93 31.93 0 0 1 31.6-9.13c39.54 10.59 84.54 8.6 114.72-21.19c32.49-32 39.5-88.56 23.75-120.93a1 1 0 0 0-1.6-.26z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fk = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '96',
      cy: '416',
      r: '16',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8Z = [_hoisted_2$hR, _hoisted_3$fk];
    vue.defineComponent({
      name: 'BuildOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hR, _hoisted_4$8Z);
      }
    });

    const _hoisted_1$hQ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hQ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M230 209.2L32 405.58L106.65 480l197.59-198.17c46.47 17.46 105.52 12.54 143-24.78c40.44-40.32 40.35-108 16.81-156.79l-87.33 87.06l-52.32-52.13l87.33-87.06C363 24.46 294.67 24.34 254.23 64.66c-38.03 37.91-42.78 97.6-24.23 144.54z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fj = [_hoisted_2$hQ];
    vue.defineComponent({
      name: 'BuildSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hQ, _hoisted_3$fj);
      }
    });

    const _hoisted_1$hP = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hP = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M288 464h-64a16 16 0 0 0 0 32h64a16 16 0 0 0 0-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fi = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M304 416h-96a16 16 0 0 0 0 32h96a16 16 0 0 0 0-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8Y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M369.42 62.69C339.35 32.58 299.07 16 256 16A159.62 159.62 0 0 0 96 176c0 46.62 17.87 90.23 49 119.64l4.36 4.09C167.37 316.57 192 339.64 192 360v24a16 16 0 0 0 16 16h24a8 8 0 0 0 8-8V274.82a8 8 0 0 0-5.13-7.47A130.73 130.73 0 0 1 208.71 253a16 16 0 1 1 18.58-26c7.4 5.24 21.65 13 28.71 13s21.31-7.78 28.73-13a16 16 0 0 1 18.56 26a130.73 130.73 0 0 1-26.16 14.32a8 8 0 0 0-5.13 7.47V392a8 8 0 0 0 8 8h24a16 16 0 0 0 16-16v-24c0-19.88 24.36-42.93 42.15-59.77l4.91-4.66C399.08 265 416 223.61 416 176a159.16 159.16 0 0 0-46.58-113.31z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4i = [_hoisted_2$hP, _hoisted_3$fi, _hoisted_4$8Y];
    vue.defineComponent({
      name: 'Bulb',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hP, _hoisted_5$4i);
      }
    });

    const _hoisted_1$hO = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hO = /*#__PURE__*/vue.createStaticVNode('<path d="M304 384v-24c0-29 31.54-56.43 52-76c28.84-27.57 44-64.61 44-108c0-80-63.73-144-144-144a143.6 143.6 0 0 0-144 144c0 41.84 15.81 81.39 44 108c20.35 19.21 52 46.7 52 76v24" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M224 480h64"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M208 432h96"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 384V256"></path><path d="M294 240s-21.51 16-38 16s-38-16-38-16" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 5);

    const _hoisted_7$Y = [_hoisted_2$hO];
    vue.defineComponent({
      name: 'BulbOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hO, _hoisted_7$Y);
      }
    });

    const _hoisted_1$hN = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hN = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M208 464h96v32h-96z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fh = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M192 416h128v32H192z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8X = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M369.42 62.69C339.35 32.58 299.07 16 256 16A159.62 159.62 0 0 0 96 176c0 46.62 17.87 90.23 49 119.64l4.36 4.09C167.37 316.57 192 339.64 192 360v40h48V269.11L195.72 244L214 217.72L256 240l41.29-22.39l19.1 25.68l-44.39 26V400h48v-40c0-19.88 24.36-42.93 42.15-59.77l4.91-4.66C399.08 265 416 223.61 416 176a159.16 159.16 0 0 0-46.58-113.31z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4h = [_hoisted_2$hN, _hoisted_3$fh, _hoisted_4$8X];
    vue.defineComponent({
      name: 'BulbSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hN, _hoisted_5$4h);
      }
    });

    const _hoisted_1$hM = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hM = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400 32H112a48 48 0 0 0-48 48v320a47.91 47.91 0 0 0 16 35.74V454a26 26 0 0 0 26 26h28a26 26 0 0 0 26-26v-6h192v6a26 26 0 0 0 26 26h28a26 26 0 0 0 26-26v-18.26A47.91 47.91 0 0 0 448 400V80a48 48 0 0 0-48-48zM147.47 399.82a32 32 0 1 1 28.35-28.35a32 32 0 0 1-28.35 28.35zM236 288H112a16 16 0 0 1-16-16V144a16 16 0 0 1 16-16h124a4 4 0 0 1 4 4v152a4 4 0 0 1-4 4zm20-192H112.46c-8.6 0-16-6.6-16.44-15.19A16 16 0 0 1 112 64h287.54c8.6 0 16 6.6 16.44 15.19A16 16 0 0 1 400 96H256zm20 32h124a16 16 0 0 1 16 16v128a16 16 0 0 1-16 16H276a4 4 0 0 1-4-4V132a4 4 0 0 1 4-4zm60.18 243.47a32 32 0 1 1 28.35 28.35a32 32 0 0 1-28.35-28.35z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fg = [_hoisted_2$hM];
    vue.defineComponent({
      name: 'Bus',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hM, _hoisted_3$fg);
      }
    });

    const _hoisted_1$hL = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hL = /*#__PURE__*/vue.createStaticVNode('<rect x="80" y="112" width="352" height="192" rx="32" ry="32" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></rect><rect x="80" y="304" width="352" height="128" rx="32" ry="32" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></rect><path d="M400 112H112a32.09 32.09 0 0 1-32-32h0a32.09 32.09 0 0 1 32-32h288a32.09 32.09 0 0 1 32 32h0a32.09 32.09 0 0 1-32 32z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M144 432v22a10 10 0 0 1-10 10h-28a10 10 0 0 1-10-10v-22z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M416 432v22a10 10 0 0 1-10 10h-28a10 10 0 0 1-10-10v-22z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><circle cx="368" cy="368" r="16" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></circle><circle cx="144" cy="368" r="16" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></circle><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 112v192"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M80 80v288"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M432 80v288"></path>', 10);

    const _hoisted_12$7 = [_hoisted_2$hL];
    vue.defineComponent({
      name: 'BusOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hL, _hoisted_12$7);
      }
    });

    const _hoisted_1$hK = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hK = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400 64H112a16 16 0 0 0 0 32h288a16 16 0 0 0 0-32z',
      fill: 'none'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ff = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M424 32H88a24 24 0 0 0-24 24v360a32 32 0 0 0 16 27.71V480h72v-32h208v32h72v-36.29A32 32 0 0 0 448 416V56a24 24 0 0 0-24-24zM175.82 371.47a32 32 0 1 1-35.3-35.29a32.09 32.09 0 0 1 35.3 35.29zM240 288H96V128h144zm16-192H96.46L96 64h320l-.46 32H256zm16 32h144v160H272zm64.18 236.53a32 32 0 1 1 35.3 35.29a32.09 32.09 0 0 1-35.3-35.29z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8W = [_hoisted_2$hK, _hoisted_3$ff];
    vue.defineComponent({
      name: 'BusSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hK, _hoisted_4$8W);
      }
    });

    const _hoisted_1$hJ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hJ = /*#__PURE__*/vue.createStaticVNode('<path d="M432 176H320V64a48 48 0 0 0-48-48H80a48 48 0 0 0-48 48v416a16 16 0 0 0 16 16h104a8 8 0 0 0 8-8v-71.55c0-8.61 6.62-16 15.23-16.43A16 16 0 0 1 192 416v72a8 8 0 0 0 8 8h264a16 16 0 0 0 16-16V224a48 48 0 0 0-48-48zM98.08 431.87a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79zm0-80a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79zm0-80a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79zm0-80a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79zm0-80a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79zm80 240a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79zm0-80a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79zm0-80a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79zm0-80a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79zm80 320a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79zm0-80a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79zm0-80a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79zm0-80a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79zm0-80a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79zM444 464H320V208h112a16 16 0 0 1 16 16v236a4 4 0 0 1-4 4z" fill="currentColor"></path><path d="M400 400a16 16 0 1 0 16 16a16 16 0 0 0-16-16z" fill="currentColor"></path><path d="M400 320a16 16 0 1 0 16 16a16 16 0 0 0-16-16z" fill="currentColor"></path><path d="M400 240a16 16 0 1 0 16 16a16 16 0 0 0-16-16z" fill="currentColor"></path><path d="M336 400a16 16 0 1 0 16 16a16 16 0 0 0-16-16z" fill="currentColor"></path><path d="M336 320a16 16 0 1 0 16 16a16 16 0 0 0-16-16z" fill="currentColor"></path><path d="M336 240a16 16 0 1 0 16 16a16 16 0 0 0-16-16z" fill="currentColor"></path>', 7);

    const _hoisted_9$h = [_hoisted_2$hJ];
    vue.defineComponent({
      name: 'Business',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hJ, _hoisted_9$h);
      }
    });

    const _hoisted_1$hI = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hI = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M176 416v64"></path><path d="M80 32h192a32 32 0 0 1 32 32v412a4 4 0 0 1-4 4H48h0V64a32 32 0 0 1 32-32z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M320 192h112a32 32 0 0 1 32 32v256h0h-160h0V208a16 16 0 0 1 16-16z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M98.08 431.87a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79z" fill="currentColor"></path><path d="M98.08 351.87a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79z" fill="currentColor"></path><path d="M98.08 271.87a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79z" fill="currentColor"></path><path d="M98.08 191.87a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79z" fill="currentColor"></path><path d="M98.08 111.87a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79z" fill="currentColor"></path><path d="M178.08 351.87a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79z" fill="currentColor"></path><path d="M178.08 271.87a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79z" fill="currentColor"></path><path d="M178.08 191.87a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79z" fill="currentColor"></path><path d="M178.08 111.87a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79z" fill="currentColor"></path><path d="M258.08 431.87a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79z" fill="currentColor"></path><path d="M258.08 351.87a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79z" fill="currentColor"></path><path d="M258.08 271.87a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79z" fill="currentColor"></path><ellipse cx="256" cy="176" rx="15.95" ry="16.03" transform="rotate(-45 255.99 175.996)" fill="currentColor"></ellipse><path d="M258.08 111.87a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79z" fill="currentColor"></path><path d="M400 400a16 16 0 1 0 16 16a16 16 0 0 0-16-16z" fill="currentColor"></path><path d="M400 320a16 16 0 1 0 16 16a16 16 0 0 0-16-16z" fill="currentColor"></path><path d="M400 240a16 16 0 1 0 16 16a16 16 0 0 0-16-16z" fill="currentColor"></path><path d="M336 400a16 16 0 1 0 16 16a16 16 0 0 0-16-16z" fill="currentColor"></path><path d="M336 320a16 16 0 1 0 16 16a16 16 0 0 0-16-16z" fill="currentColor"></path><path d="M336 240a16 16 0 1 0 16 16a16 16 0 0 0-16-16z" fill="currentColor"></path>', 23);

    const _hoisted_25 = [_hoisted_2$hI];
    vue.defineComponent({
      name: 'BusinessOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hI, _hoisted_25);
      }
    });

    const _hoisted_1$hH = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hH = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 176V16H32v480h128v-96h32v96h288V176zM112 432H80v-32h32zm0-80H80v-32h32zm0-80H80v-32h32zm0-80H80v-32h32zm0-80H80V80h32zm128-32h32v32h-32zm-48 272h-32v-32h32zm0-80h-32v-32h32zm0-80h-32v-32h32zm0-80h-32V80h32zm80 320h-32v-32h32zm0-80h-32v-32h32zm0-80h-32v-32h32zm0-80h-32v-32h32v32zm176 272H320v-32h32v-32h-32v-48h32v-32h-32v-48h32v-32h-32v-32h128z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fe = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 400h32v32h-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8V = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 320h32v32h-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4g = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 240h32v32h-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1O = [_hoisted_2$hH, _hoisted_3$fe, _hoisted_4$8V, _hoisted_5$4g];
    vue.defineComponent({
      name: 'BusinessSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hH, _hoisted_6$1O);
      }
    });

    const _hoisted_1$hG = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hG = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M432 64H96a16 16 0 0 0-16 16v192a96.11 96.11 0 0 0 96 96h112a96.11 96.11 0 0 0 96-96v-80h18a62.07 62.07 0 0 0 62-62V96a32 32 0 0 0-32-32zm0 66a30 30 0 0 1-30 30h-18V96h48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fd = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400 400H64a16 16 0 0 0 0 32h336a16 16 0 0 0 0-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8U = [_hoisted_2$hG, _hoisted_3$fd];
    vue.defineComponent({
      name: 'Cafe',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hG, _hoisted_4$8U);
      }
    });

    const _hoisted_1$hF = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hF = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M368 80h64a16 16 0 0 1 16 16v34a46 46 0 0 1-46 46h-34',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fc = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M96 80h272v192a80 80 0 0 1-80 80H176a80 80 0 0 1-80-80V80h0z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8T = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M64 416h336'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4f = [_hoisted_2$hF, _hoisted_3$fc, _hoisted_4$8T];
    vue.defineComponent({
      name: 'CafeOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hF, _hoisted_5$4f);
      }
    });

    const _hoisted_1$hE = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hE = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 64H80v254.34a19.83 19.83 0 0 0 5.86 14.14l29.65 29.66a19.87 19.87 0 0 0 14.15 5.86h204.68a19.87 19.87 0 0 0 14.15-5.86l29.65-29.66a19.83 19.83 0 0 0 5.86-14.14V192h32a16 16 0 0 0 11.31-4.69l32-32A16 16 0 0 0 464 144V80a16 16 0 0 0-16-16zm-16 73.37L409.37 160H384V96h48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fb = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 400h368v32H48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8S = [_hoisted_2$hE, _hoisted_3$fb];
    vue.defineComponent({
      name: 'CafeSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hE, _hoisted_4$8S);
      }
    });

    const _hoisted_1$hD = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hD = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 80a48.05 48.05 0 0 0-48-48H144a48.05 48.05 0 0 0-48 48v352a48.05 48.05 0 0 0 48 48h224a48.05 48.05 0 0 0 48-48zM168 432a24 24 0 1 1 24-24a24 24 0 0 1-24 24zm0-80a24 24 0 1 1 24-24a24 24 0 0 1-24 24zm0-80a24 24 0 1 1 24-24a24 24 0 0 1-24 24zm88 160a24 24 0 1 1 24-24a24 24 0 0 1-24 24zm0-80a24 24 0 1 1 24-24a24 24 0 0 1-24 24zm0-80a24 24 0 1 1 24-24a24 24 0 0 1-24 24zm112 136a24 24 0 0 1-48 0v-80a24 24 0 0 1 48 0zm-24-136a24 24 0 1 1 24-24a24 24 0 0 1-24 24zm19.31-100.69A16 16 0 0 1 352 176H160a16 16 0 0 1-16-16V96a16 16 0 0 1 16-16h192a16 16 0 0 1 16 16v64a16 16 0 0 1-4.69 11.31z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$fa = [_hoisted_2$hD];
    vue.defineComponent({
      name: 'Calculator',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hD, _hoisted_3$fa);
      }
    });

    const _hoisted_1$hC = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hC = /*#__PURE__*/vue.createStaticVNode('<rect x="112" y="48" width="288" height="416" rx="32" ry="32" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></rect><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M160.01 112H352v64H160.01z"></path><circle cx="168" cy="248" r="24" fill="currentColor"></circle><circle cx="256" cy="248" r="24" fill="currentColor"></circle><circle cx="344" cy="248" r="24" fill="currentColor"></circle><circle cx="168" cy="328" r="24" fill="currentColor"></circle><circle cx="256" cy="328" r="24" fill="currentColor"></circle><circle cx="168" cy="408" r="24" fill="currentColor"></circle><circle cx="256" cy="408" r="24" fill="currentColor"></circle><rect x="320" y="304" width="48" height="128" rx="24" ry="24" fill="currentColor"></rect>', 10);

    const _hoisted_12$6 = [_hoisted_2$hC];
    vue.defineComponent({
      name: 'CalculatorOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hC, _hoisted_12$6);
      }
    });

    const _hoisted_1$hB = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hB = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 48a16 16 0 0 0-16-16H112a16 16 0 0 0-16 16v416a16 16 0 0 0 16 16h288a16 16 0 0 0 16-16zM192 432h-48v-48h48zm0-80h-48v-48h48zm0-80h-48v-48h48zm88 160h-48v-48h48zm0-80h-48v-48h48zm0-80h-48v-48h48zm88 160h-48V304h48zm0-160h-48v-48h48zm0-96H144V80h224z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$f9 = [_hoisted_2$hB];
    vue.defineComponent({
      name: 'CalculatorSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hB, _hoisted_3$f9);
      }
    });

    const _hoisted_1$hA = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hA = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 128a64 64 0 0 0-64-64h-16V48.45c0-8.61-6.62-16-15.23-16.43A16 16 0 0 0 368 48v16H144V48.45c0-8.61-6.62-16-15.23-16.43A16 16 0 0 0 112 48v16H96a64 64 0 0 0-64 64v12a4 4 0 0 0 4 4h440a4 4 0 0 0 4-4z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$f8 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M32 416a64 64 0 0 0 64 64h320a64 64 0 0 0 64-64V179a3 3 0 0 0-3-3H35a3 3 0 0 0-3 3zm344-208a24 24 0 1 1-24 24a24 24 0 0 1 24-24zm0 80a24 24 0 1 1-24 24a24 24 0 0 1 24-24zm-80-80a24 24 0 1 1-24 24a24 24 0 0 1 24-24zm0 80a24 24 0 1 1-24 24a24 24 0 0 1 24-24zm0 80a24 24 0 1 1-24 24a24 24 0 0 1 24-24zm-80-80a24 24 0 1 1-24 24a24 24 0 0 1 24-24zm0 80a24 24 0 1 1-24 24a24 24 0 0 1 24-24zm-80-80a24 24 0 1 1-24 24a24 24 0 0 1 24-24zm0 80a24 24 0 1 1-24 24a24 24 0 0 1 24-24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8R = [_hoisted_2$hA, _hoisted_3$f8];
    vue.defineComponent({
      name: 'Calendar',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hA, _hoisted_4$8R);
      }
    });

    const _hoisted_1$hz = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hz = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 128a64 64 0 0 0-64-64h-16V48.45c0-8.61-6.62-16-15.23-16.43A16 16 0 0 0 368 48v16H144V48.45c0-8.61-6.62-16-15.23-16.43A16 16 0 0 0 112 48v16H96a64 64 0 0 0-64 64v12a4 4 0 0 0 4 4h440a4 4 0 0 0 4-4z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$f7 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M32 416a64 64 0 0 0 64 64h320a64 64 0 0 0 64-64V180a4 4 0 0 0-4-4H36a4 4 0 0 0-4 4z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8Q = [_hoisted_2$hz, _hoisted_3$f7];
    vue.defineComponent({
      name: 'CalendarClear',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hz, _hoisted_4$8Q);
      }
    });

    const _hoisted_1$hy = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hy = /*#__PURE__*/vue.createElementVNode('rect', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      x: '48',
      y: '80',
      width: '416',
      height: '384',
      rx: '48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$f6 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      'stroke-linecap': 'round',
      d: 'M128 48v32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8P = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      'stroke-linecap': 'round',
      d: 'M384 48v32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4e = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      'stroke-linecap': 'round',
      d: 'M464 160H48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1N = [_hoisted_2$hy, _hoisted_3$f6, _hoisted_4$8P, _hoisted_5$4e];
    vue.defineComponent({
      name: 'CalendarClearOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hy, _hoisted_6$1N);
      }
    });

    const _hoisted_1$hx = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hx = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M32 456a24 24 0 0 0 24 24h400a24 24 0 0 0 24-24V192H32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$f5 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 87.77A23.8 23.8 0 0 0 456 64h-55.92V32h-48v32H159.92V32h-48v32H56a23.8 23.8 0 0 0-24 23.77V144h448z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8O = [_hoisted_2$hx, _hoisted_3$f5];
    vue.defineComponent({
      name: 'CalendarClearSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hx, _hoisted_4$8O);
      }
    });

    const _hoisted_1$hw = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hw = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 64h-16V48.45c0-8.61-6.62-16-15.23-16.43A16 16 0 0 0 368 48v16H144V48.45c0-8.61-6.62-16-15.23-16.43A16 16 0 0 0 112 48v16H96a64 64 0 0 0-64 64v12a4 4 0 0 0 4 4h440a4 4 0 0 0 4-4v-12a64 64 0 0 0-64-64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$f4 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M476 176H36a4 4 0 0 0-4 4v236a64 64 0 0 0 64 64h320a64 64 0 0 0 64-64V180a4 4 0 0 0-4-4zM239.58 401.1c-12.17 9.61-28.75 14.9-46.7 14.9c-27.87 0-48.48-18.16-57.66-33.7a16 16 0 0 1 27.56-16.3c1.08 1.84 11.15 18 30.1 18c16.66 0 36.12-7.29 36.12-27.82c0-6.25-1.22-14.95-7-20.88c-8.54-8.74-22.75-12.67-30.11-12.67a16 16 0 0 1 0-32c4.85 0 17.41-2.6 25.28-10.65a22 22 0 0 0 6.57-16.08c0-23.23-28.63-23.9-31.89-23.9c-17.34 0-23.8 10.61-24.07 11.06a16 16 0 1 1-27.55-16.26c7.64-13 25.22-26.8 51.62-26.8c16.44 0 31.76 4.77 43.13 13.42c13.39 10.2 20.76 25.28 20.76 42.48A54 54 0 0 1 240 302.35c-1.15 1.18-2.36 2.28-3.59 3.35a66.18 66.18 0 0 1 8.42 7.23c10.56 10.8 16.14 25.75 16.14 43.25c.03 18.06-7.58 34.01-21.39 44.92zM368 396a16 16 0 0 1-32 0V256.29l-22.51 16.59a16 16 0 1 1-19-25.76l43.42-32a16 16 0 0 1 9.49-3.12h4.6a16 16 0 0 1 16 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8N = [_hoisted_2$hw, _hoisted_3$f4];
    vue.defineComponent({
      name: 'CalendarNumber',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hw, _hoisted_4$8N);
      }
    });

    const _hoisted_1$hv = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hv = /*#__PURE__*/vue.createStaticVNode('<rect x="48" y="80" width="416" height="384" rx="48" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></rect><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M128 48v32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M384 48v32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M464 160H48"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M304 260l43.42-32H352v168"></path><path d="M191.87 306.63c9.11 0 25.79-4.28 36.72-15.47a37.9 37.9 0 0 0 11.13-27.26c0-26.12-22.59-39.9-47.89-39.9c-21.4 0-33.52 11.61-37.85 18.93" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M149 374.16c4.88 8.27 19.71 25.84 43.88 25.84c28.59 0 52.12-15.94 52.12-43.82c0-12.62-3.66-24-11.58-32.07c-12.36-12.64-31.25-17.48-41.55-17.48" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 7);

    const _hoisted_9$g = [_hoisted_2$hv];
    vue.defineComponent({
      name: 'CalendarNumberOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hv, _hoisted_9$g);
      }
    });

    const _hoisted_1$hu = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hu = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M32 456a24 24 0 0 0 24 24h400a24 24 0 0 0 24-24V176H32zm310.17-244H368v200h-32V256.29l-35.39 26.08l-19-25.76zM222 335.3c-8.54-8.74-22.75-12.67-30.11-12.67h-16v-32h16c4.85 0 17.41-2.6 25.28-10.65a22 22 0 0 0 6.57-16.08c0-23.23-28.63-23.9-31.89-23.9c-17.34 0-23.8 10.61-24.07 11.06l-8.13 13.78l-27.56-16.27l8.14-13.77c7.64-13 25.22-26.8 51.62-26.8c16.44 0 31.76 4.77 43.13 13.42c13.39 10.2 20.76 25.28 20.76 42.48A54 54 0 0 1 240 302.35c-1.15 1.18-2.36 2.28-3.59 3.35a66.18 66.18 0 0 1 8.42 7.23c10.56 10.8 16.14 25.75 16.14 43.25c0 18.06-7.61 34-21.42 44.92c-12.17 9.61-28.75 14.9-46.7 14.9c-27.87 0-48.48-18.16-57.66-33.7l-8.13-13.78l27.56-16.27l8.16 13.75c1.08 1.84 11.15 18 30.1 18c16.66 0 36.12-7.29 36.12-27.82c0-6.25-1.22-14.95-7-20.88z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$f3 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M456 64h-55.92V32h-48v32H159.92V32h-48v32H56a23.8 23.8 0 0 0-24 23.77V144h448V87.77A23.8 23.8 0 0 0 456 64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8M = [_hoisted_2$hu, _hoisted_3$f3];
    vue.defineComponent({
      name: 'CalendarNumberSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hu, _hoisted_4$8M);
      }
    });

    const _hoisted_1$ht = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ht = /*#__PURE__*/vue.createStaticVNode('<rect fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32" x="48" y="80" width="416" height="384" rx="48"></rect><circle cx="296" cy="232" r="24" fill="currentColor"></circle><circle cx="376" cy="232" r="24" fill="currentColor"></circle><circle cx="296" cy="312" r="24" fill="currentColor"></circle><circle cx="376" cy="312" r="24" fill="currentColor"></circle><circle cx="136" cy="312" r="24" fill="currentColor"></circle><circle cx="216" cy="312" r="24" fill="currentColor"></circle><circle cx="136" cy="392" r="24" fill="currentColor"></circle><circle cx="216" cy="392" r="24" fill="currentColor"></circle><circle cx="296" cy="392" r="24" fill="currentColor"></circle><path fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32" stroke-linecap="round" d="M128 48v32"></path><path fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32" stroke-linecap="round" d="M384 48v32"></path><path fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32" d="M464 160H48"></path>', 13);

    const _hoisted_15 = [_hoisted_2$ht];
    vue.defineComponent({
      name: 'CalendarOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ht, _hoisted_15);
      }
    });

    const _hoisted_1$hs = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hs = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M32 456a24 24 0 0 0 24 24h400a24 24 0 0 0 24-24V176H32zm320-244a4 4 0 0 1 4-4h40a4 4 0 0 1 4 4v40a4 4 0 0 1-4 4h-40a4 4 0 0 1-4-4zm0 80a4 4 0 0 1 4-4h40a4 4 0 0 1 4 4v40a4 4 0 0 1-4 4h-40a4 4 0 0 1-4-4zm-80-80a4 4 0 0 1 4-4h40a4 4 0 0 1 4 4v40a4 4 0 0 1-4 4h-40a4 4 0 0 1-4-4zm0 80a4 4 0 0 1 4-4h40a4 4 0 0 1 4 4v40a4 4 0 0 1-4 4h-40a4 4 0 0 1-4-4zm0 80a4 4 0 0 1 4-4h40a4 4 0 0 1 4 4v40a4 4 0 0 1-4 4h-40a4 4 0 0 1-4-4zm-80-80a4 4 0 0 1 4-4h40a4 4 0 0 1 4 4v40a4 4 0 0 1-4 4h-40a4 4 0 0 1-4-4zm0 80a4 4 0 0 1 4-4h40a4 4 0 0 1 4 4v40a4 4 0 0 1-4 4h-40a4 4 0 0 1-4-4zm-80-80a4 4 0 0 1 4-4h40a4 4 0 0 1 4 4v40a4 4 0 0 1-4 4h-40a4 4 0 0 1-4-4zm0 80a4 4 0 0 1 4-4h40a4 4 0 0 1 4 4v40a4 4 0 0 1-4 4h-40a4 4 0 0 1-4-4z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$f2 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M456 64h-55.92V32h-48v32H159.92V32h-48v32H56a23.8 23.8 0 0 0-24 23.77V144h448V87.77A23.8 23.8 0 0 0 456 64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8L = [_hoisted_2$hs, _hoisted_3$f2];
    vue.defineComponent({
      name: 'CalendarSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hs, _hoisted_4$8L);
      }
    });

    const _hoisted_1$hr = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hr = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M391 480c-19.52 0-46.94-7.06-88-30c-49.93-28-88.55-53.85-138.21-103.38C116.91 298.77 93.61 267.79 61 208.45c-36.84-67-30.56-102.12-23.54-117.13C45.82 73.38 58.16 62.65 74.11 52a176.3 176.3 0 0 1 28.64-15.2c1-.43 1.93-.84 2.76-1.21c4.95-2.23 12.45-5.6 21.95-2c6.34 2.38 12 7.25 20.86 16c18.17 17.92 43 57.83 52.16 77.43c6.15 13.21 10.22 21.93 10.23 31.71c0 11.45-5.76 20.28-12.75 29.81c-1.31 1.79-2.61 3.5-3.87 5.16c-7.61 10-9.28 12.89-8.18 18.05c2.23 10.37 18.86 41.24 46.19 68.51s57.31 42.85 67.72 45.07c5.38 1.15 8.33-.59 18.65-8.47c1.48-1.13 3-2.3 4.59-3.47c10.66-7.93 19.08-13.54 30.26-13.54h.06c9.73 0 18.06 4.22 31.86 11.18c18 9.08 59.11 33.59 77.14 51.78c8.77 8.84 13.66 14.48 16.05 20.81c3.6 9.53.21 17-2 22c-.37.83-.78 1.74-1.21 2.75a176.49 176.49 0 0 1-15.29 28.58c-10.63 15.9-21.4 28.21-39.38 36.58A67.42 67.42 0 0 1 391 480z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$f1 = [_hoisted_2$hr];
    vue.defineComponent({
      name: 'Call',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hr, _hoisted_3$f1);
      }
    });

    const _hoisted_1$hq = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hq = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M451 374c-15.88-16-54.34-39.35-73-48.76c-24.3-12.24-26.3-13.24-45.4.95c-12.74 9.47-21.21 17.93-36.12 14.75s-47.31-21.11-75.68-49.39s-47.34-61.62-50.53-76.48s5.41-23.23 14.79-36c13.22-18 12.22-21 .92-45.3c-8.81-18.9-32.84-57-48.9-72.8C119.9 44 119.9 47 108.83 51.6A160.15 160.15 0 0 0 83 65.37C67 76 58.12 84.83 51.91 98.1s-9 44.38 23.07 102.64s54.57 88.05 101.14 134.49S258.5 406.64 310.85 436c64.76 36.27 89.6 29.2 102.91 23s22.18-15 32.83-31a159.09 159.09 0 0 0 13.8-25.8C465 391.17 468 391.17 451 374z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$f0 = [_hoisted_2$hq];
    vue.defineComponent({
      name: 'CallOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hq, _hoisted_3$f0);
      }
    });

    const _hoisted_1$hp = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hp = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M478.94 370.14c-5.22-5.56-23.65-22-57.53-43.75c-34.13-21.94-59.3-35.62-66.52-38.81a3.83 3.83 0 0 0-3.92.49c-11.63 9.07-31.21 25.73-32.26 26.63c-6.78 5.81-6.78 5.81-12.33 4c-9.76-3.2-40.08-19.3-66.5-45.78s-43.35-57.55-46.55-67.3c-1.83-5.56-1.83-5.56 4-12.34c.9-1.05 17.57-20.63 26.64-32.25a3.83 3.83 0 0 0 .49-3.92c-3.19-7.23-16.87-32.39-38.81-66.52c-21.78-33.87-38.2-52.3-43.76-57.52a3.9 3.9 0 0 0-3.89-.87a322.35 322.35 0 0 0-56 25.45A338 338 0 0 0 33.35 92a3.83 3.83 0 0 0-1.26 3.74c2.09 9.74 12.08 50.4 43.08 106.72c31.63 57.48 53.55 86.93 100 133.22S252 405.21 309.54 436.84c56.32 31 97 41 106.72 43.07a3.86 3.86 0 0 0 3.75-1.26A337.73 337.73 0 0 0 454.35 430a322.7 322.7 0 0 0 25.45-56a3.9 3.9 0 0 0-.86-3.86z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$e$ = [_hoisted_2$hp];
    vue.defineComponent({
      name: 'CallSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hp, _hoisted_3$e$);
      }
    });

    const _hoisted_1$ho = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ho = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '272',
      r: '64',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$e_ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M432 144h-59c-3 0-6.72-1.94-9.62-5l-25.94-40.94a15.52 15.52 0 0 0-1.37-1.85C327.11 85.76 315 80 302 80h-92c-13 0-25.11 5.76-34.07 16.21a15.52 15.52 0 0 0-1.37 1.85l-25.94 41c-2.22 2.42-5.34 5-8.62 5v-8a16 16 0 0 0-16-16h-24a16 16 0 0 0-16 16v8h-4a48.05 48.05 0 0 0-48 48V384a48.05 48.05 0 0 0 48 48h352a48.05 48.05 0 0 0 48-48V192a48.05 48.05 0 0 0-48-48zM256 368a96 96 0 1 1 96-96a96.11 96.11 0 0 1-96 96z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8K = [_hoisted_2$ho, _hoisted_3$e_];
    vue.defineComponent({
      name: 'Camera',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ho, _hoisted_4$8K);
      }
    });

    const _hoisted_1$hn = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hn = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M350.54 148.68l-26.62-42.06C318.31 100.08 310.62 96 302 96h-92c-8.62 0-16.31 4.08-21.92 10.62l-26.62 42.06C155.85 155.23 148.62 160 140 160H80a32 32 0 0 0-32 32v192a32 32 0 0 0 32 32h352a32 32 0 0 0 32-32V192a32 32 0 0 0-32-32h-59c-8.65 0-16.85-4.77-22.46-11.32z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eZ = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '272',
      r: '80',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8J = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M124 158v-22h-24v22'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4d = [_hoisted_2$hn, _hoisted_3$eZ, _hoisted_4$8J];
    vue.defineComponent({
      name: 'CameraOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hn, _hoisted_5$4d);
      }
    });

    const _hoisted_1$hm = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hm = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M432 144h-59c-3 0-6.72-1.94-9.62-5l-25.94-40.94a15.52 15.52 0 0 0-1.37-1.85C327.11 85.76 315 80 302 80h-92c-13 0-25.11 5.76-34.07 16.21a15.52 15.52 0 0 0-1.37 1.85l-25.94 41c-2.22 2.42-5.34 5-8.62 5v-8a16 16 0 0 0-16-16h-24a16 16 0 0 0-16 16v8h-4a48.05 48.05 0 0 0-48 48V384a48.05 48.05 0 0 0 48 48h352a48.05 48.05 0 0 0 48-48V192a48.05 48.05 0 0 0-48-48zM316.84 346.3a96.06 96.06 0 0 1-155.66-59.18a16 16 0 0 1-16.49-26.43l20-20a16 16 0 0 1 22.62 0l20 20A16 16 0 0 1 196 288a17.31 17.31 0 0 1-2-.14a64.07 64.07 0 0 0 102.66 33.63a16 16 0 1 1 20.21 24.81zm50.47-63l-20 20a16 16 0 0 1-22.62 0l-20-20a16 16 0 0 1 13.09-27.2A64 64 0 0 0 215 222.64A16 16 0 1 1 194.61 198a96 96 0 0 1 156 59a16 16 0 0 1 16.72 26.35z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eY = [_hoisted_2$hm];
    vue.defineComponent({
      name: 'CameraReverse',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hm, _hoisted_3$eY);
      }
    });

    const _hoisted_1$hl = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hl = /*#__PURE__*/vue.createStaticVNode('<path d="M350.54 148.68l-26.62-42.06C318.31 100.08 310.62 96 302 96h-92c-8.62 0-16.31 4.08-21.92 10.62l-26.62 42.06C155.85 155.23 148.62 160 140 160H80a32 32 0 0 0-32 32v192a32 32 0 0 0 32 32h352a32 32 0 0 0 32-32V192a32 32 0 0 0-32-32h-59c-8.65 0-16.85-4.77-22.46-11.32z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M124 158v-22h-24v22"></path><path d="M335.76 285.22v-13.31a80 80 0 0 0-131-61.6M176 258.78v13.31a80 80 0 0 0 130.73 61.8" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M196 272l-20-20l-20 20"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M356 272l-20 20l-20-20"></path>', 5);

    const _hoisted_7$X = [_hoisted_2$hl];
    vue.defineComponent({
      name: 'CameraReverseOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hl, _hoisted_7$X);
      }
    });

    const _hoisted_1$hk = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hk = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M456 144h-83c-3 0-6.72-1.94-9.62-5l-27.31-42.79C326 80 320 80 302 80h-92c-18 0-23 0-34.07 16.21L148.62 139c-2.22 2.42-5.34 5-8.62 5v-16a8 8 0 0 0-8-8H92a8 8 0 0 0-8 8v16H56a24 24 0 0 0-24 24v240a24 24 0 0 0 24 24h400a24 24 0 0 0 24-24V168a24 24 0 0 0-24-24zM256 368c-47.82 0-87.76-34.23-95-80h-43.63L176 229.37L234.63 288H194a64.07 64.07 0 0 0 102.63 33.49L320 343l-3.68 3.72A96.64 96.64 0 0 1 256 368zm80-53.84L277.11 256H318a64.26 64.26 0 0 0-103-33.36L192 200l3.14-2.45A96.19 96.19 0 0 1 255.76 176c47.85 0 87 34.19 94.24 80h44.92z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eX = [_hoisted_2$hk];
    vue.defineComponent({
      name: 'CameraReverseSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hk, _hoisted_3$eX);
      }
    });

    const _hoisted_1$hj = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hj = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '272',
      r: '64',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eW = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M456 144h-83c-3 0-6.72-1.94-9.62-5L336.1 96.2C325 80 320 80 302 80h-92c-18 0-24 0-34.07 16.21L148.62 139c-2.22 2.42-5.34 5-8.62 5v-16a8 8 0 0 0-8-8H92a8 8 0 0 0-8 8v16H56a24 24 0 0 0-24 24v240a24 24 0 0 0 24 24h400a24 24 0 0 0 24-24V168a24 24 0 0 0-24-24zM260.51 367.9a96 96 0 1 1 91.39-91.39a96.11 96.11 0 0 1-91.39 91.39z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8I = [_hoisted_2$hj, _hoisted_3$eW];
    vue.defineComponent({
      name: 'CameraSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hj, _hoisted_4$8I);
      }
    });

    const _hoisted_1$hi = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hi = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M447.68 220.78a16 16 0 0 0-1-3.08l-37.78-88.16C400.19 109.17 379 96 354.89 96H157.11c-24.09 0-45.3 13.17-54 33.54L65.29 217.7A15.72 15.72 0 0 0 64 224v176a16 16 0 0 0 16 16h32a16 16 0 0 0 16-16v-16h256v16a16 16 0 0 0 16 16h32a16 16 0 0 0 16-16V224a16.15 16.15 0 0 0-.32-3.22zM144 320a32 32 0 1 1 32-32a32 32 0 0 1-32 32zm224 0a32 32 0 1 1 32-32a32 32 0 0 1-32 32zM104.26 208l28.23-65.85C136.11 133.69 146 128 157.11 128h197.78c11.1 0 21 5.69 24.62 14.15L407.74 208z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eV = [_hoisted_2$hi];
    vue.defineComponent({
      name: 'Car',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hi, _hoisted_3$eV);
      }
    });

    const _hoisted_1$hh = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hh = /*#__PURE__*/vue.createStaticVNode('<path d="M80 224l37.78-88.15C123.93 121.5 139.6 112 157.11 112h197.78c17.51 0 33.18 9.5 39.33 23.85L432 224" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M80 224h352v144H80z"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M112 368v32H80v-32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M432 368v32h-32v-32"></path><circle cx="144" cy="288" r="16" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><circle cx="368" cy="288" r="16" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle>', 6);

    const _hoisted_8$y = [_hoisted_2$hh];
    vue.defineComponent({
      name: 'CarOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hh, _hoisted_8$y);
      }
    });

    const _hoisted_1$hg = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hg = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M447.68 220.78a16.44 16.44 0 0 0-1-3.1l-48-112A16 16 0 0 0 384 96H128a16 16 0 0 0-14.71 9.7l-48 112a16.44 16.44 0 0 0-1 3.1A16.15 16.15 0 0 0 64 224v184a8 8 0 0 0 8 8h32a8 8 0 0 0 8-8v-24h288v24a8 8 0 0 0 8 8h32a8 8 0 0 0 8-8V224a16.15 16.15 0 0 0-.32-3.22zM144 320a32 32 0 1 1 32-32a32 32 0 0 1-32 32zm224 0a32 32 0 1 1 32-32a32 32 0 0 1-32 32zM104.26 208l34.29-80h234.9l34.29 80z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eU = [_hoisted_2$hg];
    vue.defineComponent({
      name: 'CarSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hg, _hoisted_3$eU);
      }
    });

    const _hoisted_1$hf = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hf = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M494.26 276.22c-3.6-40.41-9.53-48.28-11.77-51.24c-5.15-6.84-13.39-11.31-22.11-16a3.6 3.6 0 0 1-.91-5.68a15.93 15.93 0 0 0 4.53-12.53A16.27 16.27 0 0 0 447.65 176h-15.6a17 17 0 0 0-2 .13a8.5 8.5 0 0 0-1.41-.47c-9.24-19.53-21.89-46.27-48.11-59.32C341.64 97 270 96 256 96s-85.64 1-124.48 20.31c-26.22 13.05-38.87 39.79-48.11 59.32l-.08.16a6.52 6.52 0 0 0-1.35.34a17 17 0 0 0-2-.13H64.35A16.27 16.27 0 0 0 48 190.77a15.93 15.93 0 0 0 4.59 12.47a3.6 3.6 0 0 1-.91 5.68c-8.72 4.72-17 9.19-22.11 16c-2.24 3-8.16 10.83-11.77 51.24c-2 22.74-2.3 46.28-.73 61.44c3.29 31.5 9.46 50.54 9.72 51.33a16 16 0 0 0 13.2 10.87v.2a16 16 0 0 0 16 16h56a16 16 0 0 0 16-16c8.61 0 14.6-1.54 20.95-3.18a158.83 158.83 0 0 1 28-4.91C207.45 389 237.79 388 256 388c17.84 0 49.52 1 80.08 3.91a159.16 159.16 0 0 1 28.11 4.93c6.08 1.56 11.85 3 19.84 3.15a16 16 0 0 0 16 16h56a16 16 0 0 0 16-16v-.12A16 16 0 0 0 485.27 389c.26-.79 6.43-19.83 9.72-51.33c1.57-15.17 1.29-38.67-.73-61.45zm-381.93-86.91c8-17 17.15-36.24 33.44-44.35c23.54-11.72 72.33-17 110.23-17s86.69 5.24 110.23 17c16.29 8.11 25.4 27.36 33.44 44.35l1 2.17a8 8 0 0 1-7.44 11.42C360 202 290 199.12 256 199.12s-104 2.95-137.28 3.85a8 8 0 0 1-7.44-11.42c.35-.74.72-1.49 1.05-2.24zm11.93 79.63A427.17 427.17 0 0 1 72.42 272c-10.6 0-21.53-3-23.56-12.44c-1.39-6.35-1.24-9.92-.49-13.51C49 243 50 240.78 55 240c13-2 20.27.51 41.55 6.78c14.11 4.15 24.29 9.68 30.09 14.06c2.91 2.16 1.36 7.8-2.38 8.1zm221.38 82c-13.16 1.5-39.48.95-89.34.95s-76.17.55-89.33-.95c-13.58-1.51-30.89-14.35-19.07-25.79c7.87-7.54 26.23-13.18 50.68-16.35s34.8-4.8 57.62-4.8s32.12 1 57.62 4.81s44.77 9.52 50.68 16.35c10.78 12.24-5.29 24.19-18.86 25.84zm117.5-91.39c-2 9.48-13 12.44-23.56 12.44a455.91 455.91 0 0 1-52.84-3.06c-3.06-.29-4.48-5.66-1.38-8.1c5.71-4.49 16-9.91 30.09-14.06c21.28-6.27 33.55-8.78 44.09-6.69c2.57.51 3.93 3.27 4.09 5a40.64 40.64 0 0 1-.49 14.48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eT = [_hoisted_2$hf];
    vue.defineComponent({
      name: 'CarSport',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hf, _hoisted_3$eT);
      }
    });

    const _hoisted_1$he = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$he = /*#__PURE__*/vue.createStaticVNode('<path d="M469.71 234.6c-7.33-9.73-34.56-16.43-46.08-33.94s-20.95-55.43-50.27-70S288 112 256 112s-88 4-117.36 18.63s-38.75 52.52-50.27 70s-38.75 24.24-46.08 33.97S29.8 305.84 32.94 336s9 48 9 48h86c14.08 0 18.66-5.29 47.46-8c31.6-3 62.6-4 80.6-4s50 1 81.58 4c28.8 2.73 33.53 8 47.46 8h85s5.86-17.84 9-48s-2.04-91.67-9.33-101.4z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M400 384h56v16h-56z"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M56 384h56v16H56z"></path><path d="M364.47 309.16c-5.91-6.83-25.17-12.53-50.67-16.35S279 288 256.2 288s-33.17 1.64-57.61 4.81s-42.79 8.81-50.66 16.35C136.12 320.6 153.42 333.44 167 335c13.16 1.5 39.47.95 89.31.95s76.15.55 89.31-.95c13.56-1.65 29.62-13.6 18.85-25.84z" fill="currentColor"></path><path d="M431.57 243.05a3.23 3.23 0 0 0-3.1-3c-11.81-.42-23.8.42-45.07 6.69a93.88 93.88 0 0 0-30.08 15.06c-2.28 1.78-1.47 6.59 1.39 7.1a455.32 455.32 0 0 0 52.82 3.1c10.59 0 21.52-3 23.55-12.44a52.41 52.41 0 0 0 .49-16.51z" fill="currentColor"></path><path d="M80.43 243.05a3.23 3.23 0 0 1 3.1-3c11.81-.42 23.8.42 45.07 6.69a93.88 93.88 0 0 1 30.08 15.06c2.28 1.78 1.47 6.59-1.39 7.1a455.32 455.32 0 0 1-52.82 3.1c-10.59 0-21.52-3-23.55-12.44a52.41 52.41 0 0 1-.49-16.51z" fill="currentColor"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M432 192h16"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M64 192h16"></path><path d="M78 211s46.35-12 178-12s178 12 178 12" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 9);

    const _hoisted_11$8 = [_hoisted_2$he];
    vue.defineComponent({
      name: 'CarSportOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$he, _hoisted_11$8);
      }
    });

    const _hoisted_1$hd = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hd = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M488 224c-3-5-32.61-17.79-32.61-17.79c5.15-2.66 8.67-3.21 8.67-14.21c0-12-.06-16-8.06-16h-27.14c-.11-.24-.23-.49-.34-.74c-17.52-38.26-19.87-47.93-46-60.95C347.47 96.88 281.76 96 256 96s-91.47.88-126.49 18.31c-26.16 13-25.51 19.69-46 60.95c0 .11-.21.4-.4.74H55.94c-7.94 0-8 4-8 16c0 11 3.52 11.55 8.67 14.21C56.61 206.21 28 220 24 224s-8 32-8 80s4 96 4 96h11.94c0 14 2.06 16 8.06 16h80c6 0 8-2 8-16h256c0 14 2 16 8 16h82c4 0 6-3 6-16h12s4-49 4-96s-5-75-8-80zm-362.74 44.94A516.94 516.94 0 0 1 70.42 272c-20.42 0-21.12 1.31-22.56-11.44a72.16 72.16 0 0 1 .51-17.51L49 240h3c12 0 23.27.51 44.55 6.78a98 98 0 0 1 30.09 15.06C131 265 132 268 132 268zm247.16 72L368 352H144s.39-.61-5-11.18c-4-7.82 1-12.82 8.91-15.66C163.23 319.64 208 304 256 304s93.66 13.48 108.5 21.16C370 328 376.83 330 372.42 341zm-257-136.53a96.23 96.23 0 0 1-9.7.07c2.61-4.64 4.06-9.81 6.61-15.21c8-17 17.15-36.24 33.44-44.35c23.54-11.72 72.33-17 110.23-17s86.69 5.24 110.23 17c16.29 8.11 25.4 27.36 33.44 44.35c2.57 5.45 4 10.66 6.68 15.33c-2 .11-4.3 0-9.79-.19zm347.72 56.11C461 273 463 272 441.58 272a516.94 516.94 0 0 1-54.84-3.06c-2.85-.51-3.66-5.32-1.38-7.1a93.84 93.84 0 0 1 30.09-15.06c21.28-6.27 33.26-7.11 45.09-6.69a3.22 3.22 0 0 1 3.09 3a70.18 70.18 0 0 1-.49 17.47z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eS = [_hoisted_2$hd];
    vue.defineComponent({
      name: 'CarSportSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hd, _hoisted_3$eS);
      }
    });

    const _hoisted_1$hc = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hc = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M32 376a56 56 0 0 0 56 56h336a56 56 0 0 0 56-56V222H32zm66-76a30 30 0 0 1 30-30h48a30 30 0 0 1 30 30v20a30 30 0 0 1-30 30h-48a30 30 0 0 1-30-30z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eR = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M424 80H88a56 56 0 0 0-56 56v26h448v-26a56 56 0 0 0-56-56z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8H = [_hoisted_2$hc, _hoisted_3$eR];
    vue.defineComponent({
      name: 'Card',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hc, _hoisted_4$8H);
      }
    });

    const _hoisted_1$hb = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$hb = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '48',
      y: '96',
      width: '416',
      height: '320',
      rx: '56',
      ry: '56',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eQ = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '60',
      d: 'M48 192h416'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8G = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '60',
      d: 'M128 300h48v20h-48z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4c = [_hoisted_2$hb, _hoisted_3$eQ, _hoisted_4$8G];
    vue.defineComponent({
      name: 'CardOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$hb, _hoisted_5$4c);
      }
    });

    const _hoisted_1$ha = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ha = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M32 416a16 16 0 0 0 16 16h416a16 16 0 0 0 16-16V222H32zm66-138a8 8 0 0 1 8-8h92a8 8 0 0 1 8 8v64a8 8 0 0 1-8 8h-92a8 8 0 0 1-8-8z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eP = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 80H48a16 16 0 0 0-16 16v66h448V96a16 16 0 0 0-16-16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8F = [_hoisted_2$ha, _hoisted_3$eP];
    vue.defineComponent({
      name: 'CardSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ha, _hoisted_4$8F);
      }
    });

    const _hoisted_1$h9 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$h9 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M321.94 98L158.82 237.78a24 24 0 0 0 0 36.44L321.94 414c15.57 13.34 39.62 2.28 39.62-18.22v-279.6c0-20.5-24.05-31.56-39.62-18.18z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eO = [_hoisted_2$h9];
    vue.defineComponent({
      name: 'CaretBack',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$h9, _hoisted_3$eO);
      }
    });

    const _hoisted_1$h8 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$h8 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 256c0 114.87 93.13 208 208 208s208-93.13 208-208S370.87 48 256 48S48 141.13 48 256zm252-74.14v148.28a16 16 0 0 1-26.23 12.29l-89.09-74.13a16 16 0 0 1 0-24.6l89.09-74.13A16 16 0 0 1 300 181.86z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eN = [_hoisted_2$h8];
    vue.defineComponent({
      name: 'CaretBackCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$h8, _hoisted_3$eN);
      }
    });

    const _hoisted_1$h7 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$h7 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M273.77 169.57l-89.09 74.13a16 16 0 0 0 0 24.6l89.09 74.13A16 16 0 0 0 300 330.14V181.86a16 16 0 0 0-26.23-12.29z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eM = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8E = [_hoisted_2$h7, _hoisted_3$eM];
    vue.defineComponent({
      name: 'CaretBackCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$h7, _hoisted_4$8E);
      }
    });

    const _hoisted_1$h6 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$h6 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 256c0 114.87 93.13 208 208 208s208-93.13 208-208S370.87 48 256 48S48 141.13 48 256zm252 108.27L169.91 256L300 147.73z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eL = [_hoisted_2$h6];
    vue.defineComponent({
      name: 'CaretBackCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$h6, _hoisted_3$eL);
      }
    });

    const _hoisted_1$h5 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$h5 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M321.94 98L158.82 237.78a24 24 0 0 0 0 36.44L321.94 414c15.57 13.34 39.62 2.28 39.62-18.22v-279.6c0-20.5-24.05-31.56-39.62-18.18z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eK = [_hoisted_2$h5];
    vue.defineComponent({
      name: 'CaretBackOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$h5, _hoisted_3$eK);
      }
    });

    const _hoisted_1$h4 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$h4 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M368 64L144 256l224 192V64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eJ = [_hoisted_2$h4];
    vue.defineComponent({
      name: 'CaretBackSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$h4, _hoisted_3$eJ);
      }
    });

    const _hoisted_1$h3 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$h3 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M98 190.06l139.78 163.12a24 24 0 0 0 36.44 0L414 190.06c13.34-15.57 2.28-39.62-18.22-39.62h-279.6c-20.5 0-31.56 24.05-18.18 39.62z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eI = [_hoisted_2$h3];
    vue.defineComponent({
      name: 'CaretDown',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$h3, _hoisted_3$eI);
      }
    });

    const _hoisted_1$h2 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$h2 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 256c0-114.87-93.13-208-208-208S48 141.13 48 256s93.13 208 208 208s208-93.13 208-208zm-121.57-17.77l-74.13 89.09a16 16 0 0 1-24.6 0l-74.13-89.09A16 16 0 0 1 181.86 212h148.28a16 16 0 0 1 12.29 26.23z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eH = [_hoisted_2$h2];
    vue.defineComponent({
      name: 'CaretDownCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$h2, _hoisted_3$eH);
      }
    });

    const _hoisted_1$h1 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$h1 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M342.43 238.23l-74.13 89.09a16 16 0 0 1-24.6 0l-74.13-89.09A16 16 0 0 1 181.86 212h148.28a16 16 0 0 1 12.29 26.23z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eG = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8D = [_hoisted_2$h1, _hoisted_3$eG];
    vue.defineComponent({
      name: 'CaretDownCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$h1, _hoisted_4$8D);
      }
    });

    const _hoisted_1$h0 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$h0 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 256c0-114.87-93.13-208-208-208S48 141.13 48 256s93.13 208 208 208s208-93.13 208-208zm-99.73-44L256 342.09L147.73 212z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eF = [_hoisted_2$h0];
    vue.defineComponent({
      name: 'CaretDownCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$h0, _hoisted_3$eF);
      }
    });

    const _hoisted_1$g$ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$g$ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M98 190.06l139.78 163.12a24 24 0 0 0 36.44 0L414 190.06c13.34-15.57 2.28-39.62-18.22-39.62h-279.6c-20.5 0-31.56 24.05-18.18 39.62z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eE = [_hoisted_2$g$];
    vue.defineComponent({
      name: 'CaretDownOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$g$, _hoisted_3$eE);
      }
    });

    const _hoisted_1$g_ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$g_ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M64 144l192 224l192-224H64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eD = [_hoisted_2$g_];
    vue.defineComponent({
      name: 'CaretDownSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$g_, _hoisted_3$eD);
      }
    });

    const _hoisted_1$gZ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gZ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M190.06 414l163.12-139.78a24 24 0 0 0 0-36.44L190.06 98c-15.57-13.34-39.62-2.28-39.62 18.22v279.6c0 20.5 24.05 31.56 39.62 18.18z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eC = [_hoisted_2$gZ];
    vue.defineComponent({
      name: 'CaretForward',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gZ, _hoisted_3$eC);
      }
    });

    const _hoisted_1$gY = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gY = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 256c0-114.87-93.13-208-208-208S48 141.13 48 256s93.13 208 208 208s208-93.13 208-208zm-252 74.14V181.86a16 16 0 0 1 26.23-12.29l89.09 74.13a16 16 0 0 1 0 24.6l-89.09 74.13A16 16 0 0 1 212 330.14z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eB = [_hoisted_2$gY];
    vue.defineComponent({
      name: 'CaretForwardCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gY, _hoisted_3$eB);
      }
    });

    const _hoisted_1$gX = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gX = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M238.23 342.43l89.09-74.13a16 16 0 0 0 0-24.6l-89.09-74.13A16 16 0 0 0 212 181.86v148.28a16 16 0 0 0 26.23 12.29z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eA = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8C = [_hoisted_2$gX, _hoisted_3$eA];
    vue.defineComponent({
      name: 'CaretForwardCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gX, _hoisted_4$8C);
      }
    });

    const _hoisted_1$gW = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gW = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 256c0-114.87-93.13-208-208-208S48 141.13 48 256s93.13 208 208 208s208-93.13 208-208zM212 147.73L342.09 256L212 364.27z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ez = [_hoisted_2$gW];
    vue.defineComponent({
      name: 'CaretForwardCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gW, _hoisted_3$ez);
      }
    });

    const _hoisted_1$gV = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gV = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M190.06 414l163.12-139.78a24 24 0 0 0 0-36.44L190.06 98c-15.57-13.34-39.62-2.28-39.62 18.22v279.6c0 20.5 24.05 31.56 39.62 18.18z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ey = [_hoisted_2$gV];
    vue.defineComponent({
      name: 'CaretForwardOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gV, _hoisted_3$ey);
      }
    });

    const _hoisted_1$gU = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gU = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M144 448l224-192L144 64v384z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ex = [_hoisted_2$gU];
    vue.defineComponent({
      name: 'CaretForwardSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gU, _hoisted_3$ex);
      }
    });

    const _hoisted_1$gT = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gT = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M414 321.94L274.22 158.82a24 24 0 0 0-36.44 0L98 321.94c-13.34 15.57-2.28 39.62 18.22 39.62h279.6c20.5 0 31.56-24.05 18.18-39.62z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ew = [_hoisted_2$gT];
    vue.defineComponent({
      name: 'CaretUp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gT, _hoisted_3$ew);
      }
    });

    const _hoisted_1$gS = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gS = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.13 48 48 141.13 48 256s93.13 208 208 208s208-93.13 208-208S370.87 48 256 48zm74.14 252H181.86a16 16 0 0 1-12.29-26.23l74.13-89.09a16 16 0 0 1 24.6 0l74.13 89.09A16 16 0 0 1 330.14 300z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ev = [_hoisted_2$gS];
    vue.defineComponent({
      name: 'CaretUpCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gS, _hoisted_3$ev);
      }
    });

    const _hoisted_1$gR = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gR = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M342.43 273.77l-74.13-89.09a16 16 0 0 0-24.6 0l-74.13 89.09A16 16 0 0 0 181.86 300h148.28a16 16 0 0 0 12.29-26.23z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eu = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8B = [_hoisted_2$gR, _hoisted_3$eu];
    vue.defineComponent({
      name: 'CaretUpCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gR, _hoisted_4$8B);
      }
    });

    const _hoisted_1$gQ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gQ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.13 48 48 141.13 48 256s93.13 208 208 208s208-93.13 208-208S370.87 48 256 48zM147.73 300L256 169.91L364.27 300z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$et = [_hoisted_2$gQ];
    vue.defineComponent({
      name: 'CaretUpCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gQ, _hoisted_3$et);
      }
    });

    const _hoisted_1$gP = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gP = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M414 321.94L274.22 158.82a24 24 0 0 0-36.44 0L98 321.94c-13.34 15.57-2.28 39.62 18.22 39.62h279.6c20.5 0 31.56-24.05 18.18-39.62z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$es = [_hoisted_2$gP];
    vue.defineComponent({
      name: 'CaretUpOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gP, _hoisted_3$es);
      }
    });

    const _hoisted_1$gO = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gO = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 368L256 144L64 368h384z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$er = [_hoisted_2$gO];
    vue.defineComponent({
      name: 'CaretUpSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gO, _hoisted_3$er);
      }
    });

    const _hoisted_1$gN = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gN = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '176',
      cy: '416',
      r: '32',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eq = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '400',
      cy: '416',
      r: '32',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8A = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M456.8 120.78a23.92 23.92 0 0 0-18.56-8.78H133.89l-6.13-34.78A16 16 0 0 0 112 64H48a16 16 0 0 0 0 32h50.58l45.66 258.78A16 16 0 0 0 160 368h256a16 16 0 0 0 0-32H173.42l-5.64-32h241.66A24.07 24.07 0 0 0 433 284.71l28.8-144a24 24 0 0 0-5-19.93z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4b = [_hoisted_2$gN, _hoisted_3$eq, _hoisted_4$8A];
    vue.defineComponent({
      name: 'Cart',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gN, _hoisted_5$4b);
      }
    });

    const _hoisted_1$gM = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gM = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '176',
      cy: '416',
      r: '16',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ep = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '400',
      cy: '416',
      r: '16',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8z = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M48 80h64l48 272h256'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4a = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M160 288h249.44a8 8 0 0 0 7.85-6.43l28.8-144a8 8 0 0 0-7.85-9.57H128',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1M = [_hoisted_2$gM, _hoisted_3$ep, _hoisted_4$8z, _hoisted_5$4a];
    vue.defineComponent({
      name: 'CartOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gM, _hoisted_6$1M);
      }
    });

    const _hoisted_1$gL = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gL = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '176',
      cy: '416',
      r: '32',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eo = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '400',
      cy: '416',
      r: '32',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M167.78 304h261.34l38.4-192H133.89l-8.47-48H32v32h66.58l48 272H432v-32H173.42l-5.64-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$49 = [_hoisted_2$gL, _hoisted_3$eo, _hoisted_4$8y];
    vue.defineComponent({
      name: 'CartSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gL, _hoisted_5$49);
      }
    });

    const _hoisted_1$gK = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gK = /*#__PURE__*/vue.createStaticVNode('<path d="M448 400H64a16 16 0 0 1 0-32h384a16 16 0 0 1 0 32z" fill="currentColor"></path><path d="M416 448H96a16 16 0 0 1 0-32h320a16 16 0 0 1 0 32z" fill="currentColor"></path><path d="M32 272H16v48a32 32 0 0 0 32 32h48v-16a64.07 64.07 0 0 0-64-64z" fill="currentColor"></path><path d="M480 240h16v-64h-16a96.11 96.11 0 0 1-96-96V64H128v16a96.11 96.11 0 0 1-96 96H16v64h16a96.11 96.11 0 0 1 96 96v16h256v-16a96.11 96.11 0 0 1 96-96zm-224 64a96 96 0 1 1 96-96a96.11 96.11 0 0 1-96 96z" fill="currentColor"></path><circle cx="256" cy="208" r="64" fill="currentColor"></circle><path d="M416 336v16h48a32 32 0 0 0 32-32v-48h-16a64.07 64.07 0 0 0-64 64z" fill="currentColor"></path><path d="M480 144h16V96a32 32 0 0 0-32-32h-48v16a64.07 64.07 0 0 0 64 64z" fill="currentColor"></path><path d="M96 80V64H48a32 32 0 0 0-32 32v48h16a64.07 64.07 0 0 0 64-64z" fill="currentColor"></path>', 8);

    const _hoisted_10$j = [_hoisted_2$gK];
    vue.defineComponent({
      name: 'Cash',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gK, _hoisted_10$j);
      }
    });

    const _hoisted_1$gJ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gJ = /*#__PURE__*/vue.createStaticVNode('<rect x="32" y="80" width="448" height="256" rx="16" ry="16" transform="rotate(180 256 208)" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></rect><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M64 384h384"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M96 432h320"></path><circle cx="256" cy="208" r="80" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><path d="M480 160a80 80 0 0 1-80-80" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M32 160a80 80 0 0 0 80-80" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M480 256a80 80 0 0 0-80 80" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M32 256a80 80 0 0 1 80 80" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 8);

    const _hoisted_10$i = [_hoisted_2$gJ];
    vue.defineComponent({
      name: 'CashOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gJ, _hoisted_10$i);
      }
    });

    const _hoisted_1$gI = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gI = /*#__PURE__*/vue.createStaticVNode('<path d="M48 368h416v32H48z" fill="currentColor"></path><path d="M80 416h352v32H80z" fill="currentColor"></path><path d="M480 176a96.11 96.11 0 0 1-96-96V64H128v16a96.11 96.11 0 0 1-96 96H16v64h16a96.11 96.11 0 0 1 96 96v16h256v-16a96.11 96.11 0 0 1 96-96h16v-64zM256 304a96 96 0 1 1 96-96a96.11 96.11 0 0 1-96 96z" fill="currentColor"></path><path d="M96 80V64H16v80h16a64.07 64.07 0 0 0 64-64z" fill="currentColor"></path><path d="M32 272H16v80h80v-16a64.07 64.07 0 0 0-64-64z" fill="currentColor"></path><path d="M480 144h16V64h-80v16a64.07 64.07 0 0 0 64 64z" fill="currentColor"></path><path d="M416 336v16h80v-80h-16a64.07 64.07 0 0 0-64 64z" fill="currentColor"></path><circle cx="256" cy="208" r="64" fill="currentColor"></circle>', 8);

    const _hoisted_10$h = [_hoisted_2$gI];
    vue.defineComponent({
      name: 'CashSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gI, _hoisted_10$h);
      }
    });

    const _hoisted_1$gH = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gH = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M472 432h-48a24 24 0 0 1-24-24V104a24 24 0 0 1 24-24h48a24 24 0 0 1 24 24v304a24 24 0 0 1-24 24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$en = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M344 432h-48a24 24 0 0 1-24-24V184a24 24 0 0 1 24-24h48a24 24 0 0 1 24 24v224a24 24 0 0 1-24 24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8x = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M216 432h-48a24 24 0 0 1-24-24V248a24 24 0 0 1 24-24h48a24 24 0 0 1 24 24v160a24 24 0 0 1-24 24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$48 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M88 432H40a24 24 0 0 1-24-24v-96a24 24 0 0 1 24-24h48a24 24 0 0 1 24 24v96a24 24 0 0 1-24 24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1L = [_hoisted_2$gH, _hoisted_3$en, _hoisted_4$8x, _hoisted_5$48];
    vue.defineComponent({
      name: 'Cellular',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gH, _hoisted_6$1L);
      }
    });

    const _hoisted_1$gG = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gG = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '416',
      y: '96',
      width: '64',
      height: '320',
      rx: '8',
      ry: '8',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$em = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '288',
      y: '176',
      width: '64',
      height: '240',
      rx: '8',
      ry: '8',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8w = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '160',
      y: '240',
      width: '64',
      height: '176',
      rx: '8',
      ry: '8',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$47 = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '32',
      y: '304',
      width: '64',
      height: '112',
      rx: '8',
      ry: '8',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1K = [_hoisted_2$gG, _hoisted_3$em, _hoisted_4$8w, _hoisted_5$47];
    vue.defineComponent({
      name: 'CellularOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gG, _hoisted_6$1K);
      }
    });

    const _hoisted_1$gF = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gF = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M496 432h-96V80h96z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$el = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M368 432h-96V160h96z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8v = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M240 432h-96V224h96z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$46 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M112 432H16V288h96z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1J = [_hoisted_2$gF, _hoisted_3$el, _hoisted_4$8v, _hoisted_5$46];
    vue.defineComponent({
      name: 'CellularSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gF, _hoisted_6$1J);
      }
    });

    const _hoisted_1$gE = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gE = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M144 464a16 16 0 0 1-16-16v-64h-24a72.08 72.08 0 0 1-72-72V120a72.08 72.08 0 0 1 72-72h304a72.08 72.08 0 0 1 72 72v192a72.08 72.08 0 0 1-72 72H245.74l-91.49 76.29A16.05 16.05 0 0 1 144 464z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ek = [_hoisted_2$gE];
    vue.defineComponent({
      name: 'Chatbox',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gE, _hoisted_3$ek);
      }
    });

    const _hoisted_1$gD = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gD = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M408 48H104a72.08 72.08 0 0 0-72 72v192a72.08 72.08 0 0 0 72 72h24v64a16 16 0 0 0 26.25 12.29L245.74 384H408a72.08 72.08 0 0 0 72-72V120a72.08 72.08 0 0 0-72-72zM160 248a32 32 0 1 1 32-32a32 32 0 0 1-32 32zm96 0a32 32 0 1 1 32-32a32 32 0 0 1-32 32zm96 0a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ej = [_hoisted_2$gD];
    vue.defineComponent({
      name: 'ChatboxEllipses',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gD, _hoisted_3$ej);
      }
    });

    const _hoisted_1$gC = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gC = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M408 64H104a56.16 56.16 0 0 0-56 56v192a56.16 56.16 0 0 0 56 56h40v80l93.72-78.14a8 8 0 0 1 5.13-1.86H408a56.16 56.16 0 0 0 56-56V120a56.16 56.16 0 0 0-56-56z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ei = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '160',
      cy: '216',
      r: '32',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8u = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '216',
      r: '32',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$45 = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '352',
      cy: '216',
      r: '32',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1I = [_hoisted_2$gC, _hoisted_3$ei, _hoisted_4$8u, _hoisted_5$45];
    vue.defineComponent({
      name: 'ChatboxEllipsesOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gC, _hoisted_6$1I);
      }
    });

    const _hoisted_1$gB = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gB = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M456 48H56a24 24 0 0 0-24 24v288a24 24 0 0 0 24 24h72v80l117.74-80H456a24 24 0 0 0 24-24V72a24 24 0 0 0-24-24zM160 248a32 32 0 1 1 32-32a32 32 0 0 1-32 32zm96 0a32 32 0 1 1 32-32a32 32 0 0 1-32 32zm96 0a32 32 0 1 1 32-32a32 32 0 0 1-32 32zM456 80z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eh = [_hoisted_2$gB];
    vue.defineComponent({
      name: 'ChatboxEllipsesSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gB, _hoisted_3$eh);
      }
    });

    const _hoisted_1$gA = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gA = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M408 64H104a56.16 56.16 0 0 0-56 56v192a56.16 56.16 0 0 0 56 56h40v80l93.72-78.14a8 8 0 0 1 5.13-1.86H408a56.16 56.16 0 0 0 56-56V120a56.16 56.16 0 0 0-56-56z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eg = [_hoisted_2$gA];
    vue.defineComponent({
      name: 'ChatboxOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gA, _hoisted_3$eg);
      }
    });

    const _hoisted_1$gz = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gz = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M128 464v-80H56a24 24 0 0 1-24-24V72a24 24 0 0 1 24-24h400a24 24 0 0 1 24 24v288a24 24 0 0 1-24 24H245.74zM456 80z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ef = [_hoisted_2$gz];
    vue.defineComponent({
      name: 'ChatboxSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gz, _hoisted_3$ef);
      }
    });

    const _hoisted_1$gy = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gy = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M76.83 480a25.69 25.69 0 0 1-25.57-25.74a29.13 29.13 0 0 1 1.2-7.63L70.88 380c.77-2.46-.1-4.94-1.23-6.9l-.22-.4c-.08-.13-.46-.66-.73-1.05s-.58-.81-.86-1.22l-.19-.27A215.66 215.66 0 0 1 32 251.37c-.18-57.59 22.35-112 63.46-153.28C138 55.47 194.9 32 255.82 32A227.4 227.4 0 0 1 398 81.84c39.45 31.75 66.87 76 77.21 124.68a213.5 213.5 0 0 1 4.78 45c0 58.93-22.64 114.28-63.76 155.87c-41.48 42-97.18 65.06-156.83 65.06c-21 0-47.87-5.36-60.77-9c-15.52-4.34-30.23-10-31.85-10.6a15.12 15.12 0 0 0-5.37-1a14.75 14.75 0 0 0-5.8 1.15l-.85.33l-67.48 24.38A29.44 29.44 0 0 1 76.83 480zm-2-31.8zM87.48 380z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ee = [_hoisted_2$gy];
    vue.defineComponent({
      name: 'Chatbubble',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gy, _hoisted_3$ee);
      }
    });

    const _hoisted_1$gx = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gx = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M398 81.84A227.4 227.4 0 0 0 255.82 32C194.9 32 138 55.47 95.46 98.09C54.35 139.33 31.82 193.78 32 251.37a215.66 215.66 0 0 0 35.65 118.76l.19.27c.28.41.57.82.86 1.22s.65.92.73 1.05l.22.4c1.13 2 2 4.44 1.23 6.9l-18.42 66.66a29.13 29.13 0 0 0-1.2 7.63A25.69 25.69 0 0 0 76.83 480a29.44 29.44 0 0 0 10.45-2.29l67.49-24.36l.85-.33a14.75 14.75 0 0 1 5.8-1.15a15.12 15.12 0 0 1 5.37 1c1.62.63 16.33 6.26 31.85 10.6c12.9 3.6 39.74 9 60.77 9c59.65 0 115.35-23.1 156.83-65.06C457.36 365.77 480 310.42 480 251.49a213.5 213.5 0 0 0-4.78-45c-10.34-48.62-37.76-92.9-77.22-124.65zM87.48 380zM160 288a32 32 0 1 1 32-32a32 32 0 0 1-32 32zm96 0a32 32 0 1 1 32-32a32 32 0 0 1-32 32zm96 0a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ed = [_hoisted_2$gx];
    vue.defineComponent({
      name: 'ChatbubbleEllipses',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gx, _hoisted_3$ed);
      }
    });

    const _hoisted_1$gw = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gw = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M87.48 380c1.2-4.38-1.43-10.47-3.94-14.86a42.63 42.63 0 0 0-2.54-3.8a199.81 199.81 0 0 1-33-110C47.64 139.09 140.72 48 255.82 48C356.2 48 440 117.54 459.57 209.85a199 199 0 0 1 4.43 41.64c0 112.41-89.49 204.93-204.59 204.93c-18.31 0-43-4.6-56.47-8.37s-26.92-8.77-30.39-10.11a31.14 31.14 0 0 0-11.13-2.07a30.7 30.7 0 0 0-12.08 2.43L81.5 462.78a15.92 15.92 0 0 1-4.66 1.22a9.61 9.61 0 0 1-9.58-9.74a15.85 15.85 0 0 1 .6-3.29z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ec = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '160',
      cy: '256',
      r: '32',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8t = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '32',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$44 = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '352',
      cy: '256',
      r: '32',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1H = [_hoisted_2$gw, _hoisted_3$ec, _hoisted_4$8t, _hoisted_5$44];
    vue.defineComponent({
      name: 'ChatbubbleEllipsesOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gw, _hoisted_6$1H);
      }
    });

    const _hoisted_1$gv = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gv = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M475.22 206.52c-10.34-48.65-37.76-92.93-77.22-124.68A227.4 227.4 0 0 0 255.82 32C194.9 32 138 55.47 95.46 98.09C54.35 139.33 31.82 193.78 32 251.37a215.66 215.66 0 0 0 35.65 118.76l4.35 6.05L48 480l114.8-28.56s2.3.77 4 1.42s16.33 6.26 31.85 10.6c12.9 3.6 39.74 9 60.77 9c59.65 0 115.35-23.1 156.83-65.06C457.36 365.77 480 310.42 480 251.49a213.5 213.5 0 0 0-4.78-44.97zM160 288a32 32 0 1 1 32-32a32 32 0 0 1-32 32zm96 0a32 32 0 1 1 32-32a32 32 0 0 1-32 32zm96 0a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$eb = [_hoisted_2$gv];
    vue.defineComponent({
      name: 'ChatbubbleEllipsesSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gv, _hoisted_3$eb);
      }
    });

    const _hoisted_1$gu = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gu = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M87.49 380c1.19-4.38-1.44-10.47-3.95-14.86a44.86 44.86 0 0 0-2.54-3.8a199.81 199.81 0 0 1-33-110C47.65 139.09 140.73 48 255.83 48C356.21 48 440 117.54 459.58 209.85a199 199 0 0 1 4.42 41.64c0 112.41-89.49 204.93-204.59 204.93c-18.3 0-43-4.6-56.47-8.37s-26.92-8.77-30.39-10.11a31.09 31.09 0 0 0-11.12-2.07a30.71 30.71 0 0 0-12.09 2.43l-67.83 24.48a16 16 0 0 1-4.67 1.22a9.6 9.6 0 0 1-9.57-9.74a15.85 15.85 0 0 1 .6-3.29z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ea = [_hoisted_2$gu];
    vue.defineComponent({
      name: 'ChatbubbleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gu, _hoisted_3$ea);
      }
    });

    const _hoisted_1$gt = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gt = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M475.22 206.52c-10.34-48.65-37.76-92.93-77.22-124.68A227.4 227.4 0 0 0 255.82 32C194.9 32 138 55.47 95.46 98.09C54.35 139.33 31.82 193.78 32 251.37a215.66 215.66 0 0 0 35.65 118.76l4.35 6.05L48 480l114.8-28.56s2.3.77 4 1.42s16.33 6.26 31.85 10.6c12.9 3.6 39.74 9 60.77 9c59.65 0 115.35-23.1 156.83-65.06C457.36 365.77 480 310.42 480 251.49a213.5 213.5 0 0 0-4.78-44.97z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$e9 = [_hoisted_2$gt];
    vue.defineComponent({
      name: 'ChatbubbleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gt, _hoisted_3$e9);
      }
    });

    const _hoisted_1$gs = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gs = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M60.44 389.17c0 .07 0 .2-.08.38c.03-.12.05-.25.08-.38z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$e8 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M439.9 405.6a26.77 26.77 0 0 1-9.59-2l-56.78-20.13l-.42-.17a9.88 9.88 0 0 0-3.91-.76a10.32 10.32 0 0 0-3.62.66c-1.38.52-13.81 5.19-26.85 8.77c-7.07 1.94-31.68 8.27-51.43 8.27c-50.48 0-97.68-19.4-132.89-54.63A183.38 183.38 0 0 1 100.3 215.1a175.9 175.9 0 0 1 4.06-37.58c8.79-40.62 32.07-77.57 65.55-104A194.76 194.76 0 0 1 290.3 32c52.21 0 100.86 20 137 56.18c34.16 34.27 52.88 79.33 52.73 126.87a177.86 177.86 0 0 1-30.3 99.15l-.19.28l-.74 1c-.17.23-.34.45-.5.68l-.15.27a21.63 21.63 0 0 0-1.08 2.09l15.74 55.94a26.42 26.42 0 0 1 1.12 7.11a24 24 0 0 1-24.03 24.03z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8s = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M299.87 425.39a15.74 15.74 0 0 0-10.29-8.1c-5.78-1.53-12.52-1.27-17.67-1.65a201.78 201.78 0 0 1-128.82-58.75A199.21 199.21 0 0 1 86.4 244.16C85 234.42 85 232 85 232a16 16 0 0 0-28-10.58s-7.88 8.58-11.6 17.19a162.09 162.09 0 0 0 11 150.06C59 393 59 395 58.42 399.5c-2.73 14.11-7.51 39-10 51.91a24 24 0 0 0 8 22.92l.46.39A24.34 24.34 0 0 0 72 480a23.42 23.42 0 0 0 9-1.79l53.51-20.65a8.05 8.05 0 0 1 5.72 0c21.07 7.84 43 12 63.78 12a176 176 0 0 0 74.91-16.66c5.46-2.56 14-5.34 19-11.12a15 15 0 0 0 1.95-16.39z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$43 = [_hoisted_2$gs, _hoisted_3$e8, _hoisted_4$8s];
    vue.defineComponent({
      name: 'Chatbubbles',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gs, _hoisted_5$43);
      }
    });

    const _hoisted_1$gr = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gr = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M431 320.6c-1-3.6 1.2-8.6 3.3-12.2a33.68 33.68 0 0 1 2.1-3.1A162 162 0 0 0 464 215c.3-92.2-77.5-167-173.7-167c-83.9 0-153.9 57.1-170.3 132.9a160.7 160.7 0 0 0-3.7 34.2c0 92.3 74.8 169.1 171 169.1c15.3 0 35.9-4.6 47.2-7.7s22.5-7.2 25.4-8.3a26.44 26.44 0 0 1 9.3-1.7a26 26 0 0 1 10.1 2l56.7 20.1a13.52 13.52 0 0 0 3.9 1a8 8 0 0 0 8-8a12.85 12.85 0 0 0-.5-2.7z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$e7 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M66.46 232a146.23 146.23 0 0 0 6.39 152.67c2.31 3.49 3.61 6.19 3.21 8s-11.93 61.87-11.93 61.87a8 8 0 0 0 2.71 7.68A8.17 8.17 0 0 0 72 464a7.26 7.26 0 0 0 2.91-.6l56.21-22a15.7 15.7 0 0 1 12 .2c18.94 7.38 39.88 12 60.83 12A159.21 159.21 0 0 0 284 432.11',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8r = [_hoisted_2$gr, _hoisted_3$e7];
    vue.defineComponent({
      name: 'ChatbubblesOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gr, _hoisted_4$8r);
      }
    });

    const _hoisted_1$gq = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gq = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 312.43c.77-1.11 1.51-2.26 2.27-3.34A174.55 174.55 0 0 0 480 211.85C480.32 112.55 396.54 32 292.94 32c-90.36 0-165.74 61.49-183.4 143.12a172.81 172.81 0 0 0-4 36.83c0 99.4 80.56 182.11 184.16 182.11c16.47 0 38.66-4.95 50.83-8.29s24.23-7.75 27.35-8.94s8-2.41 11.89-1.29l77.42 22.38a4 4 0 0 0 5-4.86l-17.72-67.49c-1.23-5-1.39-5.94 3.53-13.14z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$e6 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M312.54 415.38a165.32 165.32 0 0 1-23.26 2.05c-42.43 0-82.5-11.2-115-32.2a184.09 184.09 0 0 1-53.09-49.32c-26.08-34.57-40.3-78.51-40.3-124.49c0-3.13.11-6.14.22-9.16a4.34 4.34 0 0 0-7.54-3.12a158.76 158.76 0 0 0-14.86 195.24c2.47 3.77 3.87 6.68 3.44 8.62l-14.09 72.26a4 4 0 0 0 5.22 4.53l68-24.24a16.85 16.85 0 0 1 12.92.22c20.35 8 42.86 12.92 65.37 12.92a169.45 169.45 0 0 0 116.63-46a4.29 4.29 0 0 0-3.66-7.31z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8q = [_hoisted_2$gq, _hoisted_3$e6];
    vue.defineComponent({
      name: 'ChatbubblesSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gq, _hoisted_4$8q);
      }
    });

    const _hoisted_1$gp = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gp = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400 48H112a64.07 64.07 0 0 0-64 64v288a64.07 64.07 0 0 0 64 64h288a64.07 64.07 0 0 0 64-64V112a64.07 64.07 0 0 0-64-64zm-35.75 138.29l-134.4 160a16 16 0 0 1-12 5.71h-.27a16 16 0 0 1-11.89-5.3l-57.6-64a16 16 0 1 1 23.78-21.4l45.29 50.32l122.59-145.91a16 16 0 0 1 24.5 20.58z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$e5 = [_hoisted_2$gp];
    vue.defineComponent({
      name: 'Checkbox',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gp, _hoisted_3$e5);
      }
    });

    const _hoisted_1$go = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$go = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M352 176L217.6 336L160 272'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$e4 = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '64',
      y: '64',
      width: '384',
      height: '384',
      rx: '48',
      ry: '48',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8p = [_hoisted_2$go, _hoisted_3$e4];
    vue.defineComponent({
      name: 'CheckboxOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$go, _hoisted_4$8p);
      }
    });

    const _hoisted_1$gn = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gn = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 48v416h416V48zm170 312.38l-80.6-89.57l23.79-21.41l56 62.22L350 153.46L374.54 174z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$e3 = [_hoisted_2$gn];
    vue.defineComponent({
      name: 'CheckboxSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gn, _hoisted_3$e3);
      }
    });

    const _hoisted_1$gm = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gm = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M416 128L192 384l-96-96'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$e2 = [_hoisted_2$gm];
    vue.defineComponent({
      name: 'Checkmark',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gm, _hoisted_3$e2);
      }
    });

    const _hoisted_1$gl = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gl = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm108.25 138.29l-134.4 160a16 16 0 0 1-12 5.71h-.27a16 16 0 0 1-11.89-5.3l-57.6-64a16 16 0 1 1 23.78-21.4l45.29 50.32l122.59-145.91a16 16 0 0 1 24.5 20.58z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$e1 = [_hoisted_2$gl];
    vue.defineComponent({
      name: 'CheckmarkCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gl, _hoisted_3$e1);
      }
    });

    const _hoisted_1$gk = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gk = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$e0 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M352 176L217.6 336L160 272'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8o = [_hoisted_2$gk, _hoisted_3$e0];
    vue.defineComponent({
      name: 'CheckmarkCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gk, _hoisted_4$8o);
      }
    });

    const _hoisted_1$gj = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gj = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm-38 312.38l-80.6-89.57l23.79-21.41l56 62.22L350 153.46L374.54 174z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$d$ = [_hoisted_2$gj];
    vue.defineComponent({
      name: 'CheckmarkCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gj, _hoisted_3$d$);
      }
    });

    const _hoisted_1$gi = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gi = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M464 128L240 384l-96-96'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$d_ = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M144 384l-96-96'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8n = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M368 128L232 284'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$42 = [_hoisted_2$gi, _hoisted_3$d_, _hoisted_4$8n];
    vue.defineComponent({
      name: 'CheckmarkDone',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gi, _hoisted_5$42);
      }
    });

    const _hoisted_1$gh = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gh = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M258.9 48C141.92 46.42 46.42 141.92 48 258.9c1.56 112.19 92.91 203.54 205.1 205.1c117 1.6 212.48-93.9 210.88-210.88C462.44 140.91 371.09 49.56 258.9 48zm-16.79 192.47l51.55-59a16 16 0 0 1 24.1 21.06l-51.55 59a16 16 0 1 1-24.1-21.06zm-38.86 90.85a16 16 0 0 1-22.62 0l-47.95-48a16 16 0 1 1 22.64-22.62l48 48a16 16 0 0 1-.07 22.62zm176.8-128.79l-111.88 128a16 16 0 0 1-11.51 5.47h-.54a16 16 0 0 1-11.32-4.69l-47.94-48a16 16 0 1 1 22.64-22.62l29.8 29.83a8 8 0 0 0 11.68-.39l95-108.66a16 16 0 0 1 24.1 21.06z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dZ = [_hoisted_2$gh];
    vue.defineComponent({
      name: 'CheckmarkDoneCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gh, _hoisted_3$dZ);
      }
    });

    const _hoisted_1$gg = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gg = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dY = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M368 192L256.13 320l-47.95-48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8m = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M191.95 320L144 272'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$41 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M305.71 192l-51.55 59'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1G = [_hoisted_2$gg, _hoisted_3$dY, _hoisted_4$8m, _hoisted_5$41];
    vue.defineComponent({
      name: 'CheckmarkDoneCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gg, _hoisted_6$1G);
      }
    });

    const _hoisted_1$gf = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gf = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm48.19 121.42l24.1 21.06l-73.61 84.1l-24.1-23.06zM191.93 342.63L121.37 272L144 249.37L214.57 320zm65 .79L185.55 272l22.64-22.62l47.16 47.21l111.13-127.17l24.1 21.06z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dX = [_hoisted_2$gf];
    vue.defineComponent({
      name: 'CheckmarkDoneCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gf, _hoisted_3$dX);
      }
    });

    const _hoisted_1$ge = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ge = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M464 128L240 384l-96-96'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dW = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M144 384l-96-96'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8l = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M368 128L232 284'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$40 = [_hoisted_2$ge, _hoisted_3$dW, _hoisted_4$8l];
    vue.defineComponent({
      name: 'CheckmarkDoneOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ge, _hoisted_5$40);
      }
    });

    const _hoisted_1$gd = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gd = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '44',
      d: 'M465 127L241 384l-92-92'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dV = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '44',
      d: 'M140 385l-93-93'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8k = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '44',
      d: 'M363 127L236 273'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3$ = [_hoisted_2$gd, _hoisted_3$dV, _hoisted_4$8k];
    vue.defineComponent({
      name: 'CheckmarkDoneSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gd, _hoisted_5$3$);
      }
    });

    const _hoisted_1$gc = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gc = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M416 128L192 384l-96-96'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dU = [_hoisted_2$gc];
    vue.defineComponent({
      name: 'CheckmarkOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gc, _hoisted_3$dU);
      }
    });

    const _hoisted_1$gb = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$gb = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '44',
      d: 'M416 128L192 384l-96-96'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dT = [_hoisted_2$gb];
    vue.defineComponent({
      name: 'CheckmarkSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$gb, _hoisted_3$dT);
      }
    });

    const _hoisted_1$ga = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ga = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M328 112L184 256l144 144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dS = [_hoisted_2$ga];
    vue.defineComponent({
      name: 'ChevronBack',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ga, _hoisted_3$dS);
      }
    });

    const _hoisted_1$g9 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$g9 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.13 48 48 141.13 48 256s93.13 208 208 208s208-93.13 208-208S370.87 48 256 48zm35.31 292.69a16 16 0 1 1-22.62 22.62l-96-96a16 16 0 0 1 0-22.62l96-96a16 16 0 0 1 22.62 22.62L206.63 256z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dR = [_hoisted_2$g9];
    vue.defineComponent({
      name: 'ChevronBackCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$g9, _hoisted_3$dR);
      }
    });

    const _hoisted_1$g8 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$g8 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 64C150 64 64 150 64 256s86 192 192 192s192-86 192-192S362 64 256 64z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dQ = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M296 352l-96-96l96-96'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8j = [_hoisted_2$g8, _hoisted_3$dQ];
    vue.defineComponent({
      name: 'ChevronBackCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$g8, _hoisted_4$8j);
      }
    });

    const _hoisted_1$g7 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$g7 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.13 48 48 141.13 48 256s93.13 208 208 208s208-93.13 208-208S370.87 48 256 48zm62.63 304L296 374.63L177.37 256L296 137.37L318.63 160l-96 96z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dP = [_hoisted_2$g7];
    vue.defineComponent({
      name: 'ChevronBackCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$g7, _hoisted_3$dP);
      }
    });

    const _hoisted_1$g6 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$g6 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M328 112L184 256l144 144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dO = [_hoisted_2$g6];
    vue.defineComponent({
      name: 'ChevronBackOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$g6, _hoisted_3$dO);
      }
    });

    const _hoisted_1$g5 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$g5 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '48',
      d: 'M328 112L184 256l144 144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dN = [_hoisted_2$g5];
    vue.defineComponent({
      name: 'ChevronBackSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$g5, _hoisted_3$dN);
      }
    });

    const _hoisted_1$g4 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$g4 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M112 184l144 144l144-144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dM = [_hoisted_2$g4];
    vue.defineComponent({
      name: 'ChevronDown',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$g4, _hoisted_3$dM);
      }
    });

    const _hoisted_1$g3 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$g3 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 256c0-114.87-93.13-208-208-208S48 141.13 48 256s93.13 208 208 208s208-93.13 208-208zm-100.69-28.69l-96 96a16 16 0 0 1-22.62 0l-96-96a16 16 0 0 1 22.62-22.62L256 289.37l84.69-84.68a16 16 0 0 1 22.62 22.62z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dL = [_hoisted_2$g3];
    vue.defineComponent({
      name: 'ChevronDownCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$g3, _hoisted_3$dL);
      }
    });

    const _hoisted_1$g2 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$g2 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 64C150 64 64 150 64 256s86 192 192 192s192-86 192-192S362 64 256 64z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dK = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M352 216l-96 96l-96-96'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8i = [_hoisted_2$g2, _hoisted_3$dK];
    vue.defineComponent({
      name: 'ChevronDownCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$g2, _hoisted_4$8i);
      }
    });

    const _hoisted_1$g1 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$g1 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 464c114.87 0 208-93.13 208-208S370.87 48 256 48S48 141.13 48 256s93.13 208 208 208zm-96-270.63l96 96l96-96L374.63 216L256 334.63L137.37 216z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dJ = [_hoisted_2$g1];
    vue.defineComponent({
      name: 'ChevronDownCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$g1, _hoisted_3$dJ);
      }
    });

    const _hoisted_1$g0 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$g0 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M112 184l144 144l144-144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dI = [_hoisted_2$g0];
    vue.defineComponent({
      name: 'ChevronDownOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$g0, _hoisted_3$dI);
      }
    });

    const _hoisted_1$f$ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$f$ = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '48',
      d: 'M112 184l144 144l144-144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dH = [_hoisted_2$f$];
    vue.defineComponent({
      name: 'ChevronDownSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$f$, _hoisted_3$dH);
      }
    });

    const _hoisted_1$f_ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$f_ = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M184 112l144 144l-144 144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dG = [_hoisted_2$f_];
    vue.defineComponent({
      name: 'ChevronForward',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$f_, _hoisted_3$dG);
      }
    });

    const _hoisted_1$fZ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fZ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 256c0 114.87 93.13 208 208 208s208-93.13 208-208S370.87 48 256 48S48 141.13 48 256zm257.37 0l-84.68-84.69a16 16 0 0 1 22.62-22.62l96 96a16 16 0 0 1 0 22.62l-96 96a16 16 0 0 1-22.62-22.62z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dF = [_hoisted_2$fZ];
    vue.defineComponent({
      name: 'ChevronForwardCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fZ, _hoisted_3$dF);
      }
    });

    const _hoisted_1$fY = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fY = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M64 256c0 106 86 192 192 192s192-86 192-192S362 64 256 64S64 150 64 256z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dE = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M216 352l96-96l-96-96'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8h = [_hoisted_2$fY, _hoisted_3$dE];
    vue.defineComponent({
      name: 'ChevronForwardCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fY, _hoisted_4$8h);
      }
    });

    const _hoisted_1$fX = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fX = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.13 48 48 141.13 48 256s93.13 208 208 208s208-93.13 208-208S370.87 48 256 48zm-40 326.63L193.37 352l96-96l-96-96L216 137.37L334.63 256z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dD = [_hoisted_2$fX];
    vue.defineComponent({
      name: 'ChevronForwardCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fX, _hoisted_3$dD);
      }
    });

    const _hoisted_1$fW = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fW = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M184 112l144 144l-144 144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dC = [_hoisted_2$fW];
    vue.defineComponent({
      name: 'ChevronForwardOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fW, _hoisted_3$dC);
      }
    });

    const _hoisted_1$fV = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fV = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '48',
      d: 'M184 112l144 144l-144 144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dB = [_hoisted_2$fV];
    vue.defineComponent({
      name: 'ChevronForwardSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fV, _hoisted_3$dB);
      }
    });

    const _hoisted_1$fU = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fU = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M112 328l144-144l144 144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dA = [_hoisted_2$fU];
    vue.defineComponent({
      name: 'ChevronUp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fU, _hoisted_3$dA);
      }
    });

    const _hoisted_1$fT = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fT = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.13 48 48 141.13 48 256s93.13 208 208 208s208-93.13 208-208S370.87 48 256 48zm107.31 259.31a16 16 0 0 1-22.62 0L256 222.63l-84.69 84.68a16 16 0 0 1-22.62-22.62l96-96a16 16 0 0 1 22.62 0l96 96a16 16 0 0 1 0 22.62z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dz = [_hoisted_2$fT];
    vue.defineComponent({
      name: 'ChevronUpCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fT, _hoisted_3$dz);
      }
    });

    const _hoisted_1$fS = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fS = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M352 296l-96-96l-96 96'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dy = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 64C150 64 64 150 64 256s86 192 192 192s192-86 192-192S362 64 256 64z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8g = [_hoisted_2$fS, _hoisted_3$dy];
    vue.defineComponent({
      name: 'ChevronUpCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fS, _hoisted_4$8g);
      }
    });

    const _hoisted_1$fR = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fR = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.13 48 48 141.13 48 256s93.13 208 208 208s208-93.13 208-208S370.87 48 256 48zm96 270.63l-96-96l-96 96L137.37 296L256 177.37L374.63 296z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dx = [_hoisted_2$fR];
    vue.defineComponent({
      name: 'ChevronUpCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fR, _hoisted_3$dx);
      }
    });

    const _hoisted_1$fQ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fQ = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M112 328l144-144l144 144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dw = [_hoisted_2$fQ];
    vue.defineComponent({
      name: 'ChevronUpOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fQ, _hoisted_3$dw);
      }
    });

    const _hoisted_1$fP = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fP = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '48',
      d: 'M112 328l144-144l144 144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dv = [_hoisted_2$fP];
    vue.defineComponent({
      name: 'ChevronUpSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fP, _hoisted_3$dv);
      }
    });

    const _hoisted_1$fO = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fO = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M368 48h-11.41a8 8 0 0 1-7.44-5.08A42.18 42.18 0 0 0 309.87 16H202.13a42.18 42.18 0 0 0-39.28 26.92a8 8 0 0 1-7.44 5.08H144a64 64 0 0 0-64 64v320a64 64 0 0 0 64 64h224a64 64 0 0 0 64-64V112a64 64 0 0 0-64-64zm-48.13 64H192.13a16 16 0 0 1 0-32h127.74a16 16 0 0 1 0 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$du = [_hoisted_2$fO];
    vue.defineComponent({
      name: 'Clipboard',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fO, _hoisted_3$du);
      }
    });

    const _hoisted_1$fN = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fN = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 64h32a48 48 0 0 1 48 48v320a48 48 0 0 1-48 48H144a48 48 0 0 1-48-48V112a48 48 0 0 1 48-48h32',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dt = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '176',
      y: '32',
      width: '160',
      height: '64',
      rx: '26.13',
      ry: '26.13',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8f = [_hoisted_2$fN, _hoisted_3$dt];
    vue.defineComponent({
      name: 'ClipboardOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fN, _hoisted_4$8f);
      }
    });

    const _hoisted_1$fM = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fM = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M420 48h-68V28a12 12 0 0 0-12-12H172a12 12 0 0 0-12 12v20H92a12 12 0 0 0-12 12v424a12 12 0 0 0 12 12h328a12 12 0 0 0 12-12V60a12 12 0 0 0-12-12zm-84.13 64H176.13V80h159.74z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ds = [_hoisted_2$fM];
    vue.defineComponent({
      name: 'ClipboardSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fM, _hoisted_3$ds);
      }
    });

    const _hoisted_1$fL = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fL = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M289.94 256l95-95A24 24 0 0 0 351 127l-95 95l-95-95a24 24 0 0 0-34 34l95 95l-95 95a24 24 0 1 0 34 34l95-95l95 95a24 24 0 0 0 34-34z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dr = [_hoisted_2$fL];
    vue.defineComponent({
      name: 'Close',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fL, _hoisted_3$dr);
      }
    });

    const _hoisted_1$fK = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fK = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm75.31 260.69a16 16 0 1 1-22.62 22.62L256 278.63l-52.69 52.68a16 16 0 0 1-22.62-22.62L233.37 256l-52.68-52.69a16 16 0 0 1 22.62-22.62L256 233.37l52.69-52.68a16 16 0 0 1 22.62 22.62L278.63 256z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dq = [_hoisted_2$fK];
    vue.defineComponent({
      name: 'CloseCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fK, _hoisted_3$dq);
      }
    });

    const _hoisted_1$fJ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fJ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dp = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M320 320L192 192'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8e = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M192 320l128-128'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3_ = [_hoisted_2$fJ, _hoisted_3$dp, _hoisted_4$8e];
    vue.defineComponent({
      name: 'CloseCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fJ, _hoisted_5$3_);
      }
    });

    const _hoisted_1$fI = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fI = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm86.63 272L320 342.63l-64-64l-64 64L169.37 320l64-64l-64-64L192 169.37l64 64l64-64L342.63 192l-64 64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$do = [_hoisted_2$fI];
    vue.defineComponent({
      name: 'CloseCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fI, _hoisted_3$do);
      }
    });

    const _hoisted_1$fH = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fH = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M368 368L144 144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dn = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M368 144L144 368'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8d = [_hoisted_2$fH, _hoisted_3$dn];
    vue.defineComponent({
      name: 'CloseOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fH, _hoisted_4$8d);
      }
    });

    const _hoisted_1$fG = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fG = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400 145.49L366.51 112L256 222.51L145.49 112L112 145.49L222.51 256L112 366.51L145.49 400L256 289.49L366.51 400L400 366.51L289.49 256L400 145.49z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dm = [_hoisted_2$fG];
    vue.defineComponent({
      name: 'CloseSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fG, _hoisted_3$dm);
      }
    });

    const _hoisted_1$fF = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fF = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M396 432H136c-36.44 0-70.36-12.57-95.51-35.41C14.38 372.88 0 340 0 304c0-36.58 13.39-68.12 38.72-91.22c18.11-16.53 42.22-28.25 69.18-33.87a16 16 0 0 0 11.37-9.15a156.24 156.24 0 0 1 42.05-56C187.76 91.69 220.5 80 256 80a153.57 153.57 0 0 1 107.14 42.9c24.73 23.81 41.5 55.28 49.18 92a16 16 0 0 0 12.12 12.39C470 237.42 512 270.43 512 328c0 33.39-12.24 60.78-35.41 79.23C456.23 423.43 428.37 432 396 432z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dl = [_hoisted_2$fF];
    vue.defineComponent({
      name: 'Cloud',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fF, _hoisted_3$dl);
      }
    });

    const _hoisted_1$fE = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fE = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.13 48 48 141.13 48 256s93.13 208 208 208s208-93.13 208-208S370.87 48 256 48zm70 280H193.05c-31.53 0-57.56-25.58-57-57.11c.53-31.74 23.68-49.95 51.35-54.3a7.92 7.92 0 0 0 6.16-5C202.07 189.22 223.63 168 256 168c33.17 0 61.85 22.49 70.14 60.21a17.75 17.75 0 0 0 13.18 13.43C357.79 246.05 376 259.21 376 284c0 30.28-22.5 44-50 44z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dk = [_hoisted_2$fE];
    vue.defineComponent({
      name: 'CloudCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fE, _hoisted_3$dk);
      }
    });

    const _hoisted_1$fD = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fD = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M333.88 240.59a8 8 0 0 1-6.66-6.66C320.68 192.78 290.82 168 256 168c-32.37 0-53.93 21.22-62.48 43.58a7.92 7.92 0 0 1-6.16 5c-27.67 4.35-50.82 22.56-51.35 54.3c-.52 31.53 25.51 57.11 57 57.11H326c27.5 0 50-13.72 50-44c0-27.22-22-40.41-42.12-43.4z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dj = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8c = [_hoisted_2$fD, _hoisted_3$dj];
    vue.defineComponent({
      name: 'CloudCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fD, _hoisted_4$8c);
      }
    });

    const _hoisted_1$fC = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fC = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.13 48 48 141.13 48 256s93.13 208 208 208s208-93.13 208-208S370.87 48 256 48zm70 280H196c-33 0-60-23-60-56c0-34.21 26-53 56-56c7.28-23.9 29.5-48 64-48c36.5 0 67.55 27.23 72 72c21.49 1.12 48 14.09 48 44c0 30.28-22.5 44-50 44z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$di = [_hoisted_2$fC];
    vue.defineComponent({
      name: 'CloudCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fC, _hoisted_3$di);
      }
    });

    const _hoisted_1$fB = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fB = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M424.44 227.25a16 16 0 0 1-12.12-12.39c-7.68-36.68-24.45-68.15-49.18-92A153.57 153.57 0 0 0 256 80c-35.5 0-68.24 11.69-94.68 33.8a156.24 156.24 0 0 0-42 56a16 16 0 0 1-11.37 9.15c-27 5.62-51.07 17.34-69.18 33.87C13.39 235.88 0 267.42 0 304c0 36 14.38 68.88 40.49 92.59C65.64 419.43 99.56 432 136 432h260c32.37 0 60.23-8.57 80.59-24.77C499.76 388.78 512 361.39 512 328c0-57.57-42-90.58-87.56-100.75zm-95.2-8.94l-107.8 128a16 16 0 0 1-12 5.69h-.27a16 16 0 0 1-11.88-5.28l-45.9-50.87c-5.77-6.39-5.82-16.33.3-22.4a16 16 0 0 1 23.16.63l33.9 37.58l96-114a16 16 0 1 1 24.48 20.62z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dh = [_hoisted_2$fB];
    vue.defineComponent({
      name: 'CloudDone',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fB, _hoisted_3$dh);
      }
    });

    const _hoisted_1$fA = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fA = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400 240c-8.89-89.54-71-144-144-144c-69 0-113.44 48.2-128 96c-60 6-112 43.59-112 112c0 66 54 112 120 112h260c55 0 100-27.44 100-88c0-59.82-53-85.76-96-88z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dg = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M317 208L209.2 336L163 284.8'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8b = [_hoisted_2$fA, _hoisted_3$dg];
    vue.defineComponent({
      name: 'CloudDoneOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fA, _hoisted_4$8b);
      }
    });

    const _hoisted_1$fz = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fz = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M414.25 225.36c-6.52-41.18-24.05-76.4-51.11-102.46A153.57 153.57 0 0 0 256 80c-35.5 0-68.24 11.69-94.68 33.8a156.42 156.42 0 0 0-45.22 63.61c-30.26 4.81-57.45 17.18-77.38 35.37C13.39 235.88 0 267.42 0 304c0 36 14.38 68.88 40.49 92.59C65.64 419.43 99.56 432 136 432h260c32.37 0 60.23-8.57 80.59-24.77C499.76 388.78 512 361.39 512 328c0-61.85-48.44-95.34-97.75-102.64zm-204.63 135l-69.22-76.7l23.76-21.44l44.62 49.46l106.29-126.2l24.47 20.61z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$df = [_hoisted_2$fz];
    vue.defineComponent({
      name: 'CloudDoneSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fz, _hoisted_3$df);
      }
    });

    const _hoisted_1$fy = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fy = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M472.7 189.5c-13.26-8.43-29.83-14.56-48.08-17.93A16 16 0 0 1 412 159.28c-7.86-34.51-24.6-64.13-49.15-86.58C334.15 46.45 296.21 32 256 32c-35.35 0-68 11.08-94.37 32a150.13 150.13 0 0 0-41.95 52.83A16.05 16.05 0 0 1 108 125.8c-27.13 4.9-50.53 14.68-68.41 28.7C13.7 174.83 0 203.56 0 237.6C0 305 55.93 352 136 352h104V224.45c0-8.61 6.62-16 15.23-16.43A16 16 0 0 1 272 224v128h124c72.64 0 116-34.24 116-91.6c0-30.05-13.59-54.57-39.3-70.9z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$de = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M240 425.42l-36.7-36.64a16 16 0 0 0-22.6 22.65l64 63.89a16 16 0 0 0 22.6 0l64-63.89a16 16 0 0 0-22.6-22.65L272 425.42V352h-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8a = [_hoisted_2$fy, _hoisted_3$de];
    vue.defineComponent({
      name: 'CloudDownload',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fy, _hoisted_4$8a);
      }
    });

    const _hoisted_1$fx = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fx = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 336h76c55 0 100-21.21 100-75.6s-53-73.47-96-75.6C391.11 99.74 329 48 256 48c-69 0-113.44 45.79-128 91.2c-60 5.7-112 35.88-112 98.4S70 336 136 336h56',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dd = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M192 400.1l64 63.9l64-63.9'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$89 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 224v224.03'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3Z = [_hoisted_2$fx, _hoisted_3$dd, _hoisted_4$89];
    vue.defineComponent({
      name: 'CloudDownloadOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fx, _hoisted_5$3Z);
      }
    });

    const _hoisted_1$fw = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fw = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M472.7 189.5c-15.76-10-36.21-16.79-58.59-19.54c-6.65-39.1-24.22-72.52-51.27-97.26C334.15 46.45 296.21 32 256 32c-35.35 0-68 11.08-94.37 32a149.7 149.7 0 0 0-45.29 60.42c-30.67 4.32-57 14.61-76.71 30C13.7 174.83 0 203.56 0 237.6C0 305 55.92 352 136 352h104V208h32v144h124c72.64 0 116-34.24 116-91.6c0-30.05-13.59-54.57-39.3-70.9z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$dc = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M240 419.42L191.98 371l-22.61 23L256 480l86.63-86l-22.61-23L272 419.42V352h-32v67.42z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$88 = [_hoisted_2$fw, _hoisted_3$dc];
    vue.defineComponent({
      name: 'CloudDownloadSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fw, _hoisted_4$88);
      }
    });

    const _hoisted_1$fv = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fv = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 464a15.92 15.92 0 0 1-11.31-4.69l-384-384a16 16 0 0 1 22.62-22.62l384 384A16 16 0 0 1 448 464z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$db = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M38.72 196.78C13.39 219.88 0 251.42 0 288c0 36 14.38 68.88 40.49 92.59C65.64 403.43 99.56 416 136 416h192.8a8 8 0 0 0 5.66-13.66L100.88 168.76a8 8 0 0 0-8-2C72 173.15 53.4 183.38 38.72 196.78z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$87 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M476.59 391.23C499.76 372.78 512 345.39 512 312c0-57.57-42-90.58-87.56-100.75a16 16 0 0 1-12.12-12.39c-7.68-36.68-24.45-68.15-49.18-92A153.57 153.57 0 0 0 256 64c-31.12 0-60.12 9-84.62 26.1a8 8 0 0 0-1.14 12.26L461.68 393.8a8 8 0 0 0 10.2.93q2.43-1.68 4.71-3.5z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3Y = [_hoisted_2$fv, _hoisted_3$db, _hoisted_4$87];
    vue.defineComponent({
      name: 'CloudOffline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fv, _hoisted_5$3Y);
      }
    });

    const _hoisted_1$fu = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fu = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M93.72 183.25C49.49 198.05 16 233.1 16 288c0 66 54 112 120 112h184.37',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$da = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M467.82 377.74C485.24 363.3 496 341.61 496 312c0-59.82-53-85.76-96-88c-8.89-89.54-71-144-144-144c-26.16 0-48.79 6.93-67.6 18.14',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$86 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M448 448L64 64'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3X = [_hoisted_2$fu, _hoisted_3$da, _hoisted_4$86];
    vue.defineComponent({
      name: 'CloudOfflineOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fu, _hoisted_5$3X);
      }
    });

    const _hoisted_1$ft = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ft = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M41.37 64l22.628-22.628L470.627 448l-22.628 22.627z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$d9 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M38.72 212.78C13.39 235.88 0 267.42 0 304c0 36 14.38 68.88 40.49 92.59C65.64 419.43 99.56 432 136 432h228.12L110.51 178.39c-28.01 5.39-53.09 17.33-71.79 34.39z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$85 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M476.59 407.23C499.76 388.78 512 361.39 512 328c0-61.85-48.44-95.34-97.75-102.64c-6.52-41.18-24.05-76.4-51.11-102.46A153.57 153.57 0 0 0 256 80c-30.47 0-58.9 8.62-83.07 25l302.82 302.86c.25-.21.57-.41.84-.63z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3W = [_hoisted_2$ft, _hoisted_3$d9, _hoisted_4$85];
    vue.defineComponent({
      name: 'CloudOfflineSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ft, _hoisted_5$3W);
      }
    });

    const _hoisted_1$fs = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fs = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400 240c-8.89-89.54-71-144-144-144c-69 0-113.44 48.2-128 96c-60 6-112 43.59-112 112c0 66 54 112 120 112h260c55 0 100-27.44 100-88c0-59.82-53-85.76-96-88z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$d8 = [_hoisted_2$fs];
    vue.defineComponent({
      name: 'CloudOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fs, _hoisted_3$d8);
      }
    });

    const _hoisted_1$fr = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fr = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M396 432H136c-36.44 0-70.36-12.57-95.51-35.41C14.38 372.88 0 340 0 304c0-36.58 13.39-68.12 38.72-91.22c19.93-18.19 47.12-30.56 77.38-35.37a156.42 156.42 0 0 1 45.22-63.61C187.76 91.69 220.5 80 256 80a153.57 153.57 0 0 1 107.14 42.9c27.06 26.06 44.59 61.28 51.11 102.46C463.56 232.66 512 266.15 512 328c0 33.39-12.24 60.78-35.41 79.23C456.23 423.43 428.37 432 396 432z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$d7 = [_hoisted_2$fr];
    vue.defineComponent({
      name: 'CloudSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fr, _hoisted_3$d7);
      }
    });

    const _hoisted_1$fq = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fq = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M473.66 210c-14-10.38-31.2-18-49.36-22.11a16.11 16.11 0 0 1-12.19-12.22c-7.8-34.75-24.59-64.55-49.27-87.13C334.15 62.25 296.21 47.79 256 47.79c-35.35 0-68 11.08-94.37 32.05a150.07 150.07 0 0 0-42.06 53a16 16 0 0 1-11.31 8.87c-26.75 5.4-50.9 16.87-69.34 33.12C13.46 197.33 0 227.24 0 261.39c0 34.52 14.49 66 40.79 88.76c25.12 21.69 58.94 33.64 95.21 33.64h104V230.42l-36.69 36.69a16 16 0 0 1-23.16-.56c-5.8-6.37-5.24-16.3.85-22.39l63.69-63.68a16 16 0 0 1 22.62 0L331 244.14c6.28 6.29 6.64 16.6.39 22.91a16 16 0 0 1-22.68.06L272 230.42v153.37h124c31.34 0 59.91-8.8 80.45-24.77c23.26-18.1 35.55-44 35.55-74.83c0-29.94-13.26-55.61-38.34-74.19z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$d6 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M240 448.21a16 16 0 1 0 32 0v-64.42h-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$84 = [_hoisted_2$fq, _hoisted_3$d6];
    vue.defineComponent({
      name: 'CloudUpload',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fq, _hoisted_4$84);
      }
    });

    const _hoisted_1$fp = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fp = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 367.79h76c55 0 100-29.21 100-83.6s-53-81.47-96-83.6c-8.89-85.06-71-136.8-144-136.8c-69 0-113.44 45.79-128 91.2c-60 5.7-112 43.88-112 106.4s54 106.4 120 106.4h56',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$d5 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M320 255.79l-64-64l-64 64'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$83 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 448.21V207.79'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3V = [_hoisted_2$fp, _hoisted_3$d5, _hoisted_4$83];
    vue.defineComponent({
      name: 'CloudUploadOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fp, _hoisted_5$3V);
      }
    });

    const _hoisted_1$fo = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fo = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M473.66 210c-16.56-12.3-37.7-20.75-59.52-24c-6.62-39.18-24.21-72.67-51.3-97.45c-28.69-26.3-66.63-40.76-106.84-40.76c-35.35 0-68 11.08-94.37 32.05a149.61 149.61 0 0 0-45.32 60.49c-29.94 4.6-57.12 16.68-77.39 34.55C13.46 197.33 0 227.24 0 261.39c0 34.52 14.49 66 40.79 88.76c25.12 21.69 58.94 33.64 95.21 33.64h104V230.42l-48 48l-22.63-22.63L256 169.17l86.63 86.62L320 278.42l-48-48v153.37h124c31.34 0 59.91-8.8 80.45-24.77c23.26-18.1 35.55-44 35.55-74.83c0-29.94-13.26-55.61-38.34-74.19z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$d4 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M240 383.79h32v80.41h-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$82 = [_hoisted_2$fo, _hoisted_3$d4];
    vue.defineComponent({
      name: 'CloudUploadSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fo, _hoisted_4$82);
      }
    });

    const _hoisted_1$fn = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fn = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M376 432H116c-32.37 0-60.23-8.57-80.59-24.77C12.24 388.78 0 361.39 0 328c0-57.57 42-90.58 87.56-100.75a16 16 0 0 0 12.12-12.39c7.68-36.68 24.45-68.15 49.18-92A153.57 153.57 0 0 1 256 80c35.5 0 68.24 11.69 94.68 33.8a156.24 156.24 0 0 1 42.05 56a16 16 0 0 0 11.37 9.16c27 5.61 51.07 17.33 69.18 33.85C498.61 235.88 512 267.42 512 304c0 36-14.38 68.88-40.49 92.59C446.36 419.43 412.44 432 376 432z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$d3 = [_hoisted_2$fn];
    vue.defineComponent({
      name: 'Cloudy',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fn, _hoisted_3$d3);
      }
    });

    const _hoisted_1$fm = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fm = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M340 480H106c-29.5 0-54.92-7.83-73.53-22.64C11.23 440.44 0 415.35 0 384.8c0-29.44 12.09-54.25 35-71.74c12.1-9.26 27.2-16.17 43.33-20.05a16 16 0 0 0 11.81-12.21c7.15-32.54 22.25-60.49 44.33-81.75A139.82 139.82 0 0 1 232 160c32.33 0 62.15 10.65 86.24 30.79a142.22 142.22 0 0 1 37.65 49.54a16.06 16.06 0 0 0 11.12 9c24 5.22 45.42 15.78 61.62 30.56C451.77 301 464 329.82 464 363.2c0 32.85-13.13 62.87-37 84.52c-22.89 20.82-53.8 32.28-87 32.28z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$d2 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M510.53 209.79a16.34 16.34 0 0 0-1.35-15.8a16 16 0 0 0-19.57-5.58c-10.7 4.65-24.48 7.17-39.92 7.28c-55.3.4-101.38-45-101.38-100.31c0-15.75 2.48-29.84 7.18-40.76a16.3 16.3 0 0 0-1.85-16.33a16 16 0 0 0-19.1-5c-38.63 16.82-66.18 51.51-75.27 92.54a4 4 0 0 0 3.19 4.79a162.54 162.54 0 0 1 76.31 35.59a172.58 172.58 0 0 1 39.64 47.84a16.35 16.35 0 0 0 9.54 7.64c23.89 7.17 45.1 18.9 62.25 34.54q4.44 4.07 8.48 8.42a4 4 0 0 0 5.16.57a129.12 129.12 0 0 0 46.69-55.43z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$81 = [_hoisted_2$fm, _hoisted_3$d2];
    vue.defineComponent({
      name: 'CloudyNight',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fm, _hoisted_4$81);
      }
    });

    const _hoisted_1$fl = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fl = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M388.31 272c47.75 0 89.77-27.77 107.69-68.92c-14.21 6.18-30.9 8.61-47.38 8.61A116.31 116.31 0 0 1 332.31 95.38c0-16.48 2.43-33.17 8.61-47.38C299.77 65.92 272 107.94 272 155.69a116.31 116.31 0 0 0 3.44 28.18',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$d1 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M90.61 306.85A16.07 16.07 0 0 0 104 293.6C116.09 220.17 169.63 176 232 176c57.93 0 96.62 37.75 112.2 77.74a15.84 15.84 0 0 0 12.2 9.87c50 8.15 91.6 41.54 91.6 99.59c0 59.4-48.6 100.8-108 100.8H106c-49.5 0-90-24.7-90-79.2c0-48.47 38.67-72.22 74.61-77.95z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$80 = [_hoisted_2$fl, _hoisted_3$d1];
    vue.defineComponent({
      name: 'CloudyNightOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fl, _hoisted_4$80);
      }
    });

    const _hoisted_1$fk = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fk = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M340 480H106c-29.5 0-54.92-7.83-73.53-22.64C11.23 440.44 0 415.35 0 384.8c0-29.44 12.09-54.25 35-71.74c14.55-11.13 33.41-18.87 53.2-22c6.06-36.92 21.92-68.53 46.29-92A139.82 139.82 0 0 1 232 160c32.33 0 62.15 10.65 86.24 30.79a142.41 142.41 0 0 1 40.83 57.05c27.18 4.48 51.59 15.68 69.56 32.08C451.77 301 464 329.82 464 363.2c0 32.85-13.13 62.87-37 84.52c-22.89 20.82-53.8 32.28-87 32.28z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$d0 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M381.55 219.93c26.5 6.93 50 19.32 68.65 36.34q3.89 3.56 7.47 7.34c25.41-18.4 45.47-44.92 54.33-71.38c-16.24 7.07-35.31 9.85-54.15 9.85c-73.42 0-115.93-42.51-115.93-115.93c0-18.84 2.78-37.91 9.85-54.15c-40.41 13.53-81 53.19-92.52 98.13a162.61 162.61 0 0 1 79.52 36.12a173 173 0 0 1 42.78 53.68z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7$ = [_hoisted_2$fk, _hoisted_3$d0];
    vue.defineComponent({
      name: 'CloudyNightSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fk, _hoisted_4$7$);
      }
    });

    const _hoisted_1$fj = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fj = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M100.18 241.19a15.93 15.93 0 0 0 13.37-13.25C126.6 145.59 186.34 96 256 96c64.69 0 107.79 42.36 124.92 87a16.11 16.11 0 0 0 12.53 10.18C449.36 202.06 496 239.21 496 304c0 66-54 112-120 112H116c-55 0-100-27.44-100-88c0-54.43 43.89-80.81 84.18-86.81z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$c$ = [_hoisted_2$fj];
    vue.defineComponent({
      name: 'CloudyOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fj, _hoisted_3$c$);
      }
    });

    const _hoisted_1$fi = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fi = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M376 432H116c-32.37 0-60.23-8.57-80.59-24.77C12.24 388.78 0 361.39 0 328c0-61.85 48.44-95.34 97.75-102.64c6.52-41.18 24-76.4 51.11-102.46A153.57 153.57 0 0 1 256 80c35.5 0 68.24 11.69 94.68 33.8a156.42 156.42 0 0 1 45.22 63.61c30.26 4.81 57.45 17.18 77.38 35.36C498.61 235.88 512 267.42 512 304c0 36-14.38 68.88-40.49 92.59C446.36 419.43 412.44 432 376 432z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$c_ = [_hoisted_2$fi];
    vue.defineComponent({
      name: 'CloudySharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fi, _hoisted_3$c_);
      }
    });

    const _hoisted_1$fh = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fh = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M160 389a20.91 20.91 0 0 1-13.82-5.2l-128-112a21 21 0 0 1 0-31.6l128-112a21 21 0 0 1 27.66 31.61L63.89 256l109.94 96.19A21 21 0 0 1 160 389z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cZ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M352 389a21 21 0 0 1-13.84-36.81L448.11 256l-109.94-96.19a21 21 0 0 1 27.66-31.61l128 112a21 21 0 0 1 0 31.6l-128 112A20.89 20.89 0 0 1 352 389z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7_ = [_hoisted_2$fh, _hoisted_3$cZ];
    vue.defineComponent({
      name: 'Code',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fh, _hoisted_4$7_);
      }
    });

    const _hoisted_1$fg = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fg = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '42',
      d: 'M160 368L32 256l128-112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cY = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '42',
      d: 'M352 368l128-112l-128-112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7Z = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '42',
      d: 'M192 288.1l64 63.9l64-63.9'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3U = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '42',
      d: 'M256 160v176.03'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1F = [_hoisted_2$fg, _hoisted_3$cY, _hoisted_4$7Z, _hoisted_5$3U];
    vue.defineComponent({
      name: 'CodeDownload',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fg, _hoisted_6$1F);
      }
    });

    const _hoisted_1$ff = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ff = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M160 368L32 256l128-112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cX = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M352 368l128-112l-128-112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7Y = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M192 288.1l64 63.9l64-63.9'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3T = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 160v176.03'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1E = [_hoisted_2$ff, _hoisted_3$cX, _hoisted_4$7Y, _hoisted_5$3T];
    vue.defineComponent({
      name: 'CodeDownloadOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ff, _hoisted_6$1E);
      }
    });

    const _hoisted_1$fe = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fe = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '42',
      d: 'M160 368L32 256l128-112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cW = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '42',
      d: 'M352 368l128-112l-128-112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7X = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '42',
      d: 'M192 288.1l64 63.9l64-63.9'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3S = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '42',
      d: 'M256 160v176.03'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1D = [_hoisted_2$fe, _hoisted_3$cW, _hoisted_4$7X, _hoisted_5$3S];
    vue.defineComponent({
      name: 'CodeDownloadSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fe, _hoisted_6$1D);
      }
    });

    const _hoisted_1$fd = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fd = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M160 368L32 256l128-112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cV = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M352 368l128-112l-128-112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7W = [_hoisted_2$fd, _hoisted_3$cV];
    vue.defineComponent({
      name: 'CodeOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fd, _hoisted_4$7W);
      }
    });

    const _hoisted_1$fc = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fc = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M161.98 397.63L0 256l161.98-141.63l27.65 31.61L64 256l125.63 110.02l-27.65 31.61z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cU = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M350.02 397.63l-27.65-31.61L448 256L322.37 145.98l27.65-31.61L512 256L350.02 397.63z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7V = [_hoisted_2$fc, _hoisted_3$cU];
    vue.defineComponent({
      name: 'CodeSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fc, _hoisted_4$7V);
      }
    });

    const _hoisted_1$fb = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fb = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M160 389a20.91 20.91 0 0 1-13.82-5.2l-128-112a21 21 0 0 1 0-31.6l128-112a21 21 0 0 1 27.66 31.61L63.89 256l109.94 96.19A21 21 0 0 1 160 389z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cT = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M352 389a21 21 0 0 1-13.84-36.81L448.11 256l-109.94-96.19a21 21 0 0 1 27.66-31.61l128 112a21 21 0 0 1 0 31.6l-128 112A20.89 20.89 0 0 1 352 389z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7U = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M208 437a21 21 0 0 1-20.12-27l96-320a21 21 0 1 1 40.23 12l-96 320A21 21 0 0 1 208 437z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3R = [_hoisted_2$fb, _hoisted_3$cT, _hoisted_4$7U];
    vue.defineComponent({
      name: 'CodeSlash',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fb, _hoisted_5$3R);
      }
    });

    const _hoisted_1$fa = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$fa = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M160 368L32 256l128-112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cS = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M352 368l128-112l-128-112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7T = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M304 96l-96 320'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3Q = [_hoisted_2$fa, _hoisted_3$cS, _hoisted_4$7T];
    vue.defineComponent({
      name: 'CodeSlashOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$fa, _hoisted_5$3Q);
      }
    });

    const _hoisted_1$f9 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$f9 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M161.98 397.63L0 256l161.98-141.63l27.65 31.61L64 256l125.63 110.02l-27.65 31.61z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cR = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M350.02 397.63l-27.65-31.61L448 256L322.37 145.98l27.65-31.61L512 256L350.02 397.63z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7S = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M222.15 442L182 430.08L289.85 70L330 81.92L222.15 442z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3P = [_hoisted_2$f9, _hoisted_3$cR, _hoisted_4$7S];
    vue.defineComponent({
      name: 'CodeSlashSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$f9, _hoisted_5$3P);
      }
    });

    const _hoisted_1$f8 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$f8 = /*#__PURE__*/vue.createStaticVNode('<circle cx="256" cy="256" r="26" stroke="currentColor" stroke-miterlimit="10" stroke-width="10" fill="currentColor"></circle><circle cx="346" cy="256" r="26" stroke="currentColor" stroke-miterlimit="10" stroke-width="10" fill="currentColor"></circle><circle cx="166" cy="256" r="26" stroke="currentColor" stroke-miterlimit="10" stroke-width="10" fill="currentColor"></circle><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="42" d="M160 368L32 256l128-112"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="42" d="M352 368l128-112l-128-112"></path>', 5);

    const _hoisted_7$W = [_hoisted_2$f8];
    vue.defineComponent({
      name: 'CodeWorking',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$f8, _hoisted_7$W);
      }
    });

    const _hoisted_1$f7 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$f7 = /*#__PURE__*/vue.createStaticVNode('<circle cx="256" cy="256" r="26" fill="currentColor"></circle><circle cx="346" cy="256" r="26" fill="currentColor"></circle><circle cx="166" cy="256" r="26" fill="currentColor"></circle><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M160 368L32 256l128-112"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M352 368l128-112l-128-112"></path>', 5);

    const _hoisted_7$V = [_hoisted_2$f7];
    vue.defineComponent({
      name: 'CodeWorkingOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$f7, _hoisted_7$V);
      }
    });

    const _hoisted_1$f6 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$f6 = /*#__PURE__*/vue.createStaticVNode('<circle cx="256" cy="256" r="26" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="10" fill="currentColor"></circle><circle cx="346" cy="256" r="26" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="10" fill="currentColor"></circle><circle cx="166" cy="256" r="26" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="10" fill="currentColor"></circle><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="42" d="M160 368L32 256l128-112"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="42" d="M352 368l128-112l-128-112"></path>', 5);

    const _hoisted_7$U = [_hoisted_2$f6];
    vue.defineComponent({
      name: 'CodeWorkingSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$f6, _hoisted_7$U);
      }
    });

    const _hoisted_1$f5 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$f5 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 249.93a10.58 10.58 0 0 0-9.36-9.94L429 235.84a5.42 5.42 0 0 1-4.5-4.67c-.49-3.15-1-6.42-1.7-9.52a5.52 5.52 0 0 1 2.63-5.85l22.78-12.65a10.35 10.35 0 0 0 5-12.83l-3.95-10.9a10.32 10.32 0 0 0-12.13-6.51l-25.55 5a5.51 5.51 0 0 1-5.82-2.81c-1.49-2.79-3.11-5.63-4.8-8.42a5.6 5.6 0 0 1 .44-6.5l17-19.64a10.42 10.42 0 0 0 .39-13.76l-7.42-8.91a10.24 10.24 0 0 0-13.58-2l-22.37 13.43a5.39 5.39 0 0 1-6.39-.63c-2.47-2.17-5-4.26-7.37-6.19a5.45 5.45 0 0 1-1.72-6.21l9.26-24.4a10.35 10.35 0 0 0-4.31-13.07l-10.09-5.89a10.3 10.3 0 0 0-13.45 2.83L325 96.28a4.6 4.6 0 0 1-5.6 1.72c-.61-.25-5.77-2.36-9.78-3.7a5.42 5.42 0 0 1-3.74-5.23l.39-26.07a10.48 10.48 0 0 0-8.57-10.88l-11.45-2a10.45 10.45 0 0 0-11.75 7.17L266 82.1a5.46 5.46 0 0 1-5.36 3.65h-9.75a5.5 5.5 0 0 1-5.3-3.67l-8.46-24.67a10.46 10.46 0 0 0-11.77-7.25l-11.47 2a10.46 10.46 0 0 0-8.56 10.79l.4 26.16a5.45 5.45 0 0 1-3.86 5.25c-2.29.89-7.26 2.79-9.52 3.63c-2 .72-4.18-.07-5.94-2.1l-16.26-20A10.3 10.3 0 0 0 156.69 73l-10.06 5.83A10.36 10.36 0 0 0 142.31 92l9.25 24.34a5.54 5.54 0 0 1-1.7 6.23c-2.43 2-4.92 4-7.4 6.22a5.38 5.38 0 0 1-6.35.64L114 115.74a10.4 10.4 0 0 0-13.61 2L93 126.63a10.31 10.31 0 0 0 .37 13.75L110.45 160a5.42 5.42 0 0 1 .45 6.45c-1.71 2.72-3.34 5.58-4.82 8.44a5.53 5.53 0 0 1-5.86 2.82l-25.51-4.93a10.34 10.34 0 0 0-12.14 6.51l-4 10.88a10.38 10.38 0 0 0 5 12.85l22.78 12.65a5.39 5.39 0 0 1 2.65 5.92l-.24 1.27c-.52 2.79-1 5.43-1.46 8.24a5.48 5.48 0 0 1-4.46 4.64l-25.69 4.15A10.42 10.42 0 0 0 48 250.16v11.58A10.26 10.26 0 0 0 57.16 272l25.68 4.14a5.41 5.41 0 0 1 4.5 4.67c.49 3.16 1 6.42 1.7 9.52a5.52 5.52 0 0 1-2.63 5.85l-22.77 12.67a10.35 10.35 0 0 0-5 12.83l4 10.9a10.33 10.33 0 0 0 12.13 6.51l25.55-4.95a5.49 5.49 0 0 1 5.82 2.81c1.5 2.8 3.11 5.63 4.8 8.42a5.58 5.58 0 0 1-.44 6.5l-17 19.63a10.41 10.41 0 0 0-.5 13.77l7.41 8.91a10.23 10.23 0 0 0 13.58 2l22.37-13.43a5.39 5.39 0 0 1 6.39.63c2.48 2.17 5 4.26 7.37 6.19a5.47 5.47 0 0 1 1.73 6.21l-9.27 24.4a10.35 10.35 0 0 0 4.31 13.07l10.11 5.84a10.3 10.3 0 0 0 13.45-2.82L187 415.92c1.4-1.73 3.6-2.5 5.23-1.84c3.48 1.44 5.81 2.25 9.94 3.63a5.44 5.44 0 0 1 3.75 5.23l-.4 26.05a10.5 10.5 0 0 0 8.57 10.88l11.45 2a10.43 10.43 0 0 0 11.75-7.17l8.5-24.77a5.45 5.45 0 0 1 5.36-3.65h9.75a5.49 5.49 0 0 1 5.3 3.67l8.47 24.67a10.48 10.48 0 0 0 10 7.41a9.74 9.74 0 0 0 1.78-.16l11.47-2a10.46 10.46 0 0 0 8.56-10.79l-.4-26.16a5.43 5.43 0 0 1 3.75-5.2c3.84-1.29 6.54-2.33 8.91-3.25l.6-.23c3.1-1.07 4.6.23 5.47 1.31l16.75 20.63A10.3 10.3 0 0 0 355 439l10.07-5.83a10.35 10.35 0 0 0 4.31-13.1l-9.24-24.34a5.52 5.52 0 0 1 1.69-6.23c2.43-2 4.92-4 7.4-6.22a5.39 5.39 0 0 1 6.38-.62l22.39 13.4a10.39 10.39 0 0 0 13.61-2l7.4-8.9a10.31 10.31 0 0 0-.37-13.75l-17.06-19.67a5.42 5.42 0 0 1-.45-6.45c1.71-2.71 3.34-5.57 4.82-8.44a5.55 5.55 0 0 1 5.86-2.82l25.48 4.97a10.34 10.34 0 0 0 12.14-6.51l3.95-10.88a10.37 10.37 0 0 0-5-12.84l-22.8-12.67a5.4 5.4 0 0 1-2.61-5.89l.24-1.27c.52-2.79 1-5.43 1.46-8.24a5.48 5.48 0 0 1 4.46-4.64l25.69-4.14a10.43 10.43 0 0 0 9.18-10.28v-11.71zm-282.45 94a15.8 15.8 0 0 1-25.47 2.66a135.06 135.06 0 0 1 .42-181.65a15.81 15.81 0 0 1 25.5 2.77l45.65 80.35a15.85 15.85 0 0 1 0 15.74zM256 391.11a134.75 134.75 0 0 1-28.31-3a15.81 15.81 0 0 1-10.23-23.36l46-80a15.79 15.79 0 0 1 13.7-7.93h92.14a15.8 15.8 0 0 1 15.1 20.53c-17.49 54.32-68.4 93.76-128.4 93.76zm7.51-163.9L218 147.07a15.81 15.81 0 0 1 10.31-23.3a134 134 0 0 1 27.69-2.88c60 0 110.91 39.44 128.37 93.79a15.8 15.8 0 0 1-15.1 20.53h-92a15.78 15.78 0 0 1-13.76-8z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cQ = [_hoisted_2$f5];
    vue.defineComponent({
      name: 'Cog',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$f5, _hoisted_3$cQ);
      }
    });

    const _hoisted_1$f4 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$f4 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M456.7 242.27l-26.08-4.2a8 8 0 0 1-6.6-6.82c-.5-3.2-1-6.41-1.7-9.51a8.08 8.08 0 0 1 3.9-8.62l23.09-12.82a8.05 8.05 0 0 0 3.9-9.92l-4-11a7.94 7.94 0 0 0-9.4-5l-25.89 5a8 8 0 0 1-8.59-4.11q-2.25-4.2-4.8-8.41a8.16 8.16 0 0 1 .7-9.52l17.29-19.94a8 8 0 0 0 .3-10.62l-7.49-9a7.88 7.88 0 0 0-10.5-1.51l-22.69 13.63a8 8 0 0 1-9.39-.9c-2.4-2.11-4.9-4.21-7.4-6.22a8 8 0 0 1-2.5-9.11l9.4-24.75A8 8 0 0 0 365 78.77l-10.2-5.91a8 8 0 0 0-10.39 2.21l-16.64 20.84a7.15 7.15 0 0 1-8.5 2.5s-5.6-2.3-9.8-3.71A8 8 0 0 1 304 87l.4-26.45a8.07 8.07 0 0 0-6.6-8.42l-11.59-2a8.07 8.07 0 0 0-9.1 5.61l-8.6 25.05a8 8 0 0 1-7.79 5.41h-9.8a8.07 8.07 0 0 1-7.79-5.41l-8.6-25.05a8.07 8.07 0 0 0-9.1-5.61l-11.59 2a8.07 8.07 0 0 0-6.6 8.42l.4 26.45a8 8 0 0 1-5.49 7.71c-2.3.9-7.3 2.81-9.7 3.71c-2.8 1-6.1.2-8.8-2.91l-16.51-20.34A8 8 0 0 0 156.75 73l-10.2 5.91a7.94 7.94 0 0 0-3.3 10.09l9.4 24.75a8.06 8.06 0 0 1-2.5 9.11c-2.5 2-5 4.11-7.4 6.22a8 8 0 0 1-9.39.9L111 116.14a8 8 0 0 0-10.5 1.51l-7.49 9a8 8 0 0 0 .3 10.62l17.29 19.94a8 8 0 0 1 .7 9.52q-2.55 4-4.8 8.41a8.11 8.11 0 0 1-8.59 4.11l-25.89-5a8 8 0 0 0-9.4 5l-4 11a8.05 8.05 0 0 0 3.9 9.92L85.58 213a7.94 7.94 0 0 1 3.9 8.62c-.6 3.2-1.2 6.31-1.7 9.51a8.08 8.08 0 0 1-6.6 6.82l-26.08 4.2a8.09 8.09 0 0 0-7.1 7.92v11.72a7.86 7.86 0 0 0 7.1 7.92l26.08 4.2a8 8 0 0 1 6.6 6.82c.5 3.2 1 6.41 1.7 9.51a8.08 8.08 0 0 1-3.9 8.62L62.49 311.7a8.05 8.05 0 0 0-3.9 9.92l4 11a7.94 7.94 0 0 0 9.4 5l25.89-5a8 8 0 0 1 8.59 4.11q2.25 4.2 4.8 8.41a8.16 8.16 0 0 1-.7 9.52l-17.29 19.96a8 8 0 0 0-.3 10.62l7.49 9a7.88 7.88 0 0 0 10.5 1.51l22.69-13.63a8 8 0 0 1 9.39.9c2.4 2.11 4.9 4.21 7.4 6.22a8 8 0 0 1 2.5 9.11l-9.4 24.75a8 8 0 0 0 3.3 10.12l10.2 5.91a8 8 0 0 0 10.39-2.21l16.79-20.64c2.1-2.6 5.5-3.7 8.2-2.6c3.4 1.4 5.7 2.2 9.9 3.61a8 8 0 0 1 5.49 7.71l-.4 26.45a8.07 8.07 0 0 0 6.6 8.42l11.59 2a8.07 8.07 0 0 0 9.1-5.61l8.6-25a8 8 0 0 1 7.79-5.41h9.8a8.07 8.07 0 0 1 7.79 5.41l8.6 25a8.07 8.07 0 0 0 9.1 5.61l11.59-2a8.07 8.07 0 0 0 6.6-8.42l-.4-26.45a8 8 0 0 1 5.49-7.71c4.2-1.41 7-2.51 9.6-3.51s5.8-1 8.3 2.1l17 20.94A8 8 0 0 0 355 439l10.2-5.91a7.93 7.93 0 0 0 3.3-10.12l-9.4-24.75a8.08 8.08 0 0 1 2.5-9.12c2.5-2 5-4.1 7.4-6.21a8 8 0 0 1 9.39-.9L401 395.66a8 8 0 0 0 10.5-1.51l7.49-9a8 8 0 0 0-.3-10.62l-17.29-19.94a8 8 0 0 1-.7-9.52q2.55-4.05 4.8-8.41a8.11 8.11 0 0 1 8.59-4.11l25.89 5a8 8 0 0 0 9.4-5l4-11a8.05 8.05 0 0 0-3.9-9.92l-23.09-12.82a7.94 7.94 0 0 1-3.9-8.62c.6-3.2 1.2-6.31 1.7-9.51a8.08 8.08 0 0 1 6.6-6.82l26.08-4.2a8.09 8.09 0 0 0 7.1-7.92V250a8.25 8.25 0 0 0-7.27-7.73zM256 112a143.82 143.82 0 0 1 139.38 108.12A16 16 0 0 1 379.85 240H274.61a16 16 0 0 1-13.91-8.09l-52.1-91.71a16 16 0 0 1 9.85-23.39A146.94 146.94 0 0 1 256 112zM112 256a144 144 0 0 1 43.65-103.41a16 16 0 0 1 25.17 3.47L233.06 248a16 16 0 0 1 0 15.87l-52.67 91.7a16 16 0 0 1-25.18 3.36A143.94 143.94 0 0 1 112 256zm144 144a146.9 146.9 0 0 1-38.19-4.95a16 16 0 0 1-9.76-23.44l52.58-91.55a16 16 0 0 1 13.88-8H379.9a16 16 0 0 1 15.52 19.88A143.84 143.84 0 0 1 256 400z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cP = [_hoisted_2$f4];
    vue.defineComponent({
      name: 'CogOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$f4, _hoisted_3$cP);
      }
    });

    const _hoisted_1$f3 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$f3 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 249.93a10.58 10.58 0 0 0-9.36-9.94L429 235.84a5.42 5.42 0 0 1-4.5-4.67c-.49-3.15-1-6.42-1.7-9.52a5.52 5.52 0 0 1 2.63-5.85l22.78-12.65a10.35 10.35 0 0 0 5-12.83l-3.95-10.9a10.32 10.32 0 0 0-12.13-6.51l-25.55 5a5.5 5.5 0 0 1-5.82-2.81c-1.49-2.79-3.11-5.63-4.8-8.42a5.6 5.6 0 0 1 .44-6.5l17-19.63a10.44 10.44 0 0 0 .39-13.77l-7.42-8.91a10.24 10.24 0 0 0-13.58-2l-22.37 13.43a5.39 5.39 0 0 1-6.39-.63c-2.47-2.17-4.95-4.26-7.37-6.19a5.45 5.45 0 0 1-1.72-6.21l9.26-24.4a10.35 10.35 0 0 0-4.31-13.07l-10.08-5.85a10.31 10.31 0 0 0-13.46 2.83L325 96.28a4.58 4.58 0 0 1-5.6 1.72c-.62-.25-5.77-2.36-9.78-3.7a5.42 5.42 0 0 1-3.74-5.23l.39-26.07a10.48 10.48 0 0 0-8.57-10.88l-11.45-2a10.45 10.45 0 0 0-11.75 7.17L266 82.1a5.42 5.42 0 0 1-5.36 3.65h-9.75a5.53 5.53 0 0 1-5.3-3.67l-8.46-24.67a10.46 10.46 0 0 0-11.77-7.25l-11.46 2a10.46 10.46 0 0 0-8.57 10.79l.4 26.16a5.45 5.45 0 0 1-3.86 5.25c-2.28.89-7.26 2.78-9.51 3.63c-2 .72-4.19-.07-6-2.1l-16.26-20A10.3 10.3 0 0 0 156.69 73l-10.06 5.83A10.36 10.36 0 0 0 142.31 92l9.25 24.34a5.54 5.54 0 0 1-1.7 6.23c-2.43 2-4.92 4-7.4 6.22a5.38 5.38 0 0 1-6.35.64L114 115.74a10.39 10.39 0 0 0-13.61 2l-7.4 8.9a10.32 10.32 0 0 0 .37 13.76l17.09 19.6a5.42 5.42 0 0 1 .45 6.45c-1.71 2.72-3.34 5.58-4.82 8.44a5.53 5.53 0 0 1-5.86 2.82l-25.51-4.93a10.34 10.34 0 0 0-12.14 6.51l-4 10.88a10.37 10.37 0 0 0 5 12.85l22.78 12.65a5.39 5.39 0 0 1 2.65 5.92l-.23 1.24c-.53 2.8-1 5.45-1.47 8.27a5.48 5.48 0 0 1-4.46 4.64l-25.7 4.15A10.42 10.42 0 0 0 48 250.16v11.58A10.26 10.26 0 0 0 57.16 272l25.68 4.14a5.41 5.41 0 0 1 4.5 4.67c.49 3.16 1 6.42 1.7 9.52a5.52 5.52 0 0 1-2.63 5.85l-22.77 12.67a10.35 10.35 0 0 0-5 12.83l4 10.9a10.33 10.33 0 0 0 12.13 6.51l25.55-4.95a5.5 5.5 0 0 1 5.82 2.81c1.5 2.8 3.12 5.64 4.8 8.42a5.58 5.58 0 0 1-.44 6.5l-17 19.64a10.41 10.41 0 0 0-.5 13.76l7.41 8.91a10.24 10.24 0 0 0 13.58 2l22.37-13.43a5.39 5.39 0 0 1 6.39.63c2.48 2.17 5 4.26 7.37 6.19a5.45 5.45 0 0 1 1.72 6.21l-9.26 24.4a10.35 10.35 0 0 0 4.31 13.07l10.11 5.84a10.3 10.3 0 0 0 13.45-2.82L187 415.92c1.39-1.73 3.6-2.5 5.24-1.84c3.47 1.44 5.8 2.25 9.93 3.63a5.44 5.44 0 0 1 3.75 5.23l-.4 26.05a10.5 10.5 0 0 0 8.57 10.88l11.45 2a10.44 10.44 0 0 0 11.75-7.17l8.5-24.77a5.48 5.48 0 0 1 5.36-3.65h9.75a5.52 5.52 0 0 1 5.3 3.67l8.47 24.67a10.48 10.48 0 0 0 10 7.41a9.74 9.74 0 0 0 1.78-.16l11.47-2a10.46 10.46 0 0 0 8.56-10.79l-.4-26.16a5.43 5.43 0 0 1 3.75-5.2c3.84-1.29 6.53-2.33 8.91-3.24l.6-.24c3.06-1.06 4.53.14 5.47 1.31l16.75 20.63A10.3 10.3 0 0 0 355 439l10.07-5.83a10.35 10.35 0 0 0 4.31-13.1l-9.24-24.34a5.52 5.52 0 0 1 1.69-6.23c2.43-2 4.92-4 7.4-6.22a5.39 5.39 0 0 1 6.38-.62l22.39 13.4a10.39 10.39 0 0 0 13.61-2l7.4-8.9a10.31 10.31 0 0 0-.37-13.75l-17.06-19.67a5.42 5.42 0 0 1-.45-6.45c1.71-2.71 3.34-5.57 4.82-8.44a5.56 5.56 0 0 1 5.86-2.82l25.48 4.97a10.34 10.34 0 0 0 12.14-6.51l3.95-10.88a10.36 10.36 0 0 0-5-12.84l-22.8-12.67a5.4 5.4 0 0 1-2.61-5.89l.23-1.25c.53-2.8 1-5.44 1.47-8.26a5.48 5.48 0 0 1 4.46-4.64l25.7-4.14a10.43 10.43 0 0 0 9.17-10.28v-11.71zM171.59 361.27a135.12 135.12 0 0 1 .5-210.94l60 105.61zM256 391.11a133.75 133.75 0 0 1-48.49-9.05L268 276.79h121.22C379.21 341.45 323.29 391.11 256 391.11zm12.06-155.9l-59.95-105.5a133.87 133.87 0 0 1 47.89-8.82c67.29 0 123.21 49.66 133.22 114.32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cO = [_hoisted_2$f3];
    vue.defineComponent({
      name: 'CogSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$f3, _hoisted_3$cO);
      }
    });

    const _hoisted_1$f2 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$f2 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 480c-35.29 0-64-29.11-64-64.88c0-33.29 28.67-65.4 44.08-82.64c1.87-2.1 3.49-3.91 4.68-5.31a19.94 19.94 0 0 1 30.55 0c1.13 1.31 2.63 3 4.36 4.93c15.5 17.3 44.33 49.51 44.33 83.05c0 35.74-28.71 64.85-64 64.85z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cN = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M398.23 276.64L166.89 47.22a52.1 52.1 0 0 0-73.6 0l-4.51 4.51a53.2 53.2 0 0 0-15.89 37.33A51.66 51.66 0 0 0 88.14 126l41.51 41.5L45 252a44.52 44.52 0 0 0-13 32a42.81 42.81 0 0 0 13.5 30.84l131.24 126a44 44 0 0 0 61.08-.18l124.11-120.28a15.6 15.6 0 0 1 8.23-4.29a69.21 69.21 0 0 1 11.93-.86h.3a22.53 22.53 0 0 0 15.84-38.59zM152.29 144.85l-41.53-41.52a20 20 0 0 1 0-28.34l5.16-5.15a20.07 20.07 0 0 1 28.39 0L186 111.21z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7R = [_hoisted_2$f2, _hoisted_3$cN];
    vue.defineComponent({
      name: 'ColorFill',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$f2, _hoisted_4$7R);
      }
    });

    const _hoisted_1$f1 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$f1 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M419.1 337.45a3.94 3.94 0 0 0-6.1 0c-10.5 12.4-45 46.55-45 77.66c0 27 21.5 48.89 48 48.89h0c26.5 0 48-22 48-48.89c0-31.11-34.3-65.26-44.9-77.66z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cM = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M387 287.9L155.61 58.36a36 36 0 0 0-51 0l-5.15 5.15a36 36 0 0 0 0 51l52.89 52.89l57-57L56.33 263.2a28 28 0 0 0 .3 40l131.2 126a28.05 28.05 0 0 0 38.9-.1c37.8-36.6 118.3-114.5 126.7-122.9c5.8-5.8 18.2-7.1 28.7-7.1h.3a6.53 6.53 0 0 0 4.57-11.2z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7Q = [_hoisted_2$f1, _hoisted_3$cM];
    vue.defineComponent({
      name: 'ColorFillOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$f1, _hoisted_4$7Q);
      }
    });

    const _hoisted_1$f0 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$f0 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 320s-64 48-64 99.84c0 33.28 28.67 60.16 64 60.16s64-27 64-60.16C480 368 416 320 416 320z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cL = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M144 32l-76 76l70 70L32 280l176 184l152.8-148.3L416 304zm24 116l-39.6-41l15.88-15.89L184 132z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7P = [_hoisted_2$f0, _hoisted_3$cL];
    vue.defineComponent({
      name: 'ColorFillSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$f0, _hoisted_4$7P);
      }
    });

    const _hoisted_1$e$ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$e$ = /*#__PURE__*/vue.createStaticVNode('<path d="M253.72 202.53a4 4 0 0 0 4.56 0a151.88 151.88 0 0 1 128.44-20.41a4 4 0 0 0 5.15-4C388.8 105.86 329 48 256 48s-132.8 57.86-135.87 130.15a4 4 0 0 0 5.15 4a151.88 151.88 0 0 1 128.44 20.41z" fill="currentColor"></path><path d="M405.31 212.56a152.53 152.53 0 0 1-83.08 108.23a4 4 0 0 0-2.28 3.69c0 1.17.05 2.34.05 3.52a151.58 151.58 0 0 1-47.15 109.94a4 4 0 0 0 .64 6.31A135.24 135.24 0 0 0 344 464c72.07 0 134.1-60.28 136-132.34a136.07 136.07 0 0 0-68.76-121.87a4 4 0 0 0-5.93 2.77z" fill="currentColor"></path><path d="M390.57 203.67a4 4 0 0 0-2.69-4.4a135.84 135.84 0 0 0-114.4 12.49a4 4 0 0 0-.64 6.29a151.92 151.92 0 0 1 44.47 81.4a4 4 0 0 0 5.94 2.72a136.29 136.29 0 0 0 67.32-98.5z" fill="currentColor"></path><path d="M192 328c0-1.18 0-2.35.05-3.52a4 4 0 0 0-2.28-3.69a152.53 152.53 0 0 1-83.08-108.23a4 4 0 0 0-5.88-2.77a136.07 136.07 0 0 0-68.76 121.87C34 403.72 96 464 168.05 464a135.24 135.24 0 0 0 70.46-19.75a4 4 0 0 0 .64-6.31A151.58 151.58 0 0 1 192 328z" fill="currentColor"></path><path d="M168 192a135.34 135.34 0 0 0-43.88 7.27a4 4 0 0 0-2.69 4.4a136.29 136.29 0 0 0 67.32 98.5a4 4 0 0 0 5.94-2.72a151.92 151.92 0 0 1 44.47-81.4a4 4 0 0 0-.64-6.29A135.18 135.18 0 0 0 168 192z" fill="currentColor"></path><path d="M256 336a151.44 151.44 0 0 1-42.72-6.12a4 4 0 0 0-5.15 4a135.69 135.69 0 0 0 45.18 95.4a4 4 0 0 0 5.38 0a135.69 135.69 0 0 0 45.18-95.4a4 4 0 0 0-5.15-4A151.44 151.44 0 0 1 256 336z" fill="currentColor"></path><path d="M302.57 308.33a135.94 135.94 0 0 0-43.87-81.58a4.06 4.06 0 0 0-5.4 0a135.94 135.94 0 0 0-43.87 81.58a4 4 0 0 0 2.69 4.4a136.06 136.06 0 0 0 87.76 0a4 4 0 0 0 2.69-4.4z" fill="currentColor"></path>', 7);

    const _hoisted_9$f = [_hoisted_2$e$];
    vue.defineComponent({
      name: 'ColorFilter',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$e$, _hoisted_9$f);
      }
    });

    const _hoisted_1$e_ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$e_ = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '184',
      r: '120',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cK = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '344',
      cy: '328',
      r: '120',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7O = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '168',
      cy: '328',
      r: '120',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3O = [_hoisted_2$e_, _hoisted_3$cK, _hoisted_4$7O];
    vue.defineComponent({
      name: 'ColorFilterOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$e_, _hoisted_5$3O);
      }
    });

    const _hoisted_1$eZ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eZ = /*#__PURE__*/vue.createStaticVNode('<path d="M256 185a167.85 167.85 0 0 1 134.9-18.28C382.36 99.83 325.12 48 256 48S129.64 99.83 121.1 166.67A167.85 167.85 0 0 1 256 185z" fill="currentColor"></path><path d="M336 331.73a167.51 167.51 0 0 1-52.37 118.08A135 135 0 0 0 344 464c75 0 136-61 136-136a136 136 0 0 0-59.06-112.08A168.53 168.53 0 0 1 336 331.73z" fill="currentColor"></path><path d="M283.58 206.19a167.87 167.87 0 0 1 49.36 89.89a136.14 136.14 0 0 0 58.06-95.7a135.87 135.87 0 0 0-107.43 5.81z" fill="currentColor"></path><path d="M176.05 331.73a168.53 168.53 0 0 1-85-115.81A136 136 0 0 0 32 328c0 75 61 136 136 136a135 135 0 0 0 60.42-14.19a167.51 167.51 0 0 1-52.37-118.08z" fill="currentColor"></path><path d="M179.06 296.08a167.87 167.87 0 0 1 49.36-89.89A135.87 135.87 0 0 0 121 200.38a136.14 136.14 0 0 0 58.06 95.7z" fill="currentColor"></path><path d="M302.9 345.33a168.22 168.22 0 0 1-93.8 0A135.9 135.9 0 0 0 256 431.6a135.9 135.9 0 0 0 46.9-86.27z" fill="currentColor"></path><path d="M209 311.62a136 136 0 0 0 94 0a135.93 135.93 0 0 0-47-87.22a135.93 135.93 0 0 0-47 87.22z" fill="currentColor"></path>', 7);

    const _hoisted_9$e = [_hoisted_2$eZ];
    vue.defineComponent({
      name: 'ColorFilterSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eZ, _hoisted_9$e);
      }
    });

    const _hoisted_1$eY = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eY = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M441 336.2l-.06-.05c-9.93-9.18-22.78-11.34-32.16-12.92l-.69-.12c-9.05-1.49-10.48-2.5-14.58-6.17c-2.44-2.17-5.35-5.65-5.35-9.94s2.91-7.77 5.34-9.94l30.28-26.87c25.92-22.91 40.2-53.66 40.2-86.59s-14.25-63.68-40.2-86.6c-35.89-31.59-85-49-138.37-49C223.72 48 162 71.37 116 112.11c-43.87 38.77-68 90.71-68 146.24s24.16 107.47 68 146.23c21.75 19.24 47.49 34.18 76.52 44.42a266.17 266.17 0 0 0 86.87 15h1.81c61 0 119.09-20.57 159.39-56.4c9.7-8.56 15.15-20.83 15.34-34.56c.21-14.17-5.37-27.95-14.93-36.84zM112 208a32 32 0 1 1 32 32a32 32 0 0 1-32-32zm40 135a32 32 0 1 1 32-32a32 32 0 0 1-32 32zm40-199a32 32 0 1 1 32 32a32 32 0 0 1-32-32zm64 271a48 48 0 1 1 48-48a48 48 0 0 1-48 48zm72-239a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cJ = [_hoisted_2$eY];
    vue.defineComponent({
      name: 'ColorPalette',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eY, _hoisted_3$cJ);
      }
    });

    const _hoisted_1$eX = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eX = /*#__PURE__*/vue.createStaticVNode('<path d="M430.11 347.9c-6.6-6.1-16.3-7.6-24.6-9c-11.5-1.9-15.9-4-22.6-10c-14.3-12.7-14.3-31.1 0-43.8l30.3-26.9c46.4-41 46.4-108.2 0-149.2c-34.2-30.1-80.1-45-127.8-45c-55.7 0-113.9 20.3-158.8 60.1c-83.5 73.8-83.5 194.7 0 268.5c41.5 36.7 97.5 55 152.9 55.4h1.7c55.4 0 110-17.9 148.8-52.4c14.4-12.7 11.99-36.6.1-47.7z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><circle cx="144" cy="208" r="32" fill="currentColor"></circle><circle cx="152" cy="311" r="32" fill="currentColor"></circle><circle cx="224" cy="144" r="32" fill="currentColor"></circle><circle cx="256" cy="367" r="48" fill="currentColor"></circle><circle cx="328" cy="144" r="32" fill="currentColor"></circle>', 6);

    const _hoisted_8$x = [_hoisted_2$eX];
    vue.defineComponent({
      name: 'ColorPaletteOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eX, _hoisted_8$x);
      }
    });

    const _hoisted_1$eW = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eW = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 352c-12.6-.84-21-4-28-12c-14-16-14-36 5.49-52.48l32.82-29.14c50.27-44.41 50.27-117.21 0-161.63C389.26 64.14 339.54 48 287.86 48c-60.34 0-123.39 22-172 65.11c-90.46 80-90.46 210.92 0 290.87c45 39.76 105.63 59.59 165.64 60h1.84c60 0 119.07-19.5 161.2-56.77C464 390 464 385 444.62 355.56C440 348 431 353 416 352zM112 208a32 32 0 1 1 32 32a32 32 0 0 1-32-32zm40 135a32 32 0 1 1 32-32a32 32 0 0 1-32 32zm40-199a32 32 0 1 1 32 32a32 32 0 0 1-32-32zm64 271a48 48 0 1 1 48-48a48 48 0 0 1-48 48zm72-239a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cI = [_hoisted_2$eW];
    vue.defineComponent({
      name: 'ColorPaletteSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eW, _hoisted_3$cI);
      }
    });

    const _hoisted_1$eV = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eV = /*#__PURE__*/vue.createStaticVNode('<path d="M96 208H48c-8.8 0-16-7.2-16-16s7.2-16 16-16h48c8.8 0 16 7.2 16 16s-7.2 16-16 16z" fill="currentColor"></path><path d="M124.1 140.1c-4.2 0-8.3-1.7-11.3-4.7l-33.9-33.9c-6.2-6.2-6.2-16.4 0-22.6s16.4-6.2 22.6 0l33.9 33.9c6.3 6.2 6.3 16.4 0 22.6c-3 3-7 4.7-11.3 4.7z" fill="currentColor"></path><path d="M192 112c-8.8 0-16-7.2-16-16V48c0-8.8 7.2-16 16-16s16 7.2 16 16v48c0 8.8-7.2 16-16 16z" fill="currentColor"></path><path d="M259.9 140.1c-8.8 0-16-7.2-16-16c0-4.2 1.7-8.3 4.7-11.3l33.9-33.9c6.2-6.2 16.4-6.2 22.6 0c6.2 6.2 6.2 16.4 0 22.6l-33.9 33.9c-3 3-7.1 4.7-11.3 4.7z" fill="currentColor"></path><path d="M90.2 309.8c-8.8 0-16-7.2-16-16c0-4.2 1.7-8.3 4.7-11.3l33.9-33.9c6.2-6.2 16.4-6.2 22.6 0s6.2 16.4 0 22.6l-33.9 33.9c-3 3-7.1 4.7-11.3 4.7z" fill="currentColor"></path><path d="M234.2 167c-18.4-18.7-48.5-19-67.2-.7s-19 48.5-.7 67.2l.7.7l39.5 39.5c3.1 3.1 8.2 3.1 11.3 0l55.9-55.9c3.1-3.1 3.1-8.2 0-11.3L234.2 167z" fill="currentColor"></path><path d="M457 389.8L307.6 240.4c-3.1-3.1-8.2-3.1-11.3 0l-55.9 55.9c-3.1 3.1-3.1 8.2 0 11.3L389.8 457c18.4 18.7 48.5 19 67.2.7c18.7-18.4 19-48.5.7-67.2c-.2-.2-.4-.5-.7-.7z" fill="currentColor"></path>', 7);

    const _hoisted_9$d = [_hoisted_2$eV];
    vue.defineComponent({
      name: 'ColorWand',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eV, _hoisted_9$d);
      }
    });

    const _hoisted_1$eU = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eU = /*#__PURE__*/vue.createStaticVNode('<rect fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32" x="280.48" y="122.9" width="63.03" height="378.2" rx="31.52" transform="rotate(-45 312.002 311.994)"></rect><path d="M178.38 178.38a31.64 31.64 0 0 0 0 44.75L223.25 268L268 223.25l-44.87-44.87a31.64 31.64 0 0 0-44.75 0z" fill="currentColor"></path><path stroke="currentColor" stroke-miterlimit="10" stroke-width="32" stroke-linecap="round" d="M48 192h48" fill="currentColor"></path><path stroke="currentColor" stroke-miterlimit="10" stroke-width="32" stroke-linecap="round" d="M90.18 90.18l33.94 33.94" fill="currentColor"></path><path stroke="currentColor" stroke-miterlimit="10" stroke-width="32" stroke-linecap="round" d="M192 48v48" fill="currentColor"></path><path stroke="currentColor" stroke-miterlimit="10" stroke-width="32" stroke-linecap="round" d="M293.82 90.18l-33.94 33.94" fill="currentColor"></path><path stroke="currentColor" stroke-miterlimit="10" stroke-width="32" stroke-linecap="round" d="M124.12 259.88l-33.94 33.94" fill="currentColor"></path>', 7);

    const _hoisted_9$c = [_hoisted_2$eU];
    vue.defineComponent({
      name: 'ColorWandOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eU, _hoisted_9$c);
      }
    });

    const _hoisted_1$eT = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eT = /*#__PURE__*/vue.createStaticVNode('<path d="M133.441 200.647l67.197-67.196l78.142 78.142l-67.196 67.196z" fill="currentColor"></path><path d="M301.41 234.21l-67.19 67.2L412 480l68-68l-178.59-177.79z" fill="currentColor"></path><path d="M32 176h80v32H32z" fill="currentColor"></path><path d="M67.624 90.25l22.627-22.628l56.569 56.569l-22.627 22.627z" fill="currentColor"></path><path d="M176 32h32v80h-32z" fill="currentColor"></path><path d="M237.32 124.195l56.569-56.569l22.627 22.627l-56.569 56.569z" fill="currentColor"></path><path d="M67.62 293.887l56.569-56.569l22.627 22.627l-56.569 56.569z" fill="currentColor"></path>', 7);

    const _hoisted_9$b = [_hoisted_2$eT];
    vue.defineComponent({
      name: 'ColorWandSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eT, _hoisted_9$b);
      }
    });

    const _hoisted_1$eS = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eS = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '24',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cH = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm105.07 113.33l-46.88 117.2a64 64 0 0 1-35.66 35.66l-117.2 46.88a8 8 0 0 1-10.4-10.4l46.88-117.2a64 64 0 0 1 35.66-35.66l117.2-46.88a8 8 0 0 1 10.4 10.4z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7N = [_hoisted_2$eS, _hoisted_3$cH];
    vue.defineComponent({
      name: 'Compass',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eS, _hoisted_4$7N);
      }
    });

    const _hoisted_1$eR = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eR = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cG = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M350.67 150.93l-117.2 46.88a64 64 0 0 0-35.66 35.66l-46.88 117.2a8 8 0 0 0 10.4 10.4l117.2-46.88a64 64 0 0 0 35.66-35.66l46.88-117.2a8 8 0 0 0-10.4-10.4zM256 280a24 24 0 1 1 24-24a24 24 0 0 1-24 24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7M = [_hoisted_2$eR, _hoisted_3$cG];
    vue.defineComponent({
      name: 'CompassOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eR, _hoisted_4$7M);
      }
    });

    const _hoisted_1$eQ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eQ = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '24',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cF = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm48 256l-160 64l64-160l160-64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7L = [_hoisted_2$eQ, _hoisted_3$cF];
    vue.defineComponent({
      name: 'CompassSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eQ, _hoisted_4$7L);
      }
    });

    const _hoisted_1$eP = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eP = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M503.58 126.2a16.85 16.85 0 0 0-27.07-4.55l-51.15 51.15a11.15 11.15 0 0 1-15.66 0l-22.48-22.48a11.17 11.17 0 0 1 0-15.67l50.88-50.89a16.85 16.85 0 0 0-5.27-27.4c-39.71-17-89.08-7.45-120 23.29c-26.81 26.61-34.83 68-22 113.7a11 11 0 0 1-3.16 11.1L114.77 365.1a56.76 56.76 0 1 0 80.14 80.18L357 272.08a11 11 0 0 1 10.9-3.17c45 12 86 4 112.43-22c15.2-15 25.81-36.17 29.89-59.71c3.83-22.2 1.41-44.44-6.64-61z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cE = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M437.33 378.41c-13.94-11.59-43.72-38.4-74.07-66.22l-66.07 70.61c28.24 30 53.8 57.85 65 70.88l.07.08A30 30 0 0 0 383.72 464h1.1a30.11 30.11 0 0 0 21-8.62l.07-.07l33.43-33.37a29.46 29.46 0 0 0-2-43.53z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7K = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M118.54 214.55a20.48 20.48 0 0 0-3-10.76a2.76 2.76 0 0 1 2.62-4.22h.06c.84.09 5.33.74 11.7 4.61c4.73 2.87 18.23 12.08 41.73 35.54a34.23 34.23 0 0 0 7.22 22.12l66.23-61.55a33.73 33.73 0 0 0-21.6-9.2a2.65 2.65 0 0 1-.21-.26l-.65-.69l-24.54-33.84a28.45 28.45 0 0 1-4-26.11a35.23 35.23 0 0 1 11.78-16.35c5.69-4.41 18.53-9.72 29.44-10.62a52.92 52.92 0 0 1 15.19.94a65.57 65.57 0 0 1 7.06 2.13a15.46 15.46 0 0 0 2.15.63a16 16 0 0 0 16.38-25.06c-.26-.35-1.32-1.79-2.89-3.73a91.85 91.85 0 0 0-9.6-10.36c-8.15-7.36-29.27-19.77-57-19.77a123.13 123.13 0 0 0-46.3 9c-38.37 15.45-63.47 36.58-75.01 47.79l-.09.09A222.14 222.14 0 0 0 63.7 129.5a27 27 0 0 0-4.7 11.77a7.33 7.33 0 0 1-7.71 6.17H50.2a20.65 20.65 0 0 0-14.59 5.9L6.16 182.05l-.32.32a20.89 20.89 0 0 0-.24 28.72c.19.2.37.39.57.58L53.67 258a21 21 0 0 0 14.65 6a20.65 20.65 0 0 0 14.59-5.9l29.46-28.79a20.51 20.51 0 0 0 6.17-14.76z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3N = [_hoisted_2$eP, _hoisted_3$cE, _hoisted_4$7K];
    vue.defineComponent({
      name: 'Construct',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eP, _hoisted_5$3N);
      }
    });

    const _hoisted_1$eO = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eO = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M436.67 184.11a27.17 27.17 0 0 1-38.3 0l-22.48-22.49a27.15 27.15 0 0 1 0-38.29l50.89-50.89a.85.85 0 0 0-.26-1.38C393.68 57 351.09 64.15 324.05 91c-25.88 25.69-27.35 64.27-17.87 98a27 27 0 0 1-7.67 27.14l-173 160.76a40.76 40.76 0 1 0 57.57 57.54l162.15-173.3a27 27 0 0 1 26.77-7.7c33.46 8.94 71.49 7.26 97.07-17.94c27.49-27.08 33.42-74.94 20.1-102.33a.85.85 0 0 0-1.36-.22z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cD = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M224 284c-17.48-17-25.49-24.91-31-30.29a18.24 18.24 0 0 1-3.33-21.35a20.76 20.76 0 0 1 3.5-4.62l15.68-15.29a18.66 18.66 0 0 1 5.63-3.87a18.11 18.11 0 0 1 20 3.62c5.45 5.29 15.43 15 33.41 32.52',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7J = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M317.07 291.3c40.95 38.1 90.62 83.27 110 99.41a13.46 13.46 0 0 1 .94 19.92L394.63 444a14 14 0 0 1-20.29-.76c-16.53-19.18-61.09-67.11-99.27-107',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3M = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M17.34 193.5l29.41-28.74a4.71 4.71 0 0 1 3.41-1.35a4.85 4.85 0 0 1 3.41 1.35h0a9.86 9.86 0 0 0 8.19 2.77c3.83-.42 7.92-1.6 10.57-4.12c6-5.8-.94-17.23 4.34-24.54a207 207 0 0 1 19.78-22.6c6-5.88 29.84-28.32 69.9-44.45A107.31 107.31 0 0 1 206.67 64c22.59 0 40 10 46.26 15.67a89.54 89.54 0 0 1 10.28 11.64a78.92 78.92 0 0 0-9.21-2.77a68.82 68.82 0 0 0-20-1.26c-13.33 1.09-29.41 7.26-38 14c-13.9 11-19.87 25.72-20.81 44.71c-.68 14.12 2.72 22.1 36.1 55.49a6.6 6.6 0 0 1-.34 9.16l-18.22 18a6.88 6.88 0 0 1-9.54.09c-21.94-21.94-36.65-33.09-45-38.16s-15.07-6.5-18.3-6.85a30.85 30.85 0 0 0-18.27 3.87a11.39 11.39 0 0 0-2.64 2a14.14 14.14 0 0 0 .42 20.08l1.71 1.6a4.63 4.63 0 0 1 0 6.64L71.73 246.6a4.71 4.71 0 0 1-3.41 1.4a4.86 4.86 0 0 1-3.41-1.35l-47.57-46.43a4.88 4.88 0 0 1 0-6.72z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1C = [_hoisted_2$eO, _hoisted_3$cD, _hoisted_4$7J, _hoisted_5$3M];
    vue.defineComponent({
      name: 'ConstructOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eO, _hoisted_6$1C);
      }
    });

    const _hoisted_1$eN = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eN = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M497.14 111.38l-81.09 80.84l-48.58-48.41L448.56 63c-45.22-22-108.65-22.09-146.2 15.35c-35.32 35.2-39.73 90.61-22.54 134.2L99.57 391.37a12 12 0 0 0 0 17l52.27 52.11a12 12 0 0 0 17 0l180-180.5c43.16 16.21 98 11.64 132.74-23c37.5-37.45 37.42-100.34 15.56-145.6z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cC = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M365.45 308.62l-71.83 72l75.53 79.92a10.88 10.88 0 0 0 15.65.21l60-60.46a11 11 0 0 0-.24-15.69z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7I = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M119 212c0-4.87-4-9.33-7.45-12.78l-.25-.24l-1.54-1.47a1.06 1.06 0 0 1-.26-.8a16.16 16.16 0 0 1 9.52-2c1.27.13 5.91.9 12.4 4.91c3.38 2.09 32.63 30.23 43.93 40.7a11 11 0 0 0 .14 15.35l7.43 7.86l65.66-65.17l-8.25-7.84a10.87 10.87 0 0 0-15.31-.06c-23-24.68-29-35.45-31-42.45c-4.42-15.47 4.14-28 14-36c5.84-4.62 17.88-8.08 29-9a52.72 52.72 0 0 1 11.61.6c3.47.5 6.3 1.14 7.39 1.4a68.51 68.51 0 0 1 11 4l12-19a88.38 88.38 0 0 0-13.4-17.7a115.05 115.05 0 0 0-5.19-5.1c-7.78-7.15-28-19.2-54.59-19.2a117.38 117.38 0 0 0-44.77 8.82c-37.44 15.34-61.88 36.25-73.11 47.35l-.07.07A219.55 219.55 0 0 0 67 128.56c-5.35 7.53-4.77 15.84-4.38 21.34c0 .32 0 .67.07 1a18.41 18.41 0 0 0-10.78-3.5A18 18 0 0 0 39 152.73L2 189.62a6.79 6.79 0 0 0 0 9.6L65 262a6.72 6.72 0 0 0 9.5 0l37.06-37c3.44-3.44 7.44-8.14 7.44-13z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3L = [_hoisted_2$eN, _hoisted_3$cC, _hoisted_4$7I];
    vue.defineComponent({
      name: 'ConstructSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eN, _hoisted_5$3L);
      }
    });

    const _hoisted_1$eM = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eM = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M304 416V304h112"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M314.2 314.23L432 432"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M208 96v112H96"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M197.8 197.77L80 80"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M416 208H304V96"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M314.23 197.8L432 80"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M96 304h112v112"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M197.77 314.2L80 432"></path>', 8);

    const _hoisted_10$g = [_hoisted_2$eM];
    vue.defineComponent({
      name: 'Contract',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eM, _hoisted_10$g);
      }
    });

    const _hoisted_1$eL = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eL = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M304 416V304h112"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M314.2 314.23L432 432"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M208 96v112H96"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M197.8 197.77L80 80"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M416 208H304V96"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M314.23 197.8L432 80"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M96 304h112v112"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M197.77 314.2L80 432"></path>', 8);

    const _hoisted_10$f = [_hoisted_2$eL];
    vue.defineComponent({
      name: 'ContractOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eL, _hoisted_10$f);
      }
    });

    const _hoisted_1$eK = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eK = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M304 416V304h112"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M314.2 314.23L432 432"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M208 96v112H96"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M197.8 197.77L80 80"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M416 208H304V96"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M314.23 197.8L432 80"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M96 304h112v112"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M197.77 314.2L80 432"></path>', 8);

    const _hoisted_10$e = [_hoisted_2$eK];
    vue.defineComponent({
      name: 'ContractSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eK, _hoisted_10$e);
      }
    });

    const _hoisted_1$eJ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eJ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 32A224 224 0 0 0 97.61 414.39A224 224 0 1 0 414.39 97.61A222.53 222.53 0 0 0 256 32zM64 256c0-105.87 86.13-192 192-192v384c-105.87 0-192-86.13-192-192z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cB = [_hoisted_2$eJ];
    vue.defineComponent({
      name: 'Contrast',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eJ, _hoisted_3$cB);
      }
    });

    const _hoisted_1$eI = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eI = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '208',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cA = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 464c-114.88 0-208-93.12-208-208S141.12 48 256 48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7H = [_hoisted_2$eI, _hoisted_3$cA];
    vue.defineComponent({
      name: 'ContrastOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eI, _hoisted_4$7H);
      }
    });

    const _hoisted_1$eH = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eH = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 32C132.29 32 32 132.29 32 256s100.29 224 224 224s224-100.29 224-224S379.71 32 256 32zM128.72 383.28A180 180 0 0 1 256 76v360a178.82 178.82 0 0 1-127.28-52.72z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cz = [_hoisted_2$eH];
    vue.defineComponent({
      name: 'ContrastSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eH, _hoisted_3$cz);
      }
    });

    const _hoisted_1$eG = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eG = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M408 480H184a72 72 0 0 1-72-72V184a72 72 0 0 1 72-72h224a72 72 0 0 1 72 72v224a72 72 0 0 1-72 72z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cy = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M160 80h235.88A72.12 72.12 0 0 0 328 32H104a72 72 0 0 0-72 72v224a72.12 72.12 0 0 0 48 67.88V160a80 80 0 0 1 80-80z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7G = [_hoisted_2$eG, _hoisted_3$cy];
    vue.defineComponent({
      name: 'Copy',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eG, _hoisted_4$7G);
      }
    });

    const _hoisted_1$eF = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eF = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '128',
      y: '128',
      width: '336',
      height: '336',
      rx: '57',
      ry: '57',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cx = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M383.5 128l.5-24a56.16 56.16 0 0 0-56-56H112a64.19 64.19 0 0 0-64 64v216a56.16 56.16 0 0 0 56 56h24',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7F = [_hoisted_2$eF, _hoisted_3$cx];
    vue.defineComponent({
      name: 'CopyOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eF, _hoisted_4$7F);
      }
    });

    const _hoisted_1$eE = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eE = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M456 480H136a24 24 0 0 1-24-24V128a16 16 0 0 1 16-16h328a24 24 0 0 1 24 24v320a24 24 0 0 1-24 24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cw = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M112 80h288V56a24 24 0 0 0-24-24H60a28 28 0 0 0-28 28v316a24 24 0 0 0 24 24h24V112a32 32 0 0 1 32-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7E = [_hoisted_2$eE, _hoisted_3$cw];
    vue.defineComponent({
      name: 'CopySharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eE, _hoisted_4$7E);
      }
    });

    const _hoisted_1$eD = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eD = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M459.94 53.25a16.06 16.06 0 0 0-23.22-.56L424.35 65a8 8 0 0 0 0 11.31l11.34 11.32a8 8 0 0 0 11.34 0l12.06-12c6.1-6.09 6.67-16.01.85-22.38z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cv = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M399.34 90L218.82 270.2a9 9 0 0 0-2.31 3.93L208.16 299a3.91 3.91 0 0 0 4.86 4.86l24.85-8.35a9 9 0 0 0 3.93-2.31L422 112.66a9 9 0 0 0 0-12.66l-9.95-10a9 9 0 0 0-12.71 0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7D = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M386.34 193.66L264.45 315.79A41.08 41.08 0 0 1 247.58 326l-25.9 8.67a35.92 35.92 0 0 1-44.33-44.33l8.67-25.9a41.08 41.08 0 0 1 10.19-16.87l122.13-121.91a8 8 0 0 0-5.65-13.66H104a56 56 0 0 0-56 56v240a56 56 0 0 0 56 56h240a56 56 0 0 0 56-56V199.31a8 8 0 0 0-13.66-5.65z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3K = [_hoisted_2$eD, _hoisted_3$cv, _hoisted_4$7D];
    vue.defineComponent({
      name: 'Create',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eD, _hoisted_5$3K);
      }
    });

    const _hoisted_1$eC = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eC = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 224v184a40 40 0 0 1-40 40H104a40 40 0 0 1-40-40V168a40 40 0 0 1 40-40h167.48',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cu = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M459.94 53.25a16.06 16.06 0 0 0-23.22-.56L424.35 65a8 8 0 0 0 0 11.31l11.34 11.32a8 8 0 0 0 11.34 0l12.06-12c6.1-6.09 6.67-16.01.85-22.38z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7C = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M399.34 90L218.82 270.2a9 9 0 0 0-2.31 3.93L208.16 299a3.91 3.91 0 0 0 4.86 4.86l24.85-8.35a9 9 0 0 0 3.93-2.31L422 112.66a9 9 0 0 0 0-12.66l-9.95-10a9 9 0 0 0-12.71 0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3J = [_hoisted_2$eC, _hoisted_3$cu, _hoisted_4$7C];
    vue.defineComponent({
      name: 'CreateOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eC, _hoisted_5$3J);
      }
    });

    const _hoisted_1$eB = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eB = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464.37 49.2a22.07 22.07 0 0 0-31.88-.76l-18.31 18.25l31.18 31.1l18-17.91a22.16 22.16 0 0 0 1.01-30.68z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ct = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M252.76 336H176V259.24l9.4-9.38L323.54 112H48v352h352V188.46L262.14 326.6l-9.38 9.4z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7B = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400 143.16l32.79-32.86l-31.09-31.09L368.85 112H400v31.16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3I = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M208 304h31.49L400 143.16V112h-31.15L208 272.51V304z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1B = [_hoisted_2$eB, _hoisted_3$ct, _hoisted_4$7B, _hoisted_5$3I];
    vue.defineComponent({
      name: 'CreateSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eB, _hoisted_6$1B);
      }
    });

    const _hoisted_1$eA = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eA = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M458 346H192a26 26 0 0 1-26-26V54a22 22 0 0 0-44 0v68H54a22 22 0 0 0 0 44h68v154a70.08 70.08 0 0 0 70 70h154v68a22 22 0 0 0 44 0v-68h68a22 22 0 0 0 0-44z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cs = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M214 166h106a26 26 0 0 1 26 26v106a22 22 0 0 0 44 0V192a70.08 70.08 0 0 0-70-70H214a22 22 0 0 0 0 44z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7A = [_hoisted_2$eA, _hoisted_3$cs];
    vue.defineComponent({
      name: 'Crop',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eA, _hoisted_4$7A);
      }
    });

    const _hoisted_1$ez = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ez = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M144 48v272a48 48 0 0 0 48 48h272',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cr = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M368 304V192a48 48 0 0 0-48-48H208',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7z = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M368 368v96'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3H = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M144 144H48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1A = [_hoisted_2$ez, _hoisted_3$cr, _hoisted_4$7z, _hoisted_5$3H];
    vue.defineComponent({
      name: 'CropOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ez, _hoisted_6$1A);
      }
    });

    const _hoisted_1$ey = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ey = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M166 346V32h-44v90H32v44h90v224h224v90h44v-90h90v-44H166z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cq = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M346 320h44V122H192v44h154v154z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7y = [_hoisted_2$ey, _hoisted_3$cq];
    vue.defineComponent({
      name: 'CropSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ey, _hoisted_4$7y);
      }
    });

    const _hoisted_1$ex = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ex = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M440.9 136.3a4 4 0 0 0 0-6.91L288.16 40.65a64.14 64.14 0 0 0-64.33 0L71.12 129.39a4 4 0 0 0 0 6.91L254 243.88a4 4 0 0 0 4.06 0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cp = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M54 163.51a4 4 0 0 0-6 3.49v173.89a48 48 0 0 0 23.84 41.39L234 479.51a4 4 0 0 0 6-3.46V274.3a4 4 0 0 0-2-3.46z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7x = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M272 275v201a4 4 0 0 0 6 3.46l162.15-97.23A48 48 0 0 0 464 340.89V167a4 4 0 0 0-6-3.45l-184 108a4 4 0 0 0-2 3.45z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3G = [_hoisted_2$ex, _hoisted_3$cp, _hoisted_4$7x];
    vue.defineComponent({
      name: 'Cube',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ex, _hoisted_5$3G);
      }
    });

    const _hoisted_1$ew = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ew = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 341.37V170.61A32 32 0 0 0 432.11 143l-152-88.46a47.94 47.94 0 0 0-48.24 0L79.89 143A32 32 0 0 0 64 170.61v170.76A32 32 0 0 0 79.89 369l152 88.46a48 48 0 0 0 48.24 0l152-88.46A32 32 0 0 0 448 341.37z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$co = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M69 153.99l187 110l187-110'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7w = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 463.99v-200'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3F = [_hoisted_2$ew, _hoisted_3$co, _hoisted_4$7w];
    vue.defineComponent({
      name: 'CubeOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ew, _hoisted_5$3F);
      }
    });

    const _hoisted_1$ev = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ev = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 170v196.92L240 480V284L48 170z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cn = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M272 480l192-113.08V170L272 284zm176-122.36z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7v = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 144L256 32L64 144l192 112l192-112z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3E = [_hoisted_2$ev, _hoisted_3$cn, _hoisted_4$7v];
    vue.defineComponent({
      name: 'CubeSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ev, _hoisted_5$3E);
      }
    });

    const _hoisted_1$eu = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eu = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M103.48 224a71.64 71.64 0 0 0 44.76-15.66l41.5 16.89l6.82-12.63a39.15 39.15 0 0 1 4.32-6.37l14.22-14.42l-41.17-24.94A72 72 0 1 0 103.48 224zm0-112a40 40 0 1 1-40 40a40 40 0 0 1 40-40z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cm = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 169l-5.52-12.58c-4.48-10.42-14.74-16-32.78-17.85c-10.12-1-26.95-1.24-49.69 3.81c-20 4.45-122.14 28.2-164.95 58.62c-20.25 14.39-24.06 33.67-27.06 49.16c-2.78 14.14-5 25.31-18 35c-15 11.14-27.27 16.38-33.58 18.6a71.74 71.74 0 1 0 24.79 38zm-224.52 87a16 16 0 1 1 16-16a16 16 0 0 1-16 16zm-152 144a40 40 0 1 1 40-40a40 40 0 0 1-40 40z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7u = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M343.79 259.87l-83.74 48.18l27.63 13.08l3.62 1.74C310 331.92 359.74 356 410.53 359c3.89.23 7.47.34 10.78.34C442 359.31 453 354 459.75 350L480 336z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3D = [_hoisted_2$eu, _hoisted_3$cm, _hoisted_4$7u];
    vue.defineComponent({
      name: 'Cut',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eu, _hoisted_5$3D);
      }
    });

    const _hoisted_1$et = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$et = /*#__PURE__*/vue.createStaticVNode('<circle cx="104" cy="152" r="56" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><circle cx="104" cy="360" r="56" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><path d="M157 175l-11 15l37 15s3.46-6.42 7-10z" fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32"></path><path d="M154.17 334.43L460 162c-2.5-6.7-28-12-64-4c-29.12 6.47-121.16 29.05-159.16 56.05C205.85 236.06 227 272 192 298c-25.61 19-44.43 22.82-44.43 22.82z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><path d="M344.47 278.24L295 306.67c14.23 6.74 65.54 33.27 117 36.33c14.92.89 30 .39 39-6z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><circle cx="256" cy="240" r="32" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></circle>', 6);

    const _hoisted_8$w = [_hoisted_2$et];
    vue.defineComponent({
      name: 'CutOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$et, _hoisted_8$w);
      }
    });

    const _hoisted_1$es = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$es = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 128h-48l-198.94 70.46l-59.13-31.59a72.16 72.16 0 1 0-25.69 41.47l52.2 31.72L192 277l-43.64 26.76a71.74 71.74 0 1 0 24.79 38L480 160zm-376.52 64a40 40 0 1 1 40-40a40 40 0 0 1-40 40zm0 208a40 40 0 1 1 40-40a40 40 0 0 1-40 40zm152-144a16 16 0 1 1 16-16a16 16 0 0 1-16 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cl = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M343.79 259.87l-83.74 48.18L432 368h47.99l.01-32l-136.21-76.13z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7t = [_hoisted_2$es, _hoisted_3$cl];
    vue.defineComponent({
      name: 'CutSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$es, _hoisted_4$7t);
      }
    });

    const _hoisted_1$er = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$er = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M16 352a48.05 48.05 0 0 0 48 48h133.88l-4 32H144a16 16 0 0 0 0 32h224a16 16 0 0 0 0-32h-49.88l-4-32H448a48.05 48.05 0 0 0 48-48v-48H16zm240-16a16 16 0 1 1-16 16a16 16 0 0 1 16-16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ck = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M496 96a48.05 48.05 0 0 0-48-48H64a48.05 48.05 0 0 0-48 48v192h480z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7s = [_hoisted_2$er, _hoisted_3$ck];
    vue.defineComponent({
      name: 'Desktop',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$er, _hoisted_4$7s);
      }
    });

    const _hoisted_1$eq = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eq = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '32',
      y: '64',
      width: '448',
      height: '320',
      rx: '32',
      ry: '32',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cj = /*#__PURE__*/vue.createElementVNode('path', {
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M304 448l-8-64h-80l-8 64h96z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7r = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M368 448H144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3C = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M32 304v48a32.09 32.09 0 0 0 32 32h384a32.09 32.09 0 0 0 32-32v-48zm224 64a16 16 0 1 1 16-16a16 16 0 0 1-16 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1z = [_hoisted_2$eq, _hoisted_3$cj, _hoisted_4$7r, _hoisted_5$3C];
    vue.defineComponent({
      name: 'DesktopOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eq, _hoisted_6$1z);
      }
    });

    const _hoisted_1$ep = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ep = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 48H32a16 16 0 0 0-16 16v320a16 16 0 0 0 16 16h168v32h-72v32h256v-32h-72v-32h168a16 16 0 0 0 16-16V64a16 16 0 0 0-16-16zm-20 36v216H52V84zM240.13 354.08a16 16 0 1 1 13.79 13.79a16 16 0 0 1-13.79-13.79z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ci = [_hoisted_2$ep];
    vue.defineComponent({
      name: 'DesktopSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ep, _hoisted_3$ci);
      }
    });

    const _hoisted_1$eo = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eo = /*#__PURE__*/vue.createStaticVNode('<path d="M121.72 32a4 4 0 0 0-3.72 5.56l2.3 5.43l40.7 94.9a4 4 0 0 0 6.88.82L243 38.4a4 4 0 0 0-3.2-6.4z" fill="currentColor"></path><path d="M419.93 58.06l-41.28 96.37a4 4 0 0 0 3.68 5.57h101a4 4 0 0 0 3.4-6.11L427 57.53a4 4 0 0 0-7.07.53z" fill="currentColor"></path><path d="M85 57.57l-59.71 96.32a4 4 0 0 0 3.4 6.11h101a4 4 0 0 0 3.67-5.58L92 58.1a4 4 0 0 0-7-.53z" fill="currentColor"></path><path d="M393.27 32H267.82a1.94 1.94 0 0 0-1.56 3.11l79.92 106.46a1.94 1.94 0 0 0 3.34-.4L391.6 43l3.4-8.34a1.92 1.92 0 0 0-1.7-2.66z" fill="currentColor"></path><path d="M239 448l-89.43-253.49A3.78 3.78 0 0 0 146 192H25.7a3.72 3.72 0 0 0-2.95 6l216 279.81a5.06 5.06 0 0 0 6.39 1.37a5 5 0 0 0 2.39-6.08z" fill="currentColor"></path><path d="M486.3 192H366a3.75 3.75 0 0 0-3.54 2.51l-98.2 278.16a5.21 5.21 0 0 0 2.42 6.31a5.22 5.22 0 0 0 6.61-1.39L489.25 198a3.72 3.72 0 0 0-2.95-6z" fill="currentColor"></path><path d="M259.2 78.93l56 74.67a4 4 0 0 1-3.2 6.4H200a4 4 0 0 1-3.2-6.4l56-74.67a4 4 0 0 1 6.4 0zm-7 310.31l-67.7-191.91a4 4 0 0 1 3.77-5.33h135.46a4 4 0 0 1 3.77 5.33l-67.73 191.91a4 4 0 0 1-7.54 0z" fill="currentColor"></path>', 7);

    const _hoisted_9$a = [_hoisted_2$eo];
    vue.defineComponent({
      name: 'Diamond',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eo, _hoisted_9$a);
      }
    });

    const _hoisted_1$en = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$en = /*#__PURE__*/vue.createStaticVNode('<path d="M35.42 188.21l207.75 269.46a16.17 16.17 0 0 0 25.66 0l207.75-269.46a16.52 16.52 0 0 0 .95-18.75L407.06 55.71A16.22 16.22 0 0 0 393.27 48H118.73a16.22 16.22 0 0 0-13.79 7.71L34.47 169.46a16.52 16.52 0 0 0 .95 18.75z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M48 176h416"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M400 64l-48 112l-96-128"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M112 64l48 112l96-128"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 448l-96-272"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 448l96-272"></path>', 6);

    const _hoisted_8$v = [_hoisted_2$en];
    vue.defineComponent({
      name: 'DiamondOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$en, _hoisted_8$v);
      }
    });

    const _hoisted_1$em = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$em = /*#__PURE__*/vue.createStaticVNode('<path d="M396.31 32H264l84.19 112.26L396.31 32z" fill="currentColor"></path><path d="M115.69 32l48.12 112.26L248 32H115.69z" fill="currentColor"></path><path d="M256 74.67L192 160h128l-64-85.33z" fill="currentColor"></path><path d="M422.95 51.06L376.26 160H488L422.95 51.06z" fill="currentColor"></path><path d="M89.05 51.06L23 160h112.74L89.05 51.06z" fill="currentColor"></path><path d="M146.68 192H24l222.8 288h.53L146.68 192z" fill="currentColor"></path><path d="M365.32 192L264.67 480h.53L488 192H365.32z" fill="currentColor"></path><path d="M329.39 192H182.61L256 400l73.39-208z" fill="currentColor"></path>', 8);

    const _hoisted_10$d = [_hoisted_2$em];
    vue.defineComponent({
      name: 'DiamondSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$em, _hoisted_10$d);
      }
    });

    const _hoisted_1$el = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$el = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M440.88 129.37L288.16 40.62a64.14 64.14 0 0 0-64.33 0L71.12 129.37a4 4 0 0 0 0 6.9L254 243.85a4 4 0 0 0 4.06 0L440.9 136.27a4 4 0 0 0-.02-6.9zM256 152c-13.25 0-24-7.16-24-16s10.75-16 24-16s24 7.16 24 16s-10.75 16-24 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ch = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M238 270.81L54 163.48a4 4 0 0 0-6 3.46v173.92a48 48 0 0 0 23.84 41.39L234 479.48a4 4 0 0 0 6-3.46V274.27a4 4 0 0 0-2-3.46zM96 368c-8.84 0-16-10.75-16-24s7.16-24 16-24s16 10.75 16 24s-7.16 24-16 24zm96-32c-8.84 0-16-10.75-16-24s7.16-24 16-24s16 10.75 16 24s-7.16 24-16 24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M458 163.51L274 271.56a4 4 0 0 0-2 3.45V476a4 4 0 0 0 6 3.46l162.15-97.23A48 48 0 0 0 464 340.86V167a4 4 0 0 0-6-3.49zM320 424c-8.84 0-16-10.75-16-24s7.16-24 16-24s16 10.75 16 24s-7.16 24-16 24zm0-88c-8.84 0-16-10.75-16-24s7.16-24 16-24s16 10.75 16 24s-7.16 24-16 24zm96 32c-8.84 0-16-10.75-16-24s7.16-24 16-24s16 10.75 16 24s-7.16 24-16 24zm0-88c-8.84 0-16-10.75-16-24s7.16-24 16-24s16 10.75 16 24s-7.16 24-16 24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3B = [_hoisted_2$el, _hoisted_3$ch, _hoisted_4$7q];
    vue.defineComponent({
      name: 'Dice',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$el, _hoisted_5$3B);
      }
    });

    const _hoisted_1$ek = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ek = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M448 341.37V170.61A32 32 0 0 0 432.11 143l-152-88.46a47.94 47.94 0 0 0-48.24 0L79.89 143A32 32 0 0 0 64 170.61v170.76A32 32 0 0 0 79.89 369l152 88.46a48 48 0 0 0 48.24 0l152-88.46A32 32 0 0 0 448 341.37z"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M69 153.99l187 110l187-110"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 463.99v-200"></path><ellipse cx="256" cy="152" rx="24" ry="16" fill="currentColor"></ellipse><ellipse cx="208" cy="296" rx="16" ry="24" fill="currentColor"></ellipse><ellipse cx="112" cy="328" rx="16" ry="24" fill="currentColor"></ellipse><ellipse cx="304" cy="296" rx="16" ry="24" fill="currentColor"></ellipse><ellipse cx="400" cy="240" rx="16" ry="24" fill="currentColor"></ellipse><ellipse cx="304" cy="384" rx="16" ry="24" fill="currentColor"></ellipse><ellipse cx="400" cy="328" rx="16" ry="24" fill="currentColor"></ellipse>', 10);

    const _hoisted_12$5 = [_hoisted_2$ek];
    vue.defineComponent({
      name: 'DiceOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ek, _hoisted_12$5);
      }
    });

    const _hoisted_1$ej = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ej = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 366.92L240 480V284L48 170zM192 288c8.84 0 16 10.75 16 24s-7.16 24-16 24s-16-10.75-16-24s7.16-24 16-24zm-96 32c8.84 0 16 10.75 16 24s-7.16 24-16 24s-16-10.75-16-24s7.16-24 16-24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cg = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M272 284v196l192-113.08V170zm48 140c-8.84 0-16-10.75-16-24s7.16-24 16-24s16 10.75 16 24s-7.16 24-16 24zm0-88c-8.84 0-16-10.75-16-24s7.16-24 16-24s16 10.75 16 24s-7.16 24-16 24zm96 32c-8.84 0-16-10.75-16-24s7.16-24 16-24s16 10.75 16 24s-7.16 24-16 24zm0-88c-8.84 0-16-10.75-16-24s7.16-24 16-24s16 10.75 16 24s-7.16 24-16 24zm32 77.64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7p = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 32L64 144l192 112l192-112zm0 120c-13.25 0-24-7.16-24-16s10.75-16 24-16s24 7.16 24 16s-10.75 16-24 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3A = [_hoisted_2$ej, _hoisted_3$cg, _hoisted_4$7p];
    vue.defineComponent({
      name: 'DiceSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ej, _hoisted_5$3A);
      }
    });

    const _hoisted_1$ei = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ei = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 176a80 80 0 1 0 80 80a80.09 80.09 0 0 0-80-80zm0 112a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cf = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M414.39 97.61A224 224 0 1 0 97.61 414.39A224 224 0 1 0 414.39 97.61zM256 368a112 112 0 1 1 112-112a112.12 112.12 0 0 1-112 112z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7o = [_hoisted_2$ei, _hoisted_3$cf];
    vue.defineComponent({
      name: 'Disc',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ei, _hoisted_4$7o);
      }
    });

    const _hoisted_1$eh = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eh = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '208',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ce = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '96',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7n = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '32',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3z = [_hoisted_2$eh, _hoisted_3$ce, _hoisted_4$7n];
    vue.defineComponent({
      name: 'DiscOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eh, _hoisted_5$3z);
      }
    });

    const _hoisted_1$eg = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eg = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '32',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cd = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M414.39 97.61A224 224 0 1 0 97.61 414.39A224 224 0 1 0 414.39 97.61zM256 336a80 80 0 1 1 80-80a80.09 80.09 0 0 1-80 80z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7m = [_hoisted_2$eg, _hoisted_3$cd];
    vue.defineComponent({
      name: 'DiscSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eg, _hoisted_4$7m);
      }
    });

    const _hoisted_1$ef = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ef = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M428 224H288a48 48 0 0 1-48-48V36a4 4 0 0 0-4-4h-92a64 64 0 0 0-64 64v320a64 64 0 0 0 64 64h224a64 64 0 0 0 64-64V228a4 4 0 0 0-4-4z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cc = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M419.22 188.59L275.41 44.78a2 2 0 0 0-3.41 1.41V176a16 16 0 0 0 16 16h129.81a2 2 0 0 0 1.41-3.41z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7l = [_hoisted_2$ef, _hoisted_3$cc];
    vue.defineComponent({
      name: 'Document',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ef, _hoisted_4$7l);
      }
    });

    const _hoisted_1$ee = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ee = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M460 240H320a48 48 0 0 1-48-48V52a4 4 0 0 0-4-4h-53.25a65.42 65.42 0 0 0-6.5-9.81C196.72 23.88 179.59 16 160 16c-37.68 0-64 29.61-64 72v144c0 25 20.34 40 40 40a39.57 39.57 0 0 0 40-40V80a16 16 0 0 0-32 0v152a7.75 7.75 0 0 1-8 8c-2.23 0-8-1.44-8-8V88c0-19.34 8.41-40 32-40c29.69 0 32 30.15 32 39.38v138.75c0 17.45-5.47 33.23-15.41 44.46C166.5 282 152.47 288 136 288s-30.5-6-40.59-17.41C85.47 259.36 80 243.58 80 226.13V144a16 16 0 0 0-32 0v82.13c0 51.51 33.19 89.63 80 93.53V432a64 64 0 0 0 64 64h208a64 64 0 0 0 64-64V244a4 4 0 0 0-4-4z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$cb = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 208h129.81a2 2 0 0 0 1.41-3.41L307.41 60.78a2 2 0 0 0-3.41 1.41V192a16 16 0 0 0 16 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7k = [_hoisted_2$ee, _hoisted_3$cb];
    vue.defineComponent({
      name: 'DocumentAttach',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ee, _hoisted_4$7k);
      }
    });

    const _hoisted_1$ed = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ed = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M208 64h66.75a32 32 0 0 1 22.62 9.37l141.26 141.26a32 32 0 0 1 9.37 22.62V432a48 48 0 0 1-48 48H192a48 48 0 0 1-48-48V304',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ca = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M288 72v120a32 32 0 0 0 32 32h120',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7j = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M160 80v152a23.69 23.69 0 0 1-24 24c-12 0-24-9.1-24-24V88c0-30.59 16.57-56 48-56s48 24.8 48 55.38v138.75c0 43-27.82 77.87-72 77.87s-72-34.86-72-77.87V144',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3y = [_hoisted_2$ed, _hoisted_3$ca, _hoisted_4$7j];
    vue.defineComponent({
      name: 'DocumentAttachOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ed, _hoisted_5$3y);
      }
    });

    const _hoisted_1$ec = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ec = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M280 240a8 8 0 0 1-8-8V48h-57.25a65.42 65.42 0 0 0-6.5-9.81C196.72 23.88 179.59 16 160 16c-37.68 0-64 29.61-64 72v144c0 25 20.34 40 40 40a39.57 39.57 0 0 0 40-40V80h-32v152a7.75 7.75 0 0 1-8 8c-2.23 0-8-1.44-8-8V88c0-19.34 8.41-40 32-40c29.69 0 32 30.15 32 39.38v138.75c0 17.45-5.47 33.23-15.41 44.46C166.5 282 152.47 288 136 288s-30.5-6-40.59-17.41C85.47 259.36 80 243.58 80 226.13V144H48v82.13c0 51.51 33.19 89.63 80 93.53V468a12 12 0 0 0 12 12h312a12 12 0 0 0 12-12V240z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$c9 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M308 208h146.31a2 2 0 0 0 1.42-3.41L307.41 56.27a2 2 0 0 0-3.41 1.42V204a4 4 0 0 0 4 4z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7i = [_hoisted_2$ec, _hoisted_3$c9];
    vue.defineComponent({
      name: 'DocumentAttachSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ec, _hoisted_4$7i);
      }
    });

    const _hoisted_1$eb = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$eb = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M288 192h129.81a2 2 0 0 0 1.41-3.41L275.41 44.78a2 2 0 0 0-3.41 1.41V176a16 16 0 0 0 16 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$c8 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 272c-8.82 0-16 6.28-16 14v18h32v-18c0-7.72-7.18-14-16-14z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7h = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M428 224H288a48 48 0 0 1-48-48V36a4 4 0 0 0-4-4h-92a64 64 0 0 0-64 64v320a64 64 0 0 0 64 64h224a64 64 0 0 0 64-64V228a4 4 0 0 0-4-4zm-92 160a32 32 0 0 1-32 32h-96a32 32 0 0 1-32-32v-48a32 32 0 0 1 32-32v-18c0-25.36 21.53-46 48-46s48 20.64 48 46v18a32 32 0 0 1 32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3x = [_hoisted_2$eb, _hoisted_3$c8, _hoisted_4$7h];
    vue.defineComponent({
      name: 'DocumentLock',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$eb, _hoisted_5$3x);
      }
    });

    const _hoisted_1$ea = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ea = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M288 304v-18c0-16.63-14.26-30-32-30s-32 13.37-32 30v18',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$c7 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M304 416h-96a32 32 0 0 1-32-32v-48a32 32 0 0 1 32-32h96a32 32 0 0 1 32 32v48a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7g = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 221.25V416a48 48 0 0 1-48 48H144a48 48 0 0 1-48-48V96a48 48 0 0 1 48-48h98.75a32 32 0 0 1 22.62 9.37l141.26 141.26a32 32 0 0 1 9.37 22.62z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3w = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 50.88V176a32 32 0 0 0 32 32h125.12',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1y = [_hoisted_2$ea, _hoisted_3$c7, _hoisted_4$7g, _hoisted_5$3w];
    vue.defineComponent({
      name: 'DocumentLockOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ea, _hoisted_6$1y);
      }
    });

    const _hoisted_1$e9 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$e9 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M276 192h146.31a2 2 0 0 0 1.42-3.41L275.41 40.27a2 2 0 0 0-3.41 1.42V188a4 4 0 0 0 4 4z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$c6 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 272c-8.82 0-16 6.28-16 14v18h32v-18c0-7.72-7.18-14-16-14z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7f = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M248 224a8 8 0 0 1-8-8V32H92a12 12 0 0 0-12 12v424a12 12 0 0 0 12 12h328a12 12 0 0 0 12-12V224zm88 175.91A16.1 16.1 0 0 1 319.91 416H192.09A16.1 16.1 0 0 1 176 399.91V320c0-10 7-16 16-16h16v-18c0-25.36 21.53-46 48-46s48 20.64 48 46v18h16a15.8 15.8 0 0 1 16 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3v = [_hoisted_2$e9, _hoisted_3$c6, _hoisted_4$7f];
    vue.defineComponent({
      name: 'DocumentLockSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$e9, _hoisted_5$3v);
      }
    });

    const _hoisted_1$e8 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$e8 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 221.25V416a48 48 0 0 1-48 48H144a48 48 0 0 1-48-48V96a48 48 0 0 1 48-48h98.75a32 32 0 0 1 22.62 9.37l141.26 141.26a32 32 0 0 1 9.37 22.62z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$c5 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 56v120a32 32 0 0 0 32 32h120',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7e = [_hoisted_2$e8, _hoisted_3$c5];
    vue.defineComponent({
      name: 'DocumentOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$e8, _hoisted_4$7e);
      }
    });

    const _hoisted_1$e7 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$e7 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M240 216V32H92a12 12 0 0 0-12 12v424a12 12 0 0 0 12 12h328a12 12 0 0 0 12-12V224H248a8 8 0 0 1-8-8z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$c4 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M272 41.69V188a4 4 0 0 0 4 4h146.31a2 2 0 0 0 1.42-3.41L275.41 40.27a2 2 0 0 0-3.41 1.42z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7d = [_hoisted_2$e7, _hoisted_3$c4];
    vue.defineComponent({
      name: 'DocumentSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$e7, _hoisted_4$7d);
      }
    });

    const _hoisted_1$e6 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$e6 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M428 224H288a48 48 0 0 1-48-48V36a4 4 0 0 0-4-4h-92a64 64 0 0 0-64 64v320a64 64 0 0 0 64 64h224a64 64 0 0 0 64-64V228a4 4 0 0 0-4-4zm-92 160H176a16 16 0 0 1 0-32h160a16 16 0 0 1 0 32zm0-80H176a16 16 0 0 1 0-32h160a16 16 0 0 1 0 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$c3 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M419.22 188.59L275.41 44.78a2 2 0 0 0-3.41 1.41V176a16 16 0 0 0 16 16h129.81a2 2 0 0 0 1.41-3.41z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7c = [_hoisted_2$e6, _hoisted_3$c3];
    vue.defineComponent({
      name: 'DocumentText',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$e6, _hoisted_4$7c);
      }
    });

    const _hoisted_1$e5 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$e5 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 221.25V416a48 48 0 0 1-48 48H144a48 48 0 0 1-48-48V96a48 48 0 0 1 48-48h98.75a32 32 0 0 1 22.62 9.37l141.26 141.26a32 32 0 0 1 9.37 22.62z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$c2 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 56v120a32 32 0 0 0 32 32h120',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7b = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M176 288h160'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3u = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M176 368h160'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1x = [_hoisted_2$e5, _hoisted_3$c2, _hoisted_4$7b, _hoisted_5$3u];
    vue.defineComponent({
      name: 'DocumentTextOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$e5, _hoisted_6$1x);
      }
    });

    const _hoisted_1$e4 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$e4 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M272 41.69V188a4 4 0 0 0 4 4h146.31a2 2 0 0 0 1.42-3.41L275.41 40.27a2 2 0 0 0-3.41 1.42z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$c1 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M248 224a8 8 0 0 1-8-8V32H92a12 12 0 0 0-12 12v424a12 12 0 0 0 12 12h328a12 12 0 0 0 12-12V224zm104 160H160v-32h192zm0-80H160v-32h192z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7a = [_hoisted_2$e4, _hoisted_3$c1];
    vue.defineComponent({
      name: 'DocumentTextSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$e4, _hoisted_4$7a);
      }
    });

    const _hoisted_1$e3 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$e3 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M298.39 248a4 4 0 0 0 2.86-6.8l-78.4-79.72a4 4 0 0 0-6.85 2.81V236a12 12 0 0 0 12 12z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$c0 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M197 267a43.67 43.67 0 0 1-13-31v-92h-72a64.19 64.19 0 0 0-64 64v224a64 64 0 0 0 64 64h144a64 64 0 0 0 64-64V280h-92a43.61 43.61 0 0 1-31-13z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$79 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M372 120h70.39a4 4 0 0 0 2.86-6.8l-78.4-79.72a4 4 0 0 0-6.85 2.81V108a12 12 0 0 0 12 12z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3t = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M372 152a44.34 44.34 0 0 1-44-44V16H220a60.07 60.07 0 0 0-60 60v36h42.12A40.81 40.81 0 0 1 231 124.14l109.16 111a41.11 41.11 0 0 1 11.83 29V400h53.05c32.51 0 58.95-26.92 58.95-60V152z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1w = [_hoisted_2$e3, _hoisted_3$c0, _hoisted_4$79, _hoisted_5$3t];
    vue.defineComponent({
      name: 'Documents',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$e3, _hoisted_6$1w);
      }
    });

    const _hoisted_1$e2 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$e2 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 264.13V436c0 24.3-19.05 44-42.95 44H107c-23.95 0-43-19.7-43-44V172a44.26 44.26 0 0 1 44-44h94.12a24.55 24.55 0 0 1 17.49 7.36l109.15 111a25.4 25.4 0 0 1 7.24 17.77z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$b$ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M200 128v108a28.34 28.34 0 0 0 28 28h108',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$78 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M176 128V76a44.26 44.26 0 0 1 44-44h94a24.83 24.83 0 0 1 17.61 7.36l109.15 111A25.09 25.09 0 0 1 448 168v172c0 24.3-19.05 44-42.95 44H344',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3s = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M312 32v108a28.34 28.34 0 0 0 28 28h108',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1v = [_hoisted_2$e2, _hoisted_3$b$, _hoisted_4$78, _hoisted_5$3s];
    vue.defineComponent({
      name: 'DocumentsOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$e2, _hoisted_6$1v);
      }
    });

    const _hoisted_1$e1 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$e1 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M307.94 248L216 154.52V242a6 6 0 0 0 6 6z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$b_ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M184 268V144H60a12 12 0 0 0-12 12v328a12 12 0 0 0 12 12h248a12 12 0 0 0 12-12V280H196a12 12 0 0 1-12-12z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$77 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M366 120h85.94L360 26.52V114a6 6 0 0 0 6 6z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3r = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M340 152a12 12 0 0 1-12-12V16H172a12 12 0 0 0-12 12v84h42.12A40.81 40.81 0 0 1 231 124.14l109.16 111a41.11 41.11 0 0 1 11.83 29V400H452a12 12 0 0 0 12-12V152z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1u = [_hoisted_2$e1, _hoisted_3$b_, _hoisted_4$77, _hoisted_5$3r];
    vue.defineComponent({
      name: 'DocumentsSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$e1, _hoisted_6$1u);
      }
    });

    const _hoisted_1$e0 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$e0 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M376 160H272v153.37l52.69-52.68a16 16 0 0 1 22.62 22.62l-80 80a16 16 0 0 1-22.62 0l-80-80a16 16 0 0 1 22.62-22.62L240 313.37V160H136a56.06 56.06 0 0 0-56 56v208a56.06 56.06 0 0 0 56 56h240a56.06 56.06 0 0 0 56-56V216a56.06 56.06 0 0 0-56-56z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bZ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M272 48a16 16 0 0 0-32 0v112h32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$76 = [_hoisted_2$e0, _hoisted_3$bZ];
    vue.defineComponent({
      name: 'Download',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$e0, _hoisted_4$76);
      }
    });

    const _hoisted_1$d$ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$d$ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 176h40a40 40 0 0 1 40 40v208a40 40 0 0 1-40 40H136a40 40 0 0 1-40-40V216a40 40 0 0 1 40-40h40',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bY = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M176 272l80 80l80-80'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$75 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 48v288'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3q = [_hoisted_2$d$, _hoisted_3$bY, _hoisted_4$75];
    vue.defineComponent({
      name: 'DownloadOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$d$, _hoisted_5$3q);
      }
    });

    const _hoisted_1$d_ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$d_ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M272 160v147.37l64-64L358.63 266L256 368.63L153.37 266L176 243.37l64 64V160H92a12 12 0 0 0-12 12v296a12 12 0 0 0 12 12h328a12 12 0 0 0 12-12V172a12 12 0 0 0-12-12z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bX = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M240 32h32v128h-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$74 = [_hoisted_2$d_, _hoisted_3$bX];
    vue.defineComponent({
      name: 'DownloadSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$d_, _hoisted_4$74);
      }
    });

    const _hoisted_1$dZ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dZ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M408 112H184a72 72 0 0 0-72 72v224a72 72 0 0 0 72 72h224a72 72 0 0 0 72-72V184a72 72 0 0 0-72-72zm-32.45 200H312v63.55c0 8.61-6.62 16-15.23 16.43A16 16 0 0 1 280 376v-64h-63.55c-8.61 0-16-6.62-16.43-15.23A16 16 0 0 1 216 280h64v-63.55c0-8.61 6.62-16 15.23-16.43A16 16 0 0 1 312 216v64h64a16 16 0 0 1 16 16.77c-.42 8.61-7.84 15.23-16.45 15.23z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bW = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M395.88 80A72.12 72.12 0 0 0 328 32H104a72 72 0 0 0-72 72v224a72.12 72.12 0 0 0 48 67.88V160a80 80 0 0 1 80-80z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$73 = [_hoisted_2$dZ, _hoisted_3$bW];
    vue.defineComponent({
      name: 'Duplicate',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dZ, _hoisted_4$73);
      }
    });

    const _hoisted_1$dY = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dY = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '128',
      y: '128',
      width: '336',
      height: '336',
      rx: '57',
      ry: '57',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bV = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M383.5 128l.5-24a56.16 56.16 0 0 0-56-56H112a64.19 64.19 0 0 0-64 64v216a56.16 56.16 0 0 0 56 56h24',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$72 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M296 216v160'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3p = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M376 296H216'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1t = [_hoisted_2$dY, _hoisted_3$bV, _hoisted_4$72, _hoisted_5$3p];
    vue.defineComponent({
      name: 'DuplicateOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dY, _hoisted_6$1t);
      }
    });

    const _hoisted_1$dX = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dX = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M112 80h288V56a24 24 0 0 0-24-24H66a34 34 0 0 0-34 34v310a24 24 0 0 0 24 24h24V112a32 32 0 0 1 32-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bU = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M456 112H136a24 24 0 0 0-24 24v320a24 24 0 0 0 24 24h320a24 24 0 0 0 24-24V136a24 24 0 0 0-24-24zm-64 200h-80v80h-32v-80h-80v-32h80v-80h32v80h80z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$71 = [_hoisted_2$dX, _hoisted_3$bU];
    vue.defineComponent({
      name: 'DuplicateSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dX, _hoisted_4$71);
      }
    });

    const _hoisted_1$dW = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dW = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 16C159 16 80 95 80 192v206.57a97.59 97.59 0 0 0 28 68.49A94.51 94.51 0 0 0 176 496c36.86 0 67.18-15.62 90.12-46.42c4.48-6 9.55-14.74 15.42-24.85c15.32-26.37 36.29-62.47 63.17-80.74c25.77-17.51 47.23-39.54 62-63.72C423.51 252.94 432 223.24 432 192c0-97-78.95-176-176-176zm96 184a16 16 0 0 1-16-16c0-39.7-35.89-72-80-72s-80 32.3-80 72v30.42c27.19-7.84 58.4-6.72 64.28-6.42a48 48 0 0 1 38.6 75.9c-.3.41-.61.81-.95 1.2c-16.55 19-36 45.48-38.46 55a16 16 0 0 1-30.94-8.14c5.51-20.94 36.93-58.2 44.66-67.15A16 16 0 0 0 239.82 240h-.88c-16.6-.89-45.89.8-62.94 8.31V304a16 16 0 0 1-32 0V184c0-57.35 50.24-104 112-104s112 46.65 112 104a16 16 0 0 1-16 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bT = [_hoisted_2$dW];
    vue.defineComponent({
      name: 'Ear',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dW, _hoisted_3$bT);
      }
    });

    const _hoisted_1$dV = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dV = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M335.72 330.76C381.73 299.5 416 251.34 416 192a160 160 0 0 0-320 0v206.57c0 44.26 35.74 81.43 80 81.43h0c44.26 0 66.83-25.94 77.29-40c14.77-19.81 41.71-81.56 82.43-109.24z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bS = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M160 304V184c0-48.4 43.2-88 96-88h0c52.8 0 96 39.6 96 88',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$70 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M160 239c25-18 79.82-15 79.82-15c26 0 41.17 29.42 26 50.6c0 0-36.86 42.4-41.86 61.4',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3o = [_hoisted_2$dV, _hoisted_3$bS, _hoisted_4$70];
    vue.defineComponent({
      name: 'EarOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dV, _hoisted_5$3o);
      }
    });

    const _hoisted_1$dU = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dU = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M380.48 68.09C347.09 34.5 302.88 16 256 16C159 16 80 95 80 192v206.57a97.59 97.59 0 0 0 28 68.49A94.49 94.49 0 0 0 176 496c19.93 0 41.06-7.69 62.8-22.87a181.46 181.46 0 0 0 25.88-21.86C327.37 390.16 432 288.06 432 192c0-46.49-18.29-90.49-51.52-123.91zM368 200h-32v-16c0-39.7-35.89-72-80-72s-80 32.3-80 72v30.41c27.5-7.84 59.89-6.62 64.26-6.41a48 48 0 0 1 38.62 75.9c-.3.41-.61.81-.95 1.2c-16.55 19-36 45.49-38.46 55l-4.07 15.47l-30.94-8.14l4.07-15.47c5.51-20.94 36.93-58.2 44.66-67.15A16 16 0 0 0 239.82 240h-.88c-10.67-.58-42.66-.25-62.12 8l-.82.35V320h-32V184c0-57.35 50.24-104 112-104s112 46.65 112 104z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bR = [_hoisted_2$dU];
    vue.defineComponent({
      name: 'EarSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dU, _hoisted_3$bR);
      }
    });

    const _hoisted_1$dT = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dT = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M414.39 97.74A224 224 0 1 0 97.61 414.52A224 224 0 1 0 414.39 97.74zM64 256.13a191.63 191.63 0 0 1 6.7-50.31c7.34 15.8 18 29.45 25.25 45.66c9.37 20.84 34.53 15.06 45.64 33.32c9.86 16.21-.67 36.71 6.71 53.67c5.36 12.31 18 15 26.72 24c8.91 9.08 8.72 21.52 10.08 33.36a305.36 305.36 0 0 0 7.45 41.27c0 .1 0 .21.08.31C117.8 411.13 64 339.8 64 256.13zm192 192a193.12 193.12 0 0 1-32-2.68c.11-2.71.16-5.24.43-7c2.43-15.9 10.39-31.45 21.13-43.35c10.61-11.74 25.15-19.68 34.11-33c8.78-13 11.41-30.5 7.79-45.69c-5.33-22.44-35.82-29.93-52.26-42.1c-9.45-7-17.86-17.82-30.27-18.7c-5.72-.4-10.51.83-16.18-.63c-5.2-1.35-9.28-4.15-14.82-3.42c-10.35 1.36-16.88 12.42-28 10.92c-10.55-1.41-21.42-13.76-23.82-23.81c-3.08-12.92 7.14-17.11 18.09-18.26c4.57-.48 9.7-1 14.09.68c5.78 2.14 8.51 7.8 13.7 10.66c9.73 5.34 11.7-3.19 10.21-11.83c-2.23-12.94-4.83-18.21 6.71-27.12c8-6.14 14.84-10.58 13.56-21.61c-.76-6.48-4.31-9.41-1-15.86c2.51-4.91 9.4-9.34 13.89-12.27c11.59-7.56 49.65-7 34.1-28.16c-4.57-6.21-13-17.31-21-18.83c-10-1.89-14.44 9.27-21.41 14.19c-7.2 5.09-21.22 10.87-28.43 3c-9.7-10.59 6.43-14.06 10-21.46c1.65-3.45 0-8.24-2.78-12.75q5.41-2.28 11-4.23a15.6 15.6 0 0 0 8 3c6.69.44 13-3.18 18.84 1.38c6.48 5 11.15 11.32 19.75 12.88c8.32 1.51 17.13-3.34 19.19-11.86c1.25-5.18 0-10.65-1.2-16a190.83 190.83 0 0 1 105 32.21c-2-.76-4.39-.67-7.34.7c-6.07 2.82-14.67 10-15.38 17.12c-.81 8.08 11.11 9.22 16.77 9.22c8.5 0 17.11-3.8 14.37-13.62c-1.19-4.26-2.81-8.69-5.42-11.37a193.27 193.27 0 0 1 18 14.14c-.09.09-.18.17-.27.27c-5.76 6-12.45 10.75-16.39 18.05c-2.78 5.14-5.91 7.58-11.54 8.91c-3.1.73-6.64 1-9.24 3.08c-7.24 5.7-3.12 19.4 3.74 23.51c8.67 5.19 21.53 2.75 28.07-4.66c5.11-5.8 8.12-15.87 17.31-15.86a15.4 15.4 0 0 1 10.82 4.41c3.8 3.94 3.05 7.62 3.86 12.54c1.43 8.74 9.14 4 13.83-.41a192.12 192.12 0 0 1 9.24 18.77c-5.16 7.43-9.26 15.53-21.67 6.87c-7.43-5.19-12-12.72-21.33-15.06c-8.15-2-16.5.08-24.55 1.47c-9.15 1.59-20 2.29-26.94 9.22c-6.71 6.68-10.26 15.62-17.4 22.33c-13.81 13-19.64 27.19-10.7 45.57c8.6 17.67 26.59 27.26 46 26c19.07-1.27 38.88-12.33 38.33 15.38c-.2 9.81 1.85 16.6 4.86 25.71c2.79 8.4 2.6 16.54 3.24 25.21a158 158 0 0 0 4.74 30.07A191.75 191.75 0 0 1 256 448.13z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bQ = [_hoisted_2$dT];
    vue.defineComponent({
      name: 'Earth',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dT, _hoisted_3$bQ);
      }
    });

    const _hoisted_1$dS = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dS = /*#__PURE__*/vue.createStaticVNode('<path d="M464 256c0-114.87-93.13-208-208-208S48 141.13 48 256s93.13 208 208 208s208-93.13 208-208z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path d="M445.57 172.14c-16.06.1-14.48 29.73-34.49 15.75c-7.43-5.18-12-12.71-21.33-15c-8.15-2-16.5.08-24.55 1.47c-9.15 1.58-20 2.29-26.94 9.22c-6.71 6.67-10.26 15.62-17.4 22.33c-13.81 13-19.64 27.19-10.7 45.57c8.6 17.67 26.59 27.26 46 26c19.07-1.27 38.88-12.33 38.33 15.38c-.2 9.8 1.85 16.6 4.86 25.71c2.79 8.4 2.6 16.54 3.24 25.21c1.18 16.2 4.16 34.36 12.2 48.67l15-21.16c1.85-2.62 5.72-6.29 6.64-9.38c1.63-5.47-1.58-14.87-1.95-21s-.19-12.34-1.13-18.47c-1.32-8.59-6.4-16.64-7.1-25.13c-1.29-15.81 1.6-28.43-10.58-41.65c-11.76-12.75-29-15.81-45.47-13.22c-8.3 1.3-41.71 6.64-28.3-12.33c2.65-3.73 7.28-6.79 10.26-10.34c2.59-3.09 4.84-8.77 7.88-11.18s17-5.18 21-3.95s8.17 7 11.64 9.56a49.89 49.89 0 0 0 21.81 9.36c13.66 2 42.22-5.94 42-23.46c-.04-8.4-7.84-20.1-10.92-27.96z" fill="currentColor"></path><path d="M287.45 316.3c-5.33-22.44-35.82-29.94-52.26-42.11c-9.45-7-17.86-17.81-30.27-18.69c-5.72-.41-10.51.83-16.18-.64c-5.2-1.34-9.28-4.14-14.82-3.41c-10.35 1.36-16.88 12.42-28 10.92c-10.55-1.42-21.42-13.76-23.82-23.81c-3.08-12.92 7.14-17.11 18.09-18.26c4.57-.48 9.7-1 14.09.67c5.78 2.15 8.51 7.81 13.7 10.67c9.73 5.33 11.7-3.19 10.21-11.83c-2.23-12.94-4.83-18.22 6.71-27.12c8-6.14 14.84-10.58 13.56-21.61c-.76-6.48-4.31-9.41-1-15.86c2.51-4.91 9.4-9.34 13.89-12.27c11.59-7.56 49.65-7 34.1-28.16c-4.57-6.21-13-17.31-21-18.83c-10-1.89-14.44 9.27-21.41 14.19c-7.2 5.09-21.22 10.87-28.43 3c-9.7-10.59 6.43-14.07 10-21.46s-8.27-21.36-14.61-24.9l-29.81 33.43a41.52 41.52 0 0 0 8.34 31.86c5.93 7.63 15.37 10.08 15.8 20.5c.42 10-1.14 15.12-7.68 22.15c-2.83 3-4.83 7.26-7.71 10.07c-3.53 3.43-2.22 2.38-7.73 3.32c-10.36 1.75-19.18 4.45-29.19 7.21C95.34 199.94 93.8 172.69 86.2 162l-25 20.19c-.27 3.31 4.1 9.4 5.29 13c6.83 20.57 20.61 36.48 29.51 56.16c9.37 20.84 34.53 15.06 45.64 33.32c9.86 16.2-.67 36.71 6.71 53.67c5.36 12.31 18 15 26.72 24c8.91 9.09 8.72 21.53 10.08 33.36a305.22 305.22 0 0 0 7.45 41.28c1.21 4.69 2.32 10.89 5.53 14.76c2.2 2.66 9.75 4.95 6.7 5.83c4.26.7 11.85 4.68 15.4 1.76c4.68-3.84 3.43-15.66 4.24-21c2.43-15.9 10.39-31.45 21.13-43.35c10.61-11.74 25.15-19.69 34.11-33c8.73-12.98 11.36-30.49 7.74-45.68zm-33.39 26.32c-6 10.71-19.36 17.88-27.95 26.39c-2.33 2.31-7.29 10.31-10.21 8.58c-2.09-1.24-2.8-11.62-3.57-14a61.17 61.17 0 0 0-21.71-29.95c-3.13-2.37-10.89-5.45-12.68-8.7c-2-3.53-.2-11.86-.13-15.7c.11-5.6-2.44-14.91-1.06-20c1.6-5.87-1.48-2.33 3.77-3.49c2.77-.62 14.21 1.39 17.66 2.11c5.48 1.14 8.5 4.55 12.82 8c11.36 9.11 23.87 16.16 36.6 23.14c9.86 5.46 12.76 12.37 6.46 23.62z" fill="currentColor"></path><path d="M184.46 67.09c4.74 4.63 9.2 10.11 16.27 10.57c6.69.45 13-3.17 18.84 1.38c6.48 5 11.15 11.33 19.75 12.89c8.32 1.51 17.13-3.35 19.19-11.86c2-8.11-2.31-16.93-2.57-25.07c0-1.13.61-6.15-.17-7c-.58-.64-5.42.08-6.16.1q-8.13.24-16.22 1.12a207.1 207.1 0 0 0-57.18 14.65c2.43 1.68 5.48 2.35 8.25 3.22z" fill="currentColor"></path><path d="M356.4 123.27c8.49 0 17.11-3.8 14.37-13.62c-2.3-8.23-6.22-17.16-15.76-12.72c-6.07 2.82-14.67 10-15.38 17.12c-.81 8.08 11.11 9.22 16.77 9.22z" fill="currentColor"></path><path d="M349.62 166.24c8.67 5.19 21.53 2.75 28.07-4.66c5.11-5.8 8.12-15.87 17.31-15.86a15.4 15.4 0 0 1 10.82 4.41c3.8 3.93 3.05 7.62 3.86 12.54c1.81 11.05 13.66.63 16.75-3.65c2-2.79 4.71-6.93 3.8-10.56c-.84-3.39-4.8-7-6.56-10.11c-5.14-9-9.37-19.47-17.07-26.74c-7.41-7-16.52-6.19-23.55 1.08c-5.76 6-12.45 10.75-16.39 18.05c-2.78 5.13-5.91 7.58-11.54 8.91c-3.1.73-6.64 1-9.24 3.08c-7.24 5.7-3.12 19.39 3.74 23.51z" fill="currentColor"></path>', 6);

    const _hoisted_8$u = [_hoisted_2$dS];
    vue.defineComponent({
      name: 'EarthOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dS, _hoisted_8$u);
      }
    });

    const _hoisted_1$dR = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dR = /*#__PURE__*/vue.createStaticVNode('<path d="M267 474l-.8-.13a.85.85 0 0 0 .8.13z" fill="currentColor"></path><path d="M448.9 187.78a5.51 5.51 0 0 0-10.67-.63A5.52 5.52 0 0 1 433 191h-15.47a5.48 5.48 0 0 1-2.84-.79l-22.38-13.42a5.48 5.48 0 0 0-2.84-.79h-35.8a5.48 5.48 0 0 0-3.06.93l-44.15 29.43A5.52 5.52 0 0 0 304 211v41.74a5.51 5.51 0 0 0 2.92 4.87l57.89 30.9a5.55 5.55 0 0 1 2.92 4.8l.27 23.49a5.53 5.53 0 0 0 2.85 4.75l23.26 12.87a5.54 5.54 0 0 1 2.85 4.83v48.6a5.52 5.52 0 0 0 9.17 4.14c9.38-8.26 22.83-20.32 24.62-23.08q4.44-6.87 8.33-14.07a207.39 207.39 0 0 0 13.6-31c12.68-36.71 2.66-102.7-3.78-136.06z" fill="currentColor"></path><path d="M286.4 302.8l-61.33-46a4 4 0 0 0-2.4-.8h-29.1a3.78 3.78 0 0 1-2.68-1.11l-13.72-13.72a4 4 0 0 0-2.83-1.17h-53.19a3.79 3.79 0 0 1-2.68-6.47l8.42-8.42a3.78 3.78 0 0 1 2.68-1.11h32.37a8 8 0 0 0 7.7-5.83l6.89-24.5a4 4 0 0 1 2-2.47L206 177.06a3.79 3.79 0 0 0 2.05-3.37v-12.5a3.82 3.82 0 0 1 .68-2.17l14.6-21.02a3.75 3.75 0 0 1 1.78-1.38l20.43-7.67a3.79 3.79 0 0 0 2.46-3.55V114a3.8 3.8 0 0 0-1.69-3.16l-20.48-13.62A3.83 3.83 0 0 0 222 97l-27.88 13.94a3.78 3.78 0 0 1-4-.41l-13.22-10.45a3.8 3.8 0 0 1 .1-6l10.74-7.91a3.78 3.78 0 0 0-.09-6.16l-16.73-11.67a3.78 3.78 0 0 0-4-.22c-6.05 3.31-23.8 13.11-30.1 17.52a209.48 209.48 0 0 0-68.16 80c-1.82 3.76-4.07 7.59-4.29 11.72s-3.46 13.35-4.81 17.08a3.78 3.78 0 0 0 .24 3.1l35.69 65.58a3.74 3.74 0 0 0 1.38 1.44l37.55 22.54a3.78 3.78 0 0 1 1.81 2.73l7.52 54.54a3.82 3.82 0 0 0 1.61 2.61l29.3 20.14a4 4 0 0 1 1.65 2.48l15.54 73.8a3.6 3.6 0 0 0 .49 1.22c1.46 2.36 7.28 11 14.3 12.28c-.65.18-1.23.59-1.88.78a47.63 47.63 0 0 1 5 1.16c2 .54 4 1 6 1.43c3.13.62 3.44 1.1 4.94-1.68c2-3.72 4.29-5 6-5.46a3.85 3.85 0 0 0 2.89-2.9l10.07-46.68a4 4 0 0 1 1.6-2.42l45-31.9a4 4 0 0 0 1.69-3.27V306a4 4 0 0 0-1.55-3.2z" fill="currentColor"></path><path d="M262 48s-3.65.21-4.39.23q-8.13.24-16.22 1.12A207.45 207.45 0 0 0 184.21 64c2.43 1.68-1.75 3.22-1.75 3.22L189 80h35l24 12l21-12z" fill="currentColor"></path><path d="M354.23 120.06l16.11-14a4 4 0 0 0-.94-6.65l-18.81-8.73a4 4 0 0 0-5.3 1.9l-7.75 16.21a4 4 0 0 0 1.49 5.11l10.46 6.54a4 4 0 0 0 4.74-.38z" fill="currentColor"></path><path d="M429.64 140.67l-5.83-9c-.09-.14-.17-.28-.25-.43c-1.05-2.15-9.74-19.7-17-26.51c-5.45-5.15-7-3.67-7.43-2.53a3.77 3.77 0 0 1-1.19 1.6l-28.84 23.31a4 4 0 0 1-2.51.89h-14.93a4 4 0 0 0-2.83 1.17l-12 12a4 4 0 0 0 0 5.66l12 12a4 4 0 0 0 2.83 1.17h75.17a4 4 0 0 0 4-4.17l-.55-13.15a4 4 0 0 0-.64-2.01z" fill="currentColor"></path><path d="M256 72a184 184 0 1 1-130.1 53.9A182.77 182.77 0 0 1 256 72m0-40C132.3 32 32 132.3 32 256s100.3 224 224 224s224-100.3 224-224S379.7 32 256 32z" fill="currentColor"></path>', 7);

    const _hoisted_9$9 = [_hoisted_2$dR];
    vue.defineComponent({
      name: 'EarthSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dR, _hoisted_9$9);
      }
    });

    const _hoisted_1$dQ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dQ = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '80',
      y: '112',
      width: '352',
      height: '208',
      rx: '12',
      ry: '12',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bP = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M432 64H272V48a16 16 0 0 0-32 0v16H80a48.05 48.05 0 0 0-48 48v208a48.05 48.05 0 0 0 48 48h42.79l-26.17 91.6a16 16 0 1 0 30.76 8.8L156.07 368H240v48a16 16 0 0 0 32 0v-48h83.93l28.69 100.4a16 16 0 1 0 30.76-8.8L389.21 368H432a48.05 48.05 0 0 0 48-48V112a48.05 48.05 0 0 0-48-48zm16 256a16 16 0 0 1-16 16H80a16 16 0 0 1-16-16V112a16 16 0 0 1 16-16h352a16 16 0 0 1 16 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6$ = [_hoisted_2$dQ, _hoisted_3$bP];
    vue.defineComponent({
      name: 'Easel',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dQ, _hoisted_4$6$);
      }
    });

    const _hoisted_1$dP = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dP = /*#__PURE__*/vue.createStaticVNode('<rect x="48" y="80" width="416" height="272" rx="32" ry="32" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></rect><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 416v-64"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 80V48"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M400 464l-32-112"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M112 464l32-112"></path>', 5);

    const _hoisted_7$T = [_hoisted_2$dP];
    vue.defineComponent({
      name: 'EaselOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dP, _hoisted_7$T);
      }
    });

    const _hoisted_1$dO = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dO = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M468 64H278V32h-44v32H44a12 12 0 0 0-12 12v280a12 12 0 0 0 12 12h78.19L89.93 470.46l36.53 9.61L161.74 368H234v64h44v-64h71.84l31 111.7l36.83-8.57L389.05 368H468a12 12 0 0 0 12-12V76a12 12 0 0 0-12-12zm-26 266H70V102h372z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bO = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M88 120h336v192H88z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6_ = [_hoisted_2$dO, _hoisted_3$bO];
    vue.defineComponent({
      name: 'EaselSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dO, _hoisted_4$6_);
      }
    });

    const _hoisted_1$dN = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dN = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 480c-52.57 0-96.72-17.54-127.7-50.73C96.7 395.4 80 346.05 80 286.55C80 230.5 101.48 168 138.93 115C175.65 63 219.41 32 256 32s80.35 31 117.07 83C410.52 168 432 230.5 432 286.55c0 59.5-16.7 108.85-48.3 142.72C352.72 462.46 308.57 480 256 480z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bN = [_hoisted_2$dN];
    vue.defineComponent({
      name: 'Egg',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dN, _hoisted_3$bN);
      }
    });

    const _hoisted_1$dM = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dM = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C192 48 96 171.69 96 286.55S160 464 256 464s160-62.59 160-177.45S320 48 256 48z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bM = [_hoisted_2$dM];
    vue.defineComponent({
      name: 'EggOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dM, _hoisted_3$bM);
      }
    });

    const _hoisted_1$dL = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dL = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M418.39 381.05c-8.08 21.68-19.76 40.1-34.72 54.75c-14.38 14.07-32.1 24.95-52.67 32.34C309.08 476 283.85 480 256 480s-53.08-4-75-11.86c-20.57-7.39-38.29-18.27-52.67-32.34c-15-14.65-26.64-33.07-34.72-54.75C84.58 356.82 80 328.53 80 296.94c0-30.28 6.68-62.57 19.86-96A371 371 0 0 1 151 111.42C195.78 53.56 241 32 256 32s62.67 22.4 105 79.42c18.33 24.71 38.87 58.34 51.17 89.54c13.18 33.41 19.86 65.7 19.86 96c-.03 31.57-4.61 59.86-13.64 84.09z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bL = [_hoisted_2$dL];
    vue.defineComponent({
      name: 'EggSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dL, _hoisted_3$bL);
      }
    });

    const _hoisted_1$dK = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dK = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 464c-114.69 0-208-93.31-208-208S141.31 48 256 48s208 93.31 208 208s-93.31 208-208 208z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bK = [_hoisted_2$dK];
    vue.defineComponent({
      name: 'Ellipse',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dK, _hoisted_3$bK);
      }
    });

    const _hoisted_1$dJ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dJ = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '192',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bJ = [_hoisted_2$dJ];
    vue.defineComponent({
      name: 'EllipseOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dJ, _hoisted_3$bJ);
      }
    });

    const _hoisted_1$dI = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dI = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 464c-114.69 0-208-93.31-208-208S141.31 48 256 48s208 93.31 208 208s-93.31 208-208 208z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bI = [_hoisted_2$dI];
    vue.defineComponent({
      name: 'EllipseSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dI, _hoisted_3$bI);
      }
    });

    const _hoisted_1$dH = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dH = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '48',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bH = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '416',
      cy: '256',
      r: '48',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6Z = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '96',
      cy: '256',
      r: '48',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3n = [_hoisted_2$dH, _hoisted_3$bH, _hoisted_4$6Z];
    vue.defineComponent({
      name: 'EllipsisHorizontal',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dH, _hoisted_5$3n);
      }
    });

    const _hoisted_1$dG = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dG = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '26',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bG = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '346',
      cy: '256',
      r: '26',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6Y = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '166',
      cy: '256',
      r: '26',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3m = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1s = [_hoisted_2$dG, _hoisted_3$bG, _hoisted_4$6Y, _hoisted_5$3m];
    vue.defineComponent({
      name: 'EllipsisHorizontalCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dG, _hoisted_6$1s);
      }
    });

    const _hoisted_1$dF = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dF = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '26',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bF = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '346',
      cy: '256',
      r: '26',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6X = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '166',
      cy: '256',
      r: '26',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3l = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1r = [_hoisted_2$dF, _hoisted_3$bF, _hoisted_4$6X, _hoisted_5$3l];
    vue.defineComponent({
      name: 'EllipsisHorizontalCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dF, _hoisted_6$1r);
      }
    });

    const _hoisted_1$dE = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dE = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.13 48 48 141.13 48 256s93.13 208 208 208s208-93.13 208-208S370.87 48 256 48zm-90 234a26 26 0 1 1 26-26a26 26 0 0 1-26 26zm90 0a26 26 0 1 1 26-26a26 26 0 0 1-26 26zm90 0a26 26 0 1 1 26-26a26 26 0 0 1-26 26z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bE = [_hoisted_2$dE];
    vue.defineComponent({
      name: 'EllipsisHorizontalCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dE, _hoisted_3$bE);
      }
    });

    const _hoisted_1$dD = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dD = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '32',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bD = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '416',
      cy: '256',
      r: '32',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6W = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '96',
      cy: '256',
      r: '32',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3k = [_hoisted_2$dD, _hoisted_3$bD, _hoisted_4$6W];
    vue.defineComponent({
      name: 'EllipsisHorizontalOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dD, _hoisted_5$3k);
      }
    });

    const _hoisted_1$dC = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dC = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '48',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bC = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '416',
      cy: '256',
      r: '48',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6V = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '96',
      cy: '256',
      r: '48',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3j = [_hoisted_2$dC, _hoisted_3$bC, _hoisted_4$6V];
    vue.defineComponent({
      name: 'EllipsisHorizontalSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dC, _hoisted_5$3j);
      }
    });

    const _hoisted_1$dB = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dB = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '48',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bB = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '416',
      r: '48',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6U = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '96',
      r: '48',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3i = [_hoisted_2$dB, _hoisted_3$bB, _hoisted_4$6U];
    vue.defineComponent({
      name: 'EllipsisVertical',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dB, _hoisted_5$3i);
      }
    });

    const _hoisted_1$dA = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dA = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '26',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bA = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '346',
      r: '26',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6T = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '166',
      r: '26',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3h = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1q = [_hoisted_2$dA, _hoisted_3$bA, _hoisted_4$6T, _hoisted_5$3h];
    vue.defineComponent({
      name: 'EllipsisVerticalCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dA, _hoisted_6$1q);
      }
    });

    const _hoisted_1$dz = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dz = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '26',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bz = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '346',
      r: '26',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6S = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '166',
      r: '26',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3g = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1p = [_hoisted_2$dz, _hoisted_3$bz, _hoisted_4$6S, _hoisted_5$3g];
    vue.defineComponent({
      name: 'EllipsisVerticalCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dz, _hoisted_6$1p);
      }
    });

    const _hoisted_1$dy = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dy = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 256c0-114.87-93.13-208-208-208S48 141.13 48 256s93.13 208 208 208s208-93.13 208-208zm-234-90a26 26 0 1 1 26 26a26 26 0 0 1-26-26zm0 90a26 26 0 1 1 26 26a26 26 0 0 1-26-26zm0 90a26 26 0 1 1 26 26a26 26 0 0 1-26-26z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$by = [_hoisted_2$dy];
    vue.defineComponent({
      name: 'EllipsisVerticalCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dy, _hoisted_3$by);
      }
    });

    const _hoisted_1$dx = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dx = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '32',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bx = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '416',
      r: '32',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6R = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '96',
      r: '32',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3f = [_hoisted_2$dx, _hoisted_3$bx, _hoisted_4$6R];
    vue.defineComponent({
      name: 'EllipsisVerticalOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dx, _hoisted_5$3f);
      }
    });

    const _hoisted_1$dw = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dw = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '48',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bw = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '416',
      r: '48',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6Q = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '96',
      r: '48',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3e = [_hoisted_2$dw, _hoisted_3$bw, _hoisted_4$6Q];
    vue.defineComponent({
      name: 'EllipsisVerticalSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dw, _hoisted_5$3e);
      }
    });

    const _hoisted_1$dv = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dv = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M160 136v104h153.37l-52.68-52.69a16 16 0 0 1 22.62-22.62l80 80a16 16 0 0 1 0 22.62l-80 80a16 16 0 0 1-22.62-22.62L313.37 272H160v104a56.06 56.06 0 0 0 56 56h208a56.06 56.06 0 0 0 56-56V136a56.06 56.06 0 0 0-56-56H216a56.06 56.06 0 0 0-56 56z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bv = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 240a16 16 0 0 0 0 32h112v-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6P = [_hoisted_2$dv, _hoisted_3$bv];
    vue.defineComponent({
      name: 'Enter',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dv, _hoisted_4$6P);
      }
    });

    const _hoisted_1$du = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$du = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M176 176v-40a40 40 0 0 1 40-40h208a40 40 0 0 1 40 40v240a40 40 0 0 1-40 40H216a40 40 0 0 1-40-40v-40',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bu = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M272 336l80-80l-80-80'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6O = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M48 256h288'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3d = [_hoisted_2$du, _hoisted_3$bu, _hoisted_4$6O];
    vue.defineComponent({
      name: 'EnterOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$du, _hoisted_5$3d);
      }
    });

    const _hoisted_1$dt = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dt = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M160 240h147.37l-64-64L266 153.37L368.63 256L266 358.63L243.37 336l64-64H160v148a12 12 0 0 0 12 12h296a12 12 0 0 0 12-12V92a12 12 0 0 0-12-12H172a12 12 0 0 0-12 12z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bt = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M32 240h128v32H32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6N = [_hoisted_2$dt, _hoisted_3$bt];
    vue.defineComponent({
      name: 'EnterSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dt, _hoisted_4$6N);
      }
    });

    const _hoisted_1$ds = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ds = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 376V272H191a16 16 0 0 1 0-32h145V136a56.06 56.06 0 0 0-56-56H88a56.06 56.06 0 0 0-56 56v240a56.06 56.06 0 0 0 56 56h192a56.06 56.06 0 0 0 56-56z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bs = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M425.37 272l-52.68 52.69a16 16 0 0 0 22.62 22.62l80-80a16 16 0 0 0 0-22.62l-80-80a16 16 0 0 0-22.62 22.62L425.37 240H336v32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6M = [_hoisted_2$ds, _hoisted_3$bs];
    vue.defineComponent({
      name: 'Exit',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ds, _hoisted_4$6M);
      }
    });

    const _hoisted_1$dr = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dr = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 176v-40a40 40 0 0 0-40-40H88a40 40 0 0 0-40 40v240a40 40 0 0 0 40 40h192a40 40 0 0 0 40-40v-40',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$br = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M384 176l80 80l-80 80'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6L = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M191 256h273'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3c = [_hoisted_2$dr, _hoisted_3$br, _hoisted_4$6L];
    vue.defineComponent({
      name: 'ExitOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dr, _hoisted_5$3c);
      }
    });

    const _hoisted_1$dq = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dq = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M335.69 272h-161v-32h161V92a12 12 0 0 0-12-12h-280a12 12 0 0 0-12 12v328a12 12 0 0 0 12 12h280a12 12 0 0 0 12-12z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bq = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M419.06 272l-64 64l22.63 22.63L480.31 256L377.69 153.37L355.06 176l64 64h-83.37v32h83.37z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6K = [_hoisted_2$dq, _hoisted_3$bq];
    vue.defineComponent({
      name: 'ExitSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dq, _hoisted_4$6K);
      }
    });

    const _hoisted_1$dp = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dp = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M432 320v112H320"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M421.8 421.77L304 304"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M80 192V80h112"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M90.2 90.23L208 208"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M320 80h112v112"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M421.77 90.2L304 208"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M192 432H80V320"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M90.23 421.8L208 304"></path>', 8);

    const _hoisted_10$c = [_hoisted_2$dp];
    vue.defineComponent({
      name: 'Expand',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dp, _hoisted_10$c);
      }
    });

    const _hoisted_1$do = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$do = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M432 320v112H320"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M421.8 421.77L304 304"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M80 192V80h112"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M90.2 90.23L208 208"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M320 80h112v112"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M421.77 90.2L304 208"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M192 432H80V320"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M90.23 421.8L208 304"></path>', 8);

    const _hoisted_10$b = [_hoisted_2$do];
    vue.defineComponent({
      name: 'ExpandOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$do, _hoisted_10$b);
      }
    });

    const _hoisted_1$dn = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dn = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M432 320v112H320"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M421.8 421.77L304 304"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M80 192V80h112"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M90.2 90.23L208 208"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M320 80h112v112"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M421.77 90.2L304 208"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M192 432H80V320"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M90.23 421.8L208 304"></path>', 8);

    const _hoisted_10$a = [_hoisted_2$dn];
    vue.defineComponent({
      name: 'ExpandSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dn, _hoisted_10$a);
      }
    });

    const _hoisted_1$dm = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dm = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M345.14 480H274a18 18 0 0 1-18-18v-27.71a31.32 31.32 0 0 0-9.71-22.77c-7.78-7.59-19.08-11.8-30.89-11.51c-21.36.5-39.4 19.3-39.4 41.06V462a18 18 0 0 1-18 18H87.62A55.62 55.62 0 0 1 32 424.38V354a18 18 0 0 1 18-18h27.71c9.16 0 18.07-3.92 25.09-11a42.06 42.06 0 0 0 12.2-29.92C114.7 273.89 97.26 256 76.91 256H50a18 18 0 0 1-18-18v-70.38A55.62 55.62 0 0 1 87.62 112h55.24a8 8 0 0 0 8-8v-6.48A65.53 65.53 0 0 1 217.54 32c35.49.62 64.36 30.38 64.36 66.33V104a8 8 0 0 0 8 8h55.24A54.86 54.86 0 0 1 400 166.86v55.24a8 8 0 0 0 8 8h5.66c36.58 0 66.34 29 66.34 64.64c0 36.61-29.39 66.4-65.52 66.4H408a8 8 0 0 0-8 8v56A54.86 54.86 0 0 1 345.14 480z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bp = [_hoisted_2$dm];
    vue.defineComponent({
      name: 'ExtensionPuzzle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dm, _hoisted_3$bp);
      }
    });

    const _hoisted_1$dl = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dl = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M413.66 246.1H386a2 2 0 0 1-2-2v-77.24A38.86 38.86 0 0 0 345.14 128H267.9a2 2 0 0 1-2-2V98.34c0-27.14-21.5-49.86-48.64-50.33a49.53 49.53 0 0 0-50.4 49.51V126a2 2 0 0 1-2 2H87.62A39.74 39.74 0 0 0 48 167.62V238a2 2 0 0 0 2 2h26.91c29.37 0 53.68 25.48 54.09 54.85c.42 29.87-23.51 57.15-53.29 57.15H50a2 2 0 0 0-2 2v70.38A39.74 39.74 0 0 0 87.62 464H158a2 2 0 0 0 2-2v-20.93c0-30.28 24.75-56.35 55-57.06c30.1-.7 57 20.31 57 50.28V462a2 2 0 0 0 2 2h71.14A38.86 38.86 0 0 0 384 425.14v-78a2 2 0 0 1 2-2h28.48c27.63 0 49.52-22.67 49.52-50.4s-23.2-48.64-50.34-48.64z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bo = [_hoisted_2$dl];
    vue.defineComponent({
      name: 'ExtensionPuzzleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dl, _hoisted_3$bo);
      }
    });

    const _hoisted_1$dk = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dk = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M345.14 480H256v-45.71a31.3 31.3 0 0 0-9.59-22.65c-7.67-7.56-18.83-11.81-30.57-11.64a44.38 44.38 0 0 0-28.45 10.67c-5.2 4.6-11.39 12.56-11.39 24.42V480H87.62A55.68 55.68 0 0 1 32 424.38V336h45.71c9.16 0 18.07-3.92 25.09-11a42.06 42.06 0 0 0 12.2-29.92C114.7 273.89 97.26 256 76.91 256H32v-89.34a53.77 53.77 0 0 1 16.53-39A55.88 55.88 0 0 1 87.62 112h63.24V97.52A65.53 65.53 0 0 1 217.54 32c35.49.62 64.36 30.38 64.36 66.33V112h63.24A54.28 54.28 0 0 1 400 166.86v63.24h13.66c36.58 0 66.34 29 66.34 64.64c0 36.61-29.39 66.4-65.52 66.4H400v63.24c0 30.67-24.61 55.62-54.86 55.62z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bn = [_hoisted_2$dk];
    vue.defineComponent({
      name: 'ExtensionPuzzleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dk, _hoisted_3$bn);
      }
    });

    const _hoisted_1$dj = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dj = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '64',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bm = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M490.84 238.6c-26.46-40.92-60.79-75.68-99.27-100.53C349 110.55 302 96 255.66 96c-42.52 0-84.33 12.15-124.27 36.11c-40.73 24.43-77.63 60.12-109.68 106.07a31.92 31.92 0 0 0-.64 35.54c26.41 41.33 60.4 76.14 98.28 100.65C162 402 207.9 416 255.66 416c46.71 0 93.81-14.43 136.2-41.72c38.46-24.77 72.72-59.66 99.08-100.92a32.2 32.2 0 0 0-.1-34.76zM256 352a96 96 0 1 1 96-96a96.11 96.11 0 0 1-96 96z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6J = [_hoisted_2$dj, _hoisted_3$bm];
    vue.defineComponent({
      name: 'Eye',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dj, _hoisted_4$6J);
      }
    });

    const _hoisted_1$di = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$di = /*#__PURE__*/vue.createStaticVNode('<path d="M432 448a15.92 15.92 0 0 1-11.31-4.69l-352-352a16 16 0 0 1 22.62-22.62l352 352A16 16 0 0 1 432 448z" fill="currentColor"></path><path d="M248 315.85l-51.79-51.79a2 2 0 0 0-3.39 1.69a64.11 64.11 0 0 0 53.49 53.49a2 2 0 0 0 1.69-3.39z" fill="currentColor"></path><path d="M264 196.15L315.87 248a2 2 0 0 0 3.4-1.69a64.13 64.13 0 0 0-53.55-53.55a2 2 0 0 0-1.72 3.39z" fill="currentColor"></path><path d="M491 273.36a32.2 32.2 0 0 0-.1-34.76c-26.46-40.92-60.79-75.68-99.27-100.53C349 110.55 302 96 255.68 96a226.54 226.54 0 0 0-71.82 11.79a4 4 0 0 0-1.56 6.63l47.24 47.24a4 4 0 0 0 3.82 1.05a96 96 0 0 1 116 116a4 4 0 0 0 1.05 3.81l67.95 68a4 4 0 0 0 5.4.24a343.81 343.81 0 0 0 67.24-77.4z" fill="currentColor"></path><path d="M256 352a96 96 0 0 1-93.3-118.63a4 4 0 0 0-1.05-3.81l-66.84-66.87a4 4 0 0 0-5.41-.23c-24.39 20.81-47 46.13-67.67 75.72a31.92 31.92 0 0 0-.64 35.54c26.41 41.33 60.39 76.14 98.28 100.65C162.06 402 207.92 416 255.68 416a238.22 238.22 0 0 0 72.64-11.55a4 4 0 0 0 1.61-6.64l-47.47-47.46a4 4 0 0 0-3.81-1.05A96 96 0 0 1 256 352z" fill="currentColor"></path>', 5);

    const _hoisted_7$S = [_hoisted_2$di];
    vue.defineComponent({
      name: 'EyeOff',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$di, _hoisted_7$S);
      }
    });

    const _hoisted_1$dh = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dh = /*#__PURE__*/vue.createStaticVNode('<path d="M432 448a15.92 15.92 0 0 1-11.31-4.69l-352-352a16 16 0 0 1 22.62-22.62l352 352A16 16 0 0 1 432 448z" fill="currentColor"></path><path d="M255.66 384c-41.49 0-81.5-12.28-118.92-36.5c-34.07-22-64.74-53.51-88.7-91v-.08c19.94-28.57 41.78-52.73 65.24-72.21a2 2 0 0 0 .14-2.94L93.5 161.38a2 2 0 0 0-2.71-.12c-24.92 21-48.05 46.76-69.08 76.92a31.92 31.92 0 0 0-.64 35.54c26.41 41.33 60.4 76.14 98.28 100.65C162 402 207.9 416 255.66 416a239.13 239.13 0 0 0 75.8-12.58a2 2 0 0 0 .77-3.31l-21.58-21.58a4 4 0 0 0-3.83-1a204.8 204.8 0 0 1-51.16 6.47z" fill="currentColor"></path><path d="M490.84 238.6c-26.46-40.92-60.79-75.68-99.27-100.53C349 110.55 302 96 255.66 96a227.34 227.34 0 0 0-74.89 12.83a2 2 0 0 0-.75 3.31l21.55 21.55a4 4 0 0 0 3.88 1a192.82 192.82 0 0 1 50.21-6.69c40.69 0 80.58 12.43 118.55 37c34.71 22.4 65.74 53.88 89.76 91a.13.13 0 0 1 0 .16a310.72 310.72 0 0 1-64.12 72.73a2 2 0 0 0-.15 2.95l19.9 19.89a2 2 0 0 0 2.7.13a343.49 343.49 0 0 0 68.64-78.48a32.2 32.2 0 0 0-.1-34.78z" fill="currentColor"></path><path d="M256 160a95.88 95.88 0 0 0-21.37 2.4a2 2 0 0 0-1 3.38l112.59 112.56a2 2 0 0 0 3.38-1A96 96 0 0 0 256 160z" fill="currentColor"></path><path d="M165.78 233.66a2 2 0 0 0-3.38 1a96 96 0 0 0 115 115a2 2 0 0 0 1-3.38z" fill="currentColor"></path>', 5);

    const _hoisted_7$R = [_hoisted_2$dh];
    vue.defineComponent({
      name: 'EyeOffOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dh, _hoisted_7$R);
      }
    });

    const _hoisted_1$dg = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dg = /*#__PURE__*/vue.createStaticVNode('<path d="M63.998 86.004l21.998-21.998L448 426.01l-21.998 21.998z" fill="currentColor"></path><path d="M259.34 192.09l60.57 60.57a64.07 64.07 0 0 0-60.57-60.57z" fill="currentColor"></path><path d="M252.66 319.91l-60.57-60.57a64.07 64.07 0 0 0 60.57 60.57z" fill="currentColor"></path><path d="M256 352a96 96 0 0 1-92.6-121.34l-69.07-69.08C66.12 187.42 39.24 221.14 16 256c26.42 44 62.56 89.24 100.2 115.18C159.38 400.92 206.33 416 255.76 416A233.47 233.47 0 0 0 335 402.2l-53.61-53.6A95.84 95.84 0 0 1 256 352z" fill="currentColor"></path><path d="M256 160a96 96 0 0 1 92.6 121.34L419.26 352c29.15-26.25 56.07-61.56 76.74-96c-26.38-43.43-62.9-88.56-101.18-114.82C351.1 111.2 304.31 96 255.76 96a222.92 222.92 0 0 0-78.21 14.29l53.11 53.11A95.84 95.84 0 0 1 256 160z" fill="currentColor"></path>', 5);

    const _hoisted_7$Q = [_hoisted_2$dg];
    vue.defineComponent({
      name: 'EyeOffSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dg, _hoisted_7$Q);
      }
    });

    const _hoisted_1$df = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$df = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M255.66 112c-77.94 0-157.89 45.11-220.83 135.33a16 16 0 0 0-.27 17.77C82.92 340.8 161.8 400 255.66 400c92.84 0 173.34-59.38 221.79-135.25a16.14 16.14 0 0 0 0-17.47C428.89 172.28 347.8 112 255.66 112z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bl = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '80',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6I = [_hoisted_2$df, _hoisted_3$bl];
    vue.defineComponent({
      name: 'EyeOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$df, _hoisted_4$6I);
      }
    });

    const _hoisted_1$de = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$de = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '64',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bk = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M394.82 141.18C351.1 111.2 304.31 96 255.76 96c-43.69 0-86.28 13-126.59 38.48C88.52 160.23 48.67 207 16 256c26.42 44 62.56 89.24 100.2 115.18C159.38 400.92 206.33 416 255.76 416c49 0 95.85-15.07 139.3-44.79C433.31 345 469.71 299.82 496 256c-26.38-43.43-62.9-88.56-101.18-114.82zM256 352a96 96 0 1 1 96-96a96.11 96.11 0 0 1-96 96z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6H = [_hoisted_2$de, _hoisted_3$bk];
    vue.defineComponent({
      name: 'EyeSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$de, _hoisted_4$6H);
      }
    });

    const _hoisted_1$dd = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dd = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M461.05 51a65 65 0 0 0-45.71-19h-.76a61.81 61.81 0 0 0-44.36 19.25a12.81 12.81 0 0 0-1.07 1.25l-54 69.76c-5.62 7.1-12.74 8.68-16.78 4.64l-1.9-1.9a48 48 0 0 0-67.92 67.92l9.91 9.91a2 2 0 0 1 0 2.83L58.7 385.38C54 390.05 46.9 399.85 38.85 431c-4.06 15.71-6.51 29.66-6.61 30.24A16 16 0 0 0 48 480a15.68 15.68 0 0 0 2.64-.22c.58-.1 14.44-2.43 30.13-6.44c31.07-7.94 41.05-15.24 45.85-20l179.77-179.79a2 2 0 0 1 2.82 0l9.92 9.92a48 48 0 0 0 67.92-67.93l-1.59-1.54c-5-5-2.52-12.11 4.32-17.14l69.75-53.94a17.82 17.82 0 0 0 1.47-1.32a63.2 63.2 0 0 0 19-45A63.88 63.88 0 0 0 461.05 51zM250.78 283.9c-2.92 2.92-16.18 7.92-23.39.71s-2.24-20.42.69-23.35l33-33a2 2 0 0 1 2.83 0l19.84 19.83a2 2 0 0 1 0 2.83z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bj = [_hoisted_2$dd];
    vue.defineComponent({
      name: 'Eyedrop',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dd, _hoisted_3$bj);
      }
    });

    const _hoisted_1$dc = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$dc = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M262.51 204.22L70 396.69C57.56 409.15 48 464 48 464s54.38-9.09 67.31-22L307.8 249.51',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bi = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '211.72',
      y: '172.19',
      width: '192.15',
      height: '64.05',
      rx: '32.03',
      ry: '32.03',
      transform: 'rotate(45 307.788 204.2)',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6G = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M289.91 141s20.57 8.57 37.22-8.08l54.67-70.63c18.5-19.41 49.26-18.69 67.94 0h0c18.68 18.68 19.34 48.81 0 67.93l-70.68 54.67c-15.65 15.65-8.08 37.22-8.08 37.22',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3b = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M115.31 442s-26.48 17.34-44.56-.73s-.75-44.58-.75-44.58',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1o = [_hoisted_2$dc, _hoisted_3$bi, _hoisted_4$6G, _hoisted_5$3b];
    vue.defineComponent({
      name: 'EyedropOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$dc, _hoisted_6$1o);
      }
    });

    const _hoisted_1$db = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$db = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 96.22a63.84 63.84 0 0 0-18.95-45.61a65 65 0 0 0-45.71-19h-.76a61.78 61.78 0 0 0-44.22 19.09l-74.88 74.88l-33.88-33.86l-34.07 33.91l-33.85 34l44 44L32 409.37V480h70.63l205.7-205.71L352 317.94l11.31-11.19c.11-.1 10.42-10.31 22.79-22.68l33.85-34l-33.89-33.89L461 141.23a63.18 63.18 0 0 0 19-45.01zM245 292.35L219.65 267l40.68-40.69l25.38 25.38z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bh = [_hoisted_2$db];
    vue.defineComponent({
      name: 'EyedropSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$db, _hoisted_3$bh);
      }
    });

    const _hoisted_1$da = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$da = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M368 128h.09',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bg = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M479.55 96h-91.06l8.92-35.66l38.32-13.05c8.15-2.77 13-11.43 10.65-19.71a16 16 0 0 0-20.54-10.73l-47 16a16 16 0 0 0-10.36 11.27L355.51 96H224.45c-8.61 0-16 6.62-16.43 15.23A16 16 0 0 0 224 128h2.75l1 8.66A8.3 8.3 0 0 0 236 144c39 0 73.66 10.9 100.12 31.52A121.9 121.9 0 0 1 371 218.07a123.4 123.4 0 0 1 10.12 29.51a7.83 7.83 0 0 0 3.29 4.88a72 72 0 0 1 26.38 86.43a7.92 7.92 0 0 0-.15 5.53A96 96 0 0 1 416 376c0 22.34-7.6 43.63-21.4 59.95a80.12 80.12 0 0 1-28.78 21.67a8 8 0 0 0-4.21 4.37a108.19 108.19 0 0 1-17.37 29.86a2.5 2.5 0 0 0 1.9 4.11h49.21a48.22 48.22 0 0 0 47.85-44.14L477.4 128h2.6a16 16 0 0 0 16-16.77c-.42-8.61-7.84-15.23-16.45-15.23z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6F = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M108.69 320a23.87 23.87 0 0 1 17 7l15.51 15.51a4 4 0 0 0 5.66 0L162.34 327a23.87 23.87 0 0 1 17-7h196.58a8 8 0 0 0 8.08-7.92V312a40.07 40.07 0 0 0-32-39.2c-.82-29.69-13-54.54-35.51-72C295.67 184.56 267.85 176 236 176h-72c-68.22 0-114.43 38.77-116 96.8A40.07 40.07 0 0 0 16 312a8 8 0 0 0 8 8z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3a = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M185.94 352a8 8 0 0 0-5.66 2.34l-22.14 22.15a20 20 0 0 1-28.28 0l-22.14-22.15a8 8 0 0 0-5.66-2.34h-69.4a15.93 15.93 0 0 0-15.76 13.17A65.22 65.22 0 0 0 16 376c0 30.59 21.13 55.51 47.26 56c2.43 15.12 8.31 28.78 17.16 39.47C93.51 487.28 112.54 496 134 496h132c21.46 0 40.49-8.72 53.58-24.55c8.85-10.69 14.73-24.35 17.16-39.47c26.13-.47 47.26-25.39 47.26-56a65.22 65.22 0 0 0-.9-10.83A15.93 15.93 0 0 0 367.34 352z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1n = [_hoisted_2$da, _hoisted_3$bg, _hoisted_4$6F, _hoisted_5$3a];
    vue.defineComponent({
      name: 'FastFood',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$da, _hoisted_6$1n);
      }
    });

    const _hoisted_1$d9 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$d9 = /*#__PURE__*/vue.createStaticVNode('<path d="M322 416c0 35.35-20.65 64-56 64H134c-35.35 0-56-28.65-56-64" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><path d="M336 336c17.67 0 32 17.91 32 40h0c0 22.09-14.33 40-32 40H64c-17.67 0-32-17.91-32-40h0c0-22.09 14.33-40 32-40" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><path d="M344 336H179.31a8 8 0 0 0-5.65 2.34l-26.83 26.83a4 4 0 0 1-5.66 0l-26.83-26.83a8 8 0 0 0-5.65-2.34H56a24 24 0 0 1-24-24h0a24 24 0 0 1 24-24h288a24 24 0 0 1 24 24h0a24 24 0 0 1-24 24z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><path d="M64 276v-.22c0-55 45-83.78 100-83.78h72c55 0 100 29 100 84v-.22" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M241 112l7.44 63.97"></path><path d="M256 480h139.31a32 32 0 0 0 31.91-29.61L463 112" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M368 112l16-64l47-16"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M224 112h256"></path>', 8);

    const _hoisted_10$9 = [_hoisted_2$d9];
    vue.defineComponent({
      name: 'FastFoodOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$d9, _hoisted_10$9);
      }
    });

    const _hoisted_1$d8 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$d8 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 352H184.36l-41 35l-41-35H16v24c0 30.59 21.13 55.51 47.26 56c2.43 15.12 8.31 28.78 17.16 39.47C93.51 487.28 112.54 496 134 496h132c21.46 0 40.49-8.72 53.58-24.55c8.85-10.69 14.73-24.35 17.16-39.47c13.88-.25 26.35-7.4 35-18.63A61.26 61.26 0 0 0 384 376z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bf = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M105 320l38.33 28.19L182 320h202v-8a40.07 40.07 0 0 0-32-39.2c-.82-29.69-13-54.54-35.51-72C295.67 184.56 267.85 176 236 176h-72c-68.22 0-114.43 38.77-116 96.8A40.07 40.07 0 0 0 16 312v8h89z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6E = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M463.08 96h-74.59l8.92-35.66L442 45l-10-29l-62 20l-14.49 60H208v32h18.75l1.86 16H236c39 0 73.66 10.9 100.12 31.52A121.9 121.9 0 0 1 371 218.07a124.16 124.16 0 0 1 10.73 32.65a72 72 0 0 1 27.89 90.9A96 96 0 0 1 416 376c0 22.34-7.6 43.63-21.4 59.95a80 80 0 0 1-31.83 22.95a109.21 109.21 0 0 1-18.53 33c-1.18 1.42-2.39 2.81-3.63 4.15H416c16 0 23-8 25-23l36.4-345H496V96z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$39 = [_hoisted_2$d8, _hoisted_3$bf, _hoisted_4$6E];
    vue.defineComponent({
      name: 'FastFoodSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$d8, _hoisted_5$39);
      }
    });

    const _hoisted_1$d7 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$d7 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M430 190c0-95.94-78.06-174-174-174S82 94.06 82 190c0 88.49 66.4 161.77 152 172.61V394h-36a22 22 0 0 0 0 44h36v36a22 22 0 0 0 44 0v-36h36a22 22 0 0 0 0-44h-36v-31.39c85.6-10.84 152-84.12 152-172.61zm-304 0c0-71.68 58.32-130 130-130s130 58.32 130 130s-58.32 130-130 130s-130-58.32-130-130z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$be = [_hoisted_2$d7];
    vue.defineComponent({
      name: 'Female',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$d7, _hoisted_3$be);
      }
    });

    const _hoisted_1$d6 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$d6 = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '184',
      r: '152',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bd = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 336v144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6D = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M314 416H198'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$38 = [_hoisted_2$d6, _hoisted_3$bd, _hoisted_4$6D];
    vue.defineComponent({
      name: 'FemaleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$d6, _hoisted_5$38);
      }
    });

    const _hoisted_1$d5 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$d5 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M430 190c0-95.94-78.06-174-174-174S82 94.06 82 190c0 88.49 66.4 161.77 152 172.61V394h-58v44h58v58h44v-58h58v-44h-58v-31.39c85.6-10.84 152-84.12 152-172.61zm-304 0c0-71.68 58.32-130 130-130s130 58.32 130 130s-58.32 130-130 130s-130-58.32-130-130z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bc = [_hoisted_2$d5];
    vue.defineComponent({
      name: 'FemaleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$d5, _hoisted_3$bc);
      }
    });

    const _hoisted_1$d4 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$d4 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M479.66 268.7l-32-151.81C441.48 83.77 417.68 64 384 64H128c-16.8 0-31 4.69-42.1 13.94s-18.37 22.31-21.58 38.89l-32 151.87A16.65 16.65 0 0 0 32 272v112a64 64 0 0 0 64 64h320a64 64 0 0 0 64-64V272a16.65 16.65 0 0 0-.34-3.3zm-384-145.4v-.28c3.55-18.43 13.81-27 32.29-27H384c18.61 0 28.87 8.55 32.27 26.91c0 .13.05.26.07.39l26.93 127.88a4 4 0 0 1-3.92 4.82H320a15.92 15.92 0 0 0-16 15.82a48 48 0 1 1-96 0A15.92 15.92 0 0 0 192 256H72.65a4 4 0 0 1-3.92-4.82z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$bb = [_hoisted_2$d4];
    vue.defineComponent({
      name: 'FileTray',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$d4, _hoisted_3$bb);
      }
    });

    const _hoisted_1$d3 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$d3 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M479.66 268.7l-32-151.81C441.48 83.77 417.68 64 384 64H128c-16.8 0-31 4.69-42.1 13.94s-18.37 22.31-21.58 38.89l-32 151.87A16.65 16.65 0 0 0 32 272v112a64 64 0 0 0 64 64h320a64 64 0 0 0 64-64V272a16.65 16.65 0 0 0-.34-3.3zm-384-145.4v-.28c3.55-18.43 13.81-27 32.29-27H384c18.61 0 28.87 8.55 32.27 26.91c0 .13.05.26.07.39l26.93 127.88a4 4 0 0 1-3.92 4.82H320a15.92 15.92 0 0 0-16 15.82a48 48 0 1 1-96 0A15.92 15.92 0 0 0 192 256H72.65a4 4 0 0 1-3.92-4.82z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ba = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M368 160H144a16 16 0 0 1 0-32h224a16 16 0 0 1 0 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6C = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 224H128a16 16 0 0 1 0-32h256a16 16 0 0 1 0 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$37 = [_hoisted_2$d3, _hoisted_3$ba, _hoisted_4$6C];
    vue.defineComponent({
      name: 'FileTrayFull',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$d3, _hoisted_5$37);
      }
    });

    const _hoisted_1$d2 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$d2 = /*#__PURE__*/vue.createStaticVNode('<path d="M384 80H128c-26 0-43 14-48 40L48 272v112a48.14 48.14 0 0 0 48 48h320a48.14 48.14 0 0 0 48-48V272l-32-152c-5-27-23-40-48-40z" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M48 272h144"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M320 272h144"></path><path d="M192 272a64 64 0 0 0 128 0" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M144 144h224"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M128 208h256"></path>', 6);

    const _hoisted_8$t = [_hoisted_2$d2];
    vue.defineComponent({
      name: 'FileTrayFullOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$d2, _hoisted_8$t);
      }
    });

    const _hoisted_1$d1 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$d1 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M128 128h256v38H128z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$b9 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M112 192h288v38H112z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6B = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 64H64L32 256v192h448V256zm-12 192H320a64 64 0 0 1-128 0H76l22-150h316z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$36 = [_hoisted_2$d1, _hoisted_3$b9, _hoisted_4$6B];
    vue.defineComponent({
      name: 'FileTrayFullSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$d1, _hoisted_5$36);
      }
    });

    const _hoisted_1$d0 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$d0 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 80H128c-26 0-43 14-48 40L48 272v112a48.14 48.14 0 0 0 48 48h320a48.14 48.14 0 0 0 48-48V272l-32-152c-5-27-23-40-48-40z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$b8 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M48 272h144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6A = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M320 272h144'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$35 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M192 272a64 64 0 0 0 128 0',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1m = [_hoisted_2$d0, _hoisted_3$b8, _hoisted_4$6A, _hoisted_5$35];
    vue.defineComponent({
      name: 'FileTrayOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$d0, _hoisted_6$1m);
      }
    });

    const _hoisted_1$c$ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$c$ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 64H64L32 256v192h448V256zm-12 192H320a64 64 0 0 1-128 0H76l22-150h316z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$b7 = [_hoisted_2$c$];
    vue.defineComponent({
      name: 'FileTraySharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$c$, _hoisted_3$b7);
      }
    });

    const _hoisted_1$c_ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$c_ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 352H320a16 16 0 0 0-16 16a48 48 0 0 1-96 0a16 16 0 0 0-16-16H48a16 16 0 0 0-16 16v64a64.07 64.07 0 0 0 64 64h320a64.07 64.07 0 0 0 64-64v-64a16 16 0 0 0-16-16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$b6 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M479.46 187.88L447.61 68.45C441.27 35.59 417.54 16 384 16H128c-16.8 0-31 4.69-42.1 13.94S67.66 52 64.4 68.4L32.54 187.88A15.9 15.9 0 0 0 32 192v48c0 35.29 28.71 80 64 80h320c35.29 0 64-44.71 64-80v-48a15.9 15.9 0 0 0-.54-4.12zM440.57 176H320a15.92 15.92 0 0 0-16 15.82a48 48 0 1 1-96 0A15.92 15.92 0 0 0 192 176H71.43a2 2 0 0 1-1.93-2.52L95.71 75c3.55-18.41 13.81-27 32.29-27h256c18.59 0 28.84 8.53 32.25 26.85l26.25 98.63a2 2 0 0 1-1.93 2.52z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6z = [_hoisted_2$c_, _hoisted_3$b6];
    vue.defineComponent({
      name: 'FileTrayStacked',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$c_, _hoisted_4$6z);
      }
    });

    const _hoisted_1$cZ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cZ = /*#__PURE__*/vue.createStaticVNode('<path d="M48 336v96a48.14 48.14 0 0 0 48 48h320a48.14 48.14 0 0 0 48-48v-96" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M48 336h144"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M320 336h144"></path><path d="M192 336a64 64 0 0 0 128 0" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M384 32H128c-26 0-43 14-48 40L48 192v96a48.14 48.14 0 0 0 48 48h320a48.14 48.14 0 0 0 48-48v-96L432 72c-5-27-23-40-48-40z" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M48 192h144"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M320 192h144"></path><path d="M192 192a64 64 0 0 0 128 0" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 8);

    const _hoisted_10$8 = [_hoisted_2$cZ];
    vue.defineComponent({
      name: 'FileTrayStackedOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cZ, _hoisted_10$8);
      }
    });

    const _hoisted_1$cY = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cY = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 16H64L32 176v144h448V176zm-12 160H320a64 64 0 0 1-128 0H76L98 58h316z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$b5 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 352a64 64 0 0 1-128 0H32v144h448V352z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6y = [_hoisted_2$cY, _hoisted_3$b5];
    vue.defineComponent({
      name: 'FileTrayStackedSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cY, _hoisted_4$6y);
      }
    });

    const _hoisted_1$cX = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cX = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M436 80H76a44.05 44.05 0 0 0-44 44v264a44.05 44.05 0 0 0 44 44h360a44.05 44.05 0 0 0 44-44V124a44.05 44.05 0 0 0-44-44zM112 388a12 12 0 0 1-12 12H76a12 12 0 0 1-12-12v-24a12 12 0 0 1 12-12h24a12 12 0 0 1 12 12zm0-80a12 12 0 0 1-12 12H76a12 12 0 0 1-12-12v-24a12 12 0 0 1 12-12h24a12 12 0 0 1 12 12zm0-80a12 12 0 0 1-12 12H76a12 12 0 0 1-12-12v-24a12 12 0 0 1 12-12h24a12 12 0 0 1 12 12zm0-80a12 12 0 0 1-12 12H76a12 12 0 0 1-12-12v-24a12 12 0 0 1 12-12h24a12 12 0 0 1 12 12zm241.68 124H158.32a16 16 0 0 1 0-32h195.36a16 16 0 1 1 0 32zM448 388a12 12 0 0 1-12 12h-24a12 12 0 0 1-12-12v-24a12 12 0 0 1 12-12h24a12 12 0 0 1 12 12zm0-80a12 12 0 0 1-12 12h-24a12 12 0 0 1-12-12v-24a12 12 0 0 1 12-12h24a12 12 0 0 1 12 12zm0-80a12 12 0 0 1-12 12h-24a12 12 0 0 1-12-12v-24a12 12 0 0 1 12-12h24a12 12 0 0 1 12 12zm0-80a12 12 0 0 1-12 12h-24a12 12 0 0 1-12-12v-24a12 12 0 0 1 12-12h24a12 12 0 0 1 12 12z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$b4 = [_hoisted_2$cX];
    vue.defineComponent({
      name: 'Film',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cX, _hoisted_3$b4);
      }
    });

    const _hoisted_1$cW = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cW = /*#__PURE__*/vue.createStaticVNode('<rect x="48" y="96" width="416" height="320" rx="28" ry="28" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></rect><rect x="384" y="336" width="80" height="80" rx="28" ry="28" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></rect><rect x="384" y="256" width="80" height="80" rx="28" ry="28" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></rect><rect x="384" y="176" width="80" height="80" rx="28" ry="28" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></rect><rect x="384" y="96" width="80" height="80" rx="28" ry="28" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></rect><rect x="48" y="336" width="80" height="80" rx="28" ry="28" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></rect><rect x="48" y="256" width="80" height="80" rx="28" ry="28" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></rect><rect x="48" y="176" width="80" height="80" rx="28" ry="28" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></rect><rect x="48" y="96" width="80" height="80" rx="28" ry="28" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></rect><rect x="128" y="96" width="256" height="160" rx="28" ry="28" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></rect><rect x="128" y="256" width="256" height="160" rx="28" ry="28" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></rect>', 11);

    const _hoisted_13$2 = [_hoisted_2$cW];
    vue.defineComponent({
      name: 'FilmOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cW, _hoisted_13$2);
      }
    });

    const _hoisted_1$cV = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cV = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 80H32v352h448zM112 352v48H64v-48zm0-80v48H64v-48zm0-80v48H64v-48zm0-80v48H64v-48zm256 160H144v-32h224zm80 80v48h-48v-48zm0-80v48h-48v-48zm0-80v48h-48v-48zm0-80v48h-48v-48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$b3 = [_hoisted_2$cV];
    vue.defineComponent({
      name: 'FilmSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cV, _hoisted_3$b3);
      }
    });

    const _hoisted_1$cU = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cU = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M472 168H40a24 24 0 0 1 0-48h432a24 24 0 0 1 0 48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$b2 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M392 280H120a24 24 0 0 1 0-48h272a24 24 0 0 1 0 48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6x = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M296 392h-80a24 24 0 0 1 0-48h80a24 24 0 0 1 0 48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$34 = [_hoisted_2$cU, _hoisted_3$b2, _hoisted_4$6x];
    vue.defineComponent({
      name: 'Filter',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cU, _hoisted_5$34);
      }
    });

    const _hoisted_1$cT = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cT = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm32 304h-64a16 16 0 0 1 0-32h64a16 16 0 0 1 0 32zm48-64H176a16 16 0 0 1 0-32h160a16 16 0 0 1 0 32zm32-64H144a16 16 0 0 1 0-32h224a16 16 0 0 1 0 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$b1 = [_hoisted_2$cT];
    vue.defineComponent({
      name: 'FilterCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cT, _hoisted_3$b1);
      }
    });

    const _hoisted_1$cS = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cS = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-width': '32',
      'stroke-miterlimit': '10',
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$b0 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-width': '32',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      d: 'M144 208h224'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6w = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-width': '32',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      d: 'M176 272h160'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$33 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-width': '32',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      d: 'M224 336h64'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1l = [_hoisted_2$cS, _hoisted_3$b0, _hoisted_4$6w, _hoisted_5$33];
    vue.defineComponent({
      name: 'FilterCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cS, _hoisted_6$1l);
      }
    });

    const _hoisted_1$cR = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cR = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm48 304h-96v-32h96zm48-64H160v-32h192zm32-64H128v-32h256z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$a$ = [_hoisted_2$cR];
    vue.defineComponent({
      name: 'FilterCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cR, _hoisted_3$a$);
      }
    });

    const _hoisted_1$cQ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cQ = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M32 144h448'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$a_ = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M112 256h288'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6v = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M208 368h96'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$32 = [_hoisted_2$cQ, _hoisted_3$a_, _hoisted_4$6v];
    vue.defineComponent({
      name: 'FilterOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cQ, _hoisted_5$32);
      }
    });

    const _hoisted_1$cP = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cP = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M16 120h480v48H16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aZ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M96 232h320v48H96z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6u = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M192 344h128v48H192z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$31 = [_hoisted_2$cP, _hoisted_3$aZ, _hoisted_4$6u];
    vue.defineComponent({
      name: 'FilterSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cP, _hoisted_5$31);
      }
    });

    const _hoisted_1$cO = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cO = /*#__PURE__*/vue.createStaticVNode('<path d="M63.28 202a15.29 15.29 0 0 1-7.7-2a14.84 14.84 0 0 1-5.52-20.46C69.34 147.36 128 72.25 256 72.25c55.47 0 104.12 14.57 144.53 43.29c33.26 23.57 51.9 50.25 60.78 63.1a14.79 14.79 0 0 1-4 20.79a15.52 15.52 0 0 1-21.24-4C420 172.32 371 102 256 102c-112.25 0-163 64.71-179.53 92.46A15 15 0 0 1 63.28 202z" fill="currentColor"></path><path d="M320.49 496a15.31 15.31 0 0 1-3.79-.43c-92.85-23-127.52-115.82-128.93-119.68l-.22-.85c-.76-2.68-19.39-66.33 9.21-103.61c13.11-17 33.05-25.72 59.38-25.72c24.48 0 42.14 7.61 54.28 23.36c10 12.86 14 28.72 17.87 44c8.13 31.82 14 48.53 47.79 50.25c14.84.75 24.59-7.93 30.12-15.32c14.95-20.15 17.55-53 6.28-82C398 228.57 346.61 158 256 158c-38.68 0-74.22 12.43-102.72 35.79c-23.59 19.35-42.28 46.67-51.28 74.75c-16.69 52.28 5.2 134.46 5.41 135.21A14.83 14.83 0 0 1 96.54 422a15.39 15.39 0 0 1-18.74-10.6c-1-3.75-24.38-91.4-5.1-151.82c21-65.47 85.81-131.47 183.33-131.47c45.07 0 87.65 15.32 123.19 44.25c27.52 22.5 50 52.72 61.76 82.93c14.95 38.57 10.94 81.86-10.19 110.14c-14.08 18.86-34.13 28.72-56.34 27.65c-57.86-2.9-68.26-43.29-75.84-72.75c-7.8-30.22-12.79-44.79-42.58-44.79c-16.36 0-27.85 4.5-35 13.82c-9.75 12.75-10.51 32.68-9.43 47.14a152.44 152.44 0 0 0 5.1 29.79c2.38 6 33.37 82 107.59 100.39a14.88 14.88 0 0 1 11 18.11a15.36 15.36 0 0 1-14.8 11.21z" fill="currentColor"></path><path d="M201.31 489.14a15.5 15.5 0 0 1-11.16-4.71c-37.16-39-58.18-82.61-66.09-137.14V347c-4.44-36.1 2.06-87.21 33.91-122.35c23.51-25.93 56.56-39.11 98.06-39.11c49.08 0 87.65 22.82 111.7 65.89c17.45 31.29 20.91 62.47 21 63.75a15.07 15.07 0 0 1-13.65 16.4a15.26 15.26 0 0 1-16.79-13.29A154 154 0 0 0 340.43 265c-18.64-32.89-47-49.61-84.51-49.61c-32.4 0-57.75 9.75-75.19 29c-25.14 27.75-30 70.5-26.55 98.78c6.93 48.22 25.46 86.58 58.18 120.86a14.7 14.7 0 0 1-.76 21.11a15.44 15.44 0 0 1-10.29 4z" fill="currentColor"></path><path d="M372.5 446.18c-32.5 0-60.13-9-82.24-26.89c-44.42-35.79-49.4-94.08-49.62-96.54a15.27 15.27 0 0 1 30.45-2.36c.11.86 4.55 48.54 38.79 76c20.26 16.18 47.34 22.6 80.71 18.85a15.2 15.2 0 0 1 16.91 13.18a14.92 14.92 0 0 1-13.44 16.5a187 187 0 0 1-21.56 1.26z" fill="currentColor"></path><path d="M398.18 48.79C385.5 40.54 340.54 16 256 16c-88.74 0-133.81 27.11-143.78 34a11.59 11.59 0 0 0-1.84 1.4a.36.36 0 0 1-.22.1a14.87 14.87 0 0 0-5.09 11.15a15.06 15.06 0 0 0 15.31 14.85a15.56 15.56 0 0 0 8.88-2.79c.43-.32 39.22-28.82 126.77-28.82S382.58 74.29 383 74.5a15.25 15.25 0 0 0 9.21 3a15.06 15.06 0 0 0 15.29-14.89a14.9 14.9 0 0 0-9.32-13.82z" fill="currentColor"></path>', 5);

    const _hoisted_7$P = [_hoisted_2$cO];
    vue.defineComponent({
      name: 'FingerPrint',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cO, _hoisted_7$P);
      }
    });

    const _hoisted_1$cN = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cN = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M390.42 75.28a10.45 10.45 0 0 1-5.32-1.44C340.72 50.08 302.35 40 256.35 40c-45.77 0-89.23 11.28-128.76 33.84C122 77 115.11 74.8 111.87 69a12.4 12.4 0 0 1 4.63-16.32A281.81 281.81 0 0 1 256.35 16c49.23 0 92.23 11.28 139.39 36.48a12 12 0 0 1 4.85 16.08a11.3 11.3 0 0 1-10.17 6.72zm-330.79 126a11.73 11.73 0 0 1-6.7-2.16a12.26 12.26 0 0 1-2.78-16.8c22.89-33.6 52-60 86.69-78.48c72.58-38.84 165.51-39.12 238.32-.24c34.68 18.48 63.8 44.64 86.69 78a12.29 12.29 0 0 1-2.78 16.8a11.26 11.26 0 0 1-16.18-2.88c-20.8-30.24-47.15-54-78.36-70.56c-66.34-35.28-151.18-35.28-217.29.24c-31.44 16.8-57.79 40.8-78.59 71a10 10 0 0 1-9.02 5.08zM204.1 491a10.66 10.66 0 0 1-8.09-3.6C175.9 466.48 165 453 149.55 424c-16-29.52-24.27-65.52-24.27-104.16c0-71.28 58.71-129.36 130.84-129.36S387 248.56 387 319.84a11.56 11.56 0 1 1-23.11 0c0-58.08-48.32-105.36-107.72-105.36S148.4 261.76 148.4 319.84c0 34.56 7.39 66.48 21.49 92.4c14.8 27.6 25 39.36 42.77 58.08a12.67 12.67 0 0 1 0 17a12.44 12.44 0 0 1-8.56 3.68zm165.75-44.4c-27.51 0-51.78-7.2-71.66-21.36a129.1 129.1 0 0 1-55-105.36a11.57 11.57 0 1 1 23.12 0a104.28 104.28 0 0 0 44.84 85.44c16.41 11.52 35.6 17 58.72 17a147.41 147.41 0 0 0 24-2.4c6.24-1.2 12.25 3.12 13.4 9.84a11.92 11.92 0 0 1-9.47 13.92a152.28 152.28 0 0 1-27.95 2.88zM323.38 496a13 13 0 0 1-3-.48c-36.76-10.56-60.8-24.72-86-50.4c-32.37-33.36-50.16-77.76-50.16-125.28c0-38.88 31.9-70.56 71.19-70.56s71.2 31.68 71.2 70.56c0 25.68 21.5 46.56 48.08 46.56s48.08-20.88 48.08-46.56c0-90.48-75.13-163.92-167.59-163.92c-65.65 0-125.75 37.92-152.79 96.72c-9 19.44-13.64 42.24-13.64 67.2c0 18.72 1.61 48.24 15.48 86.64c2.32 6.24-.69 13.2-6.7 15.36a11.34 11.34 0 0 1-14.79-7a276.39 276.39 0 0 1-16.88-95c0-28.8 5.32-55 15.72-77.76c30.75-67 98.94-110.4 173.6-110.4c105.18 0 190.71 84.24 190.71 187.92c0 38.88-31.9 70.56-71.2 70.56s-71.2-31.68-71.2-70.56c.01-25.68-21.49-46.6-48.07-46.6s-48.08 20.88-48.08 46.56c0 41 15.26 79.44 43.23 108.24c22 22.56 43 35 75.59 44.4c6.24 1.68 9.71 8.4 8.09 14.64a11.39 11.39 0 0 1-10.87 9.16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aY = [_hoisted_2$cN];
    vue.defineComponent({
      name: 'FingerPrintOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cN, _hoisted_3$aY);
      }
    });

    const _hoisted_1$cM = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cM = /*#__PURE__*/vue.createStaticVNode('<path d="M56.79 200.58l12.36 7.5l7.35-13.58C93.07 166.75 143.78 102 256 102c115 0 164 70.32 180.1 93.46l8.16 12.7L469.88 192l-8.54-13.36c-8.88-12.85-27.52-39.53-60.78-63.1C360.15 86.82 311.5 72.25 256 72.25c-128.07 0-186.69 75.11-206 107.25L42.63 192L54 198.86a14.09 14.09 0 0 0 1.63 1.1a12.57 12.57 0 0 0 1.16.62z" fill="currentColor"></path><path d="M379.22 172.32c-35.54-28.93-78.12-44.25-123.22-44.25c-97.52 0-162.31 66-183.33 131.47C53.42 320 76.82 407.61 77.8 411.36l4.38 13.81l29.93-6.43l-4.74-15c-.21-.75-22.1-82.93-5.41-135.21c9-28.08 27.73-55.4 51.35-74.79C181.81 170.39 217.35 158 256 158c90.58 0 141.93 70.61 156.45 108.11c11.27 28.93 8.67 61.82-6.28 82c-5.53 7.39-15.28 16.07-30.12 15.32c-33.81-1.72-39.66-18.43-47.79-50.25c-3.9-15.32-7.9-31.18-17.87-44c-12.14-15.75-29.8-23.36-54.28-23.36c-26.33 0-46.27 8.68-59.38 25.72c-28.6 37.28-10 100.93-9.21 103.61l.22.85c1.41 3.86 36.08 96.65 128.93 119.68l14.77 3.21l8.09-28.71l-15.27-3.43c-74.22-18.43-105.21-94.39-107.59-100.39a152.44 152.44 0 0 1-5.1-29.79c-1.08-14.46-.32-34.39 9.43-47.14c7.15-9.32 18.64-13.82 35-13.82c29.79 0 34.78 14.57 42.58 44.79c7.58 29.46 18 69.85 75.84 72.75c22.21 1.07 42.26-8.79 56.34-27.65c21.13-28.28 25.14-71.57 10.19-110.14c-11.68-30.36-34.21-60.54-61.73-83.04z" fill="currentColor"></path><path d="M154.18 343.21c-3.47-28.28 1.41-71 26.55-98.78c17.44-19.29 42.79-29 75.19-29c37.49 0 65.87 16.72 84.51 49.61a154 154 0 0 1 17.88 53.25l1.43 14.69l30-2.2a112.63 112.63 0 0 0-1-15.6c-.11-1.28-3.57-32.46-21-63.75c-24.06-43.11-62.63-65.93-111.74-65.93c-41.5 0-74.55 13.18-98.06 39.11c-31.85 35.14-38.35 86.25-33.91 122.35v.33c7.97 54.53 28.97 98.14 66.12 137.14l11.6 11.22l20.95-21.79l-10.34-9.79c-32.72-34.28-51.25-72.64-58.18-120.86z" fill="currentColor"></path><path d="M132.47 72.66c11.08-6.72 50.27-26.77 123.53-26.77c87.54 0 126.44 28.72 126.87 28.93l13.9 8.86L413 58.47l-13.22-8.56c-.52-.38-1.06-.76-1.6-1.12C385.5 40.54 340.54 16 256 16c-87.71 0-132.75 26.48-143.41 33.71L99 58.52l16.2 25.21z" fill="currentColor"></path><path d="M390.59 415.21c-33.37 3.75-60.45-2.67-80.71-18.85c-34.24-27.43-38.68-75.11-38.79-76l-1.23-14.88l-30.53 2.23l1.31 15c.22 2.46 5.2 60.75 49.62 96.54c22.11 17.89 49.74 26.89 82.24 26.89a187 187 0 0 0 21.56-1.29l16.59-2.09l-6.1-29.71z" fill="currentColor"></path>', 5);

    const _hoisted_7$O = [_hoisted_2$cM];
    vue.defineComponent({
      name: 'FingerPrintSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cM, _hoisted_7$O);
      }
    });

    const _hoisted_1$cL = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cL = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M512 256c0-16.54-14.27-46.76-45.61-74a207.06 207.06 0 0 0-60.28-36.12a3.15 3.15 0 0 0-3.93 1.56c-.15.29-.3.57-.47.86l-9.59 15.9a183.24 183.24 0 0 0 .07 183.78l.23.39l8.74 16a4 4 0 0 0 4.94 1.82C479.63 337.42 512 281.49 512 256zm-93.92-.14a16 16 0 1 1 13.79-13.79a16 16 0 0 1-13.79 13.79z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aX = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M335.45 256a214.8 214.8 0 0 1 29.08-108l.12-.21l4.62-7.67a4 4 0 0 0-2.59-6a284.29 284.29 0 0 0-39.26-5.39a7.94 7.94 0 0 1-4.29-1.6c-19.28-14.66-57.5-40.3-96.46-46.89a16 16 0 0 0-18 20.18l10.62 37.17a4 4 0 0 1-2.42 4.84c-36.85 13.69-68.59 38.75-91.74 57.85a8 8 0 0 1-10.06.06q-4.72-3.75-9.69-7.39c-39.64-28.95-86.21-32.76-88.17-32.9a16 16 0 0 0-16.83 19.4c.42 1.93 9.19 40.69 31.7 71.61a8.09 8.09 0 0 1 0 9.55C9.57 291.52.8 330.29.38 332.22a16 16 0 0 0 16.83 19.4c2-.14 48.53-4 88.12-32.88q4.85-3.56 9.47-7.22a8 8 0 0 1 10.06.07c23.25 19.19 55.05 44.28 92 58a4 4 0 0 1 2.42 4.83l-10.66 37.18a16 16 0 0 0 18 20.18c17.16-2.9 51.88-12.86 96.05-46.83a8.15 8.15 0 0 1 4.36-1.65a287.36 287.36 0 0 0 39.22-5.3a4 4 0 0 0 2.69-5.83l-4.51-8.29A214.81 214.81 0 0 1 335.45 256z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6t = [_hoisted_2$cL, _hoisted_3$aX];
    vue.defineComponent({
      name: 'Fish',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cL, _hoisted_4$6t);
      }
    });

    const _hoisted_1$cK = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cK = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-width': '32',
      'stroke-linejoin': 'round',
      d: 'M240 152c-50.71 12.21-94.15 52.31-120.3 73.43a261.14 261.14 0 0 0-23.81-19.58C59.53 179.29 16 176 16 176s11.37 51.53 41.36 79.83C27.37 284.14 16 335.67 16 335.67s43.53-3.29 79.89-29.85a259.18 259.18 0 0 0 23.61-19.41c26.1 21.14 69.74 61.34 120.5 73.59l-16 56c39.43-6.67 78.86-35.51 94.72-48.25C448 362 496 279 496 256c0-22-48-106-176.89-111.73C303.52 131.78 263.76 102.72 224 96z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aW = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '416',
      cy: '239.99',
      r: '16',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6s = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-width': '32',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '20',
      d: 'M378.37 356a199.22 199.22 0 0 1 0-200'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$30 = [_hoisted_2$cK, _hoisted_3$aW, _hoisted_4$6s];
    vue.defineComponent({
      name: 'FishOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cK, _hoisted_5$30);
      }
    });

    const _hoisted_1$cJ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cJ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M335.45 256a214.83 214.83 0 0 1 29.08-108l7.62-13.26a280.69 280.69 0 0 0-48.64-7.15c-21.94-16.9-54.64-36.95-92.34-43.33L208 80l13.37 61.86c-41.67 14.14-78.43 42.86-102.76 62.62q-7.06-5.91-14.78-11.55c-39.71-29-82.6-31.8-84.4-31.9L0 160l2.67 19.31c.29 2 6.79 44.73 31.65 76.52C9.46 287.63 3 330.33 2.67 332.36L0 352l19.43-1.36c1.8-.1 44.69-2.89 84.4-31.9q7.58-5.53 14.56-11.37c24.37 19.83 61.14 48.6 102.86 62.74L208 432l23.17-4.22c37.49-6.34 70.08-26.4 92-43.32a284.27 284.27 0 0 0 49.32-7.23l-7.91-13.18A214.92 214.92 0 0 1 335.45 256z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aV = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M499.59 221.75c-5.85-9.88-16.54-24.9-34.19-40.28a209.82 209.82 0 0 0-62-37L392.23 164a183.22 183.22 0 0 0-.09 183.87l11.75 19.57a209.26 209.26 0 0 0 61.42-36.49C497.05 303.47 512 269 512 256c0-12.31-8-26.74-12.41-34.25zM416 256a16 16 0 1 1 16-16a16 16 0 0 1-16 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6r = [_hoisted_2$cJ, _hoisted_3$aV];
    vue.defineComponent({
      name: 'FishSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cJ, _hoisted_4$6r);
      }
    });

    const _hoisted_1$cI = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cI = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M193.69 152.84a16 16 0 0 1 29.64 2.56l36.4 121.36l30-59.92a16 16 0 0 1 28.62 0L345.89 272h96.76A213.08 213.08 0 0 0 464 176.65C463.37 114.54 413.54 64 352.92 64c-48.09 0-80 29.54-96.92 51c-16.88-21.49-48.83-51-96.92-51C98.46 64 48.63 114.54 48 176.65A211.13 211.13 0 0 0 56.93 240h93.18z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aU = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M321.69 295.16L304 259.78l-33.69 67.38A16 16 0 0 1 256 336q-.67 0-1.38-.06a16 16 0 0 1-14-11.34l-36.4-121.36l-30 59.92A16 16 0 0 1 160 272H69.35q14 29.29 37.27 57.66c18.77 22.88 52.8 59.46 131.39 112.81a31.84 31.84 0 0 0 36 0c78.59-53.35 112.62-89.93 131.39-112.81a316.79 316.79 0 0 0 19-25.66H336a16 16 0 0 1-14.31-8.84z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 272h-21.35a260.11 260.11 0 0 1-18.25 32H464a16 16 0 0 0 0-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2$ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 240a16 16 0 0 0 0 32h21.35a225.22 225.22 0 0 1-12.42-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1k = [_hoisted_2$cI, _hoisted_3$aU, _hoisted_4$6q, _hoisted_5$2$];
    vue.defineComponent({
      name: 'Fitness',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cI, _hoisted_6$1k);
      }
    });

    const _hoisted_1$cH = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cH = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M352.92 80C288 80 256 144 256 144s-32-64-96.92-64c-52.76 0-94.54 44.14-95.08 96.81c-1.1 109.33 86.73 187.08 183 252.42a16 16 0 0 0 18 0c96.26-65.34 184.09-143.09 183-252.42c-.54-52.67-42.32-96.81-95.08-96.81z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aT = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M48 256h112l48-96l48 160l48-96l32 64h128'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6p = [_hoisted_2$cH, _hoisted_3$aT];
    vue.defineComponent({
      name: 'FitnessOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cH, _hoisted_4$6p);
      }
    });

    const _hoisted_1$cG = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cG = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 272h-37.34a261.41 261.41 0 0 1-18.25 32H480z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aS = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M32 240v32h37.34a225.1 225.1 0 0 1-12.4-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6o = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M304 259.78l-51.73 103.46l-48-160L169.89 272H69.34c10 20.92 23.5 41.41 40.63 61.68c40.12 47.46 94.25 79.75 137 108.32l9 6l9-6c42.78-28.57 96.91-60.86 137-108.32A322.78 322.78 0 0 0 424.41 304h-98.3z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2_ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M211.73 116.76l48 160L304 188.22L345.89 272h96.77A213.13 213.13 0 0 0 464 176.65C463.37 114.54 413.54 64 352.92 64c-48.11 0-80.1 28-96.92 48.21C239.18 92 207.19 64 159.08 64C98.46 64 48.63 114.54 48 176.65A211.23 211.23 0 0 0 56.94 240h93.17z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1j = [_hoisted_2$cG, _hoisted_3$aS, _hoisted_4$6o, _hoisted_5$2_];
    vue.defineComponent({
      name: 'FitnessSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cG, _hoisted_6$1j);
      }
    });

    const _hoisted_1$cF = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cF = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M80 480a16 16 0 0 1-16-16V68.13a24 24 0 0 1 11.9-20.72C88 40.38 112.38 32 160 32c37.21 0 78.83 14.71 115.55 27.68C305.12 70.13 333.05 80 352 80a183.84 183.84 0 0 0 71-14.5a18 18 0 0 1 25 16.58v219.36a20 20 0 0 1-12 18.31c-8.71 3.81-40.51 16.25-84 16.25c-24.14 0-54.38-7.14-86.39-14.71C229.63 312.79 192.43 304 160 304c-36.87 0-55.74 5.58-64 9.11V464a16 16 0 0 1-16 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aR = [_hoisted_2$cF];
    vue.defineComponent({
      name: 'Flag',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cF, _hoisted_3$aR);
      }
    });

    const _hoisted_1$cE = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cE = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M80 464V68.14a8 8 0 0 1 4-6.9C91.81 56.66 112.92 48 160 48c64 0 145 48 192 48a199.53 199.53 0 0 0 77.23-15.77a2 2 0 0 1 2.77 1.85v219.36a4 4 0 0 1-2.39 3.65C421.37 308.7 392.33 320 352 320c-48 0-128-32-192-32s-80 16-80 16',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aQ = [_hoisted_2$cE];
    vue.defineComponent({
      name: 'FlagOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cE, _hoisted_3$aQ);
      }
    });

    const _hoisted_1$cD = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cD = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M102 480H64V57.37l4.69-4.68C72.14 49.23 92.78 32 160 32c37.21 0 78.83 14.71 115.55 27.68C305.12 70.13 333.05 80 352 80c42.83 0 72.72-14.25 73-14.4l23-11.14v259.43l-8.84 4.42C437.71 319 403.19 336 352 336c-24.14 0-54.38-7.14-86.39-14.71C229.63 312.79 192.43 304 160 304c-36.87 0-49.74 5.58-58 9.11z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aP = [_hoisted_2$cD];
    vue.defineComponent({
      name: 'FlagSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cD, _hoisted_3$aP);
      }
    });

    const _hoisted_1$cC = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cC = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M394.23 197.56a300.43 300.43 0 0 0-53.37-90C301.2 61.65 249.05 32 208 32a16 16 0 0 0-15.48 20c13.87 53-14.88 97.07-45.31 143.72C122 234.36 96 274.27 96 320c0 88.22 71.78 160 160 160s160-71.78 160-160c0-43.3-7.32-84.49-21.77-122.44zm-105.9 221.13C278 429.69 265.05 432 256 432s-22-2.31-32.33-13.31S208 390.24 208 368c0-25.14 8.82-44.28 17.34-62.78c4.95-10.74 10-21.67 13-33.37a8 8 0 0 1 12.49-4.51A126.48 126.48 0 0 1 275 292c18.17 24 29 52.42 29 76c0 22.24-5.42 39.77-15.67 50.69z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aO = [_hoisted_2$cC];
    vue.defineComponent({
      name: 'Flame',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cC, _hoisted_3$aO);
      }
    });

    const _hoisted_1$cB = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cB = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M112 320c0-93 124-165 96-272c66 0 192 96 192 272a144 144 0 0 1-288 0z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aN = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 368c0 57.71-32 80-64 80s-64-22.29-64-80s40-86 32-128c42 0 96 70.29 96 128z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6n = [_hoisted_2$cB, _hoisted_3$aN];
    vue.defineComponent({
      name: 'FlameOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cB, _hoisted_4$6n);
      }
    });

    const _hoisted_1$cA = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cA = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M394.24 197.56a300.67 300.67 0 0 0-53.38-90C301.2 61.65 240 32 192 32c19 70-14.36 117.12-44.79 163.77C122 234.36 96 274.27 96 320c0 88.22 71.78 160 160 160s160-71.78 160-160c0-43.3-7.32-84.49-21.76-122.44zM288.33 418.69C278 429.69 265.05 432 256 432s-22-2.31-32.33-13.31S208 390.24 208 368c0-25.14 8.82-44.28 17.34-62.78c6.48-14.07 14.66-27.22 15.11-44.49c11.3 5.88 23.67 16.91 34.54 31.28c18.17 24 29 52.42 29 76c.01 22.23-5.41 39.76-15.66 50.68z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aM = [_hoisted_2$cA];
    vue.defineComponent({
      name: 'FlameSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cA, _hoisted_3$aM);
      }
    });

    const _hoisted_1$cz = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cz = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M194.82 496a18.36 18.36 0 0 1-18.1-21.53v-.11L204.83 320H96a16 16 0 0 1-12.44-26.06L302.73 23a18.45 18.45 0 0 1 32.8 13.71c0 .3-.08.59-.13.89L307.19 192H416a16 16 0 0 1 12.44 26.06L209.24 489a18.45 18.45 0 0 1-14.42 7z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aL = [_hoisted_2$cz];
    vue.defineComponent({
      name: 'Flash',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cz, _hoisted_3$aL);
      }
    });

    const _hoisted_1$cy = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cy = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M432 448a15.92 15.92 0 0 1-11.31-4.69l-352-352a16 16 0 0 1 22.62-22.62l352 352A16 16 0 0 1 432 448z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aK = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M431.5 204a16 16 0 0 0-15.5-12H307.19L335.4 37.63c.05-.3.1-.59.13-.89A18.45 18.45 0 0 0 302.73 23l-92.58 114.46a4 4 0 0 0 .29 5.35l151 151a4 4 0 0 0 5.94-.31l60.8-75.16A16.37 16.37 0 0 0 431.5 204z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6m = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M301.57 369.19l-151-151a4 4 0 0 0-5.93.31L83.8 293.64A16.37 16.37 0 0 0 80.5 308A16 16 0 0 0 96 320h108.83l-28.09 154.36v.11a18.37 18.37 0 0 0 32.5 14.53l92.61-114.46a4 4 0 0 0-.28-5.35z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2Z = [_hoisted_2$cy, _hoisted_3$aK, _hoisted_4$6m];
    vue.defineComponent({
      name: 'FlashOff',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cy, _hoisted_5$2Z);
      }
    });

    const _hoisted_1$cx = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cx = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M432 448a15.92 15.92 0 0 1-11.31-4.69l-352-352a16 16 0 0 1 22.62-22.62l352 352A16 16 0 0 1 432 448z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aJ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M294.34 84.28l-22.08 120.84a16 16 0 0 0 6.17 15.71a16.49 16.49 0 0 0 9.93 3.17h94.12l-38.37 47.42a4 4 0 0 0 .28 5.34l17.07 17.07a4 4 0 0 0 5.94-.31l60.8-75.16a16.37 16.37 0 0 0 3.3-14.36a16 16 0 0 0-15.5-12H307.19L335.4 37.63c.05-.3.1-.59.13-.89A18.45 18.45 0 0 0 302.73 23l-92.58 114.46a4 4 0 0 0 .28 5.35l17.07 17.06a4 4 0 0 0 5.94-.31z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6l = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M217.78 427.57l22-120.71a16 16 0 0 0-6.19-15.7a16.54 16.54 0 0 0-9.92-3.16h-94.1l38.36-47.42a4 4 0 0 0-.28-5.34l-17.07-17.07a4 4 0 0 0-5.93.31L83.8 293.64A16.37 16.37 0 0 0 80.5 308A16 16 0 0 0 96 320h108.83l-28.09 154.36v.11a18.37 18.37 0 0 0 32.5 14.53l92.61-114.46a4 4 0 0 0-.28-5.35l-17.07-17.06a4 4 0 0 0-5.94.31z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2Y = [_hoisted_2$cx, _hoisted_3$aJ, _hoisted_4$6l];
    vue.defineComponent({
      name: 'FlashOffOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cx, _hoisted_5$2Y);
      }
    });

    const _hoisted_1$cw = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cw = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M63.998 86.004l21.998-21.998L448 426.01l-21.998 21.998z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aI = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M80 304h144l-32 192l108.18-129.82l-148.36-148.36L80 304z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6k = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M432 208H288l32-192l-108.18 129.82l148.36 148.36L432 208z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2X = [_hoisted_2$cw, _hoisted_3$aI, _hoisted_4$6k];
    vue.defineComponent({
      name: 'FlashOffSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cw, _hoisted_5$2X);
      }
    });

    const _hoisted_1$cv = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cv = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M315.27 33L96 304h128l-31.51 173.23a2.36 2.36 0 0 0 2.33 2.77h0a2.36 2.36 0 0 0 1.89-.95L416 208H288l31.66-173.25a2.45 2.45 0 0 0-2.44-2.75h0a2.42 2.42 0 0 0-1.95 1z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aH = [_hoisted_2$cv];
    vue.defineComponent({
      name: 'FlashOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cv, _hoisted_3$aH);
      }
    });

    const _hoisted_1$cu = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cu = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M432 208H288l32-192L80 304h144l-32 192z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aG = [_hoisted_2$cu];
    vue.defineComponent({
      name: 'FlashSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cu, _hoisted_3$aG);
      }
    });

    const _hoisted_1$ct = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ct = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M462 216c9.35-9.35 15.14-19.09 17.19-28.95c2.7-12.95-1.29-25.55-11.22-35.48L360.43 44.05C346.29 29.92 322 24.07 296 50l-2 2a8 8 0 0 0 0 11.32L448.64 218a8 8 0 0 0 11.36 0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aF = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M250.14 153.08l-.16 2.34c-.53 7.18-6.88 19.15-13.88 26.14L47.27 370.36c-11.12 11.11-16.46 25.57-15.05 40.7C33.49 424.58 40.16 438 51 448.83L63.17 461c12.61 12.6 27.78 19 42.49 19a50.4 50.4 0 0 0 36-15.24l188.84-188.8c7.07-7.07 18.84-13.3 26.17-13.87c17.48-1.32 43.57-3.28 67.79-15.65a4 4 0 0 0 1-6.37L271.69 86.31a4 4 0 0 0-6.39 1c-12.12 22.99-13.82 46.91-15.16 65.77zm-9.95 146.83a20 20 0 1 1 0-25.25a20 20 0 0 1 0 25.25z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6j = [_hoisted_2$ct, _hoisted_3$aF];
    vue.defineComponent({
      name: 'Flashlight',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ct, _hoisted_4$6j);
      }
    });

    const _hoisted_1$cs = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cs = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M456.64 162.86L349.12 55.36c-13.15-13.14-28.68-7.17-41.82 6l-11.95 12c-26.13 26.13-27.62 58.38-29.42 83.31c-.89 12.24-9.78 27.55-18.51 36.28L58.58 381.67c-16.35 16.33-12.69 39.42 3.73 55.84l12.17 12.17c16.36 16.35 39.43 20.16 55.86 3.74l188.83-188.8c8.74-8.74 24-17.55 36.29-18.52c24.87-1.86 58.62-4.85 83.26-29.49l11.94-11.94c13.15-13.14 19.12-28.67 5.98-41.81z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aE = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '224.68',
      cy: '287.28',
      r: '20',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6i = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M289 81l142 142'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2W = [_hoisted_2$cs, _hoisted_3$aE, _hoisted_4$6i];
    vue.defineComponent({
      name: 'FlashlightOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cs, _hoisted_5$2W);
      }
    });

    const _hoisted_1$cr = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cr = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M330 16l-42.68 42.7L453.3 224.68L496 182L330 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aD = /*#__PURE__*/vue.createElementVNode('ellipse', {
      cx: '224.68',
      cy: '287.3',
      rx: '20.03',
      ry: '19.96',
      fill: 'none'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6h = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M429.21 243.85L268 82.59L249.65 168L16 402l94 94l234.23-233.8zm-189 56.07a20 20 0 1 1 0-25.25a20 20 0 0 1-.02 25.25z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2V = [_hoisted_2$cr, _hoisted_3$aD, _hoisted_4$6h];
    vue.defineComponent({
      name: 'FlashlightSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cr, _hoisted_5$2V);
      }
    });

    const _hoisted_1$cq = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cq = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M452.32 365L327.4 167.12a48.07 48.07 0 0 1-7.4-25.64V64h15.56c8.61 0 16-6.62 16.43-15.23A16 16 0 0 0 336 32H176.45c-8.61 0-16 6.62-16.43 15.23A16 16 0 0 0 176 64h16v77.48a47.92 47.92 0 0 1-7.41 25.63L59.68 365a74 74 0 0 0-2.5 75.84C70.44 465.19 96.36 480 124.13 480h263.74c27.77 0 53.69-14.81 66.95-39.21a74 74 0 0 0-2.5-75.79zM211.66 184.2A79.94 79.94 0 0 0 224 141.48V68a4 4 0 0 1 4-4h56a4 4 0 0 1 4 4v73.48a79.94 79.94 0 0 0 12.35 42.72l57.8 91.53a8 8 0 0 1-6.78 12.27H160.63a8 8 0 0 1-6.77-12.27z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aC = [_hoisted_2$cq];
    vue.defineComponent({
      name: 'Flask',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cq, _hoisted_3$aC);
      }
    });

    const _hoisted_1$cp = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cp = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M176 48h160'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aB = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M118 304h276'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6g = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M208 48v93.48a64.09 64.09 0 0 1-9.88 34.18L73.21 373.49C48.4 412.78 76.63 464 123.08 464h265.84c46.45 0 74.68-51.22 49.87-90.51L313.87 175.66a64.09 64.09 0 0 1-9.87-34.18V48',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2U = [_hoisted_2$cp, _hoisted_3$aB, _hoisted_4$6g];
    vue.defineComponent({
      name: 'FlaskOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cp, _hoisted_5$2U);
      }
    });

    const _hoisted_1$co = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$co = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M469.11 382.76L325 153.92V74h32V32H155v42h32v79.92L42.89 382.76c-13 20.64-14.78 43.73-3 65.1S71.59 480 96 480h320c24.41 0 44.32-10.76 56.1-32.14s10.04-44.46-2.99-65.1zM224.39 173.39a29.76 29.76 0 0 0 4.62-16V74h54v84.59a25.85 25.85 0 0 0 4 13.82L356.82 283H155.18z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aA = [_hoisted_2$co];
    vue.defineComponent({
      name: 'FlaskSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$co, _hoisted_3$aA);
      }
    });

    const _hoisted_1$cn = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cn = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '48',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$az = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M475.93 303.91a67.49 67.49 0 0 0-44.34-115.53a5.2 5.2 0 0 1-4.58-3.21a5.21 5.21 0 0 1 1-5.51A67.83 67.83 0 0 0 378 66.33h-.25A67.13 67.13 0 0 0 332.35 84a5.21 5.21 0 0 1-5.52 1a5.23 5.23 0 0 1-3.22-4.58a67.68 67.68 0 0 0-135.23 0a5.2 5.2 0 0 1-3.21 4.58a5.21 5.21 0 0 1-5.52-1a67.11 67.11 0 0 0-45.44-17.69H134a67.91 67.91 0 0 0-50 113.34a5.21 5.21 0 0 1 1 5.51a5.2 5.2 0 0 1-4.58 3.21a67.71 67.71 0 0 0 0 135.23a5.23 5.23 0 0 1 4.58 3.23a5.22 5.22 0 0 1-1 5.52a67.54 67.54 0 0 0 50.08 113h.25A67.38 67.38 0 0 0 179.65 428a5.21 5.21 0 0 1 5.51-1a5.2 5.2 0 0 1 3.21 4.58a67.71 67.71 0 0 0 135.23 0a5.23 5.23 0 0 1 3.22-4.58a5.21 5.21 0 0 1 5.51 1a67.38 67.38 0 0 0 45.29 17.42h.25a67.48 67.48 0 0 0 50.08-113a5.22 5.22 0 0 1-1-5.52a5.23 5.23 0 0 1 4.58-3.22a67.31 67.31 0 0 0 44.4-19.77zM256 336a80 80 0 1 1 80-80a80.09 80.09 0 0 1-80 80z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6f = [_hoisted_2$cn, _hoisted_3$az];
    vue.defineComponent({
      name: 'Flower',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cn, _hoisted_4$6f);
      }
    });

    const _hoisted_1$cm = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cm = /*#__PURE__*/vue.createStaticVNode('<path d="M215.08 156.92c-4.89-24-10.77-56.27-10.77-73.23A51.36 51.36 0 0 1 256 32h0c28.55 0 51.69 23.69 51.69 51.69c0 16.5-5.85 48.95-10.77 73.23" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><path d="M215.08 355.08c-4.91 24.06-10.77 56.16-10.77 73.23A51.36 51.36 0 0 0 256 480h0c28.55 0 51.69-23.69 51.69-51.69c0-16.54-5.85-48.93-10.77-73.23" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><path d="M355.08 215.08c24.06-4.91 56.16-10.77 73.23-10.77A51.36 51.36 0 0 1 480 256h0c0 28.55-23.69 51.69-51.69 51.69c-16.5 0-48.95-5.85-73.23-10.77" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><path d="M156.92 215.07c-24-4.89-56.25-10.76-73.23-10.76A51.36 51.36 0 0 0 32 256h0c0 28.55 23.69 51.69 51.69 51.69c16.5 0 48.95-5.85 73.23-10.77" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><path d="M296.92 156.92c13.55-20.48 32.3-47.25 44.37-59.31a51.35 51.35 0 0 1 73.1 0h0c20.19 20.19 19.8 53.3 0 73.1c-11.66 11.67-38.67 30.67-59.31 44.37" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><path d="M156.92 296.92c-20.48 13.55-47.25 32.3-59.31 44.37a51.35 51.35 0 0 0 0 73.1h0c20.19 20.19 53.3 19.8 73.1 0c11.67-11.66 30.67-38.67 44.37-59.31" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><path d="M355.08 296.92c20.48 13.55 47.25 32.3 59.31 44.37a51.35 51.35 0 0 1 0 73.1h0c-20.19 20.19-53.3 19.8-73.1 0c-11.69-11.69-30.66-38.65-44.37-59.31" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><path d="M215.08 156.92c-13.53-20.43-32.38-47.32-44.37-59.31a51.35 51.35 0 0 0-73.1 0h0c-20.19 20.19-19.8 53.3 0 73.1c11.61 11.61 38.7 30.68 59.31 44.37" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><circle cx="256" cy="256" r="64" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></circle>', 9);

    const _hoisted_11$7 = [_hoisted_2$cm];
    vue.defineComponent({
      name: 'FlowerOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cm, _hoisted_11$7);
      }
    });

    const _hoisted_1$cl = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cl = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '43',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ay = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M475.93 303.91a67.49 67.49 0 0 0-47.62-115.6c-2.88 0-6.2.14-9.93.43c2.75-2.36 5.23-4.62 7.33-6.71A67.83 67.83 0 0 0 378 66.33h-.25a67.27 67.27 0 0 0-47.82 20c-2.11 2.11-4.37 4.59-6.72 7.33c.29-3.75.44-7.07.44-9.93a67.69 67.69 0 1 0-135.38 0c0 2.87.15 6.19.44 9.93c-2.36-2.74-4.62-5.22-6.72-7.33a67.27 67.27 0 0 0-47.82-20H134A67.9 67.9 0 0 0 86.29 182c2.1 2.09 4.58 4.35 7.34 6.72c-3.74-.29-7.06-.44-9.94-.44a67.69 67.69 0 0 0 0 135.38c2.86 0 6.18-.15 9.93-.44c-2.74 2.35-5.22 4.61-7.33 6.72a67.55 67.55 0 0 0 47.82 115.42h.25A67.32 67.32 0 0 0 182 425.71c2.09-2.1 4.35-4.58 6.71-7.33c-.28 3.73-.43 7.05-.43 9.93a67.69 67.69 0 0 0 135.38 0c0-2.87-.15-6.19-.44-9.94c2.36 2.75 4.62 5.24 6.72 7.34a67.32 67.32 0 0 0 47.67 19.68h.25A67.5 67.5 0 0 0 425.71 330c-2.11-2.11-4.59-4.37-7.33-6.72c3.75.29 7.07.44 9.93.44a67.27 67.27 0 0 0 47.62-19.81zM256 341a85 85 0 1 1 85-85a85.1 85.1 0 0 1-85 85z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6e = [_hoisted_2$cl, _hoisted_3$ay];
    vue.defineComponent({
      name: 'FlowerSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cl, _hoisted_4$6e);
      }
    });

    const _hoisted_1$ck = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ck = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M496 152a56 56 0 0 0-56-56H220.11a23.89 23.89 0 0 1-13.31-4L179 73.41A55.77 55.77 0 0 0 147.89 64H72a56 56 0 0 0-56 56v48a8 8 0 0 0 8 8h464a8 8 0 0 0 8-8z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ax = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M16 392a56 56 0 0 0 56 56h368a56 56 0 0 0 56-56V216a8 8 0 0 0-8-8H24a8 8 0 0 0-8 8z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6d = [_hoisted_2$ck, _hoisted_3$ax];
    vue.defineComponent({
      name: 'Folder',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ck, _hoisted_4$6d);
      }
    });

    const _hoisted_1$cj = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cj = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M408 96H252.11a23.89 23.89 0 0 1-13.31-4L211 73.41A55.77 55.77 0 0 0 179.89 64H104a56.06 56.06 0 0 0-56 56v24h416c0-30.88-25.12-48-56-48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aw = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M423.75 448H88.25a56 56 0 0 1-55.93-55.15L16.18 228.11v-.28A48 48 0 0 1 64 176h384.1a48 48 0 0 1 47.8 51.83v.28l-16.22 164.74A56 56 0 0 1 423.75 448zm56.15-221.45z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6c = [_hoisted_2$cj, _hoisted_3$aw];
    vue.defineComponent({
      name: 'FolderOpen',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cj, _hoisted_4$6c);
      }
    });

    const _hoisted_1$ci = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ci = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M64 192v-72a40 40 0 0 1 40-40h75.89a40 40 0 0 1 22.19 6.72l27.84 18.56a40 40 0 0 0 22.19 6.72H408a40 40 0 0 1 40 40v40',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$av = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M479.9 226.55L463.68 392a40 40 0 0 1-39.93 40H88.25a40 40 0 0 1-39.93-40L32.1 226.55A32 32 0 0 1 64 192h384.1a32 32 0 0 1 31.8 34.55z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6b = [_hoisted_2$ci, _hoisted_3$av];
    vue.defineComponent({
      name: 'FolderOpenOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ci, _hoisted_4$6b);
      }
    });

    const _hoisted_1$ch = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ch = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M16.08 189.4l28.58 233.87A28 28 0 0 0 72.52 448h367a28 28 0 0 0 27.86-24.73l28.54-233.87A12 12 0 0 0 484 176H28a12 12 0 0 0-11.92 13.4z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$au = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 124a28 28 0 0 0-28-28H244.84l-48-32H76a28 28 0 0 0-28 28v52h416z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6a = [_hoisted_2$ch, _hoisted_3$au];
    vue.defineComponent({
      name: 'FolderOpenSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ch, _hoisted_4$6a);
      }
    });

    const _hoisted_1$cg = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cg = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M440 432H72a40 40 0 0 1-40-40V120a40 40 0 0 1 40-40h75.89a40 40 0 0 1 22.19 6.72l27.84 18.56a40 40 0 0 0 22.19 6.72H440a40 40 0 0 1 40 40v240a40 40 0 0 1-40 40z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$at = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M32 192h448'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$69 = [_hoisted_2$cg, _hoisted_3$at];
    vue.defineComponent({
      name: 'FolderOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cg, _hoisted_4$69);
      }
    });

    const _hoisted_1$cf = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cf = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M16 420a28 28 0 0 0 28 28h424a28 28 0 0 0 28-28V208H16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$as = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M496 124a28 28 0 0 0-28-28H212.84l-48-32H44a28 28 0 0 0-28 28v84h480z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$68 = [_hoisted_2$cf, _hoisted_3$as];
    vue.defineComponent({
      name: 'FolderSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cf, _hoisted_4$68);
      }
    });

    const _hoisted_1$ce = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ce = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm143 304h-45.22a8 8 0 0 1-6.91-4l-16.14-27.68a8 8 0 0 1-.86-6l14.86-59.92a8 8 0 0 1 4.65-5.45l28.1-11.9a8 8 0 0 1 8.34 1.3l41.63 35.82a8 8 0 0 1 2.69 7.26a174.75 174.75 0 0 1-24.28 66.68A8 8 0 0 1 399 352zM134.52 237.13l28.1 11.9a8 8 0 0 1 4.65 5.45l14.86 59.92a8 8 0 0 1-.86 6L165.13 348a8 8 0 0 1-6.91 4H113a8 8 0 0 1-6.82-3.81a174.75 174.75 0 0 1-24.28-66.68a8 8 0 0 1 2.69-7.26l41.63-35.82a8 8 0 0 1 8.3-1.3zm256.94-87.24l-18.07 51.38A8 8 0 0 1 369 206l-29.58 12.53a8 8 0 0 1-8.26-1.24L274.9 170.1a8 8 0 0 1-2.9-6.1v-33.58a8 8 0 0 1 3.56-6.65l42.83-28.54a8 8 0 0 1 7.66-.67A176.92 176.92 0 0 1 390 142a8 8 0 0 1 1.46 7.89zM193.6 95.23l42.84 28.54a8 8 0 0 1 3.56 6.65V164a8 8 0 0 1-2.86 6.13l-56.26 47.19a8 8 0 0 1-8.26 1.24L143 206a8 8 0 0 1-4.43-4.72L120.5 149.9a8 8 0 0 1 1.5-7.9a176.92 176.92 0 0 1 64-47.48a8 8 0 0 1 7.6.71zm17.31 327.46L191.18 373a8 8 0 0 1 .52-7l15.17-26a8 8 0 0 1 6.91-4h84.44a8 8 0 0 1 6.91 4l15.18 26a8 8 0 0 1 .53 7l-19.59 49.67a8 8 0 0 1-5.69 4.87a176.58 176.58 0 0 1-79 0a8 8 0 0 1-5.65-4.85z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ar = [_hoisted_2$ce];
    vue.defineComponent({
      name: 'Football',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ce, _hoisted_3$ar);
      }
    });

    const _hoisted_1$cd = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cd = /*#__PURE__*/vue.createStaticVNode('<circle cx="256" cy="256" r="192" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></circle><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 175.15l-76.09 63.83L200 320h112l20.09-81.02L256 175.15z"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M332.09 238.98l52.87-22.4l25.78-73.26"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M447 269.97l-62.04-53.39"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M179.91 238.98l-52.87-22.4l-25.78-73.26"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M65 269.97l62.04-53.39"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 175.15v-57.57l64-42.64"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M192 74.93l64 42.65"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M312 320l28 48l-28 71"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M410.74 368H342"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M200 320l-28 48l28.37 71.5"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M101.63 368H172"></path>', 12);

    const _hoisted_14 = [_hoisted_2$cd];
    vue.defineComponent({
      name: 'FootballOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cd, _hoisted_14);
      }
    });

    const _hoisted_1$cc = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cc = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm140.64 296.08h-46.77l-16.89-29l15-60.44L377.79 242l42.65 36.71a164.87 164.87 0 0 1-23.8 65.37zM134.21 242L164 254.67l15 60.44l-16.89 29h-46.75a164.87 164.87 0 0 1-23.8-65.34zm249.07-92.47l-18.41 52.33l-31.12 13.18L277 167.46v-35l43.86-29.22a166.87 166.87 0 0 1 62.42 46.32zM191.14 103.2L235 132.42v35l-56.75 47.61l-31.12-13.18l-18.41-52.33a166.87 166.87 0 0 1 62.42-46.32zm26.44 314.3l-20.1-50.66l16-27.51h85l16.06 27.53l-20 50.6a166.23 166.23 0 0 1-77 0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aq = [_hoisted_2$cc];
    vue.defineComponent({
      name: 'FootballSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cc, _hoisted_3$aq);
      }
    });

    const _hoisted_1$cb = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$cb = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M133.83 361.27c-22.61 0-41-8.17-54.79-24.39s-22.84-40.29-28.11-75.31c-7.76-51.61-.06-95.11 21.68-122.48c12.8-16.12 29.6-25.44 48.58-26.94c16.25-1.3 40.54 5.29 64 44c14.69 24.24 25.86 56.44 30.65 88.34c5.79 38.51 1.48 66.86-13.18 86.65c-11.64 15.72-29.54 25.46-53.21 29a106.46 106.46 0 0 1-15.62 1.13z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ap = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M173 496c-13.21 0-26.6-4.23-38.66-12.36a79.79 79.79 0 0 1-33.52-50.6c-2.85-14.66-1.14-26.31 5.22-35.64c10.33-15.15 28.87-18.56 48.49-22.18c2.07-.38 4.17-.76 6.3-1.17c4.52-.86 9.14-2 13.62-3.11c16.78-4.14 34.14-8.43 48.47 1.75c9.59 6.8 15 18.36 16.62 35.32c1.84 19.57-2.36 39.1-11.83 55c-10.19 17.11-25.47 28.42-43 31.86A61 61 0 0 1 173 496z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$67 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M378.17 265.27a106.69 106.69 0 0 1-15.6-1.2c-23.66-3.5-41.56-13.25-53.2-29c-14.66-19.79-19-48.13-13.18-86.65c4.79-31.93 15.93-64.1 30.55-88.25c23.34-38.57 47.66-45.26 64-44.08c18.92 1.38 35.69 10.57 48.51 26.6c21.89 27.37 29.65 71 21.86 122.84c-5.27 35-14.2 58.95-28.11 75.31s-32.22 24.43-54.83 24.43z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2T = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M339 400a61 61 0 0 1-11.68-1.13c-17.56-3.44-32.84-14.75-43-31.86c-9.47-15.9-13.67-35.43-11.83-55c1.6-17 7-28.52 16.62-35.33c14.33-10.17 31.69-5.89 48.47-1.74c4.48 1.1 9.1 2.24 13.62 3.11l6.29 1.17c19.63 3.61 38.17 7 48.5 22.17c6.36 9.33 8.07 21 5.22 35.64a79.78 79.78 0 0 1-33.52 50.61C365.56 395.78 352.17 400 339 400z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1i = [_hoisted_2$cb, _hoisted_3$ap, _hoisted_4$67, _hoisted_5$2T];
    vue.defineComponent({
      name: 'Footsteps',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$cb, _hoisted_6$1i);
      }
    });

    const _hoisted_1$ca = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ca = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M200 246.84c8.81 58.62-7.33 90.67-52.91 97.41c-50.65 7.49-71.52-26.44-80.33-85.06c-11.85-78.88 16-127.94 55.71-131.1c36.14-2.87 68.71 60.14 77.53 118.75z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ao = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M223.65 409.53c3.13 33.28-14.86 64.34-42 69.66c-27.4 5.36-58.71-16.37-65.09-49.19s17.75-34.56 47.32-40.21s55.99-20.4 59.77 19.74z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$66 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M312 150.83c-8.81 58.62 7.33 90.67 52.9 97.41c50.66 7.49 71.52-26.44 80.33-85.06c11.86-78.89-16-128.22-55.7-131.1c-36.4-2.64-68.71 60.13-77.53 118.75z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2S = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M288.35 313.53c-3.13 33.27 14.86 64.34 42 69.66c27.4 5.36 58.71-16.37 65.09-49.19s-17.75-34.56-47.32-40.22s-55.99-20.4-59.77 19.75z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1h = [_hoisted_2$ca, _hoisted_3$ao, _hoisted_4$66, _hoisted_5$2S];
    vue.defineComponent({
      name: 'FootstepsOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ca, _hoisted_6$1h);
      }
    });

    const _hoisted_1$c9 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$c9 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M130.54 358.31c-12.83 1.88-33.95 5.38-48-10.56S56.34 293.32 51 258.92c-7.88-50.7-.06-93.43 22-120.31c13-15.83 30.06-25 49.34-26.46c16.51-1.27 41.18 5.19 65 43.19c14.92 23.81 26.27 55.44 31.14 86.77c5.88 37.82 11.61 78.18-8.44 92.65c-11.31 8.17-19.43 11-38.62 15.57c-15.78 3.75-28.04 6.09-40.88 7.98z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$an = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M107.72 390.84l108.89-22.46c9.2-1.9 16.58 3.16 20 18.32c11.22 49.76-4.86 109.3-55.22 109.3c-47.69 0-79.47-54.36-84.66-83.58c-2.37-13.25 1.01-19.53 10.99-21.58z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$65 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M340.59 254.34c-19.19-4.55-27.31-7.4-38.62-15.57c-20.05-14.47-14.32-54.83-8.44-92.65c4.87-31.33 16.22-63 31.14-86.77c23.8-38 48.47-44.46 65-43.19C408.93 17.63 426 26.78 439 42.61c22.08 26.88 29.9 69.61 22 120.31c-5.35 34.4-17.46 72.76-31.59 88.83s-35.13 12.44-48 10.56s-25.05-4.23-40.82-7.97z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2R = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M404.28 294.84l-108.89-22.46c-9.2-1.9-16.58 3.16-20 18.32c-11.21 49.76 4.87 109.3 55.23 109.3c47.69 0 79.47-54.36 84.66-83.58c2.36-13.25-1.02-19.53-11-21.58z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1g = [_hoisted_2$c9, _hoisted_3$an, _hoisted_4$65, _hoisted_5$2R];
    vue.defineComponent({
      name: 'FootstepsSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$c9, _hoisted_6$1g);
      }
    });

    const _hoisted_1$c8 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$c8 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M296 464a23.88 23.88 0 0 1-7.55-1.23L208.3 436.1a23.92 23.92 0 0 1-16.3-22.78V294.11a.44.44 0 0 0-.09-.13L23.26 97.54A30 30 0 0 1 46.05 48H466a30 30 0 0 1 22.79 49.54L320.09 294a.77.77 0 0 0-.09.13V440a23.93 23.93 0 0 1-24 24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$am = [_hoisted_2$c8];
    vue.defineComponent({
      name: 'Funnel',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$c8, _hoisted_3$am);
      }
    });

    const _hoisted_1$c7 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$c7 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M35.4 87.12l168.65 196.44A16.07 16.07 0 0 1 208 294v119.32a7.93 7.93 0 0 0 5.39 7.59l80.15 26.67A7.94 7.94 0 0 0 304 440V294a16.07 16.07 0 0 1 4-10.44L476.6 87.12A14 14 0 0 0 466 64H46.05A14 14 0 0 0 35.4 87.12z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$al = [_hoisted_2$c7];
    vue.defineComponent({
      name: 'FunnelOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$c7, _hoisted_3$al);
      }
    });

    const _hoisted_1$c6 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$c6 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M0 48l192 240v128l128 48V288L512 48H0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ak = [_hoisted_2$c6];
    vue.defineComponent({
      name: 'FunnelSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$c6, _hoisted_3$ak);
      }
    });

    const _hoisted_1$c5 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$c5 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M483.13 245.38C461.92 149.49 430 98.31 382.65 84.33A107.13 107.13 0 0 0 352 80c-13.71 0-25.65 3.34-38.28 6.88C298.5 91.15 281.21 96 256 96s-42.51-4.84-57.76-9.11C185.6 83.34 173.67 80 160 80a115.74 115.74 0 0 0-31.73 4.32c-47.1 13.92-79 65.08-100.52 161C4.61 348.54 16 413.71 59.69 428.83a56.62 56.62 0 0 0 18.64 3.22c29.93 0 53.93-24.93 70.33-45.34c18.53-23.1 40.22-34.82 107.34-34.82c59.95 0 84.76 8.13 106.19 34.82c13.47 16.78 26.2 28.52 38.9 35.91c16.89 9.82 33.77 12 50.16 6.37c25.82-8.81 40.62-32.1 44-69.24c2.57-28.48-1.39-65.89-12.12-114.37zM208 240h-32v32a16 16 0 0 1-32 0v-32h-32a16 16 0 0 1 0-32h32v-32a16 16 0 0 1 32 0v32h32a16 16 0 0 1 0 32zm84 4a20 20 0 1 1 20-20a20 20 0 0 1-20 20zm44 44a20 20 0 1 1 20-19.95A20 20 0 0 1 336 288zm0-88a20 20 0 1 1 20-20a20 20 0 0 1-20 20zm44 44a20 20 0 1 1 20-20a20 20 0 0 1-20 20z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aj = [_hoisted_2$c5];
    vue.defineComponent({
      name: 'GameController',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$c5, _hoisted_3$aj);
      }
    });

    const _hoisted_1$c4 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$c4 = /*#__PURE__*/vue.createStaticVNode('<path d="M467.51 248.83c-18.4-83.18-45.69-136.24-89.43-149.17A91.5 91.5 0 0 0 352 96c-26.89 0-48.11 16-96 16s-69.15-16-96-16a99.09 99.09 0 0 0-27.2 3.66C89 112.59 61.94 165.7 43.33 248.83c-19 84.91-15.56 152 21.58 164.88c26 9 49.25-9.61 71.27-37c25-31.2 55.79-40.8 119.82-40.8s93.62 9.6 118.66 40.8c22 27.41 46.11 45.79 71.42 37.16c41.02-14.01 40.44-79.13 21.43-165.04z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><circle cx="292" cy="224" r="20" fill="currentColor"></circle><path d="M336 288a20 20 0 1 1 20-19.95A20 20 0 0 1 336 288z" fill="currentColor"></path><circle cx="336" cy="180" r="20" fill="currentColor"></circle><circle cx="380" cy="224" r="20" fill="currentColor"></circle><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M160 176v96"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M208 224h-96"></path>', 7);

    const _hoisted_9$8 = [_hoisted_2$c4];
    vue.defineComponent({
      name: 'GameControllerOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$c4, _hoisted_9$8);
      }
    });

    const _hoisted_1$c3 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$c3 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M478.07 356.88L439 151c-8.86-40.35-23-71-88-71H145c-66 0-79.14 30.65-88 71L18 356.88c-7 34.12 4.43 61.25 33.37 71.81S103 423 119.18 391.3l15.42-30.52a16 16 0 0 1 14.28-8.78h198.28a16 16 0 0 1 14.28 8.78l15.42 30.52c16.14 31.7 38.88 48 67.81 37.39S485 391 478.07 356.88zM224 240h-48v48h-32v-48H96v-32h48v-48h32v48h48zm68 4a20 20 0 1 1 20-20a20 20 0 0 1-20 20zm44 44a20 20 0 1 1 20-20a20 20 0 0 1-20 20zm0-88a20 20 0 1 1 20-20a20 20 0 0 1-20 20zm44 44a20 20 0 1 1 20-20a20 20 0 0 1-20 20z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ai = [_hoisted_2$c3];
    vue.defineComponent({
      name: 'GameControllerSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$c3, _hoisted_3$ai);
      }
    });

    const _hoisted_1$c2 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$c2 = /*#__PURE__*/vue.createStaticVNode('<path d="M200 144h40v-40a40 40 0 1 0-40 40z" fill="none"></path><path d="M352 104a40 40 0 0 0-80 0v40h40a40 40 0 0 0 40-40z" fill="none"></path><path d="M80 416a64 64 0 0 0 64 64h92a4 4 0 0 0 4-4V292a4 4 0 0 0-4-4H88a8 8 0 0 0-8 8z" fill="currentColor"></path><path d="M240 252V144h32v108a4 4 0 0 0 4 4h140a47.93 47.93 0 0 0 16-2.75A48.09 48.09 0 0 0 464 208v-16a48 48 0 0 0-48-48h-40.54a2 2 0 0 1-1.7-3A72 72 0 0 0 256 58.82A72 72 0 0 0 138.24 141a2 2 0 0 1-1.7 3H96a48 48 0 0 0-48 48v16a48.09 48.09 0 0 0 32 45.25A47.93 47.93 0 0 0 96 256h140a4 4 0 0 0 4-4zm32-148a40 40 0 1 1 40 40h-40zm-74.86-39.9A40 40 0 0 1 240 104v40h-40a40 40 0 0 1-2.86-79.89z" fill="currentColor"></path><path d="M276 480h92a64 64 0 0 0 64-64V296a8 8 0 0 0-8-8H276a4 4 0 0 0-4 4v184a4 4 0 0 0 4 4z" fill="currentColor"></path>', 5);

    const _hoisted_7$N = [_hoisted_2$c2];
    vue.defineComponent({
      name: 'Gift',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$c2, _hoisted_7$N);
      }
    });

    const _hoisted_1$c1 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$c1 = /*#__PURE__*/vue.createStaticVNode('<path d="M256 104v56h56a56 56 0 1 0-56-56z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><path d="M256 104v56h-56a56 56 0 1 1 56-56z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><rect x="64" y="160" width="384" height="112" rx="32" ry="32" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></rect><path d="M416 272v144a48 48 0 0 1-48 48H144a48 48 0 0 1-48-48V272" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 160v304"></path>', 5);

    const _hoisted_7$M = [_hoisted_2$c1];
    vue.defineComponent({
      name: 'GiftOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$c1, _hoisted_7$M);
      }
    });

    const _hoisted_1$c0 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$c0 = /*#__PURE__*/vue.createStaticVNode('<path d="M346 110a34 34 0 0 0-68 0v34h34a34 34 0 0 0 34-34z" fill="none"></path><path d="M234 110a34 34 0 1 0-34 34h34z" fill="none"></path><path d="M234 144h44v112h164a22 22 0 0 0 22-22v-68a22 22 0 0 0-22-22h-59.82A77.95 77.95 0 0 0 256 55.79A78 78 0 0 0 129.81 144H70a22 22 0 0 0-22 22v68a22 22 0 0 0 22 22h164zm44-34a34 34 0 1 1 34 34h-34zm-112 0a34 34 0 1 1 68 0v34h-34a34 34 0 0 1-34-34z" fill="currentColor"></path><path d="M278 480h132a22 22 0 0 0 22-22V288H278z" fill="currentColor"></path><path d="M80 458a22 22 0 0 0 22 22h132V288H80z" fill="currentColor"></path>', 5);

    const _hoisted_7$L = [_hoisted_2$c0];
    vue.defineComponent({
      name: 'GiftSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$c0, _hoisted_7$L);
      }
    });

    const _hoisted_1$b$ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$b$ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 160a64 64 0 1 0-96.27 55.24c-2.29 29.08-20.08 37-75 48.42c-17.76 3.68-35.93 7.45-52.71 13.93v-126.2a64 64 0 1 0-64 0v209.22a64 64 0 1 0 64.42.24c2.39-18 16-24.33 65.26-34.52c27.43-5.67 55.78-11.54 79.78-26.95c29-18.58 44.53-46.78 46.36-83.89A64 64 0 0 0 416 160zM160 64a32 32 0 1 1-32 32a32 32 0 0 1 32-32zm0 384a32 32 0 1 1 32-32a32 32 0 0 1-32 32zm192-256a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ah = [_hoisted_2$b$];
    vue.defineComponent({
      name: 'GitBranch',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$b$, _hoisted_3$ah);
      }
    });

    const _hoisted_1$b_ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$b_ = /*#__PURE__*/vue.createStaticVNode('<circle cx="160" cy="96" r="48" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><circle cx="160" cy="416" r="48" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M160 368V144"></path><circle cx="352" cy="160" r="48" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><path d="M352 208c0 128-192 48-192 160" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 5);

    const _hoisted_7$K = [_hoisted_2$b_];
    vue.defineComponent({
      name: 'GitBranchOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$b_, _hoisted_7$K);
      }
    });

    const _hoisted_1$bZ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bZ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M352 96a64 64 0 0 0-58.86 89.11l-101.14 88V151.39a64 64 0 1 0-64 0v209.22a64 64 0 1 0 64 0V358l154.25-134.27c1.9.17 3.81.27 5.75.27a64 64 0 0 0 0-128zM160 64a32 32 0 1 1-32 32a32 32 0 0 1 32-32zm0 384a32 32 0 1 1 32-32a32 32 0 0 1-32 32zm192-256a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ag = [_hoisted_2$bZ];
    vue.defineComponent({
      name: 'GitBranchSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bZ, _hoisted_3$ag);
      }
    });

    const _hoisted_1$bY = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bY = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 224h-68a128 128 0 0 0-247.9 0H64a32 32 0 0 0 0 64h68.05A128 128 0 0 0 380 288h68a32 32 0 0 0 0-64zm-192 96a64 64 0 1 1 64-64a64.07 64.07 0 0 1-64 64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$af = [_hoisted_2$bY];
    vue.defineComponent({
      name: 'GitCommit',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bY, _hoisted_3$af);
      }
    });

    const _hoisted_1$bX = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bX = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '96',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ae = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M160 256H48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$64 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M464 256H352'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2Q = [_hoisted_2$bX, _hoisted_3$ae, _hoisted_4$64];
    vue.defineComponent({
      name: 'GitCommitOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bX, _hoisted_5$2Q);
      }
    });

    const _hoisted_1$bW = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bW = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 224H380a128 128 0 0 0-247.9 0H32v64h100.05A128 128 0 0 0 380 288h100zm-224 96a64 64 0 1 1 64-64a64.07 64.07 0 0 1-64 64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ad = [_hoisted_2$bW];
    vue.defineComponent({
      name: 'GitCommitSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bW, _hoisted_3$ad);
      }
    });

    const _hoisted_1$bV = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bV = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M218.31 340.69A16 16 0 0 0 191 352v32h-20a28 28 0 0 1-28-28V152a64 64 0 1 0-64-1.16V356a92.1 92.1 0 0 0 92 92h20v32a16 16 0 0 0 27.31 11.31l64-64a16 16 0 0 0 0-22.62zM112 64a32 32 0 1 1-32 32a32 32 0 0 1 32-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ac = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M432 360.61V156a92.1 92.1 0 0 0-92-92h-20V32a16 16 0 0 0-27.31-11.31l-64 64a16 16 0 0 0 0 22.62l64 64A16 16 0 0 0 320 160v-32h20a28 28 0 0 1 28 28v204.61a64 64 0 1 0 64 0zM400 448a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$63 = [_hoisted_2$bV, _hoisted_3$ac];
    vue.defineComponent({
      name: 'GitCompare',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bV, _hoisted_4$63);
      }
    });

    const _hoisted_1$bU = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bU = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M304 160l-64-64l64-64"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M207 352l64 64l-64 64"></path><circle cx="112" cy="96" r="48" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><circle cx="400" cy="416" r="48" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><path d="M256 96h84a60 60 0 0 1 60 60v212" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M255 416h-84a60 60 0 0 1-60-60V144" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 6);

    const _hoisted_8$s = [_hoisted_2$bU];
    vue.defineComponent({
      name: 'GitCompareOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bU, _hoisted_8$s);
      }
    });

    const _hoisted_1$bT = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bT = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M209 384h-37a28 28 0 0 1-28-28V152a64 64 0 1 0-64-1.16V356a92.1 92.1 0 0 0 92 92h37v55.21L294.39 416L209 328.79zM113 64a32 32 0 1 1-32 32a32 32 0 0 1 32-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$ab = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M432 360.61V156a92.1 92.1 0 0 0-92-92h-35V9.93L217.14 96L305 182.07V128h35a28 28 0 0 1 28 28v204.61a64 64 0 1 0 64 0zM400 448a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$62 = [_hoisted_2$bT, _hoisted_3$ab];
    vue.defineComponent({
      name: 'GitCompareSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bT, _hoisted_4$62);
      }
    });

    const _hoisted_1$bS = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bS = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M385 224a64 64 0 0 0-55.33 31.89c-42.23-1.21-85.19-12.72-116.21-31.33c-32.2-19.32-49.71-44-52.15-73.35a64 64 0 1 0-64.31.18v209.22a64 64 0 1 0 64 0v-94.46c44.76 34 107.28 52.38 168.56 53.76A64 64 0 1 0 385 224zM129 64a32 32 0 1 1-32 32a32 32 0 0 1 32-32zm0 384a32 32 0 1 1 32-32a32 32 0 0 1-32 32zm256-128a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$aa = [_hoisted_2$bS];
    vue.defineComponent({
      name: 'GitMerge',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bS, _hoisted_3$aa);
      }
    });

    const _hoisted_1$bR = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bR = /*#__PURE__*/vue.createStaticVNode('<circle cx="129" cy="96" r="48" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><circle cx="129" cy="416" r="48" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M129 144v224"></path><circle cx="385" cy="288" r="48" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><path d="M129 144c0 96 112 144 208 144" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 5);

    const _hoisted_7$J = [_hoisted_2$bR];
    vue.defineComponent({
      name: 'GitMergeOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bR, _hoisted_7$J);
      }
    });

    const _hoisted_1$bQ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bQ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 224a63.66 63.66 0 0 0-37.95 12.5L160 153.36v-2a64 64 0 1 0-64 0v209.25a64 64 0 1 0 64 0V223.46l160.41 71.69A64 64 0 1 0 384 224zM128 64a32 32 0 1 1-32 32a32 32 0 0 1 32-32zm0 384a32 32 0 1 1 32-32a32 32 0 0 1-32 32zm256-128a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$a9 = [_hoisted_2$bQ];
    vue.defineComponent({
      name: 'GitMergeSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bQ, _hoisted_3$a9);
      }
    });

    const _hoisted_1$bP = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bP = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 96a64 64 0 1 0-96.31 55.21c-1.79 20.87-11.47 38.1-28.87 51.29C305.07 216 280.09 224 256 224s-49.07-8-66.82-21.5c-17.4-13.19-27.08-30.42-28.87-51.29a64 64 0 1 0-64.11.29c2.08 40.87 21.17 76.87 54.31 102C171.3 269.26 197 280.19 224 285.09v75.52a64 64 0 1 0 64 0v-75.52c27-4.9 52.7-15.83 73.49-31.59c33.14-25.13 52.23-61.13 54.31-102A64 64 0 0 0 448 96zM128 64a32 32 0 1 1-32 32a32 32 0 0 1 32-32zm128 384a32 32 0 1 1 32-32a32 32 0 0 1-32 32zm128-320a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$a8 = [_hoisted_2$bP];
    vue.defineComponent({
      name: 'GitNetwork',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bP, _hoisted_3$a8);
      }
    });

    const _hoisted_1$bO = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bO = /*#__PURE__*/vue.createStaticVNode('<circle cx="128" cy="96" r="48" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><circle cx="256" cy="416" r="48" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 256v112"></path><circle cx="384" cy="96" r="48" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><path d="M128 144c0 74.67 68.92 112 128 112" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M384 144c0 74.67-68.92 112-128 112" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 6);

    const _hoisted_8$r = [_hoisted_2$bO];
    vue.defineComponent({
      name: 'GitNetworkOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bO, _hoisted_8$r);
      }
    });

    const _hoisted_1$bN = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bN = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 32a64 64 0 0 0-57.67 91.73l-70.83 80.82l-70.19-80.1A64 64 0 1 0 128 160c1.1 0 2.2 0 3.29-.08L224 265.7v94.91a64 64 0 1 0 64 0v-96.05l91.78-104.71c1.39.09 2.8.15 4.22.15a64 64 0 0 0 0-128zM96 96a32 32 0 1 1 32 32a32 32 0 0 1-32-32zm160 352a32 32 0 1 1 32-32a32 32 0 0 1-32 32zm128-320a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$a7 = [_hoisted_2$bN];
    vue.defineComponent({
      name: 'GitNetworkSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bN, _hoisted_3$a7);
      }
    });

    const _hoisted_1$bM = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bM = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M192 96a64 64 0 1 0-96 55.39v209.22a64 64 0 1 0 64 0V151.39A64 64 0 0 0 192 96zm-64-32a32 32 0 1 1-32 32a32 32 0 0 1 32-32zm0 384a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$a6 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 360.61V156a92.1 92.1 0 0 0-92-92h-20V32a16 16 0 0 0-27.31-11.31l-64 64a16 16 0 0 0 0 22.62l64 64A16 16 0 0 0 304 160v-32h20a28 28 0 0 1 28 28v204.61a64 64 0 1 0 64 0zM384 448a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$61 = [_hoisted_2$bM, _hoisted_3$a6];
    vue.defineComponent({
      name: 'GitPullRequest',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bM, _hoisted_4$61);
      }
    });

    const _hoisted_1$bL = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bL = /*#__PURE__*/vue.createStaticVNode('<circle cx="128" cy="416" r="48" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M128 144v224"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M288 160l-64-64l64-64"></path><circle cx="128" cy="96" r="48" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><circle cx="384" cy="416" r="48" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><path d="M240 96h84a60 60 0 0 1 60 60v212" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 6);

    const _hoisted_8$q = [_hoisted_2$bL];
    vue.defineComponent({
      name: 'GitPullRequestOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bL, _hoisted_8$q);
      }
    });

    const _hoisted_1$bK = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bK = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M192 96a64 64 0 1 0-97 54.81v209.8a64 64 0 1 0 64 0V152a64.06 64.06 0 0 0 33-56zm-64-32a32 32 0 1 1-32 32a32 32 0 0 1 32-32zm-1 384a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$a5 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 360.61V156a92.1 92.1 0 0 0-92-92h-35V9.93L201.14 96L289 182.07V128h35a28 28 0 0 1 28 28v204.61a64 64 0 1 0 64 0zM384 448a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$60 = [_hoisted_2$bK, _hoisted_3$a5];
    vue.defineComponent({
      name: 'GitPullRequestSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bK, _hoisted_4$60);
      }
    });

    const _hoisted_1$bJ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bJ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 184h-10.9a78.72 78.72 0 0 0-16-7.18C419.5 171 396.26 168 368 168s-51.5 3-69.06 8.82c-14.06 4.69-20.25 9.86-22.25 11.87a47.94 47.94 0 0 0-41.36 0c-2-2-8.19-7.18-22.25-11.87C195.5 171 172.26 168 144 168s-51.5 3-69.06 8.82a78.72 78.72 0 0 0-16 7.18H48a16 16 0 0 0 0 32h.17c1 45.46 6.44 72.78 18.11 92.23a66.78 66.78 0 0 0 31.92 28c12.23 5.24 27.22 7.79 45.8 7.79c24.15 0 58.48-3.71 77.72-35.77c9.68-16.14 15.09-37.69 17.21-70.52A16 16 0 0 0 240 232a16 16 0 0 1 32 0a16 16 0 0 0 1.07 5.71c2.12 32.83 7.53 54.38 17.21 70.52a66.78 66.78 0 0 0 31.92 28c12.23 5.24 27.22 7.79 45.8 7.79c24.15 0 58.48-3.71 77.72-35.77c11.67-19.45 17.13-46.77 18.11-92.23h.17a16 16 0 0 0 0-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$a4 = [_hoisted_2$bJ];
    vue.defineComponent({
      name: 'Glasses',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bJ, _hoisted_3$a4);
      }
    });

    const _hoisted_1$bI = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bI = /*#__PURE__*/vue.createStaticVNode('<path d="M224 232a32 32 0 0 1 64 0" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M448 200h16"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M64 200H48"></path><path d="M64 200c0 96 16 128 80 128s80-32 80-128c0 0-16-16-80-16s-80 16-80 16z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M448 200c0 96-16 128-80 128s-80-32-80-128c0 0 16-16 80-16s80 16 80 16z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 5);

    const _hoisted_7$I = [_hoisted_2$bI];
    vue.defineComponent({
      name: 'GlassesOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bI, _hoisted_7$I);
      }
    });

    const _hoisted_1$bH = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bH = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M496 176H16v64h21.24l12.44 112h171.87L240 241.32V240a16 16 0 0 1 32 0v1.32L290.45 352h171.87l12.44-112H496z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$a3 = [_hoisted_2$bH];
    vue.defineComponent({
      name: 'GlassesSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bH, _hoisted_3$a3);
      }
    });

    const _hoisted_1$bG = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bG = /*#__PURE__*/vue.createStaticVNode('<path d="M340.75 344.49c5.91-20.7 9.82-44.75 11.31-67.84a4.41 4.41 0 0 0-4.46-4.65h-71.06a4.43 4.43 0 0 0-4.47 4.39v55.3a4.44 4.44 0 0 0 4.14 4.38a273.51 273.51 0 0 1 59 11.39a4.45 4.45 0 0 0 5.54-2.97z" fill="currentColor"></path><path d="M323.58 377.31a260.05 260.05 0 0 0-46.6-9.09a4.42 4.42 0 0 0-4.91 4.29v65.24a4.47 4.47 0 0 0 6.76 3.7c15.9-9.27 29-24.84 40.84-45.43c1.94-3.36 4.89-9.15 6.67-12.69a4.29 4.29 0 0 0-2.76-6.02z" fill="currentColor"></path><path d="M235.29 368.4a256.85 256.85 0 0 0-46.56 8.82c-2.64.76-3.75 4.4-2.55 6.79c1.79 3.56 4 8.11 5.89 11.51c13 23 26.84 37.5 41.24 45.93a4.47 4.47 0 0 0 6.76-3.7v-65.27a4.16 4.16 0 0 0-4.78-4.08z" fill="currentColor"></path><path d="M235.6 272h-71.06a4.41 4.41 0 0 0-4.46 4.64c1.48 23.06 5.37 47.16 11.26 67.84a4.46 4.46 0 0 0 5.59 3a272.2 272.2 0 0 1 59-11.36a4.44 4.44 0 0 0 4.15-4.38V276.4a4.43 4.43 0 0 0-4.48-4.4z" fill="currentColor"></path><path d="M277 143.78a235.8 235.8 0 0 0 46.5-9.14a4.3 4.3 0 0 0 2.76-6c-1.79-3.57-4.27-8.68-6.17-12.09c-12.29-22-26.14-37.35-41.24-46a4.48 4.48 0 0 0-6.76 3.7v65.23a4.43 4.43 0 0 0 4.91 4.3z" fill="currentColor"></path><path d="M276.54 240h71.06a4.39 4.39 0 0 0 4.46-4.58c-1.48-22.77-5.27-47.8-11.16-68.22a4.46 4.46 0 0 0-5.59-2.95c-19 5.74-38.79 10.43-59.09 12a4.4 4.4 0 0 0-4.15 4.32v55.11a4.4 4.4 0 0 0 4.47 4.32z" fill="currentColor"></path><path d="M233.31 70.56c-15.42 8.57-29.17 24.43-41.47 46.37c-1.91 3.41-4.19 8.11-6 11.67a4.31 4.31 0 0 0 2.76 6a225.42 225.42 0 0 0 46.54 9.17a4.43 4.43 0 0 0 4.91-4.29V74.26a4.49 4.49 0 0 0-6.74-3.7z" fill="currentColor"></path><path d="M235.92 176.26c-20.3-1.55-40.11-6.24-59.09-12a4.46 4.46 0 0 0-5.59 2.95c-5.89 20.42-9.68 45.45-11.16 68.22a4.39 4.39 0 0 0 4.46 4.58h71.06a4.4 4.4 0 0 0 4.47-4.34v-55.09a4.4 4.4 0 0 0-4.15-4.32z" fill="currentColor"></path><path d="M414.39 97.61A224 224 0 1 0 97.61 414.39A224 224 0 1 0 414.39 97.61zM176.6 430.85a219.08 219.08 0 0 1-12.48-19.66c-2-3.69-4.84-9.26-6.73-13.13a7.29 7.29 0 0 0-10.31-3.16c-4.3 2.41-10 5.72-14.13 8.43a147.29 147.29 0 0 1-23.57-22.43a248.83 248.83 0 0 1 30.41-18.36c1.86-1 2.77-2.14 2.18-4.18a374.8 374.8 0 0 1-14.09-82.17a4.36 4.36 0 0 0-4.3-4.17H66.84a2 2 0 0 1-2-1.7A98.28 98.28 0 0 1 64 256a96.27 96.27 0 0 1 .86-14.29a2 2 0 0 1 2-1.7h56.74c2.29 0 4.17-1.32 4.29-3.63a372.71 372.71 0 0 1 14-81.83a4.36 4.36 0 0 0-2.19-5.11a260.63 260.63 0 0 1-29.84-17.9a169.82 169.82 0 0 1 23.14-22.8c4.08 2.68 9.4 5.71 13.66 8.11a7.89 7.89 0 0 0 11-3.42c1.88-3.87 4-8.18 6.06-11.88a221.93 221.93 0 0 1 12.54-19.91A185 185 0 0 1 256 64c28.94 0 55.9 7 80.53 18.46a202.23 202.23 0 0 1 12 19c2.59 4.66 5.34 10.37 7.66 15.32a4.29 4.29 0 0 0 5.92 1.94c5.38-2.91 11.21-6.26 16.34-9.63a171.36 171.36 0 0 1 23.2 23a244.89 244.89 0 0 1-29.06 17.31a4.35 4.35 0 0 0-2.18 5.12a348.68 348.68 0 0 1 13.85 81.4a4.33 4.33 0 0 0 4.3 4.12l56.62-.07a2 2 0 0 1 2 1.7a117.46 117.46 0 0 1 0 28.62a2 2 0 0 1-2 1.72h-56.67a4.35 4.35 0 0 0-4.3 4.17a367.4 367.4 0 0 1-13.87 81.3a4.45 4.45 0 0 0 2.19 5.19c5 2.59 10.57 5.48 15.37 8.42s9.55 6.08 14.13 9.34a172.73 172.73 0 0 1-23 22.93c-2.44-1.61-5.34-3.44-7.84-4.94c-1.72-1-4.89-2.77-6.65-3.76c-3.82-2.14-7.88-.54-9.79 3.4s-4.83 9.59-6.87 13.25a212.42 212.42 0 0 1-12.35 19.53C310.91 442.37 284.94 448 256 448s-54.77-5.63-79.4-17.15z" fill="currentColor"></path>', 9);

    const _hoisted_11$6 = [_hoisted_2$bG];
    vue.defineComponent({
      name: 'Globe',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bG, _hoisted_11$6);
      }
    });

    const _hoisted_1$bF = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bF = /*#__PURE__*/vue.createStaticVNode('<path d="M256 48C141.13 48 48 141.13 48 256s93.13 208 208 208s208-93.13 208-208S370.87 48 256 48z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path d="M256 48c-58.07 0-112.67 93.13-112.67 208S197.93 464 256 464s112.67-93.13 112.67-208S314.07 48 256 48z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path d="M117.33 117.33c38.24 27.15 86.38 43.34 138.67 43.34s100.43-16.19 138.67-43.34" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M394.67 394.67c-38.24-27.15-86.38-43.34-138.67-43.34s-100.43 16.19-138.67 43.34" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32" d="M256 48v416"></path><path fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32" d="M464 256H48"></path>', 6);

    const _hoisted_8$p = [_hoisted_2$bF];
    vue.defineComponent({
      name: 'GlobeOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bF, _hoisted_8$p);
      }
    });

    const _hoisted_1$bE = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bE = /*#__PURE__*/vue.createStaticVNode('<path d="M256 48C141.13 48 48 141.13 48 256s93.13 208 208 208s208-93.13 208-208S370.87 48 256 48z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="44"></path><path d="M256 48c-58.07 0-112.67 93.13-112.67 208S197.93 464 256 464s112.67-93.13 112.67-208S314.07 48 256 48z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="44"></path><path d="M117.33 121.33c38.24 27.15 86.38 43.34 138.67 43.34s100.43-16.19 138.67-43.34" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="44"></path><path d="M394.67 390.67c-38.24-27.15-86.38-43.34-138.67-43.34s-100.43 16.19-138.67 43.34" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="44"></path><path fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="44" d="M256 48v416"></path><path fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="44" d="M464 256H48"></path>', 6);

    const _hoisted_8$o = [_hoisted_2$bE];
    vue.defineComponent({
      name: 'GlobeSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bE, _hoisted_8$o);
      }
    });

    const _hoisted_1$bD = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bD = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M272 320.46V202.3l166.62-75.73a16 16 0 0 0 0-29.14l-176-80A16 16 0 0 0 240 32v288.46q8-.45 16-.46t16 .46z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$a2 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M463.33 457.5c-8.56-42.85-35.11-78.74-76.78-103.8c-32.5-19.55-72.67-31.3-114.55-33.7v79.75a16 16 0 1 1-32 0V320c-41.88 2.4-82.05 14.15-114.55 33.7c-41.67 25.06-68.22 60.95-76.78 103.8a32.49 32.49 0 0 0 6.44 27.08C61.13 492 70 496 80 496h352c10 0 18.88-4.05 24.9-11.42a32.49 32.49 0 0 0 6.43-27.08z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5$ = [_hoisted_2$bD, _hoisted_3$a2];
    vue.defineComponent({
      name: 'Golf',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bD, _hoisted_4$5$);
      }
    });

    const _hoisted_1$bC = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bC = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 400V32l176 80l-176 80'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$a1 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 336c-87 0-175.3 43.2-191.64 124.74C62.39 470.57 68.57 480 80 480h352c11.44 0 17.62-9.43 15.65-19.26C431.3 379.2 343 336 256 336z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5_ = [_hoisted_2$bC, _hoisted_3$a1];
    vue.defineComponent({
      name: 'GolfOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bC, _hoisted_4$5_);
      }
    });

    const _hoisted_1$bB = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bB = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M240 16v304.47q8-.47 16-.47t16 .47V202.3L448 112z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$a0 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M462.91 457.5c-8.54-42.85-35-78.74-76.62-103.8c-32.43-19.55-72.53-31.3-114.29-33.7v95.79h-32V320c-41.79 2.4-81.89 14.15-114.32 33.7c-41.59 25.06-68.08 60.95-76.62 103.8c-2 9.81-.68 38.5-.68 38.5h415.21s1.28-28.69-.68-38.5z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5Z = [_hoisted_2$bB, _hoisted_3$a0];
    vue.defineComponent({
      name: 'GolfSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bB, _hoisted_4$5Z);
      }
    });

    const _hoisted_1$bA = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bA = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M204 240H68a36 36 0 0 1-36-36V68a36 36 0 0 1 36-36h136a36 36 0 0 1 36 36v136a36 36 0 0 1-36 36z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9$ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M444 240H308a36 36 0 0 1-36-36V68a36 36 0 0 1 36-36h136a36 36 0 0 1 36 36v136a36 36 0 0 1-36 36z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5Y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M204 480H68a36 36 0 0 1-36-36V308a36 36 0 0 1 36-36h136a36 36 0 0 1 36 36v136a36 36 0 0 1-36 36z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2P = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M444 480H308a36 36 0 0 1-36-36V308a36 36 0 0 1 36-36h136a36 36 0 0 1 36 36v136a36 36 0 0 1-36 36z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1f = [_hoisted_2$bA, _hoisted_3$9$, _hoisted_4$5Y, _hoisted_5$2P];
    vue.defineComponent({
      name: 'Grid',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bA, _hoisted_6$1f);
      }
    });

    const _hoisted_1$bz = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bz = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '48',
      y: '48',
      width: '176',
      height: '176',
      rx: '20',
      ry: '20',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9_ = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '288',
      y: '48',
      width: '176',
      height: '176',
      rx: '20',
      ry: '20',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5X = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '48',
      y: '288',
      width: '176',
      height: '176',
      rx: '20',
      ry: '20',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2O = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '288',
      y: '288',
      width: '176',
      height: '176',
      rx: '20',
      ry: '20',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1e = [_hoisted_2$bz, _hoisted_3$9_, _hoisted_4$5X, _hoisted_5$2O];
    vue.defineComponent({
      name: 'GridOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bz, _hoisted_6$1e);
      }
    });

    const _hoisted_1$by = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$by = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M240 240H32V32h208z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9Z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 240H272V32h208z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5W = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M240 480H32V272h208z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2N = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 480H272V272h208z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1d = [_hoisted_2$by, _hoisted_3$9Z, _hoisted_4$5W, _hoisted_5$2N];
    vue.defineComponent({
      name: 'GridSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$by, _hoisted_6$1d);
      }
    });

    const _hoisted_1$bx = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bx = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M280.16 242.79l-26.11-26.12a32 32 0 0 0-45.14-.12L27.38 384.08c-6.61 6.23-10.95 14.17-11.35 23.06a32.11 32.11 0 0 0 9.21 23.94l39 39.43a.46.46 0 0 0 .07.07A32.29 32.29 0 0 0 87 480h1.18c8.89-.33 16.85-4.5 23.17-11.17l168.7-180.7a32 32 0 0 0 .11-45.34z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9Y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M490 190l-.31-.31l-34.27-33.92a21.46 21.46 0 0 0-15.28-6.26a21.89 21.89 0 0 0-12.79 4.14c0-.43.06-.85.09-1.22c.45-6.5 1.15-16.32-5.2-25.22a258 258 0 0 0-24.8-28.74a.6.6 0 0 0-.08-.08c-13.32-13.12-42.31-37.83-86.72-55.94A139.55 139.55 0 0 0 257.56 32C226 32 202 46.24 192.81 54.68a119.92 119.92 0 0 0-14.18 16.22a16 16 0 0 0 18.65 24.34a74.45 74.45 0 0 1 8.58-2.63a63.46 63.46 0 0 1 18.45-1.15c13.19 1.09 28.79 7.64 35.69 13.09c11.7 9.41 17.33 22.09 18.26 41.09c.18 3.82-7.72 18.14-20 34.48a16 16 0 0 0 1.45 21l34.41 34.41a16 16 0 0 0 22 .62c9.73-8.69 24.55-21.79 29.73-25c7.69-4.73 13.19-5.64 14.7-5.8a19.18 19.18 0 0 1 11.29 2.38a1.24 1.24 0 0 1-.31.95l-1.82 1.73l-.3.28a21.52 21.52 0 0 0 .05 30.54l34.26 33.91a21.45 21.45 0 0 0 15.28 6.25a21.7 21.7 0 0 0 15.22-6.2l55.5-54.82c.19-.19.38-.39.56-.59A21.87 21.87 0 0 0 490 190z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5V = [_hoisted_2$bx, _hoisted_3$9Y];
    vue.defineComponent({
      name: 'Hammer',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bx, _hoisted_4$5V);
      }
    });

    const _hoisted_1$bw = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bw = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M277.42 247a24.68 24.68 0 0 0-4.08-5.47L255 223.44a21.63 21.63 0 0 0-6.56-4.57a20.93 20.93 0 0 0-23.28 4.27c-6.36 6.26-18 17.68-39 38.43C146 301.3 71.43 367.89 37.71 396.29a16 16 0 0 0-1.09 23.54l39 39.43a16.13 16.13 0 0 0 23.67-.89c29.24-34.37 96.3-109 136-148.23c20.39-20.06 31.82-31.58 38.29-37.94a21.76 21.76 0 0 0 3.84-25.2z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9X = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M478.43 201l-34.31-34a5.44 5.44 0 0 0-4-1.59a5.59 5.59 0 0 0-4 1.59h0a11.41 11.41 0 0 1-9.55 3.27c-4.48-.49-9.25-1.88-12.33-4.86c-7-6.86 1.09-20.36-5.07-29a242.88 242.88 0 0 0-23.08-26.72c-7.06-7-34.81-33.47-81.55-52.53a123.79 123.79 0 0 0-47-9.24c-26.35 0-46.61 11.76-54 18.51c-5.88 5.32-12 13.77-12 13.77a91.29 91.29 0 0 1 10.81-3.2a79.53 79.53 0 0 1 23.28-1.49C241.19 76.8 259.94 84.1 270 92c16.21 13 23.18 30.39 24.27 52.83c.8 16.69-15.23 37.76-30.44 54.94a7.85 7.85 0 0 0 .4 10.83l21.24 21.23a8 8 0 0 0 11.14.1c13.93-13.51 31.09-28.47 40.82-34.46s17.58-7.68 21.35-8.09a35.71 35.71 0 0 1 21.3 4.62a13.65 13.65 0 0 1 3.08 2.38c6.46 6.56 6.07 17.28-.5 23.74l-2 1.89a5.5 5.5 0 0 0 0 7.84l34.31 34a5.5 5.5 0 0 0 4 1.58a5.65 5.65 0 0 0 4-1.58L478.43 209a5.82 5.82 0 0 0 0-8z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5U = [_hoisted_2$bw, _hoisted_3$9X];
    vue.defineComponent({
      name: 'HammerOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bw, _hoisted_4$5U);
      }
    });

    const _hoisted_1$bv = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bv = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M294.28 256.9l-54.42-54.41a12 12 0 0 0-17 0L12.45 401a12 12 0 0 0-.27 17.2l66.05 66.28a12 12 0 0 0 17.22-.23l198.81-210.36a12 12 0 0 0 .02-16.99z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9W = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M499.33 199.33l-43.89-43.58a21.46 21.46 0 0 0-15.28-6.26a21.89 21.89 0 0 0-12.79 4.14c0-.43.06-.85.09-1.22c.45-6.5 1.15-16.32-5.2-25.22a258 258 0 0 0-24.8-28.74a.6.6 0 0 0-.08-.08c-13.32-13.12-42.31-37.83-86.72-55.94A139.55 139.55 0 0 0 257.56 32C226 32 202 46.24 192.81 54.68A53.4 53.4 0 0 0 176 86.17L192 96s8.06-2 13.86-3.39a62.73 62.73 0 0 1 18.45-1.15c13.19 1.09 28.79 7.64 35.69 13.09c11.7 9.41 17.33 22.09 18.26 41.09c.2 4.23-9.52 21.35-24.16 39.84a8 8 0 0 0 .61 10.62l45.37 45.37a8 8 0 0 0 11 .25c12.07-11 30.49-28 34.67-30.59c7.69-4.73 13.19-5.64 14.7-5.8a19.18 19.18 0 0 1 11.29 2.38a1.24 1.24 0 0 1-.31.95l-1.82 1.73l-.3.28a21.52 21.52 0 0 0 .05 30.54l43.95 43.68a8 8 0 0 0 11.28 0l74.68-74.2a8 8 0 0 0 .06-11.36z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5T = [_hoisted_2$bv, _hoisted_3$9W];
    vue.defineComponent({
      name: 'HammerSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bv, _hoisted_4$5T);
      }
    });

    const _hoisted_1$bu = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bu = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M432.8 211.44c-15.52-8.82-34.91-2.28-43.31 13.68l-41.38 84.41a7 7 0 0 1-8.93 3.43a7 7 0 0 1-4.41-6.52V72c0-13.91-12.85-24-26.77-24s-26 10.09-26 24v156.64A11.24 11.24 0 0 1 271.21 240A11 11 0 0 1 260 229V24c0-13.91-10.94-24-24.86-24S210 10.09 210 24v204.64A11.24 11.24 0 0 1 199.21 240A11 11 0 0 1 188 229V56c0-13.91-12.08-24-26-24s-26 11.09-26 25v187.64A11.24 11.24 0 0 1 125.21 256A11 11 0 0 1 114 245V120c0-13.91-11.08-24-25-24s-25.12 10.22-25 24v216c0 117.41 72 176 160 176h16c88 0 115.71-39.6 136-88l68.71-169c6.62-18 3.6-34.75-11.91-43.56z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9V = [_hoisted_2$bu];
    vue.defineComponent({
      name: 'HandLeft',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bu, _hoisted_3$9V);
      }
    });

    const _hoisted_1$bt = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bt = /*#__PURE__*/vue.createStaticVNode('<path d="M80 320V144a32 32 0 0 1 32-32h0a32 32 0 0 1 32 32v112" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M144 256V80a32 32 0 0 1 32-32h0a32 32 0 0 1 32 32v160" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M272 241V96a32 32 0 0 1 32-32h0a32 32 0 0 1 32 32v224" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M208 240V48a32 32 0 0 1 32-32h0a32 32 0 0 1 32 32v192" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M80 320c0 117.4 64 176 152 176s123.71-39.6 144-88l52.71-144c6.66-18.05 3.64-34.79-11.87-43.6h0c-15.52-8.82-35.91-4.28-44.31 11.68L336 320" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 5);

    const _hoisted_7$H = [_hoisted_2$bt];
    vue.defineComponent({
      name: 'HandLeftOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bt, _hoisted_7$H);
      }
    });

    const _hoisted_1$bs = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bs = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M429.58 209.08c-15.06-6.62-32.38 1.31-38.5 17.62L356 312h-11.27V80c0-17.6-13.3-32-29.55-32c-16.26 0-29.55 14.4-29.55 32v151.75l-14.78.25V32c0-17.6-13.3-32-29.55-32s-29.55 14.4-29.55 32v199.75L197 232V64c0-17.6-13.3-32-29.55-32c-16.26 0-29.55 14.4-29.55 32v183.75l-14.8.25V128c0-17.6-13.3-32-29.55-32S64 110.4 64 128v216c0 75.8 37.13 168 169 168c40.8 0 79.42-7 100.66-21a121.41 121.41 0 0 0 33.72-33.31a138 138 0 0 0 16-31.78l62.45-175.14c6.17-16.31-1.19-35.06-16.25-41.69z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9U = [_hoisted_2$bs];
    vue.defineComponent({
      name: 'HandLeftSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bs, _hoisted_3$9U);
      }
    });

    const _hoisted_1$br = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$br = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M79.2 211.44c15.52-8.82 34.91-2.28 43.31 13.68l41.38 84.41a7 7 0 0 0 8.93 3.43a7 7 0 0 0 4.41-6.52V72c0-13.91 12.85-24 26.77-24s26 10.09 26 24v156.64A11.24 11.24 0 0 0 240.79 240A11 11 0 0 0 252 229V24c0-13.91 10.94-24 24.86-24S302 10.09 302 24v204.64A11.24 11.24 0 0 0 312.79 240A11 11 0 0 0 324 229V56c0-13.91 12.08-24 26-24s26 11.09 26 25v187.64A11.24 11.24 0 0 0 386.79 256A11 11 0 0 0 398 245V120c0-13.91 11.08-24 25-24s25.12 10.22 25 24v216c0 117.41-72 176-160 176h-16c-88 0-115.71-39.6-136-88L67.33 255c-6.66-18-3.64-34.75 11.87-43.56z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9T = [_hoisted_2$br];
    vue.defineComponent({
      name: 'HandRight',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$br, _hoisted_3$9T);
      }
    });

    const _hoisted_1$bq = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bq = /*#__PURE__*/vue.createStaticVNode('<path d="M432 320V144a32 32 0 0 0-32-32h0a32 32 0 0 0-32 32v112" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M368 256V80a32 32 0 0 0-32-32h0a32 32 0 0 0-32 32v160" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M240 241V96a32 32 0 0 0-32-32h0a32 32 0 0 0-32 32v224" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M304 240V48a32 32 0 0 0-32-32h0a32 32 0 0 0-32 32v192" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M432 320c0 117.4-64 176-152 176s-123.71-39.6-144-88L83.33 264c-6.66-18.05-3.64-34.79 11.87-43.6h0c15.52-8.82 35.91-4.28 44.31 11.68L176 320" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 5);

    const _hoisted_7$G = [_hoisted_2$bq];
    vue.defineComponent({
      name: 'HandRightOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bq, _hoisted_7$G);
      }
    });

    const _hoisted_1$bp = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bp = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M82.42 209.08c15.06-6.62 32.38 1.31 38.5 17.62L156 312h11.27V80c0-17.6 13.3-32 29.55-32c16.26 0 29.55 14.4 29.55 32v151.75l14.78.25V32c0-17.6 13.3-32 29.55-32c16.3 0 29.55 14.4 29.55 32v199.75L315 232V64c0-17.6 13.3-32 29.55-32c16.26 0 29.55 14.4 29.55 32v183.75l14.78.25V128c0-17.6 13.3-32 29.55-32C434.7 96 448 110.4 448 128v216c0 75.8-37.13 168-169 168c-40.8 0-79.42-7-100.66-21a121.41 121.41 0 0 1-33.72-33.31a138 138 0 0 1-16-31.78L66.16 250.77c-6.11-16.31 1.2-35.06 16.26-41.69z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9S = [_hoisted_2$bp];
    vue.defineComponent({
      name: 'HandRightSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bp, _hoisted_3$9S);
      }
    });

    const _hoisted_1$bo = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bo = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M414.39 97.61A224 224 0 1 0 97.61 414.39A224 224 0 1 0 414.39 97.61zM184 208a24 24 0 1 1-24 24a23.94 23.94 0 0 1 24-24zm167.67 106.17c-12 40.3-50.2 69.83-95.62 69.83s-83.62-29.53-95.72-69.83a8 8 0 0 1 7.83-10.17h175.69a8 8 0 0 1 7.82 10.17zM328 256a24 24 0 1 1 24-24a23.94 23.94 0 0 1-24 24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9R = [_hoisted_2$bo];
    vue.defineComponent({
      name: 'Happy',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bo, _hoisted_3$9R);
      }
    });

    const _hoisted_1$bn = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bn = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '184',
      cy: '232',
      r: '24',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9Q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256.05 384c-45.42 0-83.62-29.53-95.71-69.83a8 8 0 0 1 7.82-10.17h175.69a8 8 0 0 1 7.82 10.17c-11.99 40.3-50.2 69.83-95.62 69.83z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5S = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '328',
      cy: '232',
      r: '24',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2M = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '208',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1c = [_hoisted_2$bn, _hoisted_3$9Q, _hoisted_4$5S, _hoisted_5$2M];
    vue.defineComponent({
      name: 'HappyOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bn, _hoisted_6$1c);
      }
    });

    const _hoisted_1$bm = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bm = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M414.39 97.61A224 224 0 1 0 97.61 414.39A224 224 0 1 0 414.39 97.61zM328 208a24 24 0 1 1-24 24a23.94 23.94 0 0 1 24-24zm-144 0a24 24 0 1 1-24 24a23.94 23.94 0 0 1 24-24zm72.05 176c-45.42 0-83.75-29.49-95.72-69.83C159.29 310.65 158 304 158 304h196s-1.31 6.69-2.33 10.17c-11.78 40.36-50.2 69.83-95.62 69.83z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9P = [_hoisted_2$bm];
    vue.defineComponent({
      name: 'HappySharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bm, _hoisted_3$9P);
      }
    });

    const _hoisted_1$bl = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bl = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M352 128H160a32 32 0 0 0-32 32v192a32 32 0 0 0 32 32h192a32 32 0 0 0 32-32V160a32 32 0 0 0-32-32zm0 216a8 8 0 0 1-8 8H168a8 8 0 0 1-8-8V168a8 8 0 0 1 8-8h176a8 8 0 0 1 8 8z',
      fill: 'none'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9O = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '160',
      y: '160',
      width: '192',
      height: '192',
      rx: '8',
      ry: '8',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5R = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 192a16 16 0 0 0 0-32h-16v-32a64.07 64.07 0 0 0-64-64h-32V48a16 16 0 0 0-32 0v16h-48V48a16 16 0 0 0-32 0v16h-48V48a16 16 0 0 0-32 0v16h-32a64.07 64.07 0 0 0-64 64v32H48a16 16 0 0 0 0 32h16v48H48a16 16 0 0 0 0 32h16v48H48a16 16 0 0 0 0 32h16v32a64.07 64.07 0 0 0 64 64h32v16a16 16 0 0 0 32 0v-16h48v16a16 16 0 0 0 32 0v-16h48v16a16 16 0 0 0 32 0v-16h32a64.07 64.07 0 0 0 64-64v-32h16a16 16 0 0 0 0-32h-16v-48h16a16 16 0 0 0 0-32h-16v-48zm-80 160a32 32 0 0 1-32 32H160a32 32 0 0 1-32-32V160a32 32 0 0 1 32-32h192a32 32 0 0 1 32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2L = [_hoisted_2$bl, _hoisted_3$9O, _hoisted_4$5R];
    vue.defineComponent({
      name: 'HardwareChip',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bl, _hoisted_5$2L);
      }
    });

    const _hoisted_1$bk = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bk = /*#__PURE__*/vue.createStaticVNode('<rect x="80" y="80" width="352" height="352" rx="48" ry="48" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></rect><rect x="144" y="144" width="224" height="224" rx="16" ry="16" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></rect><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 80V48"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M336 80V48"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M176 80V48"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 464v-32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M336 464v-32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M176 464v-32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M432 256h32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M432 336h32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M432 176h32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M48 256h32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M48 336h32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M48 176h32"></path>', 14);

    const _hoisted_16$2 = [_hoisted_2$bk];
    vue.defineComponent({
      name: 'HardwareChipOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bk, _hoisted_16$2);
      }
    });

    const _hoisted_1$bj = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bj = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M160 160h192v192H160z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9N = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 198v-44h-32V88a24 24 0 0 0-24-24h-66V32h-44v32h-36V32h-44v32h-36V32h-44v32H88a24 24 0 0 0-24 24v66H32v44h32v36H32v44h32v36H32v44h32v66a24 24 0 0 0 24 24h66v32h44v-32h36v32h44v-32h36v32h44v-32h66a24 24 0 0 0 24-24v-66h32v-44h-32v-36h32v-44h-32v-36zm-352-70h256v256H128z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5Q = [_hoisted_2$bj, _hoisted_3$9N];
    vue.defineComponent({
      name: 'HardwareChipSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bj, _hoisted_4$5Q);
      }
    });

    const _hoisted_1$bi = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bi = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M411.16 97.46C368.43 55.86 311.88 32 256 32S143.57 55.86 100.84 97.46C56.45 140.67 32 197 32 256c0 26.67 8.75 61.09 32.88 125.55S137 473 157.27 477.41c5.81 1.27 12.62 2.59 18.73 2.59a60.06 60.06 0 0 0 30-8l14-8c15.07-8.82 19.47-28.13 10.8-43.35l-86.92-152.57a31.73 31.73 0 0 0-43.57-11.76l-13.69 8a56.49 56.49 0 0 0-14 11.59a4 4 0 0 1-7-2A114.68 114.68 0 0 1 64 256c0-50.31 21-98.48 59.16-135.61C160 84.55 208.39 64 256 64s96 20.55 132.84 56.39C427 157.52 448 205.69 448 256a114.68 114.68 0 0 1-1.68 17.91a4 4 0 0 1-7 2a56.49 56.49 0 0 0-14-11.59l-13.69-8a31.73 31.73 0 0 0-43.57 11.76L281.2 420.65c-8.67 15.22-4.27 34.53 10.8 43.35l14 8a60.06 60.06 0 0 0 30 8c6.11 0 12.92-1.32 18.73-2.59C375 473 423 446 447.12 381.55S480 282.67 480 256c0-59-24.45-115.33-68.84-158.54z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9M = [_hoisted_2$bi];
    vue.defineComponent({
      name: 'Headset',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bi, _hoisted_3$9M);
      }
    });

    const _hoisted_1$bh = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bh = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M83 384c-13-33-35-93.37-35-128C48 141.12 149.33 48 256 48s208 93.12 208 208c0 34.63-23 97-35 128',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9L = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M108.39 270.13l-13.69 8h0c-30.23 17.7-31.7 72.41-3.38 122.2s75.87 75.81 106.1 58.12h0l13.69-8a16.16 16.16 0 0 0 5.78-21.87L130 276a15.74 15.74 0 0 0-21.61-5.87z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5P = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M403.61 270.13l13.69 8h0c30.23 17.69 31.74 72.4 3.38 122.19s-75.87 75.81-106.1 58.12h0l-13.69-8a16.16 16.16 0 0 1-5.78-21.87L382 276a15.74 15.74 0 0 1 21.61-5.87z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2K = [_hoisted_2$bh, _hoisted_3$9L, _hoisted_4$5P];
    vue.defineComponent({
      name: 'HeadsetOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bh, _hoisted_5$2K);
      }
    });

    const _hoisted_1$bg = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bg = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M411.16 97.45C368.43 55.85 311.88 32 256 32S143.57 55.85 100.84 97.45C56.45 140.67 32 196 32 256s26.84 118.49 45.42 152.25S121 480 144 480c32 0 96-32 96-32L128 240l-54.42 31.73a176.07 176.07 0 0 1-1-18.84c0-48.57 19.32-94.1 56.15-130C164.24 88.34 210 70 256 70s91.73 18.34 127.27 52.93c36.83 35.86 56.14 81.39 56.14 130a175.56 175.56 0 0 1-1 18.82L384 240L272 448s64 32 96 32c23 0 48-38 66.58-71.75S480 316 480 256s-24.45-115.33-68.84-158.55z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9K = [_hoisted_2$bg];
    vue.defineComponent({
      name: 'HeadsetSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bg, _hoisted_3$9K);
      }
    });

    const _hoisted_1$bf = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bf = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 448a32 32 0 0 1-18-5.57c-78.59-53.35-112.62-89.93-131.39-112.8c-40-48.75-59.15-98.8-58.61-153C48.63 114.52 98.46 64 159.08 64c44.08 0 74.61 24.83 92.39 45.51a6 6 0 0 0 9.06 0C278.31 88.81 308.84 64 352.92 64c60.62 0 110.45 50.52 111.08 112.64c.54 54.21-18.63 104.26-58.61 153c-18.77 22.87-52.8 59.45-131.39 112.8a32 32 0 0 1-18 5.56z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9J = [_hoisted_2$bf];
    vue.defineComponent({
      name: 'Heart',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bf, _hoisted_3$9J);
      }
    });

    const _hoisted_1$be = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$be = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm74.69 252.82c-9.38 11.44-26.4 29.73-65.7 56.41a15.93 15.93 0 0 1-18 0c-39.3-26.68-56.32-45-65.7-56.41c-20-24.37-29.58-49.4-29.3-76.5c.31-31.06 25.22-56.33 55.53-56.33c20.4 0 35 10.63 44.1 20.41a6 6 0 0 0 8.72 0c9.11-9.78 23.7-20.41 44.1-20.41c30.31 0 55.22 25.27 55.53 56.33c.3 27.1-9.29 52.13-29.28 76.5z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9I = [_hoisted_2$be];
    vue.defineComponent({
      name: 'HeartCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$be, _hoisted_3$9I);
      }
    });

    const _hoisted_1$bd = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bd = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9H = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 360a16 16 0 0 1-9-2.78c-39.3-26.68-56.32-45-65.7-56.41c-20-24.37-29.58-49.4-29.3-76.5c.31-31.06 25.22-56.33 55.53-56.33c20.4 0 35 10.63 44.1 20.41a6 6 0 0 0 8.72 0c9.11-9.78 23.7-20.41 44.1-20.41c30.31 0 55.22 25.27 55.53 56.33c.28 27.1-9.31 52.13-29.3 76.5c-9.38 11.44-26.4 29.73-65.7 56.41A16 16 0 0 1 256 360z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5O = [_hoisted_2$bd, _hoisted_3$9H];
    vue.defineComponent({
      name: 'HeartCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bd, _hoisted_4$5O);
      }
    });

    const _hoisted_1$bc = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bc = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm74.69 252.82c-8.5 10.36-39.69 38.48-74.69 63.51c-35-25-66.19-53.15-74.69-63.51c-20-24.37-29.58-49.4-29.3-76.5c.31-31.06 25.22-56.33 55.53-56.33c22 0 37.3 12.41 46.19 22.76l2.27 2.75l2.27-2.75C267 180.29 282.42 168 304.46 168c30.31 0 55.22 25.27 55.53 56.33c.28 27.09-9.31 52.12-29.3 76.49z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9G = [_hoisted_2$bc];
    vue.defineComponent({
      name: 'HeartCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bc, _hoisted_3$9G);
      }
    });

    const _hoisted_1$bb = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$bb = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M417.84 448a16 16 0 0 1-11.35-4.72l-365.84-368a16 16 0 1 1 22.7-22.56l365.83 368A16 16 0 0 1 417.84 448z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9F = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M364.92 80c-44.09 0-74.61 24.82-92.39 45.5a6 6 0 0 1-9.06 0C245.69 104.82 215.16 80 171.08 80a107.71 107.71 0 0 0-31 4.54l269.13 270.7c3-3.44 5.7-6.64 8.14-9.6c40-48.75 59.15-98.79 58.61-153C475.37 130.53 425.54 80 364.92 80z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5N = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M69 149.15a115.06 115.06 0 0 0-9 43.49c-.54 54.21 18.63 104.25 58.61 153c18.77 22.87 52.8 59.45 131.39 112.8a31.88 31.88 0 0 0 36 0c20.35-13.82 37.7-26.5 52.58-38.12z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2J = [_hoisted_2$bb, _hoisted_3$9F, _hoisted_4$5N];
    vue.defineComponent({
      name: 'HeartDislike',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$bb, _hoisted_5$2J);
      }
    });

    const _hoisted_1$ba = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ba = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm23.3 299.19c-4.41 3.2-9.16 6.55-14.31 10a15.93 15.93 0 0 1-18 0c-39.3-26.68-56.32-45-65.7-56.41c-20-24.37-29.58-49.4-29.3-76.5v-.64a4 4 0 0 1 6.82-2.72l120.95 120.2a4 4 0 0 1-.46 6.07zm68 16.12a16 16 0 0 1-22.62 0l-176-176a16 16 0 0 1 22.62-22.62l176 176a16 16 0 0 1 .01 22.62zm-14.1-65.62a3.92 3.92 0 0 1-6 .37l-124-123.21A4 4 0 0 1 206 168h1.55c20.4 0 35 10.64 44.11 20.42a5.93 5.93 0 0 0 8.7 0c9.11-9.78 23.71-20.42 44.11-20.42c30.31 0 55.22 25.27 55.53 56.33c.26 25.93-8.52 49.97-26.8 73.36z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9E = [_hoisted_2$ba];
    vue.defineComponent({
      name: 'HeartDislikeCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ba, _hoisted_3$9E);
      }
    });

    const _hoisted_1$b9 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$b9 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9D = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M333.2 297.69c18.28-23.39 27.06-47.43 26.79-73.37c-.31-31.06-25.22-56.33-55.53-56.33c-20.4 0-35 10.64-44.11 20.42a5.93 5.93 0 0 1-8.7 0c-9.11-9.78-23.71-20.42-44.11-20.42L206 168a4 4 0 0 0-2.75 6.84l124 123.21a3.92 3.92 0 0 0 5.95-.36z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5M = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M158.84 221a4 4 0 0 0-6.82 2.72v.64c-.28 27.1 9.31 52.13 29.3 76.5c9.38 11.44 26.4 29.73 65.7 56.41a15.93 15.93 0 0 0 18 0c5.15-3.49 9.9-6.84 14.31-10a4 4 0 0 0 .46-6.07z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2I = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 368a15.92 15.92 0 0 1-11.31-4.69l-176-176a16 16 0 0 1 22.62-22.62l176 176A16 16 0 0 1 336 368z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1b = [_hoisted_2$b9, _hoisted_3$9D, _hoisted_4$5M, _hoisted_5$2I];
    vue.defineComponent({
      name: 'HeartDislikeCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$b9, _hoisted_6$1b);
      }
    });

    const _hoisted_1$b8 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$b8 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm63.73 310.36l-183.14-182.3l22.74-22.51l183.19 182.36zm-63.51 4.86c-35.36-25-66.31-51.92-74.91-62.4c-20-24.37-29.58-49.4-29.3-76.5a58.27 58.27 0 0 1 .85-9.31l130.21 129.4c-3.43 2.59-16.21 11.45-26.85 18.81zm74.47-62.4l-.31.38L197.33 169a53.8 53.8 0 0 1 10.21-1a59.34 59.34 0 0 1 44.1 19.41L256 192l4.36-4.6a59.34 59.34 0 0 1 44.1-19.4c30.31 0 55.22 25.27 55.53 56.33c.28 27.09-9.31 52.12-29.3 76.49z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9C = [_hoisted_2$b8];
    vue.defineComponent({
      name: 'HeartDislikeCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$b8, _hoisted_3$9C);
      }
    });

    const _hoisted_1$b7 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$b7 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M417.84 448a15.94 15.94 0 0 1-11.35-4.72L40.65 75.26a16 16 0 0 1 22.7-22.56l365.83 368a16 16 0 0 1-11.34 27.3z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9B = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M364.92 80c-48.09 0-80 29.55-96.92 51c-16.88-21.48-48.83-51-96.92-51a107.37 107.37 0 0 0-31 4.55L168 112c22.26 0 45.81 9 63.94 26.67a123 123 0 0 1 21.75 28.47a16 16 0 0 0 28.6 0a123 123 0 0 1 21.77-28.51C322.19 121 342.66 112 364.92 112c43.15 0 78.62 36.33 79.07 81c.54 53.69-22.75 99.55-57.38 139.52l22.63 22.77c3-3.44 5.7-6.64 8.14-9.6c40-48.75 59.15-98.8 58.61-153C475.37 130.52 425.54 80 364.92 80z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5L = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M268 432C180.38 372.51 91 297.6 92 193a83.69 83.69 0 0 1 2.24-18.39L69 149.14a115.1 115.1 0 0 0-9 43.49c-.54 54.22 18.63 104.27 58.61 153c18.77 22.87 52.8 59.45 131.39 112.8a31.84 31.84 0 0 0 36 0c20.35-13.81 37.7-26.5 52.58-38.11l-22.66-22.81C300.25 409.6 284.09 421.05 268 432z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2H = [_hoisted_2$b7, _hoisted_3$9B, _hoisted_4$5L];
    vue.defineComponent({
      name: 'HeartDislikeOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$b7, _hoisted_5$2H);
      }
    });

    const _hoisted_1$b6 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$b6 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M32 64.45l389.47 389.94l22.84-22.47L54.85 42L32 64.45z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9A = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M62.67 192.91c-.56 55.63 19.77 106.94 62.16 156.88c40.25 47.42 94.56 79.67 137.47 108.21l9 6l9-6c18.49-12.3 39.1-25.3 59.79-39.89L71.74 149.28a114.62 114.62 0 0 0-9.07 43.63z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5K = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M417.83 349.79c42.39-49.94 62.72-101.25 62.16-156.88c-.63-62-50.61-112.54-111.43-112.54c-48.26 0-80.35 28-97.23 48.17c-16.88-20.2-49-48.17-97.23-48.17A108.24 108.24 0 0 0 142.84 85l270 270.48c1.71-1.89 3.37-3.78 4.99-5.69z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2G = [_hoisted_2$b6, _hoisted_3$9A, _hoisted_4$5K];
    vue.defineComponent({
      name: 'HeartDislikeSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$b6, _hoisted_5$2G);
      }
    });

    const _hoisted_1$b5 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$b5 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M352.92 64c-48.09 0-80 29.54-96.92 51c-16.88-21.49-48.83-51-96.92-51C98.46 64 48.63 114.54 48 176.65c-.54 54.21 18.63 104.27 58.61 153c18.77 22.88 52.8 59.46 131.39 112.81a31.84 31.84 0 0 0 36 0c78.59-53.35 112.62-89.93 131.39-112.81c40-48.74 59.15-98.8 58.61-153C463.37 114.54 413.54 64 352.92 64zM256 416V207.58c0-19.63 5.23-38.76 14.21-56.22a1.19 1.19 0 0 1 .08-.16a123 123 0 0 1 21.77-28.51C310.19 105 330.66 96 352.92 96c43.15 0 78.62 36.32 79.07 81C433 281.61 343.63 356.51 256 416z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9z = [_hoisted_2$b5];
    vue.defineComponent({
      name: 'HeartHalf',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$b5, _hoisted_3$9z);
      }
    });

    const _hoisted_1$b4 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$b4 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M352.92 64c-48.09 0-80 29.54-96.92 51c-16.88-21.49-48.83-51-96.92-51C98.46 64 48.63 114.54 48 176.65c-.54 54.21 18.63 104.27 58.61 153c18.77 22.88 52.8 59.46 131.39 112.81a31.84 31.84 0 0 0 36 0c78.59-53.35 112.62-89.93 131.39-112.81c40-48.74 59.15-98.8 58.61-153C463.37 114.54 413.54 64 352.92 64zM256 416V207.58c0-19.63 5.23-38.76 14.21-56.22a1.19 1.19 0 0 1 .08-.16a123 123 0 0 1 21.77-28.51C310.19 105 330.66 96 352.92 96c43.15 0 78.62 36.32 79.07 81C433 281.61 343.63 356.51 256 416z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9y = [_hoisted_2$b4];
    vue.defineComponent({
      name: 'HeartHalfOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$b4, _hoisted_3$9y);
      }
    });

    const _hoisted_1$b3 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$b3 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M352.92 64c-48.11 0-80.1 28-96.92 48.21C239.18 92 207.19 64 159.08 64C98.46 64 48.63 114.54 48 176.65c-.56 55.68 19.71 107 62 157c40.12 47.46 94.25 79.75 137 108.32l9 6l9-6c42.78-28.57 96.91-60.86 137-108.32c42.25-50 62.52-101.35 62-157C463.37 114.54 413.54 64 352.92 64zm24.67 249c-31.78 37.6-74.68 65.75-112.52 90.59l-9.07 6V162.23l24.59-29.54C294.53 116 318.38 96 352.92 96c43.15 0 78.62 36.32 79.07 81a178.63 178.63 0 0 1-12.69 68.59c-9.03 22.84-22.67 44.91-41.71 67.41z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9x = [_hoisted_2$b3];
    vue.defineComponent({
      name: 'HeartHalfSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$b3, _hoisted_3$9x);
      }
    });

    const _hoisted_1$b2 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$b2 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M352.92 80C288 80 256 144 256 144s-32-64-96.92-64c-52.76 0-94.54 44.14-95.08 96.81c-1.1 109.33 86.73 187.08 183 252.42a16 16 0 0 0 18 0c96.26-65.34 184.09-143.09 183-252.42c-.54-52.67-42.32-96.81-95.08-96.81z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9w = [_hoisted_2$b2];
    vue.defineComponent({
      name: 'HeartOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$b2, _hoisted_3$9w);
      }
    });

    const _hoisted_1$b1 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$b1 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 448l-9-6c-42.78-28.57-96.91-60.86-137-108.32c-42.25-50-62.52-101.35-62-157C48.63 114.54 98.46 64 159.08 64c48.11 0 80.1 28 96.92 48.21C272.82 92 304.81 64 352.92 64c60.62 0 110.45 50.54 111.08 112.65c.56 55.68-19.71 107-62 157c-40.09 47.49-94.22 79.78-137 108.35z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9v = [_hoisted_2$b1];
    vue.defineComponent({
      name: 'HeartSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$b1, _hoisted_3$9v);
      }
    });

    const _hoisted_1$b0 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$b0 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M160 164s1.44-33 33.54-59.46C212.6 88.83 235.49 84.28 256 84c18.73-.23 35.47 2.94 45.48 7.82C318.59 100.2 352 120.6 352 164c0 45.67-29.18 66.37-62.35 89.18S248 298.36 248 324',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '40'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9u = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '248',
      cy: '399.99',
      r: '32',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5J = [_hoisted_2$b0, _hoisted_3$9u];
    vue.defineComponent({
      name: 'Help',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$b0, _hoisted_4$5J);
      }
    });

    const _hoisted_1$a$ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$a$ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M414.39 97.61A224 224 0 1 0 97.61 414.39A224 224 0 1 0 414.39 97.61zM192.13 260.18a64 64 0 1 1 59.69 59.69a64.07 64.07 0 0 1-59.69-59.69zm240-66.64l-96.37 5.84a4.06 4.06 0 0 1-3.44-1.59a96 96 0 0 0-18.07-18.07a4.06 4.06 0 0 1-1.59-3.44l5.84-96.37a4 4 0 0 1 5.42-3.51A193 193 0 0 1 435.6 188.12a4 4 0 0 1-3.51 5.42zM193.54 79.91l5.84 96.37a4.06 4.06 0 0 1-1.59 3.44a96 96 0 0 0-18.07 18.07a4.06 4.06 0 0 1-3.44 1.59l-96.37-5.84a4 4 0 0 1-3.51-5.42A193 193 0 0 1 188.12 76.4a4 4 0 0 1 5.42 3.51zM79.91 318.46l96.37-5.84a4.06 4.06 0 0 1 3.44 1.59a96 96 0 0 0 18.07 18.07a4.06 4.06 0 0 1 1.59 3.44l-5.84 96.37a4 4 0 0 1-5.42 3.51A193 193 0 0 1 76.4 323.88a4 4 0 0 1 3.51-5.42zm238.55 113.63l-5.84-96.37a4.06 4.06 0 0 1 1.59-3.44a96 96 0 0 0 18.07-18.07a4.06 4.06 0 0 1 3.44-1.59l96.37 5.84a4 4 0 0 1 3.51 5.42A193 193 0 0 1 323.88 435.6a4 4 0 0 1-5.42-3.51z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9t = [_hoisted_2$a$];
    vue.defineComponent({
      name: 'HelpBuoy',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$a$, _hoisted_3$9t);
      }
    });

    const _hoisted_1$a_ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$a_ = /*#__PURE__*/vue.createStaticVNode('<circle cx="256" cy="256" r="208" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><circle cx="256" cy="256" r="80" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M208 54l8 132"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M296 186l8-132"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M208 458l8-132"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M296 326l8 132"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M458 208l-132 8"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M326 296l132 8"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M54 208l132 8"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M186 296l-132 8"></path>', 10);

    const _hoisted_12$4 = [_hoisted_2$a_];
    vue.defineComponent({
      name: 'HelpBuoyOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$a_, _hoisted_12$4);
      }
    });

    const _hoisted_1$aZ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aZ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 32C132.29 32 32 132.29 32 256s100.29 224 224 224s224-100.29 224-224S379.71 32 256 32zm-64 224a64 64 0 1 1 64 64a64 64 0 0 1-64-64zm237.24-62.29L342.91 199a104.86 104.86 0 0 0-29.86-29.86l5.24-86.33a185 185 0 0 1 111 111zm-303.35-67.82a183.44 183.44 0 0 1 67.82-43.13l5.29 86.33A104.86 104.86 0 0 0 169.09 199l-86.33-5.24a183.44 183.44 0 0 1 43.13-67.87zm-43.13 192.4l86.33-5.24A104.86 104.86 0 0 0 199 342.91l-5.24 86.33a185 185 0 0 1-111-110.95zm303.35 67.82a183.44 183.44 0 0 1-67.82 43.13l-5.24-86.33a104.86 104.86 0 0 0 29.86-29.86l86.33 5.24a183.44 183.44 0 0 1-43.13 67.82z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9s = [_hoisted_2$aZ];
    vue.defineComponent({
      name: 'HelpBuoySharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aZ, _hoisted_3$9s);
      }
    });

    const _hoisted_1$aY = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aY = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 64C150 64 64 150 64 256s86 192 192 192s192-86 192-192S362 64 256 64zm-6 304a20 20 0 1 1 20-20a20 20 0 0 1-20 20zm33.44-102C267.23 276.88 265 286.85 265 296a14 14 0 0 1-28 0c0-21.91 10.08-39.33 30.82-53.26C287.1 229.8 298 221.6 298 203.57c0-12.26-7-21.57-21.49-28.46c-3.41-1.62-11-3.2-20.34-3.09c-11.72.15-20.82 2.95-27.83 8.59C215.12 191.25 214 202.83 214 203a14 14 0 1 1-28-1.35c.11-2.43 1.8-24.32 24.77-42.8c11.91-9.58 27.06-14.56 45-14.78c12.7-.15 24.63 2 32.72 5.82C312.7 161.34 326 180.43 326 203.57c0 33.83-22.61 49.02-42.56 62.43z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9r = [_hoisted_2$aY];
    vue.defineComponent({
      name: 'HelpCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aY, _hoisted_3$9r);
      }
    });

    const _hoisted_1$aX = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aX = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 80a176 176 0 1 0 176 176A176 176 0 0 0 256 80z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M200 202.29s.84-17.5 19.57-32.57C230.68 160.77 244 158.18 256 158c10.93-.14 20.69 1.67 26.53 4.45c10 4.76 29.47 16.38 29.47 41.09c0 26-17 37.81-36.37 50.8S251 281.43 251 296',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '28'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5I = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '250',
      cy: '348',
      r: '20',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2F = [_hoisted_2$aX, _hoisted_3$9q, _hoisted_4$5I];
    vue.defineComponent({
      name: 'HelpCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aX, _hoisted_5$2F);
      }
    });

    const _hoisted_1$aW = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aW = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M288.55 150.84c-8.09-3.86-20-6-32.72-5.82c-18 .22-33.13 5.2-45 14.78c-23 18.48-24.55 40.37-24.77 42.8a61.69 61.69 0 0 0-.09 12a3 3 0 0 0 3 2.69h21.23a3 3 0 0 0 3-3A65.7 65.7 0 0 1 214 204c0-.11 1.14-11.7 14.36-22.34c7-5.64 16.11-8.44 27.83-8.59c9.32-.11 16.93 1.47 20.34 3.09C291 183 298 192.31 298 204.57c0 18-10.9 26.23-30.18 39.18C247.08 257.68 237 275.1 237 297v11a3 3 0 0 0 3 3h22a3 3 0 0 0 3-3v-11c0-9.16 2.23-19.13 18.44-30c19.95-13.41 42.56-28.6 42.56-62.43c0-23.14-13.3-42.23-37.45-53.73z',
      fill: 'none'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9p = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 64C150 64 64 150 64 256s86 192 192 192s192-86 192-192S362 64 256 64zm10.44 302h-30.21a2.57 2.57 0 0 1-2.56-2.57v-30.2a2.57 2.57 0 0 1 2.56-2.57h30.21a2.57 2.57 0 0 1 2.56 2.57v30.2a2.57 2.57 0 0 1-2.56 2.57zm17-99C267.23 277.88 265 287.85 265 297v11a3 3 0 0 1-3 3h-22a3 3 0 0 1-3-3v-11c0-21.91 10.08-39.33 30.82-53.26C287.1 230.8 298 222.6 298 204.57c0-12.26-7-21.57-21.49-28.46c-3.41-1.62-11-3.2-20.34-3.09c-11.72.15-20.82 2.95-27.83 8.59C215.12 192.25 214 203.84 214 204a65.7 65.7 0 0 0-.84 10.28a3 3 0 0 1-3 3h-21.25a3 3 0 0 1-3-2.69a61.69 61.69 0 0 1 .09-12c.22-2.43 1.8-24.32 24.77-42.8c11.91-9.58 27.06-14.56 45-14.78c12.7-.15 24.63 2 32.72 5.82c24.21 11.51 37.51 30.6 37.51 53.74c0 33.83-22.61 49.02-42.56 62.43z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5H = [_hoisted_2$aW, _hoisted_3$9p];
    vue.defineComponent({
      name: 'HelpCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aW, _hoisted_4$5H);
      }
    });

    const _hoisted_1$aV = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aV = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M160 164s1.44-33 33.54-59.46C212.6 88.83 235.49 84.28 256 84c18.73-.23 35.47 2.94 45.48 7.82C318.59 100.2 352 120.6 352 164c0 45.67-29.18 66.37-62.35 89.18S248 298.36 248 324',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '40'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9o = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '248',
      cy: '399.99',
      r: '32',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5G = [_hoisted_2$aV, _hoisted_3$9o];
    vue.defineComponent({
      name: 'HelpOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aV, _hoisted_4$5G);
      }
    });

    const _hoisted_1$aU = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aU = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M160 164c0-10 1.44-33 33.54-59.46C212.6 88.83 235.49 84.28 256 84c18.73-.23 35.47 2.94 45.48 7.82C318.59 100.2 352 120.6 352 164c0 45.67-29.18 66.37-62.35 89.18S248 290.36 248 316',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '40'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9n = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '220',
      y: '368',
      width: '56',
      height: '56',
      rx: '3.5',
      ry: '3.5',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5F = [_hoisted_2$aU, _hoisted_3$9n];
    vue.defineComponent({
      name: 'HelpSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aU, _hoisted_4$5F);
      }
    });

    const _hoisted_1$aT = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aT = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M261.56 101.28a8 8 0 0 0-11.06 0L66.4 277.15a8 8 0 0 0-2.47 5.79L63.9 448a32 32 0 0 0 32 32H192a16 16 0 0 0 16-16V328a8 8 0 0 1 8-8h80a8 8 0 0 1 8 8v136a16 16 0 0 0 16 16h96.06a32 32 0 0 0 32-32V282.94a8 8 0 0 0-2.47-5.79z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9m = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M490.91 244.15l-74.8-71.56V64a16 16 0 0 0-16-16h-48a16 16 0 0 0-16 16v32l-57.92-55.38C272.77 35.14 264.71 32 256 32c-8.68 0-16.72 3.14-22.14 8.63l-212.7 203.5c-6.22 6-7 15.87-1.34 22.37A16 16 0 0 0 43 267.56L250.5 69.28a8 8 0 0 1 11.06 0l207.52 198.28a16 16 0 0 0 22.59-.44c6.14-6.36 5.63-16.86-.76-22.97z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5E = [_hoisted_2$aT, _hoisted_3$9m];
    vue.defineComponent({
      name: 'Home',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aT, _hoisted_4$5E);
      }
    });

    const _hoisted_1$aS = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aS = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M80 212v236a16 16 0 0 0 16 16h96V328a24 24 0 0 1 24-24h80a24 24 0 0 1 24 24v136h96a16 16 0 0 0 16-16V212',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9l = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 256L266.89 52c-5-5.28-16.69-5.34-21.78 0L32 256',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5D = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M400 179V64h-48v69'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2E = [_hoisted_2$aS, _hoisted_3$9l, _hoisted_4$5D];
    vue.defineComponent({
      name: 'HomeOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aS, _hoisted_5$2E);
      }
    });

    const _hoisted_1$aR = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aR = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 174.74V48h-80v58.45L256 32L0 272h64v208h144V320h96v160h144V272h64l-96-97.26z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9k = [_hoisted_2$aR];
    vue.defineComponent({
      name: 'HomeSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aR, _hoisted_3$9k);
      }
    });

    const _hoisted_1$aQ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aQ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M415.7 427.13c-8.74-76.89-43.83-108.76-69.46-132C328.52 279 320 270.61 320 256c0-14.41 8.49-22.64 26.16-38.44c25.93-23.17 61.44-54.91 69.56-132.84a47 47 0 0 0-12-36.26A50.3 50.3 0 0 0 366.39 32H145.61a50.34 50.34 0 0 0-37.39 16.46a47.05 47.05 0 0 0-11.94 36.26c8.09 77.68 43.47 109.19 69.3 132.19C183.42 232.8 192 241.09 192 256c0 15.1-8.6 23.56-26.5 39.75c-25.5 23.1-60.5 54.73-69.2 131.38a46.59 46.59 0 0 0 11.7 36.2A50.44 50.44 0 0 0 145.61 480h220.78A50.44 50.44 0 0 0 404 463.33a46.59 46.59 0 0 0 11.7-36.2zM343.3 432H169.13c-15.6 0-20-18-9.06-29.16C186.55 376 240 356.78 240 326V224c0-19.85-38-35-61.51-67.2c-3.88-5.31-3.49-12.8 6.37-12.8h142.73c8.41 0 10.22 7.43 6.4 12.75C310.82 189 272 204.05 272 224v102c0 30.53 55.71 47 80.4 76.87c9.95 12.04 6.47 29.13-9.1 29.13z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9j = [_hoisted_2$aQ];
    vue.defineComponent({
      name: 'Hourglass',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aQ, _hoisted_3$9j);
      }
    });

    const _hoisted_1$aP = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aP = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M145.61 464h220.78c19.8 0 35.55-16.29 33.42-35.06C386.06 308 304 310 304 256s83.11-51 95.8-172.94c2-18.78-13.61-35.06-33.41-35.06H145.61c-19.8 0-35.37 16.28-33.41 35.06C124.89 205 208 201 208 256s-82.06 52-95.8 172.94c-2.14 18.77 13.61 35.06 33.41 35.06z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9i = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M343.3 432H169.13c-15.6 0-20-18-9.06-29.16C186.55 376 240 356.78 240 326V224c0-19.85-38-35-61.51-67.2c-3.88-5.31-3.49-12.8 6.37-12.8h142.73c8.41 0 10.23 7.43 6.4 12.75C310.82 189 272 204.05 272 224v102c0 30.53 55.71 47 80.4 76.87c9.95 12.04 6.47 29.13-9.1 29.13z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5C = [_hoisted_2$aP, _hoisted_3$9i];
    vue.defineComponent({
      name: 'HourglassOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aP, _hoisted_4$5C);
      }
    });

    const _hoisted_1$aO = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aO = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 32H96v112l108 112L96 368v112h320V368L308 256l108-112zM272 224v112l91 96H148l92-96V224l-80-80h192z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9h = [_hoisted_2$aO];
    vue.defineComponent({
      name: 'HourglassSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aO, _hoisted_3$9h);
      }
    });

    const _hoisted_1$aN = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aN = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M183 352c-21.84-.52-39-18.9-39-40.74v-34.07a8 8 0 0 0-6-7.74c-33.75-8.85-58-39.71-58-77.45a80.14 80.14 0 0 1 66.27-78.82a8 8 0 0 0 6.62-6.83a104 104 0 0 1 206.22 0a8 8 0 0 0 6.62 6.83A80 80 0 0 1 352 272a74.33 74.33 0 0 1-47.45-17.41a7.93 7.93 0 0 0-9.92-.14A62.89 62.89 0 0 1 256 268a80.47 80.47 0 0 1-21.8-3.18a8 8 0 0 0-10.2 7.69V312a40 40 0 0 1-41 40z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9g = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M263.39 299.7a8 8 0 0 0-7.39 7.91V312a72.11 72.11 0 0 1-50.69 68.76a8 8 0 0 0-4.91 10.78l40.91 94.8A16 16 0 0 0 256 496a16 16 0 0 0 14.69-9.7l73.78-172.15a8 8 0 0 0-6.2-11.07a106.31 106.31 0 0 1-35.9-11.59a8 8 0 0 0-7.13-.2a95 95 0 0 1-31.85 8.41z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5B = [_hoisted_2$aN, _hoisted_3$9g];
    vue.defineComponent({
      name: 'IceCream',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aN, _hoisted_4$5B);
      }
    });

    const _hoisted_1$aM = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aM = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M352 256l-96 224l-62-145'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9f = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M299.42 223.48C291.74 239.75 275.18 252 256 252c-13.1 0-27-5-33.63-9.76C216.27 237.87 208 240 208 250v62a24.07 24.07 0 0 1-24 24h0a24.07 24.07 0 0 1-24-24v-56h-2c-35.35 0-62-28.65-62-64a64 64 0 0 1 64-64h8v-8a88 88 0 0 1 176 0v8h8a64 64 0 0 1 0 128c-21.78 0-42-13-52.59-32.51z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5A = [_hoisted_2$aM, _hoisted_3$9f];
    vue.defineComponent({
      name: 'IceCreamOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aM, _hoisted_4$5A);
      }
    });

    const _hoisted_1$aL = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aL = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M359.72 112.37a104 104 0 0 0-207.44 0A80.12 80.12 0 0 0 80 192c0 39.36 26.37 71.23 62.38 78.46a2 2 0 0 1 1.62 2v38.83c0 21.84 17.2 40.22 39 40.74a40 40 0 0 0 41-40v-47.84a2 2 0 0 1 2.72-1.86A83.47 83.47 0 0 0 256 268a63.18 63.18 0 0 0 42.24-16.59a2 2 0 0 1 2.74 0A74.63 74.63 0 0 0 352 272a80 80 0 0 0 7.72-159.63z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9e = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 300v12a72.1 72.1 0 0 1-58.21 70.64L256 496l92.06-192.08a105.29 105.29 0 0 1-49.18-14.36A93.75 93.75 0 0 1 256 300z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5z = [_hoisted_2$aL, _hoisted_3$9e];
    vue.defineComponent({
      name: 'IceCreamSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aL, _hoisted_4$5z);
      }
    });

    const _hoisted_1$aK = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aK = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M368 16H144a64.07 64.07 0 0 0-64 64v352a64.07 64.07 0 0 0 64 64h224a64.07 64.07 0 0 0 64-64V80a64.07 64.07 0 0 0-64-64zm-34.52 268.51c7.57 8.17 11.27 19.16 10.39 30.94C342.14 338.91 324.25 358 304 358s-38.17-19.09-39.88-42.55c-.86-11.9 2.81-22.91 10.34-31S292.4 272 304 272a39.65 39.65 0 0 1 29.48 12.51zM192 80a16 16 0 0 1 16-16h96a16 16 0 0 1 0 32h-96a16 16 0 0 1-16-16zm189 363.83a12.05 12.05 0 0 1-9.31 4.17H236.31a12.05 12.05 0 0 1-9.31-4.17a13 13 0 0 1-2.76-10.92c3.25-17.56 13.38-32.31 29.3-42.66C267.68 381.06 285.6 376 304 376s36.32 5.06 50.46 14.25c15.92 10.35 26.05 25.1 29.3 42.66a13 13 0 0 1-2.76 10.92z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9d = [_hoisted_2$aK];
    vue.defineComponent({
      name: 'IdCard',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aK, _hoisted_3$9d);
      }
    });

    const _hoisted_1$aJ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aJ = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '96',
      y: '32',
      width: '320',
      height: '448',
      rx: '48',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9c = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M208 80h96'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M333.48 284.51A39.65 39.65 0 0 0 304 272c-11.6 0-22.09 4.41-29.54 12.43s-11.2 19.12-10.34 31C265.83 338.91 283.72 358 304 358s38.14-19.09 39.87-42.55c.88-11.78-2.82-22.77-10.39-30.94z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2D = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M371.69 448H236.31a12.05 12.05 0 0 1-9.31-4.17a13 13 0 0 1-2.76-10.92c3.25-17.56 13.38-32.31 29.3-42.66C267.68 381.06 285.6 376 304 376s36.32 5.06 50.46 14.25c15.92 10.35 26.05 25.1 29.3 42.66a13 13 0 0 1-2.76 10.92a12.05 12.05 0 0 1-9.31 4.17z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1a = [_hoisted_2$aJ, _hoisted_3$9c, _hoisted_4$5y, _hoisted_5$2D];
    vue.defineComponent({
      name: 'IdCardOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aJ, _hoisted_6$1a);
      }
    });

    const _hoisted_1$aI = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aI = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M408 16H104a24 24 0 0 0-24 24v432a24 24 0 0 0 24 24h304a24 24 0 0 0 24-24V40a24 24 0 0 0-24-24zm-61.1 296.77a43 43 0 1 1-40.71-40.71a43 43 0 0 1 40.71 40.71zM192 64h128v32H192zm192 384H224v-24.6c0-32.72 53.27-49.21 80-49.21s80 16.49 80 49.21z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9b = [_hoisted_2$aI];
    vue.defineComponent({
      name: 'IdCardSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aI, _hoisted_3$9b);
      }
    });

    const _hoisted_1$aH = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aH = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 64H96a64.07 64.07 0 0 0-64 64v256a64.07 64.07 0 0 0 64 64h320a64.07 64.07 0 0 0 64-64V128a64.07 64.07 0 0 0-64-64zm-80 64a48 48 0 1 1-48 48a48.05 48.05 0 0 1 48-48zM96 416a32 32 0 0 1-32-32v-67.63l94.84-84.3a48.06 48.06 0 0 1 65.8 1.9l64.95 64.81L172.37 416zm352-32a32 32 0 0 1-32 32H217.63l121.42-121.42a47.72 47.72 0 0 1 61.64-.16L448 333.84z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9a = [_hoisted_2$aH];
    vue.defineComponent({
      name: 'Image',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aH, _hoisted_3$9a);
      }
    });

    const _hoisted_1$aG = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aG = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '48',
      y: '80',
      width: '416',
      height: '352',
      rx: '48',
      ry: '48',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$99 = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '336',
      cy: '176',
      r: '32',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5x = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M304 335.79l-90.66-90.49a32 32 0 0 0-43.87-1.3L48 352',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2C = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M224 432l123.34-123.34a32 32 0 0 1 43.11-2L464 368',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$19 = [_hoisted_2$aG, _hoisted_3$99, _hoisted_4$5x, _hoisted_5$2C];
    vue.defineComponent({
      name: 'ImageOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aG, _hoisted_6$19);
      }
    });

    const _hoisted_1$aF = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aF = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M456 64H56a24 24 0 0 0-24 24v336a24 24 0 0 0 24 24h400a24 24 0 0 0 24-24V88a24 24 0 0 0-24-24zm-124.38 64.2a48 48 0 1 1-43.42 43.42a48 48 0 0 1 43.42-43.42zM76 416a12 12 0 0 1-12-12v-87.63L192.64 202l96.95 96.75L172.37 416zm372-12a12 12 0 0 1-12 12H217.63l149.53-149.53L448 333.84z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$98 = [_hoisted_2$aF];
    vue.defineComponent({
      name: 'ImageSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aF, _hoisted_3$98);
      }
    });

    const _hoisted_1$aE = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aE = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M450.29 112H142c-34 0-62 27.51-62 61.33v245.34c0 33.82 28 61.33 62 61.33h308c34 0 62-26.18 62-60V173.33c0-33.82-27.68-61.33-61.71-61.33zm-77.15 61.34a46 46 0 1 1-46.28 46a46.19 46.19 0 0 1 46.28-46.01zm-231.55 276c-17 0-29.86-13.75-29.86-30.66v-64.83l90.46-80.79a46.54 46.54 0 0 1 63.44 1.83L328.27 337l-113 112.33zM480 418.67a30.67 30.67 0 0 1-30.71 30.66H259L376.08 333a46.24 46.24 0 0 1 59.44-.16L480 370.59z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$97 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 32H64A64 64 0 0 0 0 96v256a64.11 64.11 0 0 0 48 62V152a72 72 0 0 1 72-72h326a64.11 64.11 0 0 0-62-48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5w = [_hoisted_2$aE, _hoisted_3$97];
    vue.defineComponent({
      name: 'Images',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aE, _hoisted_4$5w);
      }
    });

    const _hoisted_1$aD = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aD = /*#__PURE__*/vue.createStaticVNode('<path d="M432 112V96a48.14 48.14 0 0 0-48-48H64a48.14 48.14 0 0 0-48 48v256a48.14 48.14 0 0 0 48 48h16" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></path><rect x="96" y="128" width="400" height="336" rx="45.99" ry="45.99" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></rect><ellipse cx="372.92" cy="219.64" rx="30.77" ry="30.55" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></ellipse><path d="M342.15 372.17L255 285.78a30.93 30.93 0 0 0-42.18-1.21L96 387.64" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M265.23 464l118.59-117.73a31 31 0 0 1 41.46-1.87L496 402.91" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 5);

    const _hoisted_7$F = [_hoisted_2$aD];
    vue.defineComponent({
      name: 'ImagesOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aD, _hoisted_7$F);
      }
    });

    const _hoisted_1$aC = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aC = /*#__PURE__*/vue.createElementVNode('ellipse', {
      cx: '373.14',
      cy: '219.33',
      rx: '46.29',
      ry: '46',
      fill: 'none'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$96 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M80 132v328a20 20 0 0 0 20 20h392a20 20 0 0 0 20-20V132a20 20 0 0 0-20-20H100a20 20 0 0 0-20 20zm293.14 41.33a46 46 0 1 1-46.28 46a46.19 46.19 0 0 1 46.28-46zm-261.41 276v-95.48l122.76-110.2L328.27 337l-113 112.33zm368.27 0H259l144.58-144L480 370.59z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5v = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M20 32A20 20 0 0 0 0 52v344a20 20 0 0 0 20 20h28V100a20 20 0 0 1 20-20h380V52a20 20 0 0 0-20-20z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2B = [_hoisted_2$aC, _hoisted_3$96, _hoisted_4$5v];
    vue.defineComponent({
      name: 'ImagesSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aC, _hoisted_5$2B);
      }
    });

    const _hoisted_1$aB = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aB = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 256s-48-96-126-96c-54.12 0-98 43-98 96s43.88 96 98 96c30 0 56.45-13.18 78-32',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$95 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 256s48 96 126 96c54.12 0 98-43 98-96s-43.88-96-98-96c-29.37 0-56.66 13.75-78 32',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5u = [_hoisted_2$aB, _hoisted_3$95];
    vue.defineComponent({
      name: 'Infinite',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aB, _hoisted_4$5u);
      }
    });

    const _hoisted_1$aA = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aA = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 256s-48-96-126-96c-54.12 0-98 43-98 96s43.88 96 98 96c37.51 0 71-22.41 94-48',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$94 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 256s48 96 126 96c54.12 0 98-43 98-96s-43.88-96-98-96c-37.51 0-71 22.41-94 48',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5t = [_hoisted_2$aA, _hoisted_3$94];
    vue.defineComponent({
      name: 'InfiniteOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aA, _hoisted_4$5t);
      }
    });

    const _hoisted_1$az = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$az = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M382 136c-40.87 0-73.46 20.53-93.6 37.76l-.71.61l-11.47 12.47l25.32 41.61l18.74-18.79C339.89 193.1 361.78 184 382 184c40.8 0 74 32.3 74 72s-33.2 72-74 72c-62 0-104.14-81.95-104.56-82.78C275 240.29 221.56 136 130 136C62.73 136 8 189.83 8 256s54.73 120 122 120c32.95 0 65.38-13.11 93.79-37.92l.61-.54l11.38-12.38l-25.33-41.61l-18.83 18.88C172 319.4 151.26 328 130 328c-40.8 0-74-32.3-74-72s33.2-72 74-72c62 0 104.14 81.95 104.56 82.78C237 271.71 290.44 376 382 376c67.27 0 122-53.83 122-120s-54.73-120-122-120z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$93 = [_hoisted_2$az];
    vue.defineComponent({
      name: 'InfiniteSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$az, _hoisted_3$93);
      }
    });

    const _hoisted_1$ay = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ay = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '40',
      d: 'M196 220h64v172'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$92 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '40',
      d: 'M187 396h138'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5s = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 160a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2A = [_hoisted_2$ay, _hoisted_3$92, _hoisted_4$5s];
    vue.defineComponent({
      name: 'Information',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ay, _hoisted_5$2A);
      }
    });

    const _hoisted_1$ax = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ax = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 56C145.72 56 56 145.72 56 256s89.72 200 200 200s200-89.72 200-200S366.28 56 256 56zm0 82a26 26 0 1 1-26 26a26 26 0 0 1 26-26zm48 226h-88a16 16 0 0 1 0-32h28v-88h-16a16 16 0 0 1 0-32h32a16 16 0 0 1 16 16v104h28a16 16 0 0 1 0 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$91 = [_hoisted_2$ax];
    vue.defineComponent({
      name: 'InformationCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ax, _hoisted_3$91);
      }
    });

    const _hoisted_1$aw = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aw = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M248 64C146.39 64 64 146.39 64 248s82.39 184 184 184s184-82.39 184-184S349.61 64 248 64z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$90 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M220 220h32v116'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5r = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M208 340h88'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M248 130a26 26 0 1 0 26 26a26 26 0 0 0-26-26z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$18 = [_hoisted_2$aw, _hoisted_3$90, _hoisted_4$5r, _hoisted_5$2z];
    vue.defineComponent({
      name: 'InformationCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aw, _hoisted_6$18);
      }
    });

    const _hoisted_1$av = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$av = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 56C145.72 56 56 145.72 56 256s89.72 200 200 200s200-89.72 200-200S366.28 56 256 56zm0 82a26 26 0 1 1-26 26a26 26 0 0 1 26-26zm64 226H200v-32h44v-88h-32v-32h64v120h44z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8$ = [_hoisted_2$av];
    vue.defineComponent({
      name: 'InformationCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$av, _hoisted_3$8$);
      }
    });

    const _hoisted_1$au = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$au = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '40',
      d: 'M196 220h64v172'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8_ = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '40',
      d: 'M187 396h138'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 160a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2y = [_hoisted_2$au, _hoisted_3$8_, _hoisted_4$5q];
    vue.defineComponent({
      name: 'InformationOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$au, _hoisted_5$2y);
      }
    });

    const _hoisted_1$at = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$at = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '40',
      d: 'M196 220h64v172'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8Z = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '40',
      d: 'M187 396h138'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5p = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 160a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2x = [_hoisted_2$at, _hoisted_3$8Z, _hoisted_4$5p];
    vue.defineComponent({
      name: 'InformationSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$at, _hoisted_5$2x);
      }
    });

    const _hoisted_1$as = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$as = /*#__PURE__*/vue.createElementVNode('circle', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      cx: '256',
      cy: '256',
      r: '208'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8Y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 176v160a80 80 0 0 0 0-160z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5o = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48v128a80 80 0 0 0 0 160v128c-114.88 0-208-93.12-208-208S141.12 48 256 48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2w = [_hoisted_2$as, _hoisted_3$8Y, _hoisted_4$5o];
    vue.defineComponent({
      name: 'InvertMode',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$as, _hoisted_5$2w);
      }
    });

    const _hoisted_1$ar = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ar = /*#__PURE__*/vue.createElementVNode('circle', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      cx: '256',
      cy: '256',
      r: '208'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8X = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 176v160a80 80 0 0 1 0-160z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5n = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48v128a80 80 0 0 1 0 160v128c114.88 0 208-93.12 208-208S370.88 48 256 48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2v = [_hoisted_2$ar, _hoisted_3$8X, _hoisted_4$5n];
    vue.defineComponent({
      name: 'InvertModeOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ar, _hoisted_5$2v);
      }
    });

    const _hoisted_1$aq = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aq = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M414.39 97.61A224 224 0 1 0 97.61 414.39A224 224 0 1 0 414.39 97.61zM256 432v-96a80 80 0 0 1 0-160V80c97.05 0 176 79 176 176s-78.95 176-176 176z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8W = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 256a80 80 0 0 0-80-80v160a80 80 0 0 0 80-80z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5m = [_hoisted_2$aq, _hoisted_3$8W];
    vue.defineComponent({
      name: 'InvertModeSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aq, _hoisted_4$5m);
      }
    });

    const _hoisted_1$ap = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ap = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M290 32H144a64.07 64.07 0 0 0-64 64v320a64.07 64.07 0 0 0 64 64h146z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8V = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M368 32h-18v448h18a64.07 64.07 0 0 0 64-64V96a64.07 64.07 0 0 0-64-64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5l = [_hoisted_2$ap, _hoisted_3$8V];
    vue.defineComponent({
      name: 'Journal',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ap, _hoisted_4$5l);
      }
    });

    const _hoisted_1$ao = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ao = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '96',
      y: '48',
      width: '320',
      height: '416',
      rx: '48',
      ry: '48',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8U = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '60',
      d: 'M320 48v416'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5k = [_hoisted_2$ao, _hoisted_3$8U];
    vue.defineComponent({
      name: 'JournalOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ao, _hoisted_4$5k);
      }
    });

    const _hoisted_1$an = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$an = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M290 32H104a24 24 0 0 0-24 24v400a24 24 0 0 0 24 24h186z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8T = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M408 32h-58v448h58a24 24 0 0 0 24-24V56a24 24 0 0 0-24-24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5j = [_hoisted_2$an, _hoisted_3$8T];
    vue.defineComponent({
      name: 'JournalSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$an, _hoisted_4$5j);
      }
    });

    const _hoisted_1$am = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$am = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M218.1 167.17c0 13 0 25.6 4.1 37.4c-43.1 50.6-156.9 184.3-167.5 194.5a20.17 20.17 0 0 0-6.7 15c0 8.5 5.2 16.7 9.6 21.3c6.6 6.9 34.8 33 40 28c15.4-15 18.5-19 24.8-25.2c9.5-9.3-1-28.3 2.3-36s6.8-9.2 12.5-10.4s15.8 2.9 23.7 3c8.3.1 12.8-3.4 19-9.2c5-4.6 8.6-8.9 8.7-15.6c.2-9-12.8-20.9-3.1-30.4s23.7 6.2 34 5s22.8-15.5 24.1-21.6s-11.7-21.8-9.7-30.7c.7-3 6.8-10 11.4-11s25 6.9 29.6 5.9c5.6-1.2 12.1-7.1 17.4-10.4c15.5 6.7 29.6 9.4 47.7 9.4c68.5 0 124-53.4 124-119.2S408.5 48 340 48s-121.9 53.37-121.9 119.17zM400 144a32 32 0 1 1-32-32a32 32 0 0 1 32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8S = [_hoisted_2$am];
    vue.defineComponent({
      name: 'Key',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$am, _hoisted_3$8S);
      }
    });

    const _hoisted_1$al = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$al = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M218.1 167.17c0 13 0 25.6 4.1 37.4c-43.1 50.6-156.9 184.3-167.5 194.5a20.17 20.17 0 0 0-6.7 15c0 8.5 5.2 16.7 9.6 21.3c6.6 6.9 34.8 33 40 28c15.4-15 18.5-19 24.8-25.2c9.5-9.3-1-28.3 2.3-36s6.8-9.2 12.5-10.4s15.8 2.9 23.7 3c8.3.1 12.8-3.4 19-9.2c5-4.6 8.6-8.9 8.7-15.6c.2-9-12.8-20.9-3.1-30.4s23.7 6.2 34 5s22.8-15.5 24.1-21.6s-11.7-21.8-9.7-30.7c.7-3 6.8-10 11.4-11s25 6.9 29.6 5.9c5.6-1.2 12.1-7.1 17.4-10.4c15.5 6.7 29.6 9.4 47.7 9.4c68.5 0 124-53.4 124-119.2S408.5 48 340 48s-121.9 53.37-121.9 119.17zM400 144a32 32 0 1 1-32-32a32 32 0 0 1 32 32z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8R = [_hoisted_2$al];
    vue.defineComponent({
      name: 'KeyOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$al, _hoisted_3$8R);
      }
    });

    const _hoisted_1$ak = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ak = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M218.1 167.2c0 13 0 25.6 4.1 37.4c-43.1 50.6-167.5 194.5-167.5 194.5l2.9 36.3s34.8 33 40 28c15.4-15 24.8-25.2 24.8-25.2l7.24-43.35l47.11-3.47l3.78-46.8l49.63-.95l.49-50.09l52.69 2.1l9-18.84c15.5 6.7 29.6 9.4 47.7 9.4c68.5 0 124-53.4 124-119.2S408.5 48 340 48s-121.9 53.4-121.9 119.2zM406.85 144A38.85 38.85 0 1 1 368 105.15A38.81 38.81 0 0 1 406.85 144z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8Q = [_hoisted_2$ak];
    vue.defineComponent({
      name: 'KeySharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ak, _hoisted_3$8Q);
      }
    });

    const _hoisted_1$aj = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aj = /*#__PURE__*/vue.createStaticVNode('<path d="M256 400a48 48 0 1 0 48 48a48 48 0 0 0-48-48z" fill="currentColor"></path><path d="M256 272a48 48 0 1 0 48 48a48 48 0 0 0-48-48z" fill="currentColor"></path><path d="M256 144a48 48 0 1 0 48 48a48 48 0 0 0-48-48z" fill="currentColor"></path><path d="M256 16a48 48 0 1 0 48 48a48 48 0 0 0-48-48z" fill="currentColor"></path><path d="M384 272a48 48 0 1 0 48 48a48 48 0 0 0-48-48z" fill="currentColor"></path><path d="M384 144a48 48 0 1 0 48 48a48 48 0 0 0-48-48z" fill="currentColor"></path><path d="M384 16a48 48 0 1 0 48 48a48 48 0 0 0-48-48z" fill="currentColor"></path><path d="M128 272a48 48 0 1 0 48 48a48 48 0 0 0-48-48z" fill="currentColor"></path><path d="M128 144a48 48 0 1 0 48 48a48 48 0 0 0-48-48z" fill="currentColor"></path><path d="M128 16a48 48 0 1 0 48 48a48 48 0 0 0-48-48z" fill="currentColor"></path>', 10);

    const _hoisted_12$3 = [_hoisted_2$aj];
    vue.defineComponent({
      name: 'Keypad',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aj, _hoisted_12$3);
      }
    });

    const _hoisted_1$ai = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ai = /*#__PURE__*/vue.createStaticVNode('<circle cx="256" cy="448" r="32" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></circle><circle cx="256" cy="320" r="32" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></circle><path d="M288 192a32 32 0 1 1-32-32a32 32 0 0 1 32 32z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><circle cx="256" cy="64" r="32" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></circle><circle cx="384" cy="320" r="32" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></circle><circle cx="384" cy="192" r="32" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></circle><circle cx="384" cy="64" r="32" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></circle><circle cx="128" cy="320" r="32" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></circle><circle cx="128" cy="192" r="32" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></circle><circle cx="128" cy="64" r="32" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></circle>', 10);

    const _hoisted_12$2 = [_hoisted_2$ai];
    vue.defineComponent({
      name: 'KeypadOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ai, _hoisted_12$2);
      }
    });

    const _hoisted_1$ah = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ah = /*#__PURE__*/vue.createStaticVNode('<rect x="80" y="16" width="96" height="96" rx="8" ry="8" fill="currentColor"></rect><rect x="208" y="16" width="96" height="96" rx="8" ry="8" fill="currentColor"></rect><rect x="336" y="16" width="96" height="96" rx="8" ry="8" fill="currentColor"></rect><rect x="80" y="144" width="96" height="96" rx="8" ry="8" fill="currentColor"></rect><rect x="208" y="144" width="96" height="96" rx="8" ry="8" fill="currentColor"></rect><rect x="336" y="144" width="96" height="96" rx="8" ry="8" fill="currentColor"></rect><rect x="80" y="272" width="96" height="96" rx="8" ry="8" fill="currentColor"></rect><rect x="208" y="272" width="96" height="96" rx="8" ry="8" fill="currentColor"></rect><rect x="208" y="400" width="96" height="96" rx="8" ry="8" fill="currentColor"></rect><rect x="336" y="272" width="96" height="96" rx="8" ry="8" fill="currentColor"></rect>', 10);

    const _hoisted_12$1 = [_hoisted_2$ah];
    vue.defineComponent({
      name: 'KeypadSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ah, _hoisted_12$1);
      }
    });

    const _hoisted_1$ag = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ag = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M478.33 433.6l-90-218a22 22 0 0 0-40.67 0l-90 218a22 22 0 1 0 40.67 16.79L316.66 406h102.67l18.33 44.39A22 22 0 0 0 458 464a22 22 0 0 0 20.32-30.4zM334.83 362L368 281.65L401.17 362z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8P = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M267.84 342.92a22 22 0 0 0-4.89-30.7c-.2-.15-15-11.13-36.49-34.73c39.65-53.68 62.11-114.75 71.27-143.49H330a22 22 0 0 0 0-44H214V70a22 22 0 0 0-44 0v20H54a22 22 0 0 0 0 44h197.25c-9.52 26.95-27.05 69.5-53.79 108.36c-31.41-41.68-43.08-68.65-43.17-68.87a22 22 0 0 0-40.58 17c.58 1.38 14.55 34.23 52.86 83.93c.92 1.19 1.83 2.35 2.74 3.51c-39.24 44.35-77.74 71.86-93.85 80.74a22 22 0 1 0 21.07 38.63c2.16-1.18 48.6-26.89 101.63-85.59c22.52 24.08 38 35.44 38.93 36.1a22 22 0 0 0 30.75-4.9z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5i = [_hoisted_2$ag, _hoisted_3$8P];
    vue.defineComponent({
      name: 'Language',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ag, _hoisted_4$5i);
      }
    });

    const _hoisted_1$af = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$af = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M48 112h288"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M192 64v48"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M272 448l96-224l96 224"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M301.5 384h133"></path><path d="M281.3 112S257 206 199 277S80 384 80 384" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M256 336s-35-27-72-75s-56-85-56-85" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 6);

    const _hoisted_8$n = [_hoisted_2$af];
    vue.defineComponent({
      name: 'LanguageOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$af, _hoisted_8$n);
      }
    });

    const _hoisted_1$ae = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ae = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M363 176L246 464h47.24l24.49-58h90.54l24.49 58H480zm-26.69 186L363 279.85L389.69 362z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8O = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M272 320c-.25-.19-20.59-15.77-45.42-42.67c39.58-53.64 62-114.61 71.15-143.33H352V90H214V48h-44v42H32v44h219.25c-9.52 26.95-27.05 69.5-53.79 108.36c-32.68-43.44-47.14-75.88-47.33-76.22L143 152l-38 22l6.87 13.86c.89 1.56 17.19 37.9 54.71 86.57c.92 1.21 1.85 2.39 2.78 3.57c-49.72 56.86-89.15 79.09-89.66 79.47L64 368l23 36l19.3-11.47c2.2-1.67 41.33-24 92-80.78c24.52 26.28 43.22 40.83 44.3 41.67L255 362z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5h = [_hoisted_2$ae, _hoisted_3$8O];
    vue.defineComponent({
      name: 'LanguageSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ae, _hoisted_4$5h);
      }
    });

    const _hoisted_1$ad = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ad = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M496 400h-28.34A47.92 47.92 0 0 0 480 367.86V128.14A48.2 48.2 0 0 0 431.86 80H80.14A48.2 48.2 0 0 0 32 128.14v239.72A47.92 47.92 0 0 0 44.34 400H16a16 16 0 0 0 0 32h480a16 16 0 0 0 0-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8N = [_hoisted_2$ad];
    vue.defineComponent({
      name: 'Laptop',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ad, _hoisted_3$8N);
      }
    });

    const _hoisted_1$ac = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ac = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '48',
      y: '96',
      width: '416',
      height: '304',
      rx: '32.14',
      ry: '32.14',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8M = /*#__PURE__*/vue.createElementVNode('path', {
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M16 416h480',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5g = [_hoisted_2$ac, _hoisted_3$8M];
    vue.defineComponent({
      name: 'LaptopOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ac, _hoisted_4$5g);
      }
    });

    const _hoisted_1$ab = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$ab = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M477.29 400a27.75 27.75 0 0 0 2.71-12V108a28 28 0 0 0-28-28H60a28 28 0 0 0-28 28v280a27.75 27.75 0 0 0 2.71 12H0v32h512v-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8L = [_hoisted_2$ab];
    vue.defineComponent({
      name: 'LaptopSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$ab, _hoisted_3$8L);
      }
    });

    const _hoisted_1$aa = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$aa = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 256c-13.47 0-26.94-2.39-37.44-7.17l-148-67.49C63.79 178.26 48 169.25 48 152.24s15.79-26 22.58-29.12l149.28-68.07c20.57-9.4 51.61-9.4 72.19 0l149.37 68.07c6.79 3.09 22.58 12.1 22.58 29.12s-15.79 26-22.58 29.11l-148 67.48C282.94 253.61 269.47 256 256 256zm176.76-100.86z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8K = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M441.36 226.81L426.27 220l-38.77 17.74l-94 43c-10.5 4.8-24 7.19-37.44 7.19s-26.93-2.39-37.42-7.19l-94.07-43L85.79 220l-15.22 6.84C63.79 229.93 48 239 48 256s15.79 26.08 22.56 29.17l148 67.63C229 357.6 242.49 360 256 360s26.94-2.4 37.44-7.19l147.87-67.61c6.81-3.09 22.69-12.11 22.69-29.2s-15.77-26.07-22.64-29.19z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5f = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M441.36 330.8l-15.09-6.8l-38.77 17.73l-94 42.95c-10.5 4.78-24 7.18-37.44 7.18s-26.93-2.39-37.42-7.18l-94.07-43L85.79 324l-15.22 6.84C63.79 333.93 48 343 48 360s15.79 26.07 22.56 29.15l148 67.59C229 461.52 242.54 464 256 464s26.88-2.48 37.38-7.27l147.92-67.57c6.82-3.08 22.7-12.1 22.7-29.16s-15.77-26.07-22.64-29.2z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2u = [_hoisted_2$aa, _hoisted_3$8K, _hoisted_4$5f];
    vue.defineComponent({
      name: 'Layers',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$aa, _hoisted_5$2u);
      }
    });

    const _hoisted_1$a9 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$a9 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M434.8 137.65l-149.36-68.1c-16.19-7.4-42.69-7.4-58.88 0L77.3 137.65c-17.6 8-17.6 21.09 0 29.09l148 67.5c16.89 7.7 44.69 7.7 61.58 0l148-67.5c17.52-8 17.52-21.1-.08-29.09z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8J = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M160 308.52l-82.7 37.11c-17.6 8-17.6 21.1 0 29.1l148 67.5c16.89 7.69 44.69 7.69 61.58 0l148-67.5c17.6-8 17.6-21.1 0-29.1l-79.94-38.47',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5e = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M160 204.48l-82.8 37.16c-17.6 8-17.6 21.1 0 29.1l148 67.49c16.89 7.7 44.69 7.7 61.58 0l148-67.49c17.7-8 17.7-21.1.1-29.1L352 204.48',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2t = [_hoisted_2$a9, _hoisted_3$8J, _hoisted_4$5e];
    vue.defineComponent({
      name: 'LayersOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$a9, _hoisted_5$2t);
      }
    });

    const _hoisted_1$a8 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$a8 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 150L256 48L32 150l224 104l224-104z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8I = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M255.71 392.95l-144.81-66.2L32 362l224 102l224-102l-78.69-35.3l-145.6 66.25z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5d = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 256l-75.53-33.53L256.1 290.6l-148.77-68.17L32 256l224 102l224-102z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2s = [_hoisted_2$a8, _hoisted_3$8I, _hoisted_4$5d];
    vue.defineComponent({
      name: 'LayersSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$a8, _hoisted_5$2s);
      }
    });

    const _hoisted_1$a7 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$a7 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M161.35 242a16 16 0 0 1 22.62-.68c73.63 69.36 147.51 111.56 234.45 133.07c11.73-32 12.77-67.22 2.64-101.58c-13.44-45.59-44.74-85.31-90.49-114.86c-40.84-26.38-81.66-33.25-121.15-39.89c-49.82-8.38-96.88-16.3-141.79-63.85c-5-5.26-11.81-7.37-18.32-5.66c-7.44 2-12.43 7.88-14.82 17.6c-5.6 22.75-2 86.51 13.75 153.82c25.29 108.14 65.65 162.86 95.06 189.73c38 34.69 87.62 53.9 136.93 53.9a186 186 0 0 0 27.77-2.04c41.71-6.32 76.43-27.27 96-57.75c-89.49-23.28-165.94-67.55-242-139.16a16 16 0 0 1-.65-22.65z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8H = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M467.43 384.19c-16.83-2.59-33.13-5.84-49-9.77a157.71 157.71 0 0 1-12.13 25.68c-.73 1.25-1.5 2.49-2.29 3.71a584.21 584.21 0 0 0 58.56 12a16 16 0 1 0 4.87-31.62z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5c = [_hoisted_2$a7, _hoisted_3$8H];
    vue.defineComponent({
      name: 'Leaf',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$a7, _hoisted_4$5c);
      }
    });

    const _hoisted_1$a6 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$a6 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M321.89 171.42C233 114 141 155.22 56 65.22c-19.8-21-8.3 235.5 98.1 332.7c77.79 71 197.9 63.08 238.4-5.92s18.28-163.17-70.61-220.58z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8G = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M173 253c86 81 175 129 292 147',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5b = [_hoisted_2$a6, _hoisted_3$8G];
    vue.defineComponent({
      name: 'LeafOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$a6, _hoisted_4$5b);
      }
    });

    const _hoisted_1$a5 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$a5 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M150.38 253.68l21.94-23.3l11.65 11c73.63 69.36 147.51 111.56 234.45 133.07c11.73-32 12.77-67.22 2.64-101.58c-13.44-45.59-44.74-85.31-90.49-114.86c-40.25-26-76.6-32.09-115.09-38.54c-21.12-3.54-43-7.2-66.85-14.43c-43.78-13.28-89.69-52.74-90.15-53.13L33.4 30.15L32 63.33c-.1 2.56-2.42 63.57 14.22 147.77c17.58 89 50.24 155.85 97.07 198.63c38 34.69 87.62 53.9 136.93 53.9a185.88 185.88 0 0 0 27.78-2.07c41.72-6.32 76.43-27.27 96-57.75c-89.5-23.28-165.95-67.55-242-139.16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8F = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M467.43 384.19c-16.83-2.59-33.13-5.84-49-9.77a158.49 158.49 0 0 1-12.13 25.68c-.74 1.25-1.51 2.49-2.29 3.71a583.43 583.43 0 0 0 58.55 12l15.82 2.44l4.86-31.63z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5a = [_hoisted_2$a5, _hoisted_3$8F];
    vue.defineComponent({
      name: 'LeafSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$a5, _hoisted_4$5a);
      }
    });

    const _hoisted_1$a4 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$a4 = /*#__PURE__*/vue.createStaticVNode('<path d="M64 480H48a32 32 0 0 1-32-32V112a32 32 0 0 1 32-32h16a32 32 0 0 1 32 32v336a32 32 0 0 1-32 32z" fill="currentColor"></path><path d="M240 176a32 32 0 0 0-32-32h-64a32 32 0 0 0-32 32v28a4 4 0 0 0 4 4h120a4 4 0 0 0 4-4z" fill="currentColor"></path><path d="M112 448a32 32 0 0 0 32 32h64a32 32 0 0 0 32-32v-30a2 2 0 0 0-2-2H114a2 2 0 0 0-2 2z" fill="currentColor"></path><rect x="112" y="240" width="128" height="144" rx="2" ry="2" fill="currentColor"></rect><path d="M320 480h-32a32 32 0 0 1-32-32V64a32 32 0 0 1 32-32h32a32 32 0 0 1 32 32v384a32 32 0 0 1-32 32z" fill="currentColor"></path><path d="M495.89 445.45l-32.23-340c-1.48-15.65-16.94-27-34.53-25.31l-31.85 3c-17.59 1.67-30.65 15.71-29.17 31.36l32.23 340c1.48 15.65 16.94 27 34.53 25.31l31.85-3c17.59-1.67 30.65-15.71 29.17-31.36z" fill="currentColor"></path>', 6);

    const _hoisted_8$m = [_hoisted_2$a4];
    vue.defineComponent({
      name: 'Library',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$a4, _hoisted_8$m);
      }
    });

    const _hoisted_1$a3 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$a3 = /*#__PURE__*/vue.createStaticVNode('<rect x="32" y="96" width="64" height="368" rx="16" ry="16" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></rect><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M112 224h128"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M112 400h128"></path><rect x="112" y="160" width="128" height="304" rx="16" ry="16" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></rect><rect x="256" y="48" width="96" height="416" rx="16" ry="16" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></rect><path d="M422.46 96.11l-40.4 4.25c-11.12 1.17-19.18 11.57-17.93 23.1l34.92 321.59c1.26 11.53 11.37 20 22.49 18.84l40.4-4.25c11.12-1.17 19.18-11.57 17.93-23.1L445 115c-1.31-11.58-11.42-20.06-22.54-18.89z" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></path>', 6);

    const _hoisted_8$l = [_hoisted_2$a3];
    vue.defineComponent({
      name: 'LibraryOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$a3, _hoisted_8$l);
      }
    });

    const _hoisted_1$a2 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$a2 = /*#__PURE__*/vue.createStaticVNode('<path d="M84 480H28a12 12 0 0 1-12-12V92a12 12 0 0 1 12-12h56a12 12 0 0 1 12 12v376a12 12 0 0 1-12 12z" fill="currentColor"></path><path d="M240 208v-52a12 12 0 0 0-12-12H124a12 12 0 0 0-12 12v52z" fill="currentColor"></path><path d="M112 416v52a12 12 0 0 0 12 12h104a12 12 0 0 0 12-12v-52z" fill="currentColor"></path><path d="M112 240h128v144H112z" fill="currentColor"></path><path d="M340 480h-72a12 12 0 0 1-12-12V44a12 12 0 0 1 12-12h72a12 12 0 0 1 12 12v424a12 12 0 0 1-12 12z" fill="currentColor"></path><path d="M369 100.7l30 367.83a12 12 0 0 0 13.45 10.92l72.16-9a12 12 0 0 0 10.47-12.9L465 91.21a12 12 0 0 0-13.2-10.94l-72.13 7.51A12 12 0 0 0 369 100.7z" fill="currentColor"></path>', 6);

    const _hoisted_8$k = [_hoisted_2$a2];
    vue.defineComponent({
      name: 'LibrarySharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$a2, _hoisted_8$k);
      }
    });

    const _hoisted_1$a1 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$a1 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M200.66 352H144a96 96 0 0 1 0-192h55.41',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8E = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M312.59 160H368a96 96 0 0 1 0 192h-56.66',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$59 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M169.07 256h175.86'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2r = [_hoisted_2$a1, _hoisted_3$8E, _hoisted_4$59];
    vue.defineComponent({
      name: 'Link',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$a1, _hoisted_5$2r);
      }
    });

    const _hoisted_1$a0 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$a0 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M208 352h-64a96 96 0 0 1 0-192h64',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '36'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8D = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M304 160h64a96 96 0 0 1 0 192h-64',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '36'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$58 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '36',
      d: 'M163.29 256h187.42'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2q = [_hoisted_2$a0, _hoisted_3$8D, _hoisted_4$58];
    vue.defineComponent({
      name: 'LinkOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$a0, _hoisted_5$2q);
      }
    });

    const _hoisted_1$9$ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9$ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M200.66 352H144a96 96 0 0 1 0-192h55.41',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-linejoin': 'round',
      'stroke-width': '48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8C = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M312.59 160H368a96 96 0 0 1 0 192h-56.66',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-linejoin': 'round',
      'stroke-width': '48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$57 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-linejoin': 'round',
      'stroke-width': '48',
      d: 'M169.07 256h175.86'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2p = [_hoisted_2$9$, _hoisted_3$8C, _hoisted_4$57];
    vue.defineComponent({
      name: 'LinkSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9$, _hoisted_5$2p);
      }
    });

    const _hoisted_1$9_ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9_ = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="48" d="M160 144h288"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="48" d="M160 256h288"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="48" d="M160 368h288"></path><circle cx="80" cy="144" r="16" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><circle cx="80" cy="256" r="16" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><circle cx="80" cy="368" r="16" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle>', 6);

    const _hoisted_8$j = [_hoisted_2$9_];
    vue.defineComponent({
      name: 'List',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9_, _hoisted_8$j);
      }
    });

    const _hoisted_1$9Z = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9Z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm-88 302a24 24 0 1 1 24-24a24 24 0 0 1-24 24zm0-71a24 24 0 1 1 24-24a24 24 0 0 1-24 24zm0-73a24 24 0 1 1 24-24a24 24 0 0 1-24 24zm184 135H224a16 16 0 0 1 0-32h128a16 16 0 0 1 0 32zm0-71H224a16 16 0 0 1 0-32h128a16 16 0 0 1 0 32zm0-72H224a16 16 0 0 1 0-32h128a16 16 0 0 1 0 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8B = [_hoisted_2$9Z];
    vue.defineComponent({
      name: 'ListCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9Z, _hoisted_3$8B);
      }
    });

    const _hoisted_1$9Y = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9Y = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M224 184h128"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M224 256h128"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M224 327h128"></path><path d="M448 258c0-106-86-192-192-192S64 152 64 258s86 192 192 192s192-86 192-192z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><circle cx="168" cy="184" r="8" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><circle cx="168" cy="257" r="8" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><circle cx="168" cy="328" r="8" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle>', 7);

    const _hoisted_9$7 = [_hoisted_2$9Y];
    vue.defineComponent({
      name: 'ListCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9Y, _hoisted_9$7);
      }
    });

    const _hoisted_1$9X = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9X = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm-64 287.5a16 16 0 0 1-16 16h-16a16 16 0 0 1-16-16v-16a16 16 0 0 1 16-16h16a16 16 0 0 1 16 16zm0-71a16 16 0 0 1-16 16h-16a16 16 0 0 1-16-16v-16a16 16 0 0 1 16-16h16a16 16 0 0 1 16 16zm0-72a16 16 0 0 1-16 16h-16a16 16 0 0 1-16-16v-16a16 16 0 0 1 16-16h16a16 16 0 0 1 16 16zm176 151H212.67v-32H368zm0-71H212.67v-32H368zm0-72H212.67v-32H368z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8A = [_hoisted_2$9X];
    vue.defineComponent({
      name: 'ListCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9X, _hoisted_3$8A);
      }
    });

    const _hoisted_1$9W = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9W = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M160 144h288"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M160 256h288"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M160 368h288"></path><circle cx="80" cy="144" r="16" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><circle cx="80" cy="256" r="16" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><circle cx="80" cy="368" r="16" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle>', 6);

    const _hoisted_8$i = [_hoisted_2$9W];
    vue.defineComponent({
      name: 'ListOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9W, _hoisted_8$i);
      }
    });

    const _hoisted_1$9V = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9V = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="48" d="M144 144h320"></path><path fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="48" d="M144 256h320"></path><path fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="48" d="M144 368h320"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-linejoin="round" stroke-width="32" d="M64 128h32v32H64z"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-linejoin="round" stroke-width="32" d="M64 240h32v32H64z"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-linejoin="round" stroke-width="32" d="M64 352h32v32H64z"></path>', 6);

    const _hoisted_8$h = [_hoisted_2$9V];
    vue.defineComponent({
      name: 'ListSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9V, _hoisted_8$h);
      }
    });

    const _hoisted_1$9U = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9U = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="48" d="M256 96V56"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="48" d="M256 456v-40"></path><path d="M256 112a144 144 0 1 0 144 144a144 144 0 0 0-144-144z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="48"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="48" d="M416 256h40"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="48" d="M56 256h40"></path>', 5);

    const _hoisted_7$E = [_hoisted_2$9U];
    vue.defineComponent({
      name: 'Locate',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9U, _hoisted_7$E);
      }
    });

    const _hoisted_1$9T = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9T = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="48" d="M256 96V56"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="48" d="M256 456v-40"></path><path d="M256 112a144 144 0 1 0 144 144a144 144 0 0 0-144-144z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="48" d="M416 256h40"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="48" d="M56 256h40"></path>', 5);

    const _hoisted_7$D = [_hoisted_2$9T];
    vue.defineComponent({
      name: 'LocateOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9T, _hoisted_7$D);
      }
    });

    const _hoisted_1$9S = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9S = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="square" stroke-linejoin="round" stroke-width="48" d="M256 96V56"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-linejoin="round" stroke-width="48" d="M256 456v-40"></path><path d="M256 112a144 144 0 1 0 144 144a144 144 0 0 0-144-144z" fill="none" stroke="currentColor" stroke-linecap="square" stroke-linejoin="round" stroke-width="48"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-linejoin="round" stroke-width="48" d="M416 256h40"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-linejoin="round" stroke-width="48" d="M56 256h40"></path>', 5);

    const _hoisted_7$C = [_hoisted_2$9S];
    vue.defineComponent({
      name: 'LocateSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9S, _hoisted_7$C);
      }
    });

    const _hoisted_1$9R = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9R = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '192',
      r: '32',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 32c-88.22 0-160 68.65-160 153c0 40.17 18.31 93.59 54.42 158.78c29 52.34 62.55 99.67 80 123.22a31.75 31.75 0 0 0 51.22 0c17.42-23.55 51-70.88 80-123.22C397.69 278.61 416 225.19 416 185c0-84.35-71.78-153-160-153zm0 224a64 64 0 1 1 64-64a64.07 64.07 0 0 1-64 64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$56 = [_hoisted_2$9R, _hoisted_3$8z];
    vue.defineComponent({
      name: 'Location',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9R, _hoisted_4$56);
      }
    });

    const _hoisted_1$9Q = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9Q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48c-79.5 0-144 61.39-144 137c0 87 96 224.87 131.25 272.49a15.77 15.77 0 0 0 25.5 0C304 409.89 400 272.07 400 185c0-75.61-64.5-137-144-137z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8y = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '192',
      r: '48',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$55 = [_hoisted_2$9Q, _hoisted_3$8y];
    vue.defineComponent({
      name: 'LocationOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9Q, _hoisted_4$55);
      }
    });

    const _hoisted_1$9P = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9P = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 32C167.67 32 96 96.51 96 176c0 128 160 304 160 304s160-176 160-304c0-79.49-71.67-144-160-144zm0 224a64 64 0 1 1 64-64a64.07 64.07 0 0 1-64 64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8x = [_hoisted_2$9P];
    vue.defineComponent({
      name: 'LocationSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9P, _hoisted_3$8x);
      }
    });

    const _hoisted_1$9O = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9O = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M368 192h-16v-80a96 96 0 1 0-192 0v80h-16a64.07 64.07 0 0 0-64 64v176a64.07 64.07 0 0 0 64 64h224a64.07 64.07 0 0 0 64-64V256a64.07 64.07 0 0 0-64-64zm-48 0H192v-80a64 64 0 1 1 128 0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8w = [_hoisted_2$9O];
    vue.defineComponent({
      name: 'LockClosed',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9O, _hoisted_3$8w);
      }
    });

    const _hoisted_1$9N = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9N = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 208v-95a80 80 0 0 0-160 0v95',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8v = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '96',
      y: '208',
      width: '320',
      height: '272',
      rx: '48',
      ry: '48',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$54 = [_hoisted_2$9N, _hoisted_3$8v];
    vue.defineComponent({
      name: 'LockClosedOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9N, _hoisted_4$54);
      }
    });

    const _hoisted_1$9M = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9M = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M420 192h-68v-80a96 96 0 1 0-192 0v80H92a12 12 0 0 0-12 12v280a12 12 0 0 0 12 12h328a12 12 0 0 0 12-12V204a12 12 0 0 0-12-12zm-106 0H198v-80.75a58 58 0 1 1 116 0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8u = [_hoisted_2$9M];
    vue.defineComponent({
      name: 'LockClosedSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9M, _hoisted_3$8u);
      }
    });

    const _hoisted_1$9L = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9L = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M368 192H192v-80a64 64 0 1 1 128 0a16 16 0 0 0 32 0a96 96 0 1 0-192 0v80h-16a64.07 64.07 0 0 0-64 64v176a64.07 64.07 0 0 0 64 64h224a64.07 64.07 0 0 0 64-64V256a64.07 64.07 0 0 0-64-64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8t = [_hoisted_2$9L];
    vue.defineComponent({
      name: 'LockOpen',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9L, _hoisted_3$8t);
      }
    });

    const _hoisted_1$9K = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9K = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 112a80 80 0 0 0-160 0v96',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8s = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '96',
      y: '208',
      width: '320',
      height: '272',
      rx: '48',
      ry: '48',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$53 = [_hoisted_2$9K, _hoisted_3$8s];
    vue.defineComponent({
      name: 'LockOpenOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9K, _hoisted_4$53);
      }
    });

    const _hoisted_1$9J = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9J = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M420 192H198v-80.75a58.08 58.08 0 0 1 99.07-41.07A59.4 59.4 0 0 1 314 112h38a96 96 0 1 0-192 0v80H92a12 12 0 0 0-12 12v280a12 12 0 0 0 12 12h328a12 12 0 0 0 12-12V204a12 12 0 0 0-12-12z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8r = [_hoisted_2$9J];
    vue.defineComponent({
      name: 'LockOpenSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9J, _hoisted_3$8r);
      }
    });

    const _hoisted_1$9I = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9I = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M392 80H232a56.06 56.06 0 0 0-56 56v104h153.37l-52.68-52.69a16 16 0 0 1 22.62-22.62l80 80a16 16 0 0 1 0 22.62l-80 80a16 16 0 0 1-22.62-22.62L329.37 272H176v104c0 32.05 33.79 56 64 56h152a56.06 56.06 0 0 0 56-56V136a56.06 56.06 0 0 0-56-56z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M80 240a16 16 0 0 0 0 32h96v-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$52 = [_hoisted_2$9I, _hoisted_3$8q];
    vue.defineComponent({
      name: 'LogIn',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9I, _hoisted_4$52);
      }
    });

    const _hoisted_1$9H = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9H = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M192 176v-40a40 40 0 0 1 40-40h160a40 40 0 0 1 40 40v240a40 40 0 0 1-40 40H240c-22.09 0-48-17.91-48-40v-40',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8p = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M288 336l80-80l-80-80'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$51 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M80 256h272'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2o = [_hoisted_2$9H, _hoisted_3$8p, _hoisted_4$51];
    vue.defineComponent({
      name: 'LogInOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9H, _hoisted_5$2o);
      }
    });

    const _hoisted_1$9G = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9G = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M432 80H192a16 16 0 0 0-16 16v144h153.37l-64-64L288 153.37l91.31 91.32a16 16 0 0 1 0 22.62L288 358.63L265.37 336l64-64H176v144a16 16 0 0 0 16 16h240a16 16 0 0 0 16-16V96a16 16 0 0 0-16-16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8o = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M64 240h112v32H64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$50 = [_hoisted_2$9G, _hoisted_3$8o];
    vue.defineComponent({
      name: 'LogInSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9G, _hoisted_4$50);
      }
    });

    const _hoisted_1$9F = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9F = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M160 256a16 16 0 0 1 16-16h144V136c0-32-33.79-56-64-56H104a56.06 56.06 0 0 0-56 56v240a56.06 56.06 0 0 0 56 56h160a56.06 56.06 0 0 0 56-56V272H176a16 16 0 0 1-16-16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8n = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M459.31 244.69l-80-80a16 16 0 0 0-22.62 22.62L409.37 240H320v32h89.37l-52.68 52.69a16 16 0 1 0 22.62 22.62l80-80a16 16 0 0 0 0-22.62z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4$ = [_hoisted_2$9F, _hoisted_3$8n];
    vue.defineComponent({
      name: 'LogOut',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9F, _hoisted_4$4$);
      }
    });

    const _hoisted_1$9E = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9E = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M304 336v40a40 40 0 0 1-40 40H104a40 40 0 0 1-40-40V136a40 40 0 0 1 40-40h152c22.09 0 48 17.91 48 40v40',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8m = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M368 336l80-80l-80-80'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4_ = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M176 256h256'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2n = [_hoisted_2$9E, _hoisted_3$8m, _hoisted_4$4_];
    vue.defineComponent({
      name: 'LogOutOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9E, _hoisted_5$2n);
      }
    });

    const _hoisted_1$9D = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9D = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M160 240h160V96a16 16 0 0 0-16-16H64a16 16 0 0 0-16 16v320a16 16 0 0 0 16 16h240a16 16 0 0 0 16-16V272H160z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8l = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M459.31 244.69L368 153.37L345.37 176l64 64H320v32h89.37l-64 64L368 358.63l91.31-91.32a16 16 0 0 0 0-22.62z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4Z = [_hoisted_2$9D, _hoisted_3$8l];
    vue.defineComponent({
      name: 'LogOutSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9D, _hoisted_4$4Z);
      }
    });

    const _hoisted_1$9C = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9C = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M102.41 32C62.38 32 32 64.12 32 103.78v304.45C32 447.86 64.38 480 104.41 480h303.2c40 0 72.39-32.14 72.39-71.77v-3.11c-1.35-.56-115.47-48.57-174.5-76.7c-39.82 48.57-91.18 78-144.5 78c-90.18 0-120.8-78.22-78.1-129.72c9.31-11.22 25.15-21.94 49.73-28c38.45-9.36 99.64 5.85 157 24.61a309.41 309.41 0 0 0 25.46-61.67H138.34V194h91.13v-31.83H119.09v-17.75h110.38V99s0-7.65 7.82-7.65h44.55v53H391v17.75H281.84V194h89.08a359.41 359.41 0 0 1-37.72 94.43c27 9.69 49.31 18.88 67.39 24.89c60.32 20 77.23 22.45 79.41 22.7V103.78C480 64.12 447.6 32 407.61 32h-305.2zM152 274.73q-5.81.06-11.67.63c-11.3 1.13-32.5 6.07-44.09 16.23c-34.74 30-13.94 84.93 56.37 84.93c40.87 0 81.71-25.9 113.79-67.37c-41.36-20-77-34.85-114.4-34.42z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8k = [_hoisted_2$9C];
    vue.defineComponent({
      name: 'LogoAlipay',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9C, _hoisted_3$8k);
      }
    });

    const _hoisted_1$9B = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9B = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48.48 378.73a300.52 300.52 0 0 0 152.89 95.92a262.57 262.57 0 0 0 159.3-17.25a225.52 225.52 0 0 0 66.79-47a6.36 6.36 0 0 0-2-8.53a11.76 11.76 0 0 0-8-.05a401.92 401.92 0 0 1-116.55 39.34a358.13 358.13 0 0 1-127.29-8.83a446.73 446.73 0 0 1-119.1-60.49a5 5 0 0 0-6.06 6.9z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8j = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M387.15 388.44a168.11 168.11 0 0 1 48.94-2.23l.67.13a10 10 0 0 1 7.37 12.05A204.71 204.71 0 0 1 429 444.47a2.55 2.55 0 0 0 1.66 3.18a2.51 2.51 0 0 0 2.23-.37A83.31 83.31 0 0 0 464 382.86a12.44 12.44 0 0 0-10.22-13.22A95.75 95.75 0 0 0 384.91 384a2.55 2.55 0 0 0-.57 3.55a2.52 2.52 0 0 0 2.81.89z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4Y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M304.24 324.92a164 164 0 0 1-28.92 25.3A135.16 135.16 0 0 1 208.63 369a99.49 99.49 0 0 1-57.49-19.85a97.25 97.25 0 0 1-27.36-100.28a112.35 112.35 0 0 1 65.3-69.06a367.67 367.67 0 0 1 104.7-15.55V127A37.82 37.82 0 0 0 261 94.72a59.9 59.9 0 0 0-31.17 4.08a48.89 48.89 0 0 0-27.13 34.67a12 12 0 0 1-12.58 6.72l-50.9-4.5a11.38 11.38 0 0 1-8.38-10.16a103.66 103.66 0 0 1 36.61-63.45A143.86 143.86 0 0 1 257.85 32a146.24 146.24 0 0 1 84.27 27.67a86.82 86.82 0 0 1 30.7 70.22V258.8a84.46 84.46 0 0 0 8 31.28l15.87 23.23a13 13 0 0 1 0 11.23l-46.99 39.71a12.5 12.5 0 0 1-12.68-.44a244.84 244.84 0 0 1-32.78-38.89zm-10.6-116.83a257.68 257.68 0 0 0-44 2.89A63 63 0 0 0 208 242.54a63 63 0 0 0 3.07 54a40.6 40.6 0 0 0 47.11 12.19a78.61 78.61 0 0 0 35.46-55.58v-45.06',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2m = [_hoisted_2$9B, _hoisted_3$8j, _hoisted_4$4Y];
    vue.defineComponent({
      name: 'LogoAmazon',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9B, _hoisted_5$2m);
      }
    });

    const _hoisted_1$9A = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9A = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M112.31 268l40.36-68.69l34.65 59l-67.54 115h135L289.31 432H16zm58.57-99.76l33.27-56.67L392.44 432h-66.68zM222.67 80h66.59L496 432h-66.68z',
      'fill-rule': 'evenodd',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8i = [_hoisted_2$9A];
    vue.defineComponent({
      name: 'LogoAmplify',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9A, _hoisted_3$8i);
      }
    });

    const _hoisted_1$9z = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M380.91 199l42.47-73.57a8.63 8.63 0 0 0-3.12-11.76a8.52 8.52 0 0 0-11.71 3.12l-43 74.52c-32.83-15-69.78-23.35-109.52-23.35s-76.69 8.36-109.52 23.35l-43-74.52a8.6 8.6 0 1 0-14.88 8.64L131 199C57.8 238.64 8.19 312.77 0 399.55h512c-8.19-86.78-57.8-160.91-131.09-200.55zM138.45 327.65a21.46 21.46 0 1 1 21.46-21.46a21.47 21.47 0 0 1-21.46 21.46zm235 0A21.46 21.46 0 1 1 395 306.19a21.47 21.47 0 0 1-21.51 21.46z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8h = [_hoisted_2$9z];
    vue.defineComponent({
      name: 'LogoAndroid',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9z, _hoisted_3$8h);
      }
    });

    const _hoisted_1$9y = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M213.57 256h84.85l-42.43-89.36L213.57 256z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8g = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 32L32 112l46.12 272L256 480l177.75-96L480 112zm88 320l-26.59-56H194.58L168 352h-40L256 72l128 280z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4X = [_hoisted_2$9y, _hoisted_3$8g];
    vue.defineComponent({
      name: 'LogoAngular',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9y, _hoisted_4$4X);
      }
    });

    const _hoisted_1$9x = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9x = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M349.13 136.86c-40.32 0-57.36 19.24-85.44 19.24c-28.79 0-50.75-19.1-85.69-19.1c-34.2 0-70.67 20.88-93.83 56.45c-32.52 50.16-27 144.63 25.67 225.11c18.84 28.81 44 61.12 77 61.47h.6c28.68 0 37.2-18.78 76.67-19h.6c38.88 0 46.68 18.89 75.24 18.89h.6c33-.35 59.51-36.15 78.35-64.85c13.56-20.64 18.6-31 29-54.35c-76.19-28.92-88.43-136.93-13.08-178.34c-23-28.8-55.32-45.48-85.79-45.48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8f = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M340.25 32c-24 1.63-52 16.91-68.4 36.86c-14.88 18.08-27.12 44.9-22.32 70.91h1.92c25.56 0 51.72-15.39 67-35.11c14.72-18.77 25.88-45.37 21.8-72.66z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4W = [_hoisted_2$9x, _hoisted_3$8f];
    vue.defineComponent({
      name: 'LogoApple',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9x, _hoisted_4$4W);
      }
    });

    const _hoisted_1$9w = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9w = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 32C132.26 32 32 132.26 32 256s100.26 224 224 224s224-100.26 224-224S379.74 32 256 32zm-85 321.89a15.48 15.48 0 0 1-13.46 7.65a14.91 14.91 0 0 1-7.86-2.16a15.48 15.48 0 0 1-5.6-21.21l15.29-25.42a8.73 8.73 0 0 1 7.54-4.3h2.26c11.09 0 18.85 6.67 21.11 13.13zm129.45-50l-100.13.11h-66.55a15.46 15.46 0 0 1-15.51-16.15c.32-8.4 7.65-14.76 16-14.76h48.24l57.19-97.35l-18.52-31.55C217 137 218.85 127.52 226 123a15.57 15.57 0 0 1 21.87 5.17l9.9 16.91h.11l9.91-16.91A15.58 15.58 0 0 1 289.6 123c7.11 4.52 8.94 14 4.74 21.22l-18.52 31.55l-18 30.69l-39.09 66.66v.11h57.61c7.22 0 16.27 3.88 19.93 10.12l.32.65c3.23 5.49 5.06 9.26 5.06 14.75a13.82 13.82 0 0 1-1.17 5.17zm77.75.11h-27.11v.11l19.82 33.71a15.8 15.8 0 0 1-5.17 21.53a15.53 15.53 0 0 1-8.08 2.27A15.71 15.71 0 0 1 344.2 354l-29.29-49.86l-18.2-31L273.23 233a38.35 38.35 0 0 1-.65-38c4.64-8.19 8.19-10.34 8.19-10.34L333 273h44.91c8.4 0 15.61 6.46 16 14.75A15.65 15.65 0 0 1 378.23 304z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8e = [_hoisted_2$9w];
    vue.defineComponent({
      name: 'LogoAppleAppstore',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9w, _hoisted_3$8e);
      }
    });

    const _hoisted_1$9v = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9v = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M201.14 64L256 32l54.86 32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M256 32v80"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M310.86 448L256 480l-54.86-32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M256 480v-80"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M64 207.51V144l53.15-31.51"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M64 144l67.29 40"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M448 304.49V368l-53.15 31.51"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M448 368l-67.29-40"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M117.15 400L64 368v-63.51"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M64 368l66.64-40"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M394.85 112.49L448 144v63.51"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M448 144l-67.29 40"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M256 320v-64l54.86-32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M256 256l-54.86-32"></path>', 14);

    const _hoisted_16$1 = [_hoisted_2$9v];
    vue.defineComponent({
      name: 'LogoAppleAr',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9v, _hoisted_16$1);
      }
    });

    const _hoisted_1$9u = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9u = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M344.1 233.6c-28.9 0-32.9 28.8-32.9 28.8h61.4s.4-28.8-28.5-28.8z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8d = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M204.8 262.4h-54.4v50h51.7c7.8-.2 22.4-2.4 22.4-24.3c0-26-19.7-25.7-19.7-25.7z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4V = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 32C132.3 32 32 132.3 32 256s100.3 224 224 224s224-100.3 224-224S379.7 32 256 32zm47.2 137.6h77.1v23h-77.1v-23zm-39 120.8c0 57-59.4 55.2-59.4 55.2h-97.2v-187h97.2c29.6 0 52.9 16.3 52.9 49.8S229.2 244 229.2 244c37.6 0 35 46.4 35 46.4zm144.2-3.1h-96.9c0 34.7 32.9 32.5 32.9 32.5c31.1 0 30-20.1 30-20.1h32.9c0 53.4-64 49.7-64 49.7c-76.7 0-71.8-71.5-71.8-71.5s-.1-71.8 71.8-71.8c75.7.1 65.1 81.2 65.1 81.2z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2l = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M218 211.3c0-19.4-13.2-19.4-13.2-19.4h-54.4v41.7h51c8.8 0 16.6-2.9 16.6-22.3z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$17 = [_hoisted_2$9u, _hoisted_3$8d, _hoisted_4$4V, _hoisted_5$2l];
    vue.defineComponent({
      name: 'LogoBehance',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9u, _hoisted_6$17);
      }
    });

    const _hoisted_1$9t = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9t = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M483.13 32.23a19.65 19.65 0 0 0-2.54-.23h-449C23 31.88 16.12 38.88 16 47.75a11.44 11.44 0 0 0 .23 2.8l65.3 411.25a22.52 22.52 0 0 0 7 12.95A20 20 0 0 0 102 480h313.18a15.45 15.45 0 0 0 15.34-13.42l38.88-247.91H325.19l-18.46 112H205.21l-25.73-148h295.58l20.76-132c1.27-8.75-4.38-17.04-12.69-18.44z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8c = [_hoisted_2$9t];
    vue.defineComponent({
      name: 'LogoBitbucket',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9t, _hoisted_3$8c);
      }
    });

    const _hoisted_1$9s = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9s = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M410.47 279.2c-5-11.5-12.7-21.6-28.1-30.1a98.15 98.15 0 0 0-25.4-10a62.22 62.22 0 0 0 16.3-11a56.37 56.37 0 0 0 15.6-23.3a77.11 77.11 0 0 0 3.5-28.2c-1.1-16.8-4.4-33.1-13.2-44.8s-21.2-20.7-37.6-27c-12.6-4.8-25.5-7.8-45.5-8.9V32h-40v64h-32V32h-41v64H96v48h27.87c8.7 0 14.6.8 17.6 2.3a13.22 13.22 0 0 1 6.5 6c1.3 2.5 1.9 8.4 1.9 17.5V343c0 9-.6 14.8-1.9 17.4s-2 4.9-5.1 6.3s-3.2 1.3-11.8 1.3h-26.4L96 416h87v64h41v-64h32v64h40v-64.4c26-1.3 44.5-4.7 59.4-10.3c19.3-7.2 34.1-17.7 44.7-31.5s14-34.9 14.93-51.2c.67-14.5-.03-33.2-4.56-43.4zM224 150h32v74h-32zm0 212v-90h32v90zm72-208.1c6 2.5 9.9 7.5 13.8 12.7c4.3 5.7 6.5 13.3 6.5 21.4c0 7.8-2.9 14.5-7.5 20.5c-3.8 4.9-6.8 8.3-12.8 11.1zm28.8 186.7c-7.8 6.9-12.3 10.1-22.1 13.8a56.06 56.06 0 0 1-6.7 1.9v-82.8a40.74 40.74 0 0 1 11.3 3.4c7.8 3.3 15.2 6.9 19.8 13.2a43.82 43.82 0 0 1 8 24.7c-.03 10.9-2.83 19.2-10.33 25.8z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8b = [_hoisted_2$9s];
    vue.defineComponent({
      name: 'LogoBitcoin',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9s, _hoisted_3$8b);
      }
    });

    const _hoisted_1$9r = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9r = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M39.93 149.25l197.4 95.32c5.14 2.45 12 3.73 18.79 3.73s13.65-1.28 18.78-3.73l197.4-95.32c10.38-5 10.38-13.18 0-18.2L274.9 35.73c-5.13-2.45-12-3.73-18.78-3.73s-13.65 1.28-18.79 3.73l-197.4 95.32c-10.38 5.02-10.38 13.18 0 18.2z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8a = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M472.3 246.9s-36.05-17.38-40.83-19.72s-6.07-2.21-11.09.12s-145.6 70.23-145.6 70.23a45.71 45.71 0 0 1-18.78 3.74c-6.77 0-13.65-1.29-18.78-3.74c0 0-136.85-66-143.27-69.18C87 225 85 225 78.67 228l-39 18.78c-10.38 5-10.38 13.19 0 18.2L237.1 360.3c5.13 2.45 12 3.73 18.78 3.73s13.65-1.28 18.79-3.73l197.4-95.3c10.61-4.92 10.61-13.08.23-18.1z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4U = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M472.3 362.75s-36.05-17.38-40.83-19.75s-6.07-2.21-11.09.12S274.9 413.5 274.9 413.5a45.74 45.74 0 0 1-18.78 3.73c-6.77 0-13.65-1.28-18.79-3.73c0 0-136.85-66-143.26-69.18c-7-3.39-9-3.39-15.29-.35l-39 18.78c-10.39 5-10.39 13.18 0 18.2l197.4 95.32c5.13 2.56 12 3.73 18.78 3.73s13.65-1.28 18.78-3.73L472.18 381c10.5-5.07 10.5-13.23.12-18.25z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2k = [_hoisted_2$9r, _hoisted_3$8a, _hoisted_4$4U];
    vue.defineComponent({
      name: 'LogoBuffer',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9r, _hoisted_5$2k);
      }
    });

    const _hoisted_1$9q = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 101.09L372.37 208.72l106.86 107.06l-69.3 69.3l-283.22-283.23L196 32.54l107.07 106.88L410.67 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$89 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M32.55 196l69.3-69.31l283.22 283.24l-69.3 69.3l-107-106.87L101.08 480L32 410.67l107.42-107.61z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4T = [_hoisted_2$9q, _hoisted_3$89];
    vue.defineComponent({
      name: 'LogoCapacitor',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9q, _hoisted_4$4T);
      }
    });

    const _hoisted_1$9p = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9p = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M188.8 255.93a67.2 67.2 0 1 0 67.2-67.18a67.38 67.38 0 0 0-67.2 67.18z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$88 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M476.75 217.79v.05a206.63 206.63 0 0 0-7-28.84h-.11a202.16 202.16 0 0 1 7.07 29a203.5 203.5 0 0 0-7.07-29h-155.4c19.05 17 31.36 40.17 31.36 67.05a86.55 86.55 0 0 1-12.31 44.73L231 478.45a2.44 2.44 0 0 1 0 .27v.28v-.26a224 224 0 0 0 25 1.26c6.84 0 13.61-.39 20.3-1a222.91 222.91 0 0 0 29.78-4.74C405.68 451.52 480 362.4 480 255.94a225.25 225.25 0 0 0-3.25-38.15z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4S = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 345.5c-33.6 0-61.6-17.91-77.29-44.79L76 123.05l-.14-.24A224 224 0 0 0 207.4 474.55v-.05l77.69-134.6a84.13 84.13 0 0 1-29.09 5.6z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2j = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M91.29 104.57l77.35 133.25A89.19 89.19 0 0 1 256 166h205.17a246.51 246.51 0 0 0-25.78-43.94l.12.08A245.26 245.26 0 0 1 461.17 166h.17a245.91 245.91 0 0 0-25.66-44a2.63 2.63 0 0 1-.35-.26a223.93 223.93 0 0 0-344.19-17.4l.14.24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$16 = [_hoisted_2$9p, _hoisted_3$88, _hoisted_4$4S, _hoisted_5$2j];
    vue.defineComponent({
      name: 'LogoChrome',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9p, _hoisted_6$16);
      }
    });

    const _hoisted_1$9o = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9o = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M0 80v352h512V80zm464 175.78c0 25.74-1.6 45.32-3.77 77.22s-19.2 54.34-59.09 57.86s-95.77 3.85-145.14 3.74c-49 .11-105.14-.11-145.14-3.74s-56.8-26-59.09-57.86S48 281.52 48 255.78s.11-42.46 3.77-77.22s23-54.12 59.09-57.64s98.28-3.52 145.14-3.52s109 0 145.14 3.52s55.43 23 59.09 57.64s3.77 51.59 3.77 77.22z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$87 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M367.57 282.84v.77c0 17.93-11.11 28.49-25.95 28.49s-24.84-11.88-26.27-28.49c0 0-1.31-8.69-1.31-26.29a229.5 229.5 0 0 1 1.53-28.6c2.64-18.7 11.77-28.49 26.6-28.49s26.49 12.76 26.49 32.12v.55h49.58c0-24.09-6.05-45.76-18.25-59.4S369.76 153 345.8 153a108.06 108.06 0 0 0-33 4.73a58.82 58.82 0 0 0-25.94 16.61c-7.23 7.96-12.86 18.52-16.86 31.83s-6 30-6 50.27c0 19.8 1.65 36.3 4.84 49.61s8 23.87 14.4 31.79a49.76 49.76 0 0 0 24 16.5q14.5 4.62 34 4.62c27.47 0 47.26-7 59.13-20.57S418 305.06 418 279.1h-50.65c.22 0 .22 2.75.22 3.74z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4R = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M197.3 282.84v.77c0 17.93-11.1 28.49-25.94 28.49s-24.84-11.88-26.27-28.49c0 0-1.31-8.69-1.31-26.29a229.5 229.5 0 0 1 1.53-28.6c2.64-18.7 11.77-28.49 26.6-28.49S198.4 213 198.4 232.35v.55H248c0-24.09-6-45.76-18.25-59.4S199.5 153 175.54 153a108.06 108.06 0 0 0-33 4.73a58.82 58.82 0 0 0-25.94 16.61c-7.26 7.92-12.86 18.48-16.93 31.79s-6 30-6 50.27c0 19.8 1.65 36.3 4.84 49.61s8 23.87 14.4 31.79a49.76 49.76 0 0 0 24 16.5q14.51 4.62 34 4.62c27.48 0 47.27-7 59.14-20.57s17.81-33.33 17.81-59.29h-50.78c.22.04.22 2.79.22 3.78z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2i = [_hoisted_2$9o, _hoisted_3$87, _hoisted_4$4R];
    vue.defineComponent({
      name: 'LogoClosedCaptioning',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9o, _hoisted_5$2i);
      }
    });

    const _hoisted_1$9n = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9n = /*#__PURE__*/vue.createStaticVNode('<path d="M241.24 303.94c-15.32-10.36-30.74-20.57-46.06-30.93c-2-1.38-3.43-1.48-5.5 0l-38.88 26.12C182 319.9 244 361.32 244 361.32v-53.79c0-1.22-1.55-2.78-2.76-3.59z" fill="currentColor"></path><path d="M195.09 240.67q23.19-15.24 46.11-30.86a7.54 7.54 0 0 0 2.8-5.34v-51.7s-62 41.12-93.26 61.94c13.7 9.16 26.67 17.91 39.78 26.44c1.02.66 3.4.28 4.57-.48z" fill="currentColor"></path><path d="M269.84 209.35q23.71 16.07 47.63 31.82a4.3 4.3 0 0 0 3.83 0l39.76-26.47L268 152.48v53.35a4.79 4.79 0 0 0 1.84 3.52z" fill="currentColor"></path><path d="M258.11 230.37a5.27 5.27 0 0 0-4.74.17c-4.82 3-9.47 6.2-14.17 9.35c-8.25 5.53-25.35 17-25.35 17l38.84 25.86a6.18 6.18 0 0 0 6.26.11l39-26s-34.07-22.66-39.84-26.49z" fill="currentColor"></path><path d="M141 237.12v39.61l29.62-19.84L141 237.12z" fill="currentColor"></path><path d="M256 32C132.29 32 32 132.29 32 256s100.29 224 224 224s224-100.29 224-224S379.71 32 256 32zm139 265c0 5.78-2.65 9.86-7.51 13.09q-61.71 41-123.29 82.19c-5.85 3.92-11.17 3.75-17-.14q-61.17-41-122.63-81.67c-5.11-3.39-7.59-7.56-7.59-13.73V217c0-6.14 2.52-10.34 7.62-13.72c40.91-27.13 81.94-54.36 122.73-81.68c5.82-3.89 11.09-4 16.94-.09q61.54 41.21 123.26 82.19c4.68 3.11 7.45 6.95 7.45 12.66z" fill="currentColor"></path><path d="M316.25 273.23q-22.59 15.34-45.39 30.34c-2.41 1.58-2.89 3.31-2.86 6.19v51.34l93-62l-38.53-25.88c-2.3-1.61-3.89-1.57-6.22.01z" fill="currentColor"></path><path d="M370 276.68v-39.62l-29.59 19.87L370 276.68z" fill="currentColor"></path>', 8);

    const _hoisted_10$7 = [_hoisted_2$9n];
    vue.defineComponent({
      name: 'LogoCodepen',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9n, _hoisted_10$7);
      }
    });

    const _hoisted_1$9m = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9m = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M64 32l35 403.22L255.77 480L413 435.15L448 32zm290.68 334.9L256.07 395l-98.46-28.24l-6.75-77.76h48.26l3.43 39.56l53.59 15.16l.13.28l53.47-14.85l5.64-64.15H203l-4-50h120.65l4.35-51H140l-4-49h240.58z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$86 = [_hoisted_2$9m];
    vue.defineComponent({
      name: 'LogoCss3',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9m, _hoisted_3$86);
      }
    });

    const _hoisted_1$9l = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9l = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M295.31 122.8L222.86 64l72.68 122.64l-.23-63.84z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$85 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M339.43 64v195.6h-41.6L225.6 141.28l1.94 118.32h-45.83V131.2L139.09 96c1.14 1.44 2.28 2.88 3.31 4.44c11.43 16.68 17.14 36.6 17.14 60.6c0 59-35 98.52-87.88 98.52H0v.48L228.11 448H512V205.72z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4Q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M111.89 162.52c0-34.8-16.23-54.12-45.38-54.12H44.57v106.8h21.72c29.71 0 45.6-18.48 45.6-52.68z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2h = [_hoisted_2$9l, _hoisted_3$85, _hoisted_4$4Q];
    vue.defineComponent({
      name: 'LogoDesignernews',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9l, _hoisted_5$2h);
      }
    });

    const _hoisted_1$9k = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9k = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M408 103.28V16h-89.31l-8.9 8.78l-42.15 78.48l-13.25 8.74H104v119.85h82.68l7.36 8.71L104 408.72V496h89.3l8.91-8.79l42.14-78.48l13.26-8.73H408V280.13h-82.68l-7.36-8.75L408 103.28z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$84 = [_hoisted_2$9k];
    vue.defineComponent({
      name: 'LogoDeviantart',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9k, _hoisted_3$84);
      }
    });

    const _hoisted_1$9j = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9j = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 66.52A50 50 0 0 0 414.12 17L97.64 16A49.65 49.65 0 0 0 48 65.52V392c0 27.3 22.28 48 49.64 48H368l-13-44l109 100zM324.65 329.81s-8.72-10.39-16-19.32C340.39 301.55 352.5 282 352.5 282a139 139 0 0 1-27.85 14.25a173.31 173.31 0 0 1-35.11 10.39a170.05 170.05 0 0 1-62.72-.24a184.45 184.45 0 0 1-35.59-10.4a141.46 141.46 0 0 1-17.68-8.21c-.73-.48-1.45-.72-2.18-1.21c-.49-.24-.73-.48-1-.48c-4.36-2.42-6.78-4.11-6.78-4.11s11.62 19.09 42.38 28.26c-7.27 9.18-16.23 19.81-16.23 19.81c-53.51-1.69-73.85-36.47-73.85-36.47c0-77.06 34.87-139.62 34.87-139.62c34.87-25.85 67.8-25.12 67.8-25.12l2.42 2.9c-43.59 12.32-63.44 31.4-63.44 31.4s5.32-2.9 14.28-6.77c25.91-11.35 46.5-14.25 55-15.21a24 24 0 0 1 4.12-.49a205.62 205.62 0 0 1 48.91-.48a201.62 201.62 0 0 1 72.89 22.95s-19.13-18.15-60.3-30.45l3.39-3.86s33.17-.73 67.81 25.16c0 0 34.87 62.56 34.87 139.62c0-.28-20.35 34.5-73.86 36.19z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$83 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M212.05 218c-13.8 0-24.7 11.84-24.7 26.57s11.14 26.57 24.7 26.57c13.8 0 24.7-11.83 24.7-26.57c.25-14.76-10.9-26.57-24.7-26.57z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4P = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M300.43 218c-13.8 0-24.7 11.84-24.7 26.57s11.14 26.57 24.7 26.57c13.81 0 24.7-11.83 24.7-26.57S314 218 300.43 218z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2g = [_hoisted_2$9j, _hoisted_3$83, _hoisted_4$4P];
    vue.defineComponent({
      name: 'LogoDiscord',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9j, _hoisted_5$2g);
      }
    });

    const _hoisted_1$9i = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9i = /*#__PURE__*/vue.createStaticVNode('<path d="M507 211.16c-1.42-1.19-14.25-10.94-41.79-10.94a132.55 132.55 0 0 0-21.61 1.9c-5.22-36.4-35.38-54-36.57-55l-7.36-4.28l-4.75 6.9a101.65 101.65 0 0 0-13.06 30.45c-5 20.7-1.9 40.2 8.55 56.85c-12.59 7.14-33 8.8-37.28 9H15.94A15.93 15.93 0 0 0 0 262.07a241.25 241.25 0 0 0 14.75 86.83C26.39 379.35 43.72 402 66 415.74C91.22 431.2 132.3 440 178.6 440a344.23 344.23 0 0 0 62.45-5.71a257.44 257.44 0 0 0 81.69-29.73a223.55 223.55 0 0 0 55.57-45.67c26.83-30.21 42.74-64 54.38-94h4.75c29.21 0 47.26-11.66 57.23-21.65a63.31 63.31 0 0 0 15.2-22.36l2.14-6.18z" fill="currentColor"></path><path d="M47.29 236.37H92.4a4 4 0 0 0 4-4v-40.48a4 4 0 0 0-4-4H47.29a4 4 0 0 0-4 4v40.44a4.16 4.16 0 0 0 4 4" fill="currentColor"></path><path d="M109.5 236.37h45.12a4 4 0 0 0 4-4v-40.48a4 4 0 0 0-4-4H109.5a4 4 0 0 0-4 4v40.44a4.16 4.16 0 0 0 4 4" fill="currentColor"></path><path d="M172.9 236.37H218a4 4 0 0 0 4-4v-40.48a4 4 0 0 0-4-4h-45.1a4 4 0 0 0-4 4v40.44a3.87 3.87 0 0 0 4 4" fill="currentColor"></path><path d="M235.36 236.37h45.12a4 4 0 0 0 4-4v-40.48a4 4 0 0 0-4-4h-45.12a4 4 0 0 0-4 4v40.44a4 4 0 0 0 4 4" fill="currentColor"></path><path d="M109.5 178.57h45.12a4.16 4.16 0 0 0 4-4v-40.48a4 4 0 0 0-4-4H109.5a4 4 0 0 0-4 4v40.44a4.34 4.34 0 0 0 4 4" fill="currentColor"></path><path d="M172.9 178.57H218a4.16 4.16 0 0 0 4-4v-40.48a4 4 0 0 0-4-4h-45.1a4 4 0 0 0-4 4v40.44a4 4 0 0 0 4 4" fill="currentColor"></path><path d="M235.36 178.57h45.12a4.16 4.16 0 0 0 4-4v-40.48a4.16 4.16 0 0 0-4-4h-45.12a4 4 0 0 0-4 4v40.44a4.16 4.16 0 0 0 4 4" fill="currentColor"></path><path d="M235.36 120.53h45.12a4 4 0 0 0 4-4V76a4.16 4.16 0 0 0-4-4h-45.12a4 4 0 0 0-4 4v40.44a4.17 4.17 0 0 0 4 4" fill="currentColor"></path><path d="M298.28 236.37h45.12a4 4 0 0 0 4-4v-40.48a4 4 0 0 0-4-4h-45.12a4 4 0 0 0-4 4v40.44a4.16 4.16 0 0 0 4 4" fill="currentColor"></path>', 10);

    const _hoisted_12 = [_hoisted_2$9i];
    vue.defineComponent({
      name: 'LogoDocker',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9i, _hoisted_12);
      }
    });

    const _hoisted_1$9h = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9h = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 32C132.33 32 32 132.33 32 256s100.33 224 224 224s224-100.22 224-224S379.67 32 256 32zm142.22 103.25a186.36 186.36 0 0 1 44 108.38c-40.37-2.1-88.67-2.1-127.4 1.52c-4.9-12.37-9.92-24.5-15.4-36.17c44.66-19.36 79.08-44.8 98.8-73.73zM256 69.33a185.81 185.81 0 0 1 119.12 42.94c-20.3 25.66-52.15 48-91.82 64.86C261.6 137 236.63 102.47 210 75.28a187.51 187.51 0 0 1 46-5.95zm-84.47 20.42c26.95 26.83 52.27 61 74.44 101C203.85 203.62 155.55 211 104 211c-9.8 0-19.36-.35-28.81-.94a186.78 186.78 0 0 1 96.34-120.31zM69.68 247.13c10.62.47 21.35.7 32.2.59c58.8-.7 113.52-9.92 160.54-25q6.65 13.83 12.6 28.35a115.43 115.43 0 0 0-16.69 5c-64.28 27-114.91 70.51-142.33 123.13A186 186 0 0 1 69.33 256c0-3 .12-5.95.35-8.87zM256 442.67a185.57 185.57 0 0 1-114.45-39.32c24.85-49.23 69.18-90 125.07-115.27c5.25-2.45 12.25-4.43 20.3-6.18q10 27.64 17.85 57.4A678 678 0 0 1 322 430.42a185.06 185.06 0 0 1-66 12.25zm100.92-29.75a672.61 672.61 0 0 0-17.39-92.05c-4-15.17-8.51-29.87-13.41-44.22c36.63-3 80.5-2.57 115.38 0a186.5 186.5 0 0 1-84.58 136.27z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$82 = [_hoisted_2$9h];
    vue.defineComponent({
      name: 'LogoDribbble',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9h, _hoisted_3$82);
      }
    });

    const _hoisted_1$9g = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9g = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256.32 126.24l-120.16 78.25l120.16 78.24L136.16 361L16 282.08l120.16-78.24L16 126.24L136.16 48zm-120.8 259.52l120.16-78.25l120.16 78.25L255.68 464zm120.8-103.68l120.16-78.24l-120.16-77.6L375.84 48L496 126.24l-120.16 78.25L496 282.73L375.84 361z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$81 = [_hoisted_2$9g];
    vue.defineComponent({
      name: 'LogoDropbox',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9g, _hoisted_3$81);
      }
    });

    const _hoisted_1$9f = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9f = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M255.5 15c-132 0-240 108-240 240s108 240 240 240c85.4 0 160.8-45.2 203.3-112.9a6.87 6.87 0 0 0-9.1-9.7a108.64 108.64 0 0 1-18.4 8.6c-36.8 12.6-57.1 13.1-82.1 12c-27.9-1.2-61.9-10.8-85.8-25s-43.5-34.6-54.1-52.3s-17-39.9-14.1-68.3c2.9-29 29.4-52.6 60.4-52.6c33.5 0 60.8 26.6 60.8 60.1c0 17-8.1 31.7-18.5 43.5c-2.3 2.1-7.6 9.7 5.8 20c15.9 12.2 51.6 18 79.9 16.6s59.1-12.6 80.2-34.8c16.8-17.7 31.8-46.1 31.8-77.4C495.5 97.7 379.5 15 255.5 15z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$80 = [_hoisted_2$9f];
    vue.defineComponent({
      name: 'LogoEdge',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9f, _hoisted_3$80);
      }
    });

    const _hoisted_1$9e = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9e = /*#__PURE__*/vue.createStaticVNode('<path d="M86.76 255a9.89 9.89 0 0 0 4.87-1.29a9.82 9.82 0 0 0 3.65-13.43c-16.46-28.56-17.81-52.12-7.45-70c14.26-24.57 53.61-33.65 105.27-24.29a9.86 9.86 0 0 0 11.45-7.9a9.84 9.84 0 0 0-7.93-11.44c-29.19-5.28-56-5.18-77.39.3c-22.3 5.71-39 17.28-48.45 33.48c-14 24.19-12.7 54.73 7.42 89.62a9.85 9.85 0 0 0 8.56 4.95z" fill="currentColor"></path><path d="M361.61 143.73c32.24.42 52.61 9.31 62.79 26.86c14.21 24.48 2.52 62.81-31.27 102.52a9.82 9.82 0 0 0 7.51 16.18a9.88 9.88 0 0 0 7.52-3.46c19.12-22.47 32.35-45.54 38.25-66.71c6.14-22 4.43-42.21-5-58.38c-13.8-23.78-40.13-36.15-79.59-36.67h-.14a9.83 9.83 0 0 0-.12 19.66z" fill="currentColor"></path><path d="M326.47 414.89a9.88 9.88 0 0 0-13.5 3.35c-16.41 27.15-36.57 42.1-56.77 42.1c-28.49 0-56-29.31-73.73-78.42a9.87 9.87 0 0 0-12.59-5.92a9.83 9.83 0 0 0-6 12.58c10 27.77 23.47 50.75 39 66.46c16.11 16.34 34.55 25 53.32 25c27.38 0 53.54-18.33 73.65-51.61a9.81 9.81 0 0 0-3.38-13.5z" fill="currentColor"></path><path d="M431.7 338.54a32.14 32.14 0 0 0-29.9 44.33c-41.8 19.5-119.8 4.79-191.87-36.62c-32.91-18.9-62.16-41.86-84.6-66.39a9.9 9.9 0 0 0-13.91-.65a9.8 9.8 0 0 0-.65 13.9c23.79 26 54.68 50.28 89.33 70.18c40.28 23.13 82.27 38.63 121.43 44.81a225.54 225.54 0 0 0 35 2.91c23.12 0 43-4.3 58.51-12.79a32.2 32.2 0 1 0 16.7-59.68zm0 44.66a12.6 12.6 0 0 1-7.82-2.72a10 10 0 0 0-2.2-2.21a12.61 12.61 0 1 1 10 4.93z" fill="currentColor"></path><path d="M82.09 338.59c.57-21.26 12.41-47 33.68-73.16c23.19-28.45 56.69-56 94.34-77.65c33.25-19.1 65.2-31.9 98.07-38.91a9.83 9.83 0 1 0-4.12-19.22c-34.85 7.43-68.78 21-103.79 41.09C116.09 219.09 59.9 289.88 62.46 343.9a32.32 32.32 0 1 0 19.63-5.31zM80.3 383.2a12.5 12.5 0 1 1 12.59-12.5a12.56 12.56 0 0 1-12.59 12.5z" fill="currentColor"></path><path d="M256.2 96.32a32.23 32.23 0 0 0 26.53-13.81c17.89 11.69 34 35 45.81 66.12c13 34.39 19.84 75.38 19.84 118.54c0 37.18-5.19 72.35-15 103.6a9.72 9.72 0 0 0 .66 7.49a9.82 9.82 0 0 0 5.8 4.84a9.89 9.89 0 0 0 12.34-6.44c10.42-33.14 15.93-70.34 15.93-109.49c0-47.17-7.77-91.77-22.47-129c-14.41-36.48-34.13-62.4-57.14-75.16a32.3 32.3 0 1 0-32.3 33.31zm0-44.66a12.5 12.5 0 1 1-12.59 12.5a12.56 12.56 0 0 1 12.59-12.5z" fill="currentColor"></path><path d="M251 243.36a24.35 24.35 0 0 0 5.16 48.16a24.68 24.68 0 0 0 5.16-.55A24.36 24.36 0 1 0 251 243.36z" fill="currentColor"></path>', 7);

    const _hoisted_9$6 = [_hoisted_2$9e];
    vue.defineComponent({
      name: 'LogoElectron',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9e, _hoisted_9$6);
      }
    });

    const _hoisted_1$9d = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9d = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M231.8 272v-48H376l8-48H231.8v-8.12c0-38.69 16.47-62.56 87.18-62.56c28.89 0 61.45 2.69 102.5 9.42l10.52-70A508.54 508.54 0 0 0 315.46 32C189.26 32 135 76.4 135 158.46V176H80v48h55v48H80v48h55v33.54C135 435.6 189.23 480 315.43 480a507.76 507.76 0 0 0 116.44-12.78l-10.58-70c-41.05 6.73-73.46 9.42-102.35 9.42c-70.7 0-87.14-20.18-87.14-67.94V320h128.47l7.87-48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7$ = [_hoisted_2$9d];
    vue.defineComponent({
      name: 'LogoEuro',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9d, _hoisted_3$7$);
      }
    });

    const _hoisted_1$9c = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9c = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 257.35c0-123.7-100.3-224-224-224s-224 100.3-224 224c0 111.8 81.9 204.47 189 221.29V322.12h-56.89v-64.77H221V208c0-56.13 33.45-87.16 84.61-87.16c24.51 0 50.15 4.38 50.15 4.38v55.13H327.5c-27.81 0-36.51 17.26-36.51 35v42h62.12l-9.92 64.77H291v156.54c107.1-16.81 189-109.48 189-221.31z',
      'fill-rule': 'evenodd',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7_ = [_hoisted_2$9c];
    vue.defineComponent({
      name: 'LogoFacebook',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9c, _hoisted_3$7_);
      }
    });

    const _hoisted_1$9b = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9b = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 176a80 80 0 0 0 0-160H176a80 80 0 0 0 0 160a80 80 0 0 0 0 160a80 80 0 1 0 80 80V176z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7Z = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '336',
      cy: '256',
      r: '80',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4O = [_hoisted_2$9b, _hoisted_3$7Z];
    vue.defineComponent({
      name: 'LogoFigma',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9b, _hoisted_4$4O);
      }
    });

    const _hoisted_1$9a = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9a = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M93.19 329.38l47.45-304.07c1.64-10.37 15.55-12.82 20.46-3.55l51 95.45zM432 400l-46.74-276.79a11 11 0 0 0-18.54-6L80 400l159.36 91.91a33.18 33.18 0 0 0 31.91 0zM302.36 158.93l-36.54-69.54a10.86 10.86 0 0 0-19.36 0L85.83 375.74z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7Y = [_hoisted_2$9a];
    vue.defineComponent({
      name: 'LogoFirebase',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9a, _hoisted_3$7Y);
      }
    });

    const _hoisted_1$99 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$99 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M471.46 194.62v-.07c-.22-.76-.45-1.52-.68-2.28c-.05-.19-.11-.38-.17-.56c-.43-1.44-.87-2.88-1.33-4.31l-.06-.2a223.24 223.24 0 0 0-10-25.56a191.77 191.77 0 0 0-12.9-23.8a225.15 225.15 0 0 0-74.74-73.74A222.9 222.9 0 0 0 256 32c-7 0-14 .34-20.82 1c-24.12 2.54-64.78 11.21-97.77 40.18C257.5 11.86 417.94 85.7 404.29 223c-4.86 49-46.46 82.67-85.19 88.35a73.73 73.73 0 0 1-20.8.21c-94.59-13.15-88.8-90.68-60.06-123.83c-38-.24-67.47 46.79-53.15 93c-32.95-61.18.35-157 70.93-186c-82.95-12-160.71 28.2-185.7 98.07A330.23 330.23 0 0 1 88.07 118s-45.22 35.74-54.44 110.9c-.14 1.16-.27 2.32-.39 3.49c-.05.4-.09.8-.13 1.21q-.53 5.25-.8 10.57v.81c-.07 1.48-.13 3-.17 4.46v1.25c0 1.76-.07 3.52-.07 5.29c0 123.71 100.29 224 224 224S480 379.71 480 256a224 224 0 0 0-8.54-61.38z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7X = [_hoisted_2$99];
    vue.defineComponent({
      name: 'LogoFirefox',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$99, _hoisted_3$7X);
      }
    });

    const _hoisted_1$98 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$98 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 32C132.8 32 32 132.8 32 256s100.8 224 224 224s224-100.8 224-224S379.2 32 256 32zm-82.16 280A56 56 0 1 1 228 257.84A56 56 0 0 1 173.84 312zm168 0A56 56 0 1 1 396 257.84A56 56 0 0 1 341.84 312z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7W = [_hoisted_2$98];
    vue.defineComponent({
      name: 'LogoFlickr',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$98, _hoisted_3$7W);
      }
    });

    const _hoisted_1$97 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$97 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M376.76 32H138.54C105.67 32 96 56.8 96 72.41v379.64c0 17.59 9.42 24.12 14.72 26.27s19.91 4 28.67-6.17c0 0 112.47-130.89 114.4-132.83c2.92-2.93 2.92-2.93 5.84-2.93h72.77c30.58 0 35.49-21.87 38.69-34.75c2.65-10.79 32.48-164 42.45-212.56C421.14 52 411.74 32 376.76 32zm-5.67 269.64c2.65-10.79 32.48-164 42.45-212.56m-50.85 7.59l-10 51.73c-1.19 5.65-8.28 11.6-14.86 11.6h-95.92c-10.44 0-17.91 6.14-17.91 16.6v13.45c0 10.47 7.52 17.89 18 17.89h81.85c7.38 0 14.61 8.11 13 16s-9.09 46.57-10 50.89s-5.84 11.72-14.61 11.72H248c-11.7 0-15.24 1.54-23.07 11.3s-78.26 94.59-78.26 94.59c-.71.82-1.41.58-1.41-.31V95.9c0-6.69 5.8-14.53 14.48-14.53h191.14a12.42 12.42 0 0 1 11.81 15.3z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7V = [_hoisted_2$97];
    vue.defineComponent({
      name: 'LogoFoursquare',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$97, _hoisted_3$7V);
      }
    });

    const _hoisted_1$96 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$96 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 32C132.3 32 32 134.9 32 261.7c0 101.5 64.2 187.5 153.2 217.9a17.56 17.56 0 0 0 3.8.4c8.3 0 11.5-6.1 11.5-11.4c0-5.5-.2-19.9-.3-39.1a102.4 102.4 0 0 1-22.6 2.7c-43.1 0-52.9-33.5-52.9-33.5c-10.2-26.5-24.9-33.6-24.9-33.6c-19.5-13.7-.1-14.1 1.4-14.1h.1c22.5 2 34.3 23.8 34.3 23.8c11.2 19.6 26.2 25.1 39.6 25.1a63 63 0 0 0 25.6-6c2-14.8 7.8-24.9 14.2-30.7c-49.7-5.8-102-25.5-102-113.5c0-25.1 8.7-45.6 23-61.6c-2.3-5.8-10-29.2 2.2-60.8a18.64 18.64 0 0 1 5-.5c8.1 0 26.4 3.1 56.6 24.1a208.21 208.21 0 0 1 112.2 0c30.2-21 48.5-24.1 56.6-24.1a18.64 18.64 0 0 1 5 .5c12.2 31.6 4.5 55 2.2 60.8c14.3 16.1 23 36.6 23 61.6c0 88.2-52.4 107.6-102.3 113.3c8 7.1 15.2 21.1 15.2 42.5c0 30.7-.3 55.5-.3 63c0 5.4 3.1 11.5 11.4 11.5a19.35 19.35 0 0 0 4-.4C415.9 449.2 480 363.1 480 261.7C480 134.9 379.7 32 256 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7U = [_hoisted_2$96];
    vue.defineComponent({
      name: 'LogoGithub',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$96, _hoisted_3$7U);
      }
    });

    const _hoisted_1$95 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$95 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M494.07 281.6l-25.18-78.08a11 11 0 0 0-.61-2.1l-50.5-156.94a20.08 20.08 0 0 0-19.17-13.82a19.77 19.77 0 0 0-18.95 13.94l-48.14 149.55h-152L131.34 44.59a19.76 19.76 0 0 0-18.86-13.94h-.11a20.15 20.15 0 0 0-19.12 14L42.7 201.73c0 .14-.11.26-.16.4l-25.63 79.48a29.15 29.15 0 0 0 10.44 32.46l221.44 162.41a11.25 11.25 0 0 0 13.38-.07l221.48-162.34a29.13 29.13 0 0 0 10.42-32.47m-331-64.51l61.73 191.76L76.63 217.09m209.64 191.8l59.19-183.84l2.55-8h86.52L300.47 390.44M398.8 59.31l43.37 134.83h-86.82M324.16 217l-43 133.58l-25.66 79.56L186.94 217M112.27 59.31l43.46 134.83H69M40.68 295.58a6.19 6.19 0 0 1-2.21-6.9l19-59l139.61 180.59m273.26-114.69L313.92 410.22l.52-.69L453.5 229.64l19 59a6.2 6.2 0 0 1-2.19 6.92',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7T = [_hoisted_2$95];
    vue.defineComponent({
      name: 'LogoGitlab',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$95, _hoisted_3$7T);
      }
    });

    const _hoisted_1$94 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$94 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M473.16 221.48l-2.26-9.59H262.46v88.22H387c-12.93 61.4-72.93 93.72-121.94 93.72c-35.66 0-73.25-15-98.13-39.11a140.08 140.08 0 0 1-41.8-98.88c0-37.16 16.7-74.33 41-98.78s61-38.13 97.49-38.13c41.79 0 71.74 22.19 82.94 32.31l62.69-62.36C390.86 72.72 340.34 32 261.6 32c-60.75 0-119 23.27-161.58 65.71C58 139.5 36.25 199.93 36.25 256s20.58 113.48 61.3 155.6c43.51 44.92 105.13 68.4 168.58 68.4c57.73 0 112.45-22.62 151.45-63.66c38.34-40.4 58.17-96.3 58.17-154.9c0-24.67-2.48-39.32-2.59-39.96z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7S = [_hoisted_2$94];
    vue.defineComponent({
      name: 'LogoGoogle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$94, _hoisted_3$7S);
      }
    });

    const _hoisted_1$93 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$93 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 59.49v393a4.33 4.33 0 0 0 7.37 3.07L260 256L55.37 56.42A4.33 4.33 0 0 0 48 59.49z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7R = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M345.8 174L89.22 32.64l-.16-.09c-4.42-2.4-8.62 3.58-5 7.06l201.13 192.32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4N = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M84.08 472.39c-3.64 3.48.56 9.46 5 7.06l.16-.09L345.8 338l-60.61-57.95z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2f = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M449.38 231l-71.65-39.46L310.36 256l67.37 64.43L449.38 281c19.49-10.77 19.49-39.23 0-50z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$15 = [_hoisted_2$93, _hoisted_3$7R, _hoisted_4$4N, _hoisted_5$2f];
    vue.defineComponent({
      name: 'LogoGooglePlaystore',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$93, _hoisted_6$15);
      }
    });

    const _hoisted_1$92 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$92 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M32 32v448h448V32zm249.67 250.83v84H235v-84l-77-140h55l46.32 97.54l44.33-97.54h52.73z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7Q = [_hoisted_2$92];
    vue.defineComponent({
      name: 'LogoHackernews',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$92, _hoisted_3$7Q);
      }
    });

    const _hoisted_1$91 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$91 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M64 32l34.94 403.21L255.77 480L413 435.15L448 32zm308 132H188l4 51h176l-13.51 151.39L256 394.48l-98.68-28l-6.78-77.48h48.26l3.42 39.29L256 343.07l53.42-14.92L315 264H148l-12.59-149.59H376.2z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7P = [_hoisted_2$91];
    vue.defineComponent({
      name: 'LogoHtml5',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$91, _hoisted_3$7P);
      }
    });

    const _hoisted_1$90 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$90 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M349.33 69.33a93.62 93.62 0 0 1 93.34 93.34v186.66a93.62 93.62 0 0 1-93.34 93.34H162.67a93.62 93.62 0 0 1-93.34-93.34V162.67a93.62 93.62 0 0 1 93.34-93.34h186.66m0-37.33H162.67C90.8 32 32 90.8 32 162.67v186.66C32 421.2 90.8 480 162.67 480h186.66C421.2 480 480 421.2 480 349.33V162.67C480 90.8 421.2 32 349.33 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7O = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M377.33 162.67a28 28 0 1 1 28-28a27.94 27.94 0 0 1-28 28z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4M = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 181.33A74.67 74.67 0 1 1 181.33 256A74.75 74.75 0 0 1 256 181.33m0-37.33a112 112 0 1 0 112 112a112 112 0 0 0-112-112z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2e = [_hoisted_2$90, _hoisted_3$7O, _hoisted_4$4M];
    vue.defineComponent({
      name: 'LogoInstagram',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$90, _hoisted_5$2e);
      }
    });

    const _hoisted_1$8$ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8$ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 153.9A102.1 102.1 0 1 0 358.1 256A102.23 102.23 0 0 0 256 153.9z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7N = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '402.59',
      cy: '116.45',
      r: '46.52',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4L = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M459.86 163.2l-1.95-4.28l-3.11 3.52a70 70 0 0 1-28.06 19.32l-3 1.1l1.22 2.93A181.43 181.43 0 0 1 439 256c0 100.92-82.1 183-183 183S73 356.92 73 256S155.08 73 256 73a180.94 180.94 0 0 1 78.43 17.7l2.87 1.3l1.25-2.92A70.19 70.19 0 0 1 359.21 62l3.67-2.93l-4.17-2.07A221.61 221.61 0 0 0 256 32C132.49 32 32 132.49 32 256s100.49 224 224 224s224-100.49 224-224a222.19 222.19 0 0 0-20.14-92.8z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2d = [_hoisted_2$8$, _hoisted_3$7N, _hoisted_4$4L];
    vue.defineComponent({
      name: 'LogoIonic',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8$, _hoisted_5$2d);
      }
    });

    const _hoisted_1$8_ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8_ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M468.41 269.19c-2.64-33.39-11.76-58-31.44-57.39a1 1 0 0 0-.92 1.37c5.11 12.59 9.68 36.9 9.17 58.07a1 1 0 0 1-2 .08c-2.19-21.21-7.1-41.19-16.22-59.43a186.69 186.69 0 0 0-348.91 41a4 4 0 0 1-3.33 3.11l-8.65 1.22c-17.2 2.4-26.9 34.9-21.7 72.5s23.5 66.2 40.7 63.8l13.24-1.85a4 4 0 0 1 3.93 1.84a186.71 186.71 0 0 0 339-56.07a4 4 0 0 1 3.68-3.08l4.4-.24c15.15-2.53 21.75-31.23 19.05-64.93zM94.5 270.42a1 1 0 0 1 1.59-1.19c9.63 10 20.25 27.65 23.32 49.86c3.24 23.05-2.24 45.2-9.13 57.87a1 1 0 0 1-1.84-.73c4.07-14.44 5.16-33.83 2.27-54.74c-2.8-20.32-8.71-38.27-16.21-51.07zm178.77 109.79a15.53 15.53 0 0 1-15.41-13.83a15.48 15.48 0 1 1 15.41 13.83zm81.84-4.72a15.37 15.37 0 1 1 14.6-16.2a15.43 15.43 0 0 1-14.6 16.2z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7M = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M165.51 70a.31.31 0 0 1 .1.2c.1.2.2.3.3.5v.1a5.78 5.78 0 0 0 2.3 2.7c2 1.5 5 2.4 8.6 3a63.69 63.69 0 0 0 11.9.5a28.25 28.25 0 0 0 2.9-.2c-.4-.4-.8-.9-1.2-1.3h-1.3a52 52 0 0 1-11.6-.9a19.71 19.71 0 0 1-8.4-3.4a9.24 9.24 0 0 1-1.4-1.4a4.48 4.48 0 0 1 0-2.3c.5-2.3 2.4-4.8 5.5-7.4a57.25 57.25 0 0 1 10.9-7c.9-.4 1.7-.9 2.6-1.3c.1-.1.3-.1.5-.2a24.69 24.69 0 0 0-.2 10.5c2.3 11.9 11.6 20.3 23.2 20.6l4 24.3l12.7-3l-4-23.3c10.8-4.6 16.3-16.1 14-28a25.8 25.8 0 0 0-3.9-9.5c-5.3-.8-15.6-.8-29.2 2.1c1.1-.3 2.1-.7 3.2-1a135.27 135.27 0 0 1 21.5-4.2c.6-.1 1.2-.1 1.8-.2l3.5-.3h.6a61.83 61.83 0 0 1 10.8.3a29 29 0 0 1 6.1 1.4a5.71 5.71 0 0 0-.9 3.2a6.12 6.12 0 0 0 4.3 5.8a25.53 25.53 0 0 1-2.1 2.8a26 26 0 0 1-2.9 2.8c-1.1.9-2.3 1.8-3.5 2.7l-6.5 3.8l-.3 1.5a.35.35 0 0 0 .2-.1l8.4-4.7c1.2-.8 2.4-1.6 3.4-2.4a29.15 29.15 0 0 0 3.2-2.8a29.86 29.86 0 0 0 2.4-2.8l.3-.6a6.14 6.14 0 0 0 5.4-6a6.06 6.06 0 0 0-6.1-6.1a6.81 6.81 0 0 0-2.8.7a24.6 24.6 0 0 0-8.2-2.7a63.48 63.48 0 0 0-15.5-.6a14.92 14.92 0 0 0-2.1.2a13.55 13.55 0 0 1-2 .2a25.15 25.15 0 0 0-18.7-3.7a25.86 25.86 0 0 0-17.8 13c-1.3.5-2.6 1.1-3.8 1.7c-.7.3-1.3.6-2 .9a60.75 60.75 0 0 0-13.9 9.1c-3.1 2.9-4.9 5.7-5.3 8.3a6.14 6.14 0 0 0 .7 4a2.19 2.19 0 0 1 .3.5z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4K = [_hoisted_2$8_, _hoisted_3$7M];
    vue.defineComponent({
      name: 'LogoIonitron',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8_, _hoisted_4$4K);
      }
    });

    const _hoisted_1$8Z = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8Z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M32 32v448h448V32zm240 348c0 43.61-25.76 64.87-63.05 64.87c-33.68 0-53.23-17.44-63.15-38.49l34.28-20.75c6.61 11.73 11.63 21.65 26.06 21.65c12 0 21.86-5.41 21.86-26.46V240h44zm99.35 63.87c-39.09 0-64.35-17.64-76.68-42L329 382c9 14.74 20.75 24.56 41.5 24.56c17.44 0 27.57-7.72 27.57-19.75c0-14.43-10.43-19.54-29.68-28l-10.52-4.52c-30.38-12.92-50.52-29.16-50.52-63.45c0-31.57 24.05-54.63 61.64-54.63c26.77 0 46 8.32 59.85 32.68L396 290c-7.22-12.93-15-18-27.06-18c-12.33 0-20.15 7.82-20.15 18c0 12.63 7.82 17.74 25.86 25.56l10.52 4.51c35.79 15.34 55.94 31 55.94 66.16c.01 37.9-29.76 57.64-69.76 57.64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7L = [_hoisted_2$8Z];
    vue.defineComponent({
      name: 'LogoJavascript',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8Z, _hoisted_3$7L);
      }
    });

    const _hoisted_1$8Y = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8Y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M505.57 234.62c-3.28-3.53-26.82-32.29-39.51-47.79c-6.75-8.24-12.08-14.75-14.32-17.45l-.18-.22l-.2-.21c-5.22-5.83-12.64-12.51-23.78-12.51a39.78 39.78 0 0 0-5.41.44c-.37.05-.75.11-1.15.15c-2.45.27-10.06 1.5-28.14 4.48c-14 2.29-35.11 5.77-38.31 6.07l-.71.06l-.69.13c-10 1.78-16.62 6.22-19.56 13.19c-1.55 3.68-3.22 11.15 2.94 19.86c1.53 2.22 6.83 9.56 15.94 22.17c6.06 8.4 12.87 17.82 18.75 26L259.9 275L150.66 96.05l-.2-.34l-.23-.33l-.44-.65C145.32 88.17 139.76 80 123.7 80c-1.13 0-2.31 0-3.63.11c-4.6.25-21.42 1.57-40.89 3.11c-21.49 1.69-50.9 4-54.72 4.1h-.73l-.79.08c-9.14.89-15.77 4.6-19.7 11c-6.55 10.69-1.42 22.69.26 26.63C6.87 133 37.56 197.7 64.63 254.81c18 37.94 36.58 77.17 38.1 80.65a34.85 34.85 0 0 0 32.94 21.59a46.62 46.62 0 0 0 9.86-1.1h.21l.2-.05c13.86-3.38 57.83-14.54 89.2-22.59c1.9 3.32 3.9 6.83 6 10.44c21.93 38.5 37.9 66.35 43.16 73.46C287 421 295 432 310.06 432c5.46 0 10.46-1.4 15.74-2.89l1.53-.43h.12c10.53-3 150.69-52.16 157.87-55.35l.22-.1c5.44-2.41 13.66-6.05 16.18-15.4c1.65-6.12.18-12.33-4.38-18.46l-.07-.09l-.07-.09c-.85-1.1-4-5.21-8.27-10.9c-9.13-12.07-23.88-31.57-36.84-48.54c17.37-4.5 38.8-10.11 43.38-11.55c11.47-3.43 14.94-10.69 16-14.73c.79-3.15 1.82-11.2-5.9-18.85zm-320 58.19c-17.81 4.17-30.22 7.08-37.89 8.9c-6.67-13.34-19.74-39.65-32.5-65.33c-29.74-59.92-45.1-90.77-53.18-106.9l8.15-.7c13.34-1.15 31.61-2.72 41.78-3.57c16.76 28.26 74.32 125.3 96.3 162.3zM427.58 172zM310.06 416.4zm53.67-56.95c-24.21 8-37.33 12.37-44.42 14.74c-6.3-10.34-20.16-33.52-32.47-54.19l115.7-29.48c5 6.81 14.57 19.72 33.46 44.93c-18.07 6.04-48.2 16.02-72.27 24zm55.87-121.63l-23.76-31.53c13.67-2.39 21.54-3.77 26.15-4.6l12 14.88l11.94 14.82c-8.2 1.99-17.74 4.32-26.33 6.43z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7K = [_hoisted_2$8Y];
    vue.defineComponent({
      name: 'LogoLaravel',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8Y, _hoisted_3$7K);
      }
    });

    const _hoisted_1$8X = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8X = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M444.17 32H70.28C49.85 32 32 46.7 32 66.89v374.72C32 461.91 49.85 480 70.28 480h373.78c20.54 0 35.94-18.21 35.94-38.39V66.89C480.12 46.7 464.6 32 444.17 32zm-273.3 373.43h-64.18V205.88h64.18zM141 175.54h-.46c-20.54 0-33.84-15.29-33.84-34.43c0-19.49 13.65-34.42 34.65-34.42s33.85 14.82 34.31 34.42c-.01 19.14-13.31 34.43-34.66 34.43zm264.43 229.89h-64.18V296.32c0-26.14-9.34-44-32.56-44c-17.74 0-28.24 12-32.91 23.69c-1.75 4.2-2.22 9.92-2.22 15.76v113.66h-64.18V205.88h64.18v27.77c9.34-13.3 23.93-32.44 57.88-32.44c42.13 0 74 27.77 74 87.64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7J = [_hoisted_2$8X];
    vue.defineComponent({
      name: 'LogoLinkedin',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8X, _hoisted_3$7J);
      }
    });

    const _hoisted_1$8W = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8W = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M475 64H37C16.58 64 0 81.38 0 102.77v306.42C0 430.59 16.58 448 37 448h438c20.38 0 37-17.41 37-38.81V102.77C512 81.38 495.42 64 475 64zM288 368h-64V256l-48 64l-48-64v112H64V144h64l48 80l48-80h64zm96 0l-80-112h48.05L352 144h64v112h48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7I = [_hoisted_2$8W];
    vue.defineComponent({
      name: 'LogoMarkdown',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8W, _hoisted_3$7I);
      }
    });

    const _hoisted_1$8V = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8V = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 173.59c0-104.13-68.26-134.65-68.26-134.65C377.3 23.15 318.2 16.5 256.8 16h-1.51c-61.4.5-120.46 7.15-154.88 22.94c0 0-68.27 30.52-68.27 134.65c0 23.85-.46 52.35.29 82.59C34.91 358 51.11 458.37 145.32 483.29c43.43 11.49 80.73 13.89 110.76 12.24c54.47-3 85-19.42 85-19.42l-1.79-39.5s-38.93 12.27-82.64 10.77c-43.31-1.48-89-4.67-96-57.81a108.44 108.44 0 0 1-1-14.9a558.91 558.91 0 0 0 96.39 12.85c32.95 1.51 63.84-1.93 95.22-5.67c60.18-7.18 112.58-44.24 119.16-78.09c10.42-53.34 9.58-130.17 9.58-130.17zm-80.54 134.16h-50V185.38c0-25.8-10.86-38.89-32.58-38.89c-24 0-36.06 15.53-36.06 46.24v67h-49.66v-67c0-30.71-12-46.24-36.06-46.24c-21.72 0-32.58 13.09-32.58 38.89v122.37h-50V181.67q0-38.65 19.75-61.39c13.6-15.15 31.4-22.92 53.51-22.92c25.58 0 44.95 9.82 57.75 29.48L256 147.69l12.45-20.85c12.81-19.66 32.17-29.48 57.75-29.48c22.11 0 39.91 7.77 53.51 22.92q19.79 22.72 19.75 61.39z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7H = [_hoisted_2$8V];
    vue.defineComponent({
      name: 'LogoMastodon',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8V, _hoisted_3$7H);
      }
    });

    const _hoisted_1$8U = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8U = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M28 28v456h456V28H28zm378.83 108.04l-24.46 23.45a7.162 7.162 0 0 0-2.72 6.86v172.28c-.44 2.61.61 5.26 2.72 6.86l23.88 23.45v5.15H286.13v-5.15l24.74-24.02c2.43-2.43 2.43-3.15 2.43-6.86V198.81l-68.79 174.71h-9.3l-80.09-174.71v117.1c-.67 4.92.97 9.88 4.43 13.44l32.18 39.03v5.15h-91.24v-5.15l32.18-39.03c3.44-3.57 4.98-8.56 4.15-13.44V180.5c.38-3.76-1.05-7.48-3.86-10.01l-28.6-34.46v-5.15h88.81l68.65 150.55l60.35-150.55h84.66v5.16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7G = [_hoisted_2$8U];
    vue.defineComponent({
      name: 'LogoMedium',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8U, _hoisted_3$7G);
      }
    });

    const _hoisted_1$8T = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8T = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M31.87 30.58H244.7v212.81H31.87z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7F = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M266.89 30.58H479.7v212.81H266.89z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4J = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M31.87 265.61H244.7v212.8H31.87z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2c = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M266.89 265.61H479.7v212.8H266.89z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$14 = [_hoisted_2$8T, _hoisted_3$7F, _hoisted_4$4J, _hoisted_5$2c];
    vue.defineComponent({
      name: 'LogoMicrosoft',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8T, _hoisted_6$14);
      }
    });

    const _hoisted_1$8S = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8S = /*#__PURE__*/vue.createStaticVNode('<path d="M360 256h16v48h-16z" fill="currentColor"></path><path d="M112 304h129.6l-48-48H112v48z" fill="currentColor"></path><path d="M364.5 60.1a8.79 8.79 0 0 1-1-.6a218.79 218.79 0 0 0-34.4-14.8l-5.4-1.8A223.2 223.2 0 0 0 256 32C132.3 32 32 132.3 32 256a223.71 223.71 0 0 0 115.4 195.8c.4.2.7.5 1.1.7a218.79 218.79 0 0 0 34.4 14.8l5.4 1.8A222.7 222.7 0 0 0 256 480c123.7 0 224-100.3 224-224A223.76 223.76 0 0 0 364.5 60.1zM256 426.4a161.85 161.85 0 0 1-27.2-2.4a170.14 170.14 0 0 1-28.5-7.3c-1.9-.6-3.8-1.2-5.6-1.9a162.39 162.39 0 0 1-19-8.6a170.33 170.33 0 0 1-90.1-150.3c0-37.2 12.4-71.4 32.7-99.4l237.2 237.2c-28.1 20.3-62.3 32.7-99.5 32.7zm137.8-71L156.6 118.2c28-20.2 62.1-32.6 99.4-32.6a162.79 162.79 0 0 1 27.2 2.4a170.14 170.14 0 0 1 28.5 7.3c1.8.6 3.7 1.2 5.6 1.9a162 162 0 0 1 18 8.1a170.25 170.25 0 0 1 91.2 150.8c-.1 37.2-12.5 71.3-32.7 99.3z" fill="currentColor"></path><path d="M352 256h-34l34 34v-34z" fill="currentColor"></path><path d="M384 256h16v48h-16z" fill="currentColor"></path><path d="M360.1 212.7c-8.8-4.1-22-5.7-45.6-5.7h-3.6c-12.7.1-15.9-.1-20-6.1c-2.8-4.2-1-14.8 3.7-21.9a8 8 0 0 0 .4-8.2a8.26 8.26 0 0 0-7-4.3a53.67 53.67 0 0 1-18.3-3.9c-10.6-4.5-15.6-12.1-15.6-23.1c0-25.8 21.8-27.7 22.8-27.7v-16c-12 0-38.8 11-38.8 43.7c0 17.5 9 31 25.7 38a66.58 66.58 0 0 0 12 3.6c-3.3 9.8-3.6 20.9 1.7 28.7c9 13.3 20.3 13.2 33.3 13.1h3.5c26.3 0 34.6 2.3 38.9 4.3c5.7 2.6 6.8 7.5 6.6 15.7v1h16v-1c0-7.1.3-22.8-15.7-30.2z" fill="currentColor"></path><path d="M400 244c0-25.7-3-39.2-9.1-49.6C382.3 180 368.5 172 352 172h-17.4c2.9-8.3 5.4-19.8 3.5-30.9c-3.2-18.8-19.1-30-43.1-30v16c21 0 26.1 9.1 27.4 16.7c2.5 14.5-6.8 32.1-6.9 32.3a8 8 0 0 0 .1 7.9a8.06 8.06 0 0 0 6.9 3.9H352c10.9 0 19.4 4.9 25.1 14.6c3.1 5.3 6.9 13.5 6.9 41.4h16z" fill="currentColor"></path>', 7);

    const _hoisted_9$5 = [_hoisted_2$8S];
    vue.defineComponent({
      name: 'LogoNoSmoking',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8S, _hoisted_9$5);
      }
    });

    const _hoisted_1$8R = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8R = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M429.76 130.07L274.33 36.85a37 37 0 0 0-36.65 0L82.24 130.06A38.2 38.2 0 0 0 64 162.83V349a38.26 38.26 0 0 0 18.24 32.8L123 406.14l.23.13c20.58 10.53 28.46 10.53 37.59 10.53c32.14 0 52.11-20.8 52.11-54.29V182a8.51 8.51 0 0 0-8.42-8.58h-22.38a8.51 8.51 0 0 0-8.42 8.58v180.51a15 15 0 0 1-6.85 13.07c-5.9 3.6-14.47 2.84-24.14-2.15l-39.06-23.51a1.1 1.1 0 0 1-.48-.92V165.46a1.32 1.32 0 0 1 .59-1.06l151.84-93a.82.82 0 0 1 .73 0l151.93 93a1.34 1.34 0 0 1 .55 1.1V349a1.28 1.28 0 0 1-.45 1l-152.06 90.65a1.22 1.22 0 0 1-.8 0l-38.83-23.06a7.8 7.8 0 0 0-7.83-.41l-.34.2c-10.72 6.35-13.6 8-23.54 11.62c-1.62.59-5.43 2-5.76 5.77s3.29 6.45 6.51 8.32l51.9 31.87a35.67 35.67 0 0 0 18.3 5.07h.58a35.87 35.87 0 0 0 17.83-5.07l155.43-93.13A38.37 38.37 0 0 0 448 349V162.83a38.21 38.21 0 0 0-18.24-32.76z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7E = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M307.88 318.05c-37.29 0-45.24-10.42-47.6-27.24a8.43 8.43 0 0 0-8.22-7.32h-19.8a8.44 8.44 0 0 0-8.26 8.58c0 14.58 5.12 62.17 83.92 62.17c24.38 0 44.66-5.7 58.63-16.49S388 311.26 388 292.55c0-37.55-24.5-47.83-72.75-54.55c-49.05-6.82-49.05-10.29-49.05-17.89c0-5.47 0-18.28 35.46-18.28c25.23 0 38.74 3.19 43.06 20a8.35 8.35 0 0 0 8.06 6.67h19.87a8.24 8.24 0 0 0 6.16-2.86a8.91 8.91 0 0 0 2.12-6.44c-2.57-35.55-28.56-53.58-79.24-53.58c-46.06 0-73.55 20.75-73.55 55.5c0 38.1 28.49 48.87 71.29 53.33c50 5.17 50 12.71 50 19.37c.03 10.38-4.28 24.23-41.55 24.23z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4I = [_hoisted_2$8R, _hoisted_3$7E];
    vue.defineComponent({
      name: 'LogoNodejs',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8R, _hoisted_4$4I);
      }
    });

    const _hoisted_1$8Q = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8Q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M227.6 213.1H256v57.1h-28.4z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7D = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M0 156v171.4h142.2V356H256v-28.6h256V156zm142.2 142.9h-28.4v-85.7H85.3v85.7H28.4V184.6h113.8zm142.2 0h-56.9v28.6h-56.9V184.6h113.8zm199.2 0h-28.4v-85.7h-28.4v85.7h-28.4v-85.7H370v85.7h-56.9V184.6h170.7v114.3z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4H = [_hoisted_2$8Q, _hoisted_3$7D];
    vue.defineComponent({
      name: 'LogoNpm',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8Q, _hoisted_4$4H);
      }
    });

    const _hoisted_1$8P = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8P = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M172.86 290.12c-9.75 0-18.11 4.56-24.86 13.87s-10.07 20.58-10.07 34s3.43 24.91 10.07 34.12S163 386 172.86 386c9.1 0 17-4.66 23.68-13.87s10.07-20.58 10.07-34.12s-3.43-24.81-10.07-34s-14.54-13.89-23.68-13.89z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7C = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M340.32 290.12c-9.64 0-18.11 4.56-24.86 13.87s-10.07 20.58-10.07 34s3.43 24.91 10.07 34.12S330.57 386 340.32 386c9.11 0 17-4.66 23.79-13.87s10.07-20.58 10.07-34.12s-3.43-24.81-10.07-34s-14.57-13.89-23.79-13.89z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4G = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M459.36 165c-.11 0 2.89-15.49.32-42.47c-2.36-27-8-51.78-17.25-74.53c0 0-4.72.87-13.72 3.14S405 58 384.89 67.18c-19.82 9.2-40.71 21.44-62.46 36.29c-14.79-4.23-36.86-6.39-66.43-6.39c-28.18 0-50.25 2.16-66.43 6.39Q117.9 53.25 69.46 48q-13.81 34.13-17.14 74.75c-2.57 27 .43 42.58.43 42.58C26.71 193.82 16 234.88 16 268.78c0 26.22.75 49.94 6.54 71c6 20.91 13.6 38 22.6 51.14A147.49 147.49 0 0 0 79 425.43c13.39 10.08 25.71 17.34 36.86 21.89c11.25 4.76 24 8.23 38.57 10.72a279.19 279.19 0 0 0 32.68 4.34s30 1.62 69 1.62s68.89-1.62 68.89-1.62a285.25 285.25 0 0 0 32.68-4.38a178.91 178.91 0 0 0 38.46-10.72c11.15-4.66 23.47-11.81 37-21.89a145 145 0 0 0 33.75-34.55c9-13.11 16.6-30.23 22.6-51.14s6.51-44.81 6.51-71.03c0-32.82-10.71-74.42-36.64-103.67zm-70.07 253.07C359.39 432.26 315.46 438 257.18 438h-2.25c-58.29 0-102.22-5.63-131.57-19.93s-44.25-43.45-44.25-87.43c0-26.32 9.21-47.66 27.32-64c7.93-7 17.57-11.92 29.57-14.84s22.93-3 33.21-2.71c10.08.43 24.22 2.38 42.11 3.79s31.39 3.25 44.79 3.25c12.53 0 29.14-2.17 55.82-4.33s46.61-3.25 59.46-1.09c13.18 2.17 24.65 6.72 34.4 15.93q28.44 25.67 28.5 64c-.11 43.98-15.22 73.24-45 87.43z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2b = [_hoisted_2$8P, _hoisted_3$7C, _hoisted_4$4G];
    vue.defineComponent({
      name: 'LogoOctocat',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8P, _hoisted_5$2b);
      }
    });

    const _hoisted_1$8O = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8O = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M424.81 148.79c-.43 2.76-.93 5.58-1.49 8.48c-19.17 98-84.76 131.8-168.54 131.8h-42.65a20.67 20.67 0 0 0-20.47 17.46l-21.84 137.84l-6.18 39.07a10.86 10.86 0 0 0 9.07 12.42a10.72 10.72 0 0 0 1.7.13h75.65a18.18 18.18 0 0 0 18-15.27l.74-3.83l14.24-90l.91-4.94a18.16 18.16 0 0 1 18-15.3h11.31c73.3 0 130.67-29.62 147.44-115.32c7-35.8 3.38-65.69-15.16-86.72a72.27 72.27 0 0 0-20.73-15.82z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7B = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M385.52 51.09C363.84 26.52 324.71 16 274.63 16H129.25a20.75 20.75 0 0 0-20.54 17.48l-60.55 382a12.43 12.43 0 0 0 10.39 14.22a12.58 12.58 0 0 0 1.94.15h89.76l22.54-142.29l-.7 4.46a20.67 20.67 0 0 1 20.47-17.46h42.65c83.77 0 149.36-33.86 168.54-131.8c.57-2.9 1.05-5.72 1.49-8.48c5.7-36.22-.05-60.87-19.72-83.19z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4F = [_hoisted_2$8O, _hoisted_3$7B];
    vue.defineComponent({
      name: 'LogoPaypal',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8O, _hoisted_4$4F);
      }
    });

    const _hoisted_1$8N = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8N = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256.05 32c-123.7 0-224 100.3-224 224c0 91.7 55.2 170.5 134.1 205.2c-.6-15.6-.1-34.4 3.9-51.4c4.3-18.2 28.8-122.1 28.8-122.1s-7.2-14.3-7.2-35.4c0-33.2 19.2-58 43.2-58c20.4 0 30.2 15.3 30.2 33.6c0 20.5-13.1 51.1-19.8 79.5c-5.6 23.8 11.9 43.1 35.4 43.1c42.4 0 71-54.5 71-119.1c0-49.1-33.1-85.8-93.2-85.8c-67.9 0-110.3 50.7-110.3 107.3c0 19.5 5.8 33.3 14.8 43.9c4.1 4.9 4.7 6.9 3.2 12.5c-1.1 4.1-3.5 14-4.6 18c-1.5 5.7-6.1 7.7-11.2 5.6c-31.3-12.8-45.9-47-45.9-85.6c0-63.6 53.7-139.9 160.1-139.9c85.5 0 141.8 61.9 141.8 128.3c0 87.9-48.9 153.5-120.9 153.5c-24.2 0-46.9-13.1-54.7-27.9c0 0-13 51.6-15.8 61.6c-4.7 17.3-14 34.5-22.5 48a225.13 225.13 0 0 0 63.5 9.2c123.7 0 224-100.3 224-224S379.75 32 256.05 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7A = [_hoisted_2$8N];
    vue.defineComponent({
      name: 'LogoPinterest',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8N, _hoisted_3$7A);
      }
    });

    const _hoisted_1$8M = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8M = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M399.77 203c-.8-17.1-3.3-34.5-10.8-50.1a82.45 82.45 0 0 0-16.5-23.2a105.59 105.59 0 0 0-21.3-16.3c-17.1-10.2-37.5-17-84.4-31S192 64 192 64v358.3l79.9 25.7s.1-198.8.1-299.5v-3.8c0-9.3 7.5-16.8 16.1-16.8h.5c8.5 0 15.5 7.5 15.5 16.8V278c11 5.3 29.2 9.3 41.8 9.1a47.79 47.79 0 0 0 24-5.7a49.11 49.11 0 0 0 18.4-17.8a78.64 78.64 0 0 0 9.9-27.3c1.87-10.8 1.97-22.1 1.57-33.3z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M86.67 357.8c27.4-9.8 89.3-29.5 89.3-29.5v-47.2s-76.5 24.8-111.3 37.1c-8.6 3.1-17.3 5.9-25.7 9.5c-9.8 4.1-19.4 8.7-28.1 14.8a26.29 26.29 0 0 0-9.2 10.1a17.36 17.36 0 0 0-.5 13.6c2 5.1 5.8 9.3 10.1 12.6c7.8 5.9 17.1 9.5 26.4 12.2a262.42 262.42 0 0 0 88.4 13.3c14.5-.2 36-1.9 50-4.4v-42s-11 2.5-41.3 12.5c-4.6 1.5-9.2 3.3-14 4.3a104.87 104.87 0 0 1-21.6 2.2c-6.5-.3-13.2-.7-19.3-3.1c-2.2-1-4.6-2.2-5.5-4.6c-.8-2 .3-4 1.7-5.4c2.8-2.9 6.8-4.5 10.6-6z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4E = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M512 345.9c-.1-6-3.7-11.2-7.9-15c-7.1-6.3-15.9-10.3-24.7-13.5c-5.5-1.9-9.3-3.3-14.7-5c-25.2-8.2-51.9-11.2-78.3-11.3c-8 .3-23.1.5-31 1.4c-21.9 2.5-67.3 15.4-67.3 15.4v48.8s67.5-21.6 96.5-31.8a94.43 94.43 0 0 1 30.3-4.6c6.5.2 13.2.7 19.4 3.1c2.2.9 4.5 2.2 5.5 4.5c.9 2.6-.9 5-2.9 6.5c-4.7 3.8-10.7 5.3-16.2 7.4c-41 14.5-132.7 44.7-132.7 44.7v47s117.2-39.6 170.8-58.8c8.9-3.3 17.9-6.1 26.4-10.4c7.9-4 15.8-8.6 21.8-15.3a19.74 19.74 0 0 0 5-13.1z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2a = [_hoisted_2$8M, _hoisted_3$7z, _hoisted_4$4E];
    vue.defineComponent({
      name: 'LogoPlaystation',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8M, _hoisted_5$2a);
      }
    });

    const _hoisted_1$8L = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8L = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M330.7 352l77.72-192H356.9l-53.16 124.07L265.93 160h-39.61l-40.58 124.07l-28.63-56.53l-25.9 79.46l26.3 45h50.7l36.68-111.27l35 111.27z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48.79 286.09h31.65a93.39 93.39 0 0 0 25.62-3.21l8.18-25.19l22.88-70.39a55.75 55.75 0 0 0-6-7.82Q113.54 160 79.59 160H0v192h48.79zm41.9-81.92q6.89 6.92 6.88 18.52t-6 18.53q-6.64 7.62-24.44 7.61H48.79v-51.58h18.42q16.59 0 23.48 6.92zm286.16 113.44l14.79-37.25h42.69l-20.26-56.51L439.41 160L512 352h-53.53l-12.4-34.39z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4D = [_hoisted_2$8L, _hoisted_3$7y];
    vue.defineComponent({
      name: 'LogoPwa',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8L, _hoisted_4$4D);
      }
    });

    const _hoisted_1$8K = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8K = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M314 36.38c-18.59-3.06-45.8-4.47-64.27-4.38a311.09 311.09 0 0 0-51.66 4.38c-45.74 8-54.07 24.7-54.07 55.54V128h112v16H107.62C66.06 144 32.33 193.67 32 255.12v.88a162.91 162.91 0 0 0 3.13 32c9.29 46.28 38.23 80 72.49 80H128v-54c0-31.3 20.84-59.95 55-66.1l9.87-1.23H314a56.05 56.05 0 0 0 15.06-2A52.48 52.48 0 0 0 368 193.68V91.92c0-28.92-24.68-50.73-54-55.54zM194.93 105.5a20.37 20.37 0 1 1 20.3-20.3a20.29 20.29 0 0 1-20.3 20.3z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7x = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M475.28 217c-10.7-42.61-38.41-73-70.9-73h-17.71v47.45c0 39.57-26 68.22-57.74 73.13a63.54 63.54 0 0 1-9.69.75H198.08a60 60 0 0 0-15.23 1.95C160.54 273.14 144 291.7 144 315.77v101.77c0 29 29.14 46 57.73 54.31c34.21 9.95 71.48 11.75 112.42 0c27.19-7.77 53.85-23.48 53.85-54.31V384H256v-16h148.38c29.44 0 54.95-24.93 67.45-61.31A156.83 156.83 0 0 0 480 256a160.64 160.64 0 0 0-4.72-39zM316.51 404a20.37 20.37 0 1 1-20.3 20.3a20.29 20.29 0 0 1 20.3-20.3z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4C = [_hoisted_2$8K, _hoisted_3$7x];
    vue.defineComponent({
      name: 'LogoPython',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8K, _hoisted_4$4C);
      }
    });

    const _hoisted_1$8J = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8J = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M410.66 180.72q-7.67-2.62-15.45-4.88q1.29-5.25 2.38-10.56c11.7-56.9 4.05-102.74-22.06-117.83c-25-14.48-66 .61-107.36 36.69q-6.1 5.34-11.95 11q-3.9-3.76-8-7.36c-43.35-38.58-86.8-54.83-112.88-39.69c-25 14.51-32.43 57.6-21.9 111.53q1.58 8 3.55 15.93a320.85 320.85 0 0 0-17.77 5.6C48.46 198.9 16 226.73 16 255.59c0 29.82 34.84 59.72 87.77 77.85q6.44 2.19 13 4.07q-2.13 8.49-3.77 17.17c-10 53-2.2 95.07 22.75 109.49c25.77 14.89 69-.41 111.14-37.31q5-4.38 10-9.25q6.32 6.11 13 11.86c40.8 35.18 81.09 49.39 106 34.93c25.75-14.94 34.12-60.14 23.25-115.13q-1.25-6.3-2.88-12.86q4.56-1.35 8.93-2.79c55-18.27 90.83-47.81 90.83-78c-.02-29-33.52-57.01-85.36-74.9zm-129-81.08c35.43-30.91 68.55-43.11 83.65-34.39c16.07 9.29 22.32 46.75 12.22 95.88q-1 4.8-2.16 9.57a487.83 487.83 0 0 0-64.18-10.16a481.27 481.27 0 0 0-40.57-50.75q5.38-5.22 11.02-10.15zM157.73 280.25q6.51 12.6 13.61 24.89q7.23 12.54 15.07 24.71a435.28 435.28 0 0 1-44.24-7.13c4.24-13.72 9.46-27.97 15.56-42.47zm0-48.33c-6-14.19-11.08-28.15-15.25-41.63c13.7-3.07 28.3-5.58 43.52-7.48q-7.65 11.94-14.72 24.23t-13.58 24.88zm10.9 24.17q9.48-19.77 20.42-38.78q10.93-19 23.27-37.13c14.28-1.08 28.92-1.65 43.71-1.65s29.52.57 43.79 1.66q12.21 18.09 23.13 37t20.69 38.6Q334 275.63 323 294.73q-10.91 19-23 37.24c-14.25 1-29 1.55-44 1.55s-29.47-.47-43.46-1.38q-12.43-18.19-23.46-37.29t-20.48-38.76zM340.75 305q7.25-12.58 13.92-25.49a440.41 440.41 0 0 1 16.12 42.32a434.44 434.44 0 0 1-44.79 7.65q7.62-12.09 14.75-24.48zm13.72-73.07q-6.64-12.65-13.81-25q-7-12.18-14.59-24.06c15.31 1.94 30 4.52 43.77 7.67a439.89 439.89 0 0 1-15.37 41.39zm-98.24-107.45a439.75 439.75 0 0 1 28.25 34.18q-28.35-1.35-56.74 0c9.33-12.34 18.88-23.79 28.49-34.18zM145.66 65.86c16.06-9.32 51.57 4 89 37.27c2.39 2.13 4.8 4.36 7.2 6.67A491.37 491.37 0 0 0 201 160.51a499.12 499.12 0 0 0-64.06 10q-1.83-7.36-3.3-14.82c-9.05-46.23-3.06-81.08 12.02-89.83zm-23.41 251.85q-6-1.71-11.85-3.71c-23.4-8-42.73-18.44-56-29.81c-11.88-10.19-17.9-20.36-17.9-28.6c0-17.51 26.06-39.85 69.52-55q8.19-2.85 16.52-5.21a493.54 493.54 0 0 0 23.4 60.75a502.46 502.46 0 0 0-23.69 61.58zm111.13 93.67c-18.63 16.32-37.29 27.89-53.74 33.72c-14.78 5.23-26.55 5.38-33.66 1.27c-15.14-8.75-21.44-42.54-12.85-87.86q1.53-8 3.5-16a480.85 480.85 0 0 0 64.69 9.39a501.2 501.2 0 0 0 41.2 51c-2.98 2.93-6.03 5.75-9.14 8.48zm23.42-23.22c-9.72-10.51-19.42-22.14-28.88-34.64q13.79.54 28.08.54c9.78 0 19.46-.21 29-.64a439.33 439.33 0 0 1-28.2 34.74zm124.52 28.59c-2.86 15.44-8.61 25.74-15.72 29.86c-15.13 8.78-47.48-2.63-82.36-32.72c-4-3.44-8-7.13-12.07-11a484.54 484.54 0 0 0 40.23-51.2a477.84 477.84 0 0 0 65-10.05q1.47 5.94 2.6 11.64c4.81 24.3 5.5 46.28 2.32 63.47zm17.4-102.64c-2.62.87-5.32 1.71-8.06 2.53a483.26 483.26 0 0 0-24.31-60.94a481.52 481.52 0 0 0 23.36-60.06c4.91 1.43 9.68 2.93 14.27 4.52c44.42 15.32 71.52 38 71.52 55.43c0 18.6-29.27 42.74-76.78 58.52z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7w = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 298.55a43 43 0 1 0-42.86-43a42.91 42.91 0 0 0 42.86 43z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4B = [_hoisted_2$8J, _hoisted_3$7w];
    vue.defineComponent({
      name: 'LogoReact',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8J, _hoisted_4$4B);
      }
    });

    const _hoisted_1$8I = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8I = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M324 256a36 36 0 1 0 36 36a36 36 0 0 0-36-36z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7v = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '188',
      cy: '292',
      r: '36',
      transform: 'rotate(-22.5 187.997 291.992)',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4A = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M496 253.77c0-31.19-25.14-56.56-56-56.56a55.72 55.72 0 0 0-35.61 12.86c-35-23.77-80.78-38.32-129.65-41.27l22-79l66.41 13.2c1.9 26.48 24 47.49 50.65 47.49c28 0 50.78-23 50.78-51.21S441 48 413 48c-19.53 0-36.31 11.19-44.85 28.77l-90-17.89l-31.1 109.52l-4.63.13c-50.63 2.21-98.34 16.93-134.77 41.53A55.38 55.38 0 0 0 72 197.21c-30.89 0-56 25.37-56 56.56a56.43 56.43 0 0 0 28.11 49.06a98.65 98.65 0 0 0-.89 13.34c.11 39.74 22.49 77 63 105C146.36 448.77 199.51 464 256 464s109.76-15.23 149.83-42.89c40.53-28 62.85-65.27 62.85-105.06a109.32 109.32 0 0 0-.84-13.3A56.32 56.32 0 0 0 496 253.77zM414 75a24 24 0 1 1-24 24a24 24 0 0 1 24-24zM42.72 253.77a29.6 29.6 0 0 1 29.42-29.71a29 29 0 0 1 13.62 3.43c-15.5 14.41-26.93 30.41-34.07 47.68a30.23 30.23 0 0 1-8.97-21.4zM390.82 399c-35.74 24.59-83.6 38.14-134.77 38.14S157 423.61 121.29 399c-33-22.79-51.24-52.26-51.24-83A78.5 78.5 0 0 1 75 288.72c5.68-15.74 16.16-30.48 31.15-43.79a155.17 155.17 0 0 1 14.76-11.53l.3-.21l.24-.17c35.72-24.52 83.52-38 134.61-38s98.9 13.51 134.62 38l.23.17l.34.25A156.57 156.57 0 0 1 406 244.92c15 13.32 25.48 28.05 31.16 43.81a85.44 85.44 0 0 1 4.31 17.67a77.29 77.29 0 0 1 .6 9.65c-.01 30.72-18.21 60.19-51.25 82.95zm69.6-123.92c-7.13-17.28-18.56-33.29-34.07-47.72A29.09 29.09 0 0 1 440 224a29.59 29.59 0 0 1 29.41 29.71a30.07 30.07 0 0 1-8.99 21.39z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$29 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M323.23 362.22c-.25.25-25.56 26.07-67.15 26.27c-42-.2-66.28-25.23-67.31-26.27a4.14 4.14 0 0 0-5.83 0l-13.7 13.47a4.15 4.15 0 0 0 0 5.89c3.4 3.4 34.7 34.23 86.78 34.45c51.94-.22 83.38-31.05 86.78-34.45a4.16 4.16 0 0 0 0-5.9l-13.71-13.47a4.13 4.13 0 0 0-5.81 0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$13 = [_hoisted_2$8I, _hoisted_3$7v, _hoisted_4$4A, _hoisted_5$29];
    vue.defineComponent({
      name: 'LogoReddit',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8I, _hoisted_6$13);
      }
    });

    const _hoisted_1$8H = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8H = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M108.56 342.78a60.34 60.34 0 1 0 60.56 60.44a60.63 60.63 0 0 0-60.56-60.44z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7u = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 186.67v86.55c52 0 101.94 15.39 138.67 52.11s52 86.56 52 138.67h86.66c0-151.56-125.66-277.33-277.33-277.33z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 48v86.56c185.25 0 329.22 144.08 329.22 329.44H464C464 234.66 277.67 48 48 48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$28 = [_hoisted_2$8H, _hoisted_3$7u, _hoisted_4$4z];
    vue.defineComponent({
      name: 'LogoRss',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8H, _hoisted_5$28);
      }
    });

    const _hoisted_1$8G = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8G = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M511.78 328.07c-1.47-11.92-7.51-22.26-18-30.77a3.58 3.58 0 0 0-.43-.44l-.53-.38l-.17-.12l-5.57-4l-.19-.14l-.71-.5a3.5 3.5 0 0 0-.83-.35c-17.62-10.49-46.79-17.84-91.42-2.09c-10.65-17.92-11.86-32.28-4.73-54.28c1.27-3.83.09-6.36-3.71-8c-7.64-3.25-18.1-1.59-25.52.37c-3.46.9-5.54 2.86-6.2 5.83c-4.7 22-18.36 42.1-31.57 61.5l-.78 1.14c-8.14-17.26-6.45-30.63-.78-47.38c1.13-3.34.24-5.56-2.89-7.22c-8.74-4.51-21.85-1.41-27.07.13c-6.62 1.93-13.72 19.82-21.65 41.24c-2 5.39-3.72 10-4.75 12.15c-2.45 5-4.79 10.7-7.27 16.75c-5.6 13.69-11.91 29.1-20.93 38.78c-3.28-7.25 1.88-18.68 6.89-29.77c5.93-13.11 11.53-25.5 5.08-33.41a11.82 11.82 0 0 0-8.33-4.32a13.26 13.26 0 0 0-6.15 1c.67-5.65.7-10.11-.95-15.5c-2.36-7.69-8.49-12-16.93-11.77c-19.22.56-35.48 14.88-45.75 26.8c-6.84 8-22 14.1-35.31 19.45c-5.26 2.23-10.26 4.23-14.43 6.23c-6.65-5.62-15.1-11.29-24-17.28c-25-16.78-53.33-35.81-54.31-61.61c-1.4-38.11 42-65.14 79.88-84.43c28.71-14.6 53.67-24.28 76.31-29.57c31.8-7.43 58.66-5.93 79.82 4.44c11.58 5.67 17 18 13.56 30.68c-9 32.95-46.29 55.53-78.18 65.69c-19.21 6.12-35.56 8.68-50 7.84c-18.1-1.05-32.88-10.13-39.2-14a21.18 21.18 0 0 0-3.2-1.8l-.29-.07a3.21 3.21 0 0 0-3.19 1c-1.3 1.55-.84 4-.37 5.24c6.15 16.07 18.85 26.22 37.74 30.17a92.09 92.09 0 0 0 18.78 1.79c44.21 0 100.62-25.49 121.34-46.48c14.13-14.3 24.42-29 28.68-54.35c4.45-26.55-13.55-45-31.89-53.5c-44.57-20.57-95.19-12.44-129.81-2c-40.5 12.21-82.4 34.41-114.94 60.93c-40.12 32.67-54.62 63-43.12 90.25c11.81 27.93 40.61 45.4 68.46 62.3c9 5.45 17.56 10.64 25.27 16c-2.32 1.13-4.69 2.28-7.1 3.43c-23.38 11.33-49.9 24.08-64.61 45.15c-10.68 15.35-12.68 30.63-5.94 45.42c3.6 7.87 10 13.21 18.89 15.87A50 50 0 0 0 53 432c17.31 0 36.36-7 46.73-13.47c18.32-11.5 30.19-26.94 35.29-45.89c4.54-16.86 3.45-33.61-3.15-48.56l22.45-11.32c-10.83 36-2.53 57.5 6.59 69.36c3.36 4.37 9.42 7 16.19 7.12s13-2.43 16.52-6.77c6.66-8.25 11.58-17.9 16.11-27.55c-.24 6.3.06 12.68 2.21 18.09c1.93 4.87 5.11 8.1 9.21 9.34c4.36 1.33 9.47.21 14.39-3.15c22.17-15.17 37.33-51.58 49.51-80.85c1.73-4.16 3.39-8.16 5-11.9a152.5 152.5 0 0 0 12.5 31.07c1.18 2.14 1.08 3.08-.52 4.84c-2.41 2.64-5.77 5.83-9.33 9.21c-10.78 10.23-24.2 23-26 34.23c-.7 4.5 2.4 8.6 7.21 9.53c14.47 2.88 31.9-1.33 46.64-11.25c13.4-9 18.44-21.55 15-37.19c-3.33-15.06 4.27-33.76 22.59-55.62c3 12.53 7 22.66 12.52 31.53l-.15.12c-13.34 11.65-31.62 27.6-28.78 46.95a13.35 13.35 0 0 0 5.58 9.22a14.22 14.22 0 0 0 11.2 2.06c17.47-3.67 30.62-11.06 40.18-22.57s6.07-24.27 2.85-34.17c25-6.78 47.26-6.61 68.1.5c11.7 4 20.09 10.57 24.93 19.64c6.09 11.41 2.8 21.94-9.29 29.65c-3.71 2.37-5.5 3.82-5.61 5.65a2.65 2.65 0 0 0 1 2.23c1.4 1.15 5.72 3.15 15.49-3c9-5.65 14.28-13.34 15.63-23a39 39 0 0 0-.01-8.01zm-399.73 25.06l-.1 1.28c-1.56 14.64-9 27.4-22.15 38c-8.26 6.66-17.23 10.75-25.25 11.53c-5.6.54-9.67-.22-12.09-2.27c-1.81-1.53-2.78-3.82-3-7c-1.64-25.48 38.32-50.8 60.81-59.13a51.39 51.39 0 0 1 1.78 17.59zm102.35-71.86c-3.7 21.09-14.49 60.9-31.45 76.35c-.81.74-1.49 1-1.8.93s-.55-.44-.8-1c-5.66-13.12-3.57-35.28 5-52.69c6.59-13.42 16-22.31 26.52-25a5.29 5.29 0 0 1 1.34-.19a1.58 1.58 0 0 1 1 .27a1.64 1.64 0 0 1 .19 1.33zm83.49 76.88c-3.19 3.33-7.56 2.88-6.53 1.66l16.24-17.24c-1.31 5.93-5.18 10.84-9.71 15.58zm67.37-14.91a14.07 14.07 0 0 1-4.93 1.39c-.46-9.07 8.33-19.28 17-26.09c2.33 9.46-2.44 19.46-12.07 24.7z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7t = [_hoisted_2$8G];
    vue.defineComponent({
      name: 'LogoSass',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8G, _hoisted_3$7t);
      }
    });

    const _hoisted_1$8F = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8F = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M467.16 303.6a205.69 205.69 0 0 0 4.9-45.15c0-116.32-95.69-210.7-213.79-210.7a221.83 221.83 0 0 0-36.52 3A123.58 123.58 0 0 0 155.93 32C87.55 32 32 86.72 32 154.15A119.56 119.56 0 0 0 49 216a211.16 211.16 0 0 0-4.32 42.35c0 116.44 95.69 210.7 213.67 210.7a214 214 0 0 0 39.09-3.5A125.45 125.45 0 0 0 356.07 480C424.57 480 480 425.28 480 357.85a118 118 0 0 0-12.84-54.25zM368 359c-9.92 13.76-24.51 24.73-43.41 32.43S283.36 403 257.69 403c-30.69 0-56.36-5.37-76.55-15.87a101 101 0 0 1-35.24-30.8c-9.11-12.83-13.66-25.66-13.66-38c0-7.7 3-14.35 8.87-19.95c5.84-5.37 13.42-8.17 22.29-8.17c7.35 0 13.65 2.1 18.79 6.42c4.9 4.08 9.1 10.15 12.48 18.08A108.09 108.09 0 0 0 207 336.15q6.32 8.22 17.86 13.65c7.82 3.62 18.2 5.48 31 5.48c17.62 0 32.09-3.73 42.94-11.08c10.74-7.12 15.88-15.75 15.88-26.25c0-8.28-2.69-14.82-8.29-19.95c-5.83-5.37-13.42-9.57-22.87-12.37c-9.69-3-22.87-6.18-39.21-9.56c-22.17-4.67-41-10.27-56-16.57c-15.28-6.42-27.65-15.4-36.76-26.48c-9.22-11.32-13.77-25.55-13.77-42.24a67.86 67.86 0 0 1 14.47-42.58c9.57-12.25 23.46-21.82 41.55-28.35c17.74-6.53 38.86-9.8 62.66-9.8c19.14 0 35.83 2.22 49.83 6.42s25.91 10.15 35.36 17.38s16.34 14.93 20.77 23s6.66 16.22 6.66 24c0 7.46-2.92 14.35-8.76 20.3a29.65 29.65 0 0 1-21.94 9.1c-7.93 0-14.12-1.87-18.43-5.6c-4-3.5-8.17-8.87-12.72-16.69c-5.37-9.91-11.79-17.85-19.14-23.45c-7.24-5.36-19.14-8.16-35.71-8.16c-15.29 0-27.77 3-37 9c-8.87 5.72-13.19 12.37-13.19 20.18a18.26 18.26 0 0 0 4.32 12.25a38.13 38.13 0 0 0 12.72 9.57a90.14 90.14 0 0 0 17.15 6.53c6 1.64 15.87 4.09 29.53 7.12c17.38 3.62 33.25 7.82 47.26 12.13c14.24 4.55 26.49 10 36.52 16.45a72.93 72.93 0 0 1 24.16 25.09c5.72 10 8.64 22.63 8.64 37.1A75.09 75.09 0 0 1 368 359z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7s = [_hoisted_2$8F];
    vue.defineComponent({
      name: 'LogoSkype',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8F, _hoisted_3$7s);
      }
    });

    const _hoisted_1$8E = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8E = /*#__PURE__*/vue.createStaticVNode('<path d="M126.12 315.1A47.06 47.06 0 1 1 79.06 268h47.06z" fill="currentColor"></path><path d="M149.84 315.1a47.06 47.06 0 0 1 94.12 0v117.84a47.06 47.06 0 1 1-94.12 0z" fill="currentColor"></path><path d="M196.9 126.12A47.06 47.06 0 1 1 244 79.06v47.06z" fill="currentColor"></path><path d="M196.9 149.84a47.06 47.06 0 0 1 0 94.12H79.06a47.06 47.06 0 0 1 0-94.12z" fill="currentColor"></path><path d="M385.88 196.9a47.06 47.06 0 1 1 47.06 47.1h-47.06z" fill="currentColor"></path><path d="M362.16 196.9a47.06 47.06 0 0 1-94.12 0V79.06a47.06 47.06 0 1 1 94.12 0z" fill="currentColor"></path><path d="M315.1 385.88a47.06 47.06 0 1 1-47.1 47.06v-47.06z" fill="currentColor"></path><path d="M315.1 362.16a47.06 47.06 0 0 1 0-94.12h117.84a47.06 47.06 0 1 1 0 94.12z" fill="currentColor"></path>', 8);

    const _hoisted_10$6 = [_hoisted_2$8E];
    vue.defineComponent({
      name: 'LogoSlack',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8E, _hoisted_10$6);
      }
    });

    const _hoisted_1$8D = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8D = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M496 347.21a190.31 190.31 0 0 1-32.79-5.31c-27.28-6.63-54.84-24.26-68.12-52.43c-6.9-14.63-2.64-18.59 11.86-24c14.18-5.27 29.8-7.72 36.86-23c5.89-12.76 1.13-27.76-10.41-35.49c-15.71-10.53-30.35-.21-46.62 2.07c3.73-46.66 8.66-88.57-22.67-127.73C338.14 48.86 297.34 32 256.29 32s-81.86 16.86-107.81 49.33c-31.38 39.26-26.4 81.18-22.67 127.92c-16.32-2.25-30.81-12.79-46.63-2.18c-14.72 9.85-17 29.76-5.44 43s31.64 9.5 43.45 20.6c6.49 6.09 3.49 12.61-.35 20.14c-14.48 28.4-39.26 45.74-69.84 51.56c-4 .76-22.31 2.87-31 3.65c0 9.28.52 16.78 1.63 21.73c2.94 13.06 12.32 23.58 23.69 30.1c11.18 6.4 35.48 6.43 41.68 15.51c3 4.48 1.76 12.28 5.33 17.38a23.8 23.8 0 0 0 15.37 9.75c18.61 3.61 37.32-7.2 56.42-2.1c14.85 3.95 26.52 15.87 39.26 24c15.51 9.85 32.34 16.42 50.83 17.49c38.1 2.21 59.93-18.91 90.58-36.42c19.5-11.14 38.15-3.86 58.88-2.68c20.1 1.15 23.53-9.25 29.62-24.88a27.37 27.37 0 0 0 1.54-4.85a10.52 10.52 0 0 0 2.28-1.47c2-1.57 10.55-2.34 12.76-2.86c10.28-2.44 20.34-5.15 29.17-11.2c11.31-7.76 17.65-18.5 19.58-32.64a93.73 93.73 0 0 0 1.38-15.67zM208 128c8.84 0 16 10.74 16 24s-7.16 24-16 24s-16-10.74-16-24s7.16-24 16-24zm103.62 77.7c-15.25 15-35 23.3-55.62 23.3a78.37 78.37 0 0 1-55.66-23.34a8 8 0 0 1 11.32-11.32A62.46 62.46 0 0 0 256 213c16.39 0 32.15-6.64 44.39-18.7a8 8 0 0 1 11.23 11.4zM304 176c-8.84 0-16-10.75-16-24s7.16-24 16-24s16 10.75 16 24s-7.16 24-16 24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7r = [_hoisted_2$8D];
    vue.defineComponent({
      name: 'LogoSnapchat',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8D, _hoisted_3$7r);
      }
    });

    const _hoisted_1$8C = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8C = /*#__PURE__*/vue.createStaticVNode('<path d="M5.8 278a2.11 2.11 0 0 0-2 2L0 308.64l3.74 28.16a2.12 2.12 0 0 0 2.05 2a2.14 2.14 0 0 0 2-2l4.44-28.17L7.83 280a2.14 2.14 0 0 0-2-2z" fill="currentColor"></path><path d="M26.85 262.32a2.13 2.13 0 0 0-4.26 0l-5 46.32l5 45.3a2.13 2.13 0 0 0 4.26 0l5.73-45.31l-5.73-46.32z" fill="currentColor"></path><path d="M106.17 219.59a4 4 0 0 0-3.87 3.87l-4 85.22l4 55.08a3.88 3.88 0 0 0 7.75 0l4.53-55.08l-4.53-85.22a4 4 0 0 0-3.88-3.87z" fill="currentColor"></path><path d="M65.12 249.21a3.09 3.09 0 0 0-3 3l-4.52 56.45l4.51 54.63a3 3 0 0 0 6 0l5.13-54.63l-5.13-56.48a3.1 3.1 0 0 0-2.99-2.97z" fill="currentColor"></path><path d="M147.88 367.6a4.83 4.83 0 0 0 4.75-4.74l3.93-54.15l-3.93-113.46a4.75 4.75 0 0 0-9.5 0l-3.49 113.45l3.49 54.17a4.81 4.81 0 0 0 4.75 4.73z" fill="currentColor"></path><path d="M233.28 367.85a6.6 6.6 0 0 0 6.5-6.52l2.74-52.6l-2.74-131a6.5 6.5 0 1 0-13 0l-2.45 131c0 .08 2.45 52.67 2.45 52.67a6.59 6.59 0 0 0 6.5 6.45z" fill="currentColor"></path><path d="M190.26 367.65a5.67 5.67 0 0 0 5.62-5.64l3.34-53.33l-3.34-114.28a5.63 5.63 0 1 0-11.25 0l-3 114.29l3 53.32a5.66 5.66 0 0 0 5.63 5.6z" fill="currentColor"></path><path d="M85.56 367.15a3.53 3.53 0 0 0 3.44-3.41l4.83-55.09l-4.83-52.4a3.44 3.44 0 0 0-6.88 0l-4.26 52.38l4.26 55.08a3.5 3.5 0 0 0 3.44 3.44z" fill="currentColor"></path><path d="M44.84 364.13a2.67 2.67 0 0 0 2.57-2.52l5.43-53l-5.42-55a2.57 2.57 0 0 0-5.14 0l-4.78 55l4.78 53a2.62 2.62 0 0 0 2.56 2.53z" fill="currentColor"></path><path d="M211.69 192.53a6.1 6.1 0 0 0-6.07 6.09l-2.71 110.11l2.71 53a6.07 6.07 0 0 0 12.13 0l3-53l-3-110.13a6.1 6.1 0 0 0-6.06-6.07z" fill="currentColor"></path><path d="M127 367.71a4.41 4.41 0 0 0 4.31-4.3l4.23-54.71l-4.28-104.7a4.32 4.32 0 0 0-8.63 0l-3.74 104.7l3.75 54.73a4.38 4.38 0 0 0 4.36 4.28z" fill="currentColor"></path><path d="M174.17 362.54l3.63-53.8l-3.63-117.28a5.19 5.19 0 1 0-10.37 0l-3.23 117.28l3.23 53.83a5.18 5.18 0 0 0 10.36 0z" fill="currentColor"></path><path d="M449 241.1a62.42 62.42 0 0 0-24.33 4.9c-5-57.18-52.61-102-110.66-102a111.92 111.92 0 0 0-40.28 7.58c-4.75 1.85-6 3.76-6.06 7.46V360.4a7.66 7.66 0 0 0 6.8 7.5l174.56.11c34.78 0 63-28.41 63-63.45s-28.2-63.46-63-63.46z" fill="currentColor"></path><path d="M254.79 158.87a7 7 0 0 0-6.94 7L245 308.75l2.85 51.87a6.94 6.94 0 1 0 13.87-.06v.06l3.09-51.87l-3.09-142.93a7 7 0 0 0-6.93-6.95z" fill="currentColor"></path>', 14);

    const _hoisted_16 = [_hoisted_2$8C];
    vue.defineComponent({
      name: 'LogoSoundcloud',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8C, _hoisted_16);
      }
    });

    const _hoisted_1$8B = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8B = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M392 440V320h40v160H64V320h40v120z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M149.1 308.77l198.57 40.87l8.4-39.32l-198.57-40.87zm26.27-93.12L359.22 300L376 263.76l-183.82-84.84zm50.95-89l156 127.78l25.74-30.52l-156-127.78zM328 32l-33.39 23.8l120.82 160.37L448 192zM144 400h204v-40H144z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4y = [_hoisted_2$8B, _hoisted_3$7q];
    vue.defineComponent({
      name: 'LogoStackoverflow',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8B, _hoisted_4$4y);
      }
    });

    const _hoisted_1$8A = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8A = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M478.8 208.2a36 36 0 1 1-36-36a36 36 0 0 1 36 36zM442.6 139a69.42 69.42 0 0 0-69.4 68.7l-43.2 62a48.86 48.86 0 0 0-5.4-.3a51.27 51.27 0 0 0-26.4 7.3L102.4 198a51.8 51.8 0 1 0-50.6 62.9a51.27 51.27 0 0 0 26.4-7.3L274 332.2a51.76 51.76 0 0 0 102.1-5.9l66.5-48.6a69.35 69.35 0 1 0 0-138.7zm0 22.9a46.45 46.45 0 1 1-46.5 46.5a46.54 46.54 0 0 1 46.5-46.5zm-390.8 9a38.18 38.18 0 0 1 33.7 20.2l-18.9-7.6v.1a30.21 30.21 0 0 0-22.6 56v.1l16.1 6.4a36.8 36.8 0 0 1-8.2.9a38.05 38.05 0 0 1-.1-76.1zm272.8 112.2a38.1 38.1 0 1 1-33.7 55.9c6.3 2.5 12.5 5 18.8 7.6a30.27 30.27 0 1 0 22.5-56.2l-15.9-6.4a46.83 46.83 0 0 1 8.3-.9z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7p = [_hoisted_2$8A];
    vue.defineComponent({
      name: 'LogoSteam',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8A, _hoisted_3$7p);
      }
    });

    const _hoisted_1$8z = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M188.8 334.07h197.33L279.47 448H83.2z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7o = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M512 199H106.61L0 313h405.39z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4x = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M232.2 64h196.6L322.62 177.93H125.87z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$27 = [_hoisted_2$8z, _hoisted_3$7o, _hoisted_4$4x];
    vue.defineComponent({
      name: 'LogoStencil',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8z, _hoisted_5$27);
      }
    });

    const _hoisted_1$8y = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8y = /*#__PURE__*/vue.createStaticVNode('<path d="M242.69 340.3h26.62v-72.6h67v-25.82h-67v-72.6h-26.62v72.6h-66.15v25.82h66.15z" fill="currentColor"></path><path d="M119.26 445.18h22.59v-64.54h59.7v-20.17h-59.7v-65.34h-22.59v65.34h-59.7v20.17h59.7z" fill="currentColor"></path><path d="M370.15 212h22.59v-64.5h60.5v-19.37h-60.5V62.79h-22.59v65.34h-59.7v19.37h59.7z" fill="currentColor"></path><path d="M246.72 496h19.36v-46h41.15v-16.92h-41.15v-46h-19.36v46h-40.33V450h40.33z" fill="currentColor"></path><path d="M120.07 212h21v-65.31h60.51v-18.56H141V62.79h-21v65.34H59.56v18.56h60.51z" fill="currentColor"></path><path d="M435.72 308.84h19.36v-45.18H496v-17.74h-40.92v-45.18h-19.36v45.18h-40.33v17.74h40.33z" fill="currentColor"></path><path fill-rule="evenodd" d="M370.15 445.18h22.59v-64.54h60.5v-20.17h-60.5v-65.34h-22.59v65.34h-59.7v20.17h59.7z" fill="currentColor"></path><path d="M307 74.08V60.37h-40.34V16h-14.52v44.37h-40.33v13.71h40.33v44.37h14.52V74.08zM56.11 305.61h14.52v-44.37H111v-13.71H70.63V204H56.11v43.56H16v14.52l40.11-.08z" fill="currentColor"></path>', 8);

    const _hoisted_10$5 = [_hoisted_2$8y];
    vue.defineComponent({
      name: 'LogoTableau',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8y, _hoisted_10$5);
      }
    });

    const _hoisted_1$8x = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8x = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M412.19 118.66a109.27 109.27 0 0 1-9.45-5.5a132.87 132.87 0 0 1-24.27-20.62c-18.1-20.71-24.86-41.72-27.35-56.43h.1C349.14 23.9 350 16 350.13 16h-82.44v318.78c0 4.28 0 8.51-.18 12.69c0 .52-.05 1-.08 1.56c0 .23 0 .47-.05.71v.18a70 70 0 0 1-35.22 55.56a68.8 68.8 0 0 1-34.11 9c-38.41 0-69.54-31.32-69.54-70s31.13-70 69.54-70a68.9 68.9 0 0 1 21.41 3.39l.1-83.94a153.14 153.14 0 0 0-118 34.52a161.79 161.79 0 0 0-35.3 43.53c-3.48 6-16.61 30.11-18.2 69.24c-1 22.21 5.67 45.22 8.85 54.73v.2c2 5.6 9.75 24.71 22.38 40.82A167.53 167.53 0 0 0 115 470.66v-.2l.2.2c39.91 27.12 84.16 25.34 84.16 25.34c7.66-.31 33.32 0 62.46-13.81c32.32-15.31 50.72-38.12 50.72-38.12a158.46 158.46 0 0 0 27.64-45.93c7.46-19.61 9.95-43.13 9.95-52.53V176.49c1 .6 14.32 9.41 14.32 9.41s19.19 12.3 49.13 20.31c21.48 5.7 50.42 6.9 50.42 6.9v-81.84c-10.14 1.1-30.73-2.1-51.81-12.61z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7n = [_hoisted_2$8x];
    vue.defineComponent({
      name: 'LogoTiktok',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8x, _hoisted_3$7n);
      }
    });

    const _hoisted_1$8w = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8w = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M390 32H120c-49.19 0-88 38.81-88 88v270c0 49.19 38.81 90 88 90h270c49.19 0 90-40.81 90-90V120c0-49.19-40.81-88-90-88zm-54 364h-52c-42.51 0-72-23.68-72-76v-80h-36v-48c42.51-11 57.95-48.32 60-80h44v72h52v56h-52l-.39 70.51c0 21.87 11 29.43 28.62 29.43L336 340z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7m = [_hoisted_2$8w];
    vue.defineComponent({
      name: 'LogoTumblr',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8w, _hoisted_3$7m);
      }
    });

    const _hoisted_1$8v = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8v = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M443.66 405.05c-1.46-.79-2.85-1.54-4-2.2c-6.47-3.83-13-10.52-11.85-17.83c2.42-15.94 2.89-23.47-.49-28.79a15.61 15.61 0 0 0-7.67-6.2v-.06c1.41-2.56 2.26-5.66 2.83-10.12c1.44-11-5-44-13.7-70.7c-8.08-24.68-29.24-50-44.7-68.56l-3.61-4.34c-23.88-28.93-24.34-38.19-26.55-82.67c-.32-6.47-.69-13.8-1.17-22C329.87 41.43 304 16 256 16c-25.2 0-44.62 7.15-57.72 21.26C187.79 48.55 182 64 182 80.78c0 29.52 2 53 2.15 54.29c1.4 35.7 1 41.22-8.31 57.55c-2.23 3.93-8.38 10.87-14.89 18.21c-8.48 9.57-18.09 20.41-23.36 29.22c-3.77 6.31-5.88 12.63-8.11 19.33c-3.4 10.21-7.26 21.78-18.15 36.57c-12.57 17.07-15.52 29.61-11 47.45c-4.94 6.45-4.83 14.37-4.75 20.23a25.84 25.84 0 0 1-.3 6.09c-2.29 7.59-12.42 9.4-22 10.18c-1.58.12-3.1.21-4.55.29c-7.26.39-13.53.74-17.13 6.3c-3.47 5.36-1.12 13.8 2.14 25.48c.72 2.58 1.46 5.25 2.19 8.06c1.83 7-.16 10.48-2.68 14.84c-2.44 4.21-5.21 9-5.21 17.55c0 14.67 20 18 43.05 21.94c7.36 1.24 15 2.53 22.63 4.24a225.58 225.58 0 0 1 34.08 10.68c9.72 3.73 17.4 6.68 26.43 6.68c16.18 0 28.25-9.77 39.92-19.21l2.15-1.75c5.53-4.49 21.5-4 34.34-3.64c3.46.1 6.73.2 9.65.2h6.22c13.48-.08 31.94-.18 42.23 2.5c3.75 1 6.2 3.72 9.29 7.19c5.87 6.56 13.17 14.75 33.39 14.75c19.39 0 29.55-8.71 41.32-18.8c7.16-6.13 14.56-12.48 25.07-17.86c3.92-2 7.62-3.87 11.08-5.61c22.64-11.38 35.11-17.65 35.11-27.82c0-9.91-12.24-16.5-20.34-20.86zM211.11 88.38a13.91 13.91 0 0 1 12.47 9c1.95 5.55 1.81 10.42.21 12.94c0 0-.22-1-.36-1.44a14.85 14.85 0 0 0-6.44-8.59a11.35 11.35 0 0 0-8.94-1.47c-4.26 1.13-8.41 5-8.91 18.79c-5.16-10.47-2.31-18 .92-23c2.31-3.73 7.47-6.33 11.05-6.23zm-17.5 375C192 479.24 175.2 479 170.09 478.59c-9.81-.82-21.66-4.69-33.13-8.43c-4.52-1.47-9.19-3-13.73-4.34c-13.2-3.89-30.12-6.74-43.72-9c-3.22-.55-6.27-1.06-9.05-1.55s-4.61-1.27-5.2-2.3c-1-1.65.38-5.25 1.93-9.41C69.27 438 72.11 430.34 72 421c0-3.91-1.47-8.3-2.84-12.56c-1.62-5-3.28-10.17-1.93-12.62c1.23-2.23 6.75-2.49 11.6-2.49h2.26c3.55 0 6.62.06 8.75-.53c6.51-1.81 14.86-6.92 17.81-13.88c.9-2.17 1.37-6.94 2-14c.37-4.12.74-8.37 1.22-10.58a3.55 3.55 0 0 1 2.11-2.55c1.65-.77 6.78-1.91 18.63 4.08c11.18 5.65 22.88 25.84 34.2 45.37c3.56 6.14 6.92 11.94 10.3 17.36c14.04 22.54 18.83 31.6 17.5 44.8zm128.84-31.56a68.74 68.74 0 0 1-4.55 10.9a.58.58 0 0 1-1.08-.42a56.61 56.61 0 0 0 2.11-18.43c-.25-4.73-.4-7.59-2.66-8.51s-4.26.83-9.45 5.54c-1.1 1-2.36 2.14-3.78 3.4c-10.8 9.47-26.88 20.68-55.61 23.37c-16.84 1.59-27.59-4.63-30.92-8.14a2.16 2.16 0 0 0-3.07-.08a2.23 2.23 0 0 0-.51 2.29c2.12 6.84 1.2 12.26-.49 16.19c-.95 2.2-1.85 2.05-2-.34c-.25-4.64-1-9.88-3-14.19c-3.11-6.94-7-14.34-8.89-17.88v-.05c3.24-1.49 8.86-4.83 11.37-10.88s4.48-18-9.82-31.74c-6.28-6.05-22.1-17.16-36.06-27c-10.9-7.65-22.17-15.56-23.65-17.51c-4.49-5.89-6.37-9.3-6.94-19.65c.07-2.3.13-4.59.19-6.89l.27-2.49a.58.58 0 0 1 1.15 0a63.07 63.07 0 0 0 2 9.72c1.08 3.73 2.4 7.58 3.62 9.18c3.19 4.22 7.56 7.39 11.67 8.49a5.48 5.48 0 0 0 5-.72c2.93-2.33 2.65-7.6 2.19-16.34c-.47-9-1.11-21.34 1.85-34.55c5.62-25 10.91-32.51 17.61-42c.86-1.22 1.75-2.47 2.65-3.79c1.44-2.08 3-4.1 4.67-6.23c7.47-9.61 15.93-20.49 13.92-40.95c-.51-5.19-.76-8.83-.86-11.39a1 1 0 0 1 1.88-.59l.49.77l1.21 2c4.86 8 13.64 22.57 25.1 22.57a13.62 13.62 0 0 0 2.36-.21c23.39-3.93 51.9-30.25 52.17-30.51c3.12-3 2.84-6.14 1.64-7.91a5.18 5.18 0 0 0-6.45-1.72c-3.29 1.4-7.14 3.15-11.22 5c-13.82 6.27-37 16.75-42.25 14.34a23.11 23.11 0 0 1-6.32-5.13a1 1 0 0 1 1.14-1.65c5.59 2.29 9.55 1.45 14.2-.08l1-.34c9.37-3.09 14.2-4.77 30.76-12.08a97.55 97.55 0 0 1 16.26-5.93c4-1 6.42-1.63 7.71-4.34a6.65 6.65 0 0 0-.5-7.13c-1.53-1.87-4.07-2.57-7-1.9c-3.22.75-4.7 3-6.41 4.49c-2.4 2.05-5 4.16-17.19 8.65c-27 10-34.58 10.61-45.21 3.43c-9.84-6.69-15.15-13.23-15.15-16c0-2.13 5.45-5.7 8.71-7.84c1.33-.87 2.59-1.69 3.62-2.46c4.34-3.22 13-11.39 13.38-11.73c5.4-5.41 17.91-2.18 25 2.58a2.23 2.23 0 0 0 1.72.41a2.14 2.14 0 0 0 1.68-2.58c-4.2-17.46-.13-27.34 4-32.55a22.58 22.58 0 0 1 17.48-8.48c12.81 0 21.76 10 21.76 24.42c0 11-2.82 16.79-5.48 20.3a1.73 1.73 0 0 1-2.58.18a1.78 1.78 0 0 1-.24-2.2A24.61 24.61 0 0 0 290 114a16.58 16.58 0 0 0-16.84-16.67c-3.94 0-13.48 1.5-16.77 15.44a29.81 29.81 0 0 0-.34 11.07l.08.71c.9 7.38 15.3 12.51 27.23 15.51c11.36 2.85 13 6.22 8.84 19.63s3.11 26.23 5.7 29.57a78.3 78.3 0 0 1 8.31 12.47a93.8 93.8 0 0 1 6.62 16.48c2.17 6.79 4.05 12.65 10.63 21.22c11.07 14.4 17.66 48.64 15 78c-.21 2.41-.53 4.29-.77 5.67c-.43 2.53-.72 4.2.66 5.38s3.16.7 7.26-.63l3.43-1.09a109.33 109.33 0 0 1 12.58-2.8a2.15 2.15 0 0 0 1.59-1.16c3.43-6.91 3.85-15.22 4-22.47q0-1.31.06-2.79c.19-7.77.45-18.93-2.95-32a1 1 0 0 1 1.93-.64a93 93 0 0 1 6.66 25.55c2.55 22.58-1.9 32.09-1.94 32.17a1.61 1.61 0 0 0 .95 2.25a17.12 17.12 0 0 1 6.95 4.67c1.46 1.66.93 2.4-1.14 1.62a36.26 36.26 0 0 0-12.77-2.29c-10.4 0-18.09 4.95-21.51 9.19c-3.19 3.94-3.7 7.67-3.83 11.27l-.06.05c-7.48-.75-12.94 1.21-17.47 6.21l-.08.09c-6.26 7.75-4 24.63-1.29 38.48c1.28 6.45 5.59 25.52 1.73 37.68zm96.1 10.07c-15.71 6.71-25.43 14.51-34 21.39c-5.65 4.53-11 8.81-17.28 12.14c-10.12 5.34-24.91 6.53-33.27-7.7c-2.37-4-.71-9.86 1.58-17.95c3.05-10.75 7.23-25.46 3.71-44.65c-.94-5.12-1.77-9.51-2.49-13.31C334 377 332.9 371.43 334 367c.63-2.45 3.43-3 5.87-3a20.83 20.83 0 0 1 2.63.19a29.51 29.51 0 0 0 7 12.1c5.7 5.86 13.63 8.83 23.56 8.85c2.1.17 25.94 1.55 36.54-22.4c1.46.18 3.65.7 4.3 2.3c1.28 3.19-.27 8.91-1.52 13.5c-.9 3.31-1.68 6.16-1.63 8.37c.31 16 11 22.78 25.83 32.16c1.79 1.13 3.66 2.31 5.55 3.54S445 425 445 426c-.52 4.79-20 13.16-26.45 15.91z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7l = [_hoisted_2$8v];
    vue.defineComponent({
      name: 'LogoTux',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8v, _hoisted_3$7l);
      }
    });

    const _hoisted_1$8u = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8u = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M80 32l-32 80v304h96v64h64l64-64h80l112-112V32zm336 256l-64 64h-96l-64 64v-64h-80V80h304z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7k = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 143h48v129h-48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4w = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M208 143h48v129h-48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$26 = [_hoisted_2$8u, _hoisted_3$7k, _hoisted_4$4w];
    vue.defineComponent({
      name: 'LogoTwitch',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8u, _hoisted_5$26);
      }
    });

    const _hoisted_1$8t = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8t = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M496 109.5a201.8 201.8 0 0 1-56.55 15.3a97.51 97.51 0 0 0 43.33-53.6a197.74 197.74 0 0 1-62.56 23.5A99.14 99.14 0 0 0 348.31 64c-54.42 0-98.46 43.4-98.46 96.9a93.21 93.21 0 0 0 2.54 22.1a280.7 280.7 0 0 1-203-101.3A95.69 95.69 0 0 0 36 130.4c0 33.6 17.53 63.3 44 80.7A97.5 97.5 0 0 1 35.22 199v1.2c0 47 34 86.1 79 95a100.76 100.76 0 0 1-25.94 3.4a94.38 94.38 0 0 1-18.51-1.8c12.51 38.5 48.92 66.5 92.05 67.3A199.59 199.59 0 0 1 39.5 405.6a203 203 0 0 1-23.5-1.4A278.68 278.68 0 0 0 166.74 448c181.36 0 280.44-147.7 280.44-275.8c0-4.2-.11-8.4-.31-12.5A198.48 198.48 0 0 0 496 109.5z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7j = [_hoisted_2$8t];
    vue.defineComponent({
      name: 'LogoTwitter',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8t, _hoisted_3$7j);
      }
    });

    const _hoisted_1$8s = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8s = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M240 480v-36.42C160.53 439 112.25 398.06 112 336h72c1.77 26.34 23.86 46.45 56 50v-98l-26.77-7c-61-14.18-93.64-49.39-93.64-102.08C119.59 116.81 164.08 76.08 240 70V32h32v38c77.39 6.3 119 47.74 120 106h-72c-.76-24.06-15.83-43.39-48-46v92l30.82 7.28C367.61 243.46 400 277 400 332c0 64.34-43.74 105.88-128 111.32V480zm0-264v-86c-27.59 1.52-47.27 18.47-47.27 42.53c0 22.3 16.39 36.88 47.27 43.47zm32 78v92c38.15-1.54 56.38-18.92 56.38-45.77c0-24.58-18.23-41.13-56.38-46.23z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7i = [_hoisted_2$8s];
    vue.defineComponent({
      name: 'LogoUsd',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8s, _hoisted_3$7i);
      }
    });

    const _hoisted_1$8r = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8r = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M444.17 32H70.28C49.85 32 32 46.7 32 66.89V441.6c0 20.31 17.85 38.4 38.28 38.4h373.78c20.54 0 35.94-18.2 35.94-38.39V66.89C480.12 46.7 464.6 32 444.17 32zM278 387H174.32l-41.57-248.56l90.75-8.62l22 176.87c20.53-33.45 45.88-86 45.88-121.87c0-19.62-3.36-33-8.61-44l82.63-16.72c9.56 15.78 13.86 32 13.86 52.57c-.01 65.5-55.92 150.59-101.26 210.33z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7h = [_hoisted_2$8r];
    vue.defineComponent({
      name: 'LogoVenmo',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8r, _hoisted_3$7h);
      }
    });

    const _hoisted_1$8q = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8q = /*#__PURE__*/vue.createElementVNode('path', {
      'fill-rule': 'evenodd',
      d: 'M256 48l240 416H16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7g = [_hoisted_2$8q];
    vue.defineComponent({
      name: 'LogoVercel',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8q, _hoisted_3$7g);
      }
    });

    const _hoisted_1$8p = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8p = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M476.9 114c-5-23.39-17.51-38.78-40.61-46.27s-64.92-4.5-94.12 16.79c-26.79 19.51-46.26 54.42-54 78.28a4 4 0 0 0 5.13 5c10.77-3.8 21.72-7.1 34-6.45c15 .8 24.51 12 24.91 25.29c.3 9.79-.2 18.69-3.6 27.68c-10.74 28.68-27.61 56.46-47.55 80.75a72.49 72.49 0 0 1-10 9.89c-10.21 8.29-18.81 6.1-25.41-5.2c-5.4-9.29-9-18.88-12.2-29.08c-12.4-39.67-16.81-80.84-23.81-121.52c-3.3-19.48-7-39.77-18-56.86c-11.6-17.79-28.61-24.58-50-22c-14.7 1.8-36.91 17.49-47.81 26.39c0 0-56 46.87-81.82 71.35l21.2 27s17.91-12.49 27.51-18.29c5.7-3.39 12.4-4.09 17.2.2c4.51 3.9 9.61 9 12.31 14.1c5.7 10.69 11.2 21.88 14.7 33.37c13.2 44.27 25.51 88.64 37.81 133.22c6.3 22.78 13.9 44.17 28 63.55c19.31 26.59 39.61 32.68 70.92 21.49c25.41-9.09 46.61-26.18 66-43.87c33.11-30.18 59.12-65.36 85.52-101.14c20.41-27.67 37.31-55.67 51.41-86.95C478.5 179.74 484 147.26 476.9 114z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7f = [_hoisted_2$8p];
    vue.defineComponent({
      name: 'LogoVimeo',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8p, _hoisted_3$7f);
      }
    });

    const _hoisted_1$8o = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8o = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M484.7 132c3.56-11.28 0-19.48-15.75-19.48h-52.37c-13.21 0-19.31 7.18-22.87 14.86c0 0-26.94 65.6-64.56 108.13c-12.2 12.3-17.79 16.4-24.4 16.4c-3.56 0-8.14-4.1-8.14-15.37V131.47c0-13.32-4.06-19.47-15.25-19.47H199c-8.14 0-13.22 6.15-13.22 12.3c0 12.81 18.81 15.89 20.84 51.76V254c0 16.91-3 20-9.66 20c-17.79 0-61-66.11-86.92-141.44C105 117.64 99.88 112 86.66 112H33.79C18.54 112 16 119.17 16 126.86c0 13.84 17.79 83.53 82.86 175.77c43.21 63 104.72 96.86 160.13 96.86c33.56 0 37.62-7.69 37.62-20.5v-47.66c0-15.37 3.05-17.93 13.73-17.93c7.62 0 21.35 4.09 52.36 34.33C398.28 383.6 404.38 400 424.21 400h52.36c15.25 0 22.37-7.69 18.3-22.55c-4.57-14.86-21.86-36.38-44.23-62c-12.2-14.34-30.5-30.23-36.09-37.92c-7.62-10.25-5.59-14.35 0-23.57c-.51 0 63.55-91.22 70.15-122',
      'fill-rule': 'evenodd',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7e = [_hoisted_2$8o];
    vue.defineComponent({
      name: 'LogoVk',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8o, _hoisted_3$7e);
      }
    });

    const _hoisted_1$8n = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8n = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 144.03l-55.49-96.11h-79.43L256 281.61L390.92 47.92h-79.43L256 144.03z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7d = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M409.4 47.92L256 313.61L102.6 47.92H15.74L256 464.08L496.26 47.92H409.4z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4v = [_hoisted_2$8n, _hoisted_3$7d];
    vue.defineComponent({
      name: 'LogoVue',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8n, _hoisted_4$4v);
      }
    });

    const _hoisted_1$8m = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8m = /*#__PURE__*/vue.createStaticVNode('<path fill="none" d="M179.9 388l-76.16-132l76.16 132z"></path><path fill="none" d="M179.9 388h152.21l76.15-132l-76.15-132H179.9l-76.16 132l76.16 132z"></path><path fill="none" d="M103.74 256l76.16-132l-76.16 132z"></path><path d="M496 256L376 48H239.74l-43.84 76h136.21l76.15 132l-76.15 132H195.9l43.84 76H376l120-208z" fill="currentColor"></path><path d="M179.9 388l-76.16-132l76.16-132l43.84-76H136L16 256l120 208h87.74l-43.84-76z" fill="currentColor"></path>', 5);

    const _hoisted_7$B = [_hoisted_2$8m];
    vue.defineComponent({
      name: 'LogoWebComponent',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8m, _hoisted_7$B);
      }
    });

    const _hoisted_1$8l = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8l = /*#__PURE__*/vue.createElementVNode('path', {
      'data-name': 'XMLID 501 -1',
      d: 'M408.67 298.53a21 21 0 1 1 20.9-21a20.85 20.85 0 0 1-20.9 21m-102.17 0a21 21 0 1 1 20.9-21a20.84 20.84 0 0 1-20.9 21m152.09 118.86C491.1 394.08 512 359.13 512 319.51c0-71.08-68.5-129.35-154.41-129.35s-154.42 58.27-154.42 129.35s68.5 129.34 154.42 129.34c17.41 0 34.83-2.33 49.92-7c2.49-.86 3.48-1.17 4.64-1.17a16.67 16.67 0 0 1 8.13 2.34L454 462.83a11.62 11.62 0 0 0 3.48 1.17a5 5 0 0 0 4.65-4.66a14.27 14.27 0 0 0-.77-3.86c-.41-1.46-5-16-7.36-25.27a18.94 18.94 0 0 1-.33-3.47a11.4 11.4 0 0 1 5-9.35',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7c = /*#__PURE__*/vue.createElementVNode('path', {
      'data-name': 'XMLID 505 -7',
      d: 'M246.13 178.51a24.47 24.47 0 0 1 0-48.94c12.77 0 24.38 11.65 24.38 24.47c1.16 12.82-10.45 24.47-24.38 24.47m-123.06 0A24.47 24.47 0 1 1 147.45 154a24.57 24.57 0 0 1-24.38 24.47M184.6 48C82.43 48 0 116.75 0 203c0 46.61 24.38 88.56 63.85 116.53C67.34 321.84 68 327 68 329a11.38 11.38 0 0 1-.66 4.49C63.85 345.14 59.4 364 59.21 365s-1.16 3.5-1.16 4.66a5.49 5.49 0 0 0 5.8 5.83a7.15 7.15 0 0 0 3.49-1.17L108 351c3.49-2.33 5.81-2.33 9.29-2.33a16.33 16.33 0 0 1 5.81 1.16c18.57 5.83 39.47 8.16 60.37 8.16h10.45a133.24 133.24 0 0 1-5.81-38.45c0-78.08 75.47-141 168.35-141h10.45C354.1 105.1 277.48 48 184.6 48',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4u = [_hoisted_2$8l, _hoisted_3$7c];
    vue.defineComponent({
      name: 'LogoWechat',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8l, _hoisted_4$4u);
      }
    });

    const _hoisted_1$8k = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8k = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M414.73 97.1A222.14 222.14 0 0 0 256.94 32C134 32 33.92 131.58 33.87 254a220.61 220.61 0 0 0 29.78 111L32 480l118.25-30.87a223.63 223.63 0 0 0 106.6 27h.09c122.93 0 223-99.59 223.06-222A220.18 220.18 0 0 0 414.73 97.1zM256.94 438.66h-.08a185.75 185.75 0 0 1-94.36-25.72l-6.77-4l-70.17 18.32l18.73-68.09l-4.41-7A183.46 183.46 0 0 1 71.53 254c0-101.73 83.21-184.5 185.48-184.5a185 185 0 0 1 185.33 184.64c-.04 101.74-83.21 184.52-185.4 184.52zm101.69-138.19c-5.57-2.78-33-16.2-38.08-18.05s-8.83-2.78-12.54 2.78s-14.4 18-17.65 21.75s-6.5 4.16-12.07 1.38s-23.54-8.63-44.83-27.53c-16.57-14.71-27.75-32.87-31-38.42s-.35-8.56 2.44-11.32c2.51-2.49 5.57-6.48 8.36-9.72s3.72-5.56 5.57-9.26s.93-6.94-.46-9.71s-12.54-30.08-17.18-41.19c-4.53-10.82-9.12-9.35-12.54-9.52c-3.25-.16-7-.2-10.69-.2a20.53 20.53 0 0 0-14.86 6.94c-5.11 5.56-19.51 19-19.51 46.28s20 53.68 22.76 57.38s39.3 59.73 95.21 83.76a323.11 323.11 0 0 0 31.78 11.68c13.35 4.22 25.5 3.63 35.1 2.2c10.71-1.59 33-13.42 37.63-26.38s4.64-24.06 3.25-26.37s-5.11-3.71-10.69-6.48z',
      'fill-rule': 'evenodd',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7b = [_hoisted_2$8k];
    vue.defineComponent({
      name: 'LogoWhatsapp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8k, _hoisted_3$7b);
      }
    });

    const _hoisted_1$8j = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8j = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 265H232v179l248 36V265z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7a = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M216 265H32v150l184 26.7V265z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4t = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 32L232 67.4V249h248V32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$25 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M216 69.7L32 96v153h184V69.7z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$12 = [_hoisted_2$8j, _hoisted_3$7a, _hoisted_4$4t, _hoisted_5$25];
    vue.defineComponent({
      name: 'LogoWindows',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8j, _hoisted_6$12);
      }
    });

    const _hoisted_1$8i = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8i = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M259 271.3L226.2 367h-.1l-25.4 73.1c1.8.5 3.5.9 5.3 1.4h.3a192.51 192.51 0 0 0 49.5 6.5a157 157 0 0 0 24.9-1.8a184.3 184.3 0 0 0 32.5-7.1c2.6-.8 5.2-1.7 7.8-2.6c-2.8-6-8.8-19.3-9.1-19.9z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$79 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M80.8 180.5C70.8 203.1 64 230.9 64 256c0 6.3.3 12.6.9 18.8c6.9 71.2 52.9 131 116.1 157.9c2.6 1.1 5.3 2.2 8 3.2L96 180.6c-8-.3-9.5.2-15.2-.1z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4s = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M430.2 175.4a188 188 0 0 0-15.1-26.6c-1.6-2.4-3.4-4.8-5.1-7.2A193 193 0 0 0 325.1 77a189.2 189.2 0 0 0-69.2-13a191.51 191.51 0 0 0-149.4 71.7A196 196 0 0 0 89 161.3c14.2.1 31.8.1 33.8.1c18.1 0 46-2.2 46-2.2c9.4-.6 10.4 13.1 1.1 14.2c0 0-9.4 1.1-19.8 1.6L213 362l37.8-113.3l-26.8-73.6c-9.4-.5-18.1-1.6-18.1-1.6c-9.4-.5-8.2-14.8 1-14.2c0 0 28.5 2.2 45.5 2.2c18.1 0 46-2.2 46-2.2c9.3-.6 10.5 13.1 1.1 14.2c0 0-9.3 1.1-19.7 1.6l62.3 185.6l17.3-57.6c8.7-22.4 13.1-40.9 13.1-55.7c0-21.3-7.7-36.1-14.3-47.6c-8.7-14.3-16.9-26.3-16.9-40.4c0-15.9 12-30.7 29-30.7h2.2c26.2-.7 34.8 25.3 35.9 43v.6c.4 7.2.1 12.5.1 18.8c0 17.4-3.3 37.1-13.1 61.8l-39 112.8l-22.3 65.7c1.8-.8 3.5-1.6 5.3-2.5c56.7-27.4 98-82 106.7-146.7a172.07 172.07 0 0 0 1.9-26a191.11 191.11 0 0 0-17.8-80.8z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$24 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48a208.06 208.06 0 0 1 81 399.66A208.06 208.06 0 0 1 175 64.34A206.7 206.7 0 0 1 256 48m0-16C132.29 32 32 132.29 32 256s100.29 224 224 224s224-100.29 224-224S379.71 32 256 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$11 = [_hoisted_2$8i, _hoisted_3$79, _hoisted_4$4s, _hoisted_5$24];
    vue.defineComponent({
      name: 'LogoWordpress',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8i, _hoisted_6$11);
      }
    });

    const _hoisted_1$8h = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8h = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M126.8 248.3c39.7-58.6 77.9-92.8 77.9-92.8s-42.1-48.9-92.8-67.4l-3.3-.8A224.13 224.13 0 0 0 77.2 391c0-4.4.6-70.3 49.6-142.7z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$78 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 256a223.71 223.71 0 0 0-76.6-168.7l-3.2.9c-50.7 18.5-92.9 67.4-92.9 67.4s38.2 34.2 77.9 92.8c49 72.4 49.6 138.3 49.5 142.7A222.8 222.8 0 0 0 480 256z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4r = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M201.2 80.9c29.3 13.1 54.6 34.6 54.6 34.6s25.5-21.4 54.8-34.6c36.8-16.5 64.9-11.3 72.3-9.5a224.06 224.06 0 0 0-253.8 0c7.2-1.8 35.2-7.1 72.1 9.5z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$23 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M358.7 292.9C312.4 236 255.8 199 255.8 199s-56.3 37-102.7 93.9c-39.8 48.9-54.6 84.8-62.6 107.8l-1.3 4.8a224 224 0 0 0 333.6 0l-1.4-4.8c-8-23-22.9-58.9-62.7-107.8z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$10 = [_hoisted_2$8h, _hoisted_3$78, _hoisted_4$4r, _hoisted_5$23];
    vue.defineComponent({
      name: 'LogoXbox',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8h, _hoisted_6$10);
      }
    });

    const _hoisted_1$8g = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8g = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M313.8 303.9L469 32H365L209.4 303.8a1.35 1.35 0 0 0 0 1.7l98.9 173.8c.4.7.8.7 1.6.7H413l-99.3-174.7a1.74 1.74 0 0 1 .1-1.4z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$77 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M221.9 216.2L163 113a2 2 0 0 0-2-1H65l58.9 104.4a1.13 1.13 0 0 1 .1.8L43 352h96.8a1.54 1.54 0 0 0 1.6-.9l80.5-133.7a2.44 2.44 0 0 0 0-1.2z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4q = [_hoisted_2$8g, _hoisted_3$77];
    vue.defineComponent({
      name: 'LogoXing',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8g, _hoisted_4$4q);
      }
    });

    const _hoisted_1$8f = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8f = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M410.32 37.13c-13.56 0-27-.93-39.12-5.13L256 218.67L140.8 32c-12.12 4.2-24.84 5.13-38.4 5.13c-13.32 0-26.52-1.05-38.4-5.13l153.6 248.15V480c12-4.08 25-5.13 38.4-5.13s26.4 1.05 38.4 5.13V280.5L448 32c-11.88 4-24.36 5.13-37.68 5.13z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$76 = [_hoisted_2$8f];
    vue.defineComponent({
      name: 'LogoYahoo',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8f, _hoisted_3$76);
      }
    });

    const _hoisted_1$8e = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8e = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 32h-80L256 253.13L144 32H64l112.37 208H128v48h73.56L216 319v17h-88v48h88v96h80v-96h88v-48h-88v-17l14.89-31H384v-48h-48.29z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$75 = [_hoisted_2$8e];
    vue.defineComponent({
      name: 'LogoYen',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8e, _hoisted_3$75);
      }
    });

    const _hoisted_1$8d = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8d = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M508.64 148.79c0-45-33.1-81.2-74-81.2C379.24 65 322.74 64 265 64h-18c-57.6 0-114.2 1-169.6 3.6C36.6 67.6 3.5 104 3.5 149C1 184.59-.06 220.19 0 255.79q-.15 53.4 3.4 106.9c0 45 33.1 81.5 73.9 81.5c58.2 2.7 117.9 3.9 178.6 3.8q91.2.3 178.6-3.8c40.9 0 74-36.5 74-81.5c2.4-35.7 3.5-71.3 3.4-107q.34-53.4-3.26-106.9zM207 353.89v-196.5l145 98.2z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$74 = [_hoisted_2$8d];
    vue.defineComponent({
      name: 'LogoYoutube',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8d, _hoisted_3$74);
      }
    });

    const _hoisted_1$8c = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8c = /*#__PURE__*/vue.createStaticVNode('<path stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M191.98 463.79v-48" fill="currentColor"></path><path stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M90.16 421.61l33.94-33.94" fill="currentColor"></path><path stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M47.98 319.79h48" fill="currentColor"></path><path d="M267.56 312.32l-31.11 31.11a16 16 0 0 0 0 22.63l45.26 45.25a16 16 0 0 0 22.62 0l31.12-31.11a4 4 0 0 0 0-5.66l-62.23-62.22a4 4 0 0 0-5.66 0z" fill="currentColor"></path><path d="M131.8 176.55l-31.11 31.12a16 16 0 0 0 0 22.62l45.25 45.26a16 16 0 0 0 22.63 0l31.11-31.11a4 4 0 0 0 0-5.66l-62.22-62.23a4 4 0 0 0-5.66 0z" fill="currentColor"></path><path d="M428.85 83.28a144 144 0 0 0-203.71-.06l-65.06 65.05a4 4 0 0 0 0 5.66l62.23 62.22a4 4 0 0 0 5.66 0l65-65.05a48 48 0 0 1 68.46.59c18.3 18.92 17.47 49.24-1.14 67.85L295.85 284a4 4 0 0 0 0 5.66l62.22 62.23a4 4 0 0 0 5.66 0l64.08-64.08c56.37-56.34 57.37-148.13 1.04-204.53z" fill="currentColor"></path>', 6);

    const _hoisted_8$g = [_hoisted_2$8c];
    vue.defineComponent({
      name: 'Magnet',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8c, _hoisted_8$g);
      }
    });

    const _hoisted_1$8b = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8b = /*#__PURE__*/vue.createStaticVNode('<path d="M421.83 293.82A144 144 0 0 0 218.18 90.17" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path d="M353.94 225.94a48 48 0 0 0-67.88-67.88" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M192 464v-48" fill="currentColor"></path><path stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M90.18 421.82l33.94-33.94" fill="currentColor"></path><path stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M48 320h48" fill="currentColor"></path><path d="M286.06 158.06L172.92 271.19a32 32 0 0 1-45.25 0L105 248.57a32 32 0 0 1 0-45.26L218.18 90.17" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></path><path d="M421.83 293.82L308.69 407a32 32 0 0 1-45.26 0l-22.62-22.63a32 32 0 0 1 0-45.26l113.13-113.17" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32" d="M139.6 169.98l67.88 67.89"></path><path fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32" d="M275.36 305.75l67.89 67.88"></path>', 9);

    const _hoisted_11$5 = [_hoisted_2$8b];
    vue.defineComponent({
      name: 'MagnetOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8b, _hoisted_11$5);
      }
    });

    const _hoisted_1$8a = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8a = /*#__PURE__*/vue.createStaticVNode('<path stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M191.98 463.58v-48" fill="currentColor"></path><path stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M90.16 421.4l33.94-33.94" fill="currentColor"></path><path stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M47.98 319.58h48" fill="currentColor"></path><path d="M422.2 89.82a144 144 0 0 0-203.71-.07l-67.88 67.88l67.88 67.89l67.88-67.89a48 48 0 0 1 68.46.59c18.3 18.92 17.48 49.24-1.14 67.86l-67.32 67.32l67.88 67.88l66.91-66.91c56.37-56.37 57.37-148.15 1.04-204.55z" fill="currentColor"></path><path d="M82.718 225.517l45.255-45.254l67.883 67.882L150.6 293.4z" fill="currentColor"></path><path d="M218.49 361.27l45.254-45.254l67.882 67.882l-45.255 45.255z" fill="currentColor"></path>', 6);

    const _hoisted_8$f = [_hoisted_2$8a];
    vue.defineComponent({
      name: 'MagnetSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8a, _hoisted_8$f);
      }
    });

    const _hoisted_1$89 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$89 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M424 80H88a56.06 56.06 0 0 0-56 56v240a56.06 56.06 0 0 0 56 56h336a56.06 56.06 0 0 0 56-56V136a56.06 56.06 0 0 0-56-56zm-14.18 92.63l-144 112a16 16 0 0 1-19.64 0l-144-112a16 16 0 1 1 19.64-25.26L256 251.73l134.18-104.36a16 16 0 0 1 19.64 25.26z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$73 = [_hoisted_2$89];
    vue.defineComponent({
      name: 'Mail',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$89, _hoisted_3$73);
      }
    });

    const _hoisted_1$88 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$88 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448.67 154.45L274.1 68.2a41.1 41.1 0 0 0-36.2 0L63.33 154.45A55.6 55.6 0 0 0 32 204.53v184.61c0 30.88 25.42 56 56.67 56h334.66c31.25 0 56.67-25.12 56.67-56V204.53a55.6 55.6 0 0 0-31.33-50.08zM252.38 96.82a8.22 8.22 0 0 1 7.24 0L429 180.48l-172 85a8.22 8.22 0 0 1-7.24 0L80.35 181.81z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$72 = [_hoisted_2$88];
    vue.defineComponent({
      name: 'MailOpen',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$88, _hoisted_3$72);
      }
    });

    const _hoisted_1$87 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$87 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M441.6 171.61L266.87 85.37a24.57 24.57 0 0 0-21.74 0L70.4 171.61A40 40 0 0 0 48 207.39V392c0 22.09 18.14 40 40.52 40h335c22.38 0 40.52-17.91 40.52-40V207.39a40 40 0 0 0-22.44-35.78z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$71 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M397.33 368L268.07 267.46a24 24 0 0 0-29.47 0L109.33 368',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4p = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M309.33 295l136-103'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$22 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M61.33 192l139 105'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$$ = [_hoisted_2$87, _hoisted_3$71, _hoisted_4$4p, _hoisted_5$22];
    vue.defineComponent({
      name: 'MailOpenOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$87, _hoisted_6$$);
      }
    });

    const _hoisted_1$86 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$86 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M471.05 168.36L263.24 65.69a16.37 16.37 0 0 0-14.48 0L41 168.36a16 16 0 0 0-9 14.31V432a16.09 16.09 0 0 0 16.19 16h415.62A16.09 16.09 0 0 0 480 432V182.67a16 16 0 0 0-8.95-14.31zM256 97.89l173 85.44l-175.7 86.78l-173-85.44z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$70 = [_hoisted_2$86];
    vue.defineComponent({
      name: 'MailOpenSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$86, _hoisted_3$70);
      }
    });

    const _hoisted_1$85 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$85 = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '48',
      y: '96',
      width: '416',
      height: '320',
      rx: '40',
      ry: '40',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6$ = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M112 160l144 112l144-112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4o = [_hoisted_2$85, _hoisted_3$6$];
    vue.defineComponent({
      name: 'MailOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$85, _hoisted_4$4o);
      }
    });

    const _hoisted_1$84 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$84 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 80H48a16 16 0 0 0-16 16v320a16 16 0 0 0 16 16h416a16 16 0 0 0 16-16V96a16 16 0 0 0-16-16zM265.82 284.63a16 16 0 0 1-19.64 0L89.55 162.81l19.64-25.26L256 251.73l146.81-114.18l19.64 25.26z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6_ = [_hoisted_2$84];
    vue.defineComponent({
      name: 'MailSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$84, _hoisted_3$6_);
      }
    });

    const _hoisted_1$83 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$83 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M496 128.05A64 64 0 0 0 389.62 80a64.52 64.52 0 0 0-12.71 15.3v.06c-.54.9-1.05 1.82-1.55 2.74l-.24.49c-.42.79-.81 1.59-1.19 2.4c-.12.25-.23.5-.34.75c-.33.73-.65 1.47-.95 2.22c-.13.31-.25.62-.37.93c-.27.7-.53 1.4-.78 2.11l-.36 1.06c-.22.68-.43 1.37-.63 2.06c-.12.39-.23.77-.33 1.16c-.19.67-.35 1.35-.51 2c-.1.41-.2.82-.29 1.23c-.14.68-.27 1.37-.39 2c-.08.42-.16.84-.23 1.26c-.11.7-.2 1.41-.29 2.12c-.05.41-.11.82-.16 1.24c-.08.77-.13 1.54-.19 2.32c0 .36-.06.72-.08 1.08c-.06 1.14-.1 2.28-.1 3.44c0 1 0 2 .08 2.94v.64q.08 1.41.21 2.82l.06.48c.09.85.19 1.69.32 2.52c0 .17 0 .35.07.52c.14.91.31 1.81.49 2.71c0 .22.09.43.13.65c.18.86.38 1.72.6 2.57v.19c.23.89.48 1.76.75 2.63l.21.68c.27.85.55 1.68.85 2.51c.06.18.13.36.2.54c.27.71.55 1.42.84 2.12c.08.21.16.41.25.61c.34.79.69 1.58 1.06 2.36l.33.67c.35.7.7 1.4 1.07 2.09a64.34 64.34 0 0 0 22.14 23.81a62.22 62.22 0 0 0 7.62 4.15l.39.18q2.66 1.2 5.43 2.16l.95.32l1.5.47c.45.14.9.26 1.36.39l1.92.5l1.73.4l1.15.23l1.83.33l.94.15c.9.13 1.81.25 2.72.35l.77.07c.73.06 1.47.12 2.21.16l.86.05c1 0 1.94.08 2.92.08c1.16 0 2.3 0 3.44-.1l1.08-.08c.78-.06 1.55-.11 2.32-.19l1.25-.16c.7-.09 1.41-.18 2.11-.29l1.26-.23c.68-.12 1.37-.25 2-.39l1.23-.29c.68-.16 1.36-.32 2-.51c.39-.1.77-.21 1.16-.33c.69-.2 1.38-.41 2.06-.63l1.06-.36c.71-.25 1.41-.51 2.11-.78l.93-.37c.75-.3 1.49-.62 2.22-.95l.75-.34c.81-.38 1.61-.77 2.4-1.19l.49-.24c.92-.5 1.84-1 2.74-1.55h.06A64.52 64.52 0 0 0 480 170.38a63.81 63.81 0 0 0 16-42.33z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6Z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M371.38 202.53l-105.56 82.1a16 16 0 0 1-19.64 0l-144-112a16 16 0 1 1 19.64-25.26L256 251.73l94.22-73.28A95.86 95.86 0 0 1 348.81 80H88a56.06 56.06 0 0 0-56 56v240a56.06 56.06 0 0 0 56 56h336a56.06 56.06 0 0 0 56-56V211.19a95.85 95.85 0 0 1-108.62-8.66z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4n = [_hoisted_2$83, _hoisted_3$6Z];
    vue.defineComponent({
      name: 'MailUnread',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$83, _hoisted_4$4n);
      }
    });

    const _hoisted_1$82 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$82 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 96H88a40 40 0 0 0-40 40v240a40 40 0 0 0 40 40h334.73a40 40 0 0 0 40-40V239',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6Y = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M112 160l144 112l87-65.67'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4m = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '431.95',
      cy: '128.05',
      r: '47.95',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$21 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M432 192a63.95 63.95 0 1 1 63.95-63.95A64 64 0 0 1 432 192zm0-95.9a32 32 0 1 0 31.95 32a32 32 0 0 0-31.95-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$_ = [_hoisted_2$82, _hoisted_3$6Y, _hoisted_4$4m, _hoisted_5$21];
    vue.defineComponent({
      name: 'MailUnreadOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$82, _hoisted_6$_);
      }
    });

    const _hoisted_1$81 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$81 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M374.09 101c-.11.23-.21.46-.31.7c-.34.75-.67 1.5-1 2.26l-.36.9c-.27.71-.54 1.42-.79 2.14c-.12.35-.24.7-.35 1c-.23.68-.44 1.37-.64 2.07l-.33 1.15q-.27 1-.51 2c-.1.41-.2.82-.28 1.23c-.15.67-.28 1.36-.4 2c-.08.42-.16.84-.23 1.27c-.11.69-.2 1.4-.29 2.1c-.05.42-.11.83-.16 1.25c-.08.77-.13 1.54-.19 2.31c0 .36-.06.72-.08 1.09c-.06 1.13-.09 2.27-.09 3.41c0 1 0 2 .07 2.94v.62c.05.95.12 1.89.21 2.83l.06.46c.09.87.2 1.72.32 2.57c0 .15 0 .31.07.46c.14.92.31 1.84.49 2.75l.12.59c.2.92.4 1.84.64 2.75c.23.92.5 1.82.77 2.71c.06.19.12.38.17.57c.28.88.57 1.74.88 2.59c.05.15.11.29.16.43c.29.78.6 1.55.92 2.32c.05.14.11.28.17.42c.35.83.73 1.65 1.11 2.47l.27.53c.4.82.81 1.64 1.24 2.44a64.21 64.21 0 0 0 29.56 27.63l.37.17c1.78.8 3.59 1.53 5.45 2.17l.95.32l1.5.47c.45.14.9.26 1.36.39l1.92.5c.57.14 1.14.27 1.72.39l1.15.24l1.83.32l.93.16c.9.13 1.81.24 2.72.34l.77.07c.73.07 1.47.13 2.22.17l.85.05c1 0 1.94.07 2.93.07c1.15 0 2.29 0 3.43-.09l1.09-.09c.77 0 1.54-.11 2.3-.19c.42 0 .83-.1 1.25-.16c.7-.08 1.41-.17 2.1-.28l1.27-.23c.68-.12 1.36-.25 2-.39l1.24-.29c.67-.16 1.35-.32 2-.51c.39-.1.78-.21 1.16-.33c.69-.2 1.37-.41 2.05-.63l1.07-.36c.7-.24 1.4-.5 2.1-.77l.94-.37c.74-.3 1.47-.62 2.19-.95l.77-.34c.8-.37 1.58-.77 2.36-1.17c.17-.09.35-.17.52-.27c.91-.48 1.8-1 2.68-1.5l.12-.07a63.95 63.95 0 1 0-89.21-84.88l-.21.39c-.3 1.03-.72 1.86-1.11 2.69z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6X = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M371.51 202.43l-105.69 82.2a16 16 0 0 1-19.64 0L89.55 162.81l19.64-25.26L256 251.73l94.36-73.39A95.81 95.81 0 0 1 349 80H48a16 16 0 0 0-16 16v320a16 16 0 0 0 16 16h416a16 16 0 0 0 16-16V211.13a95.75 95.75 0 0 1-108.49-8.7z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4l = [_hoisted_2$81, _hoisted_3$6X];
    vue.defineComponent({
      name: 'MailUnreadSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$81, _hoisted_4$4l);
      }
    });

    const _hoisted_1$80 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$80 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M442 48h-90a22 22 0 0 0 0 44h36.89l-60.39 60.39c-68.19-52.86-167-48-229.54 14.57C31.12 234.81 31.12 345.19 99 413a174.21 174.21 0 0 0 246 0c62.57-62.58 67.43-161.35 14.57-229.54L420 123.11V160a22 22 0 0 0 44 0V70a22 22 0 0 0-22-22zM313.92 381.92a130.13 130.13 0 0 1-183.84 0c-50.69-50.68-50.69-133.16 0-183.84s133.16-50.69 183.84 0s50.69 133.16 0 183.84z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6W = [_hoisted_2$80];
    vue.defineComponent({
      name: 'Male',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$80, _hoisted_3$6W);
      }
    });

    const _hoisted_1$7$ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7$ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M426 16h-74a22 22 0 0 0 0 44h20.89l-37.1 37.09A157.68 157.68 0 0 0 216 42c-87.12 0-158 70.88-158 158c0 79.66 59.26 145.72 136 156.46V394h-28a22 22 0 0 0 0 44h28v36a22 22 0 0 0 44 0v-36h28a22 22 0 0 0 0-44h-28v-37.54c76.74-10.74 136-76.8 136-156.46a157.15 157.15 0 0 0-14-64.92l44-44V112a22 22 0 0 0 44 0V38a22 22 0 0 0-22-22zM216 314a114 114 0 1 1 114-114a114.13 114.13 0 0 1-114 114z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6V = [_hoisted_2$7$];
    vue.defineComponent({
      name: 'MaleFemale',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7$, _hoisted_3$6V);
      }
    });

    const _hoisted_1$7_ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7_ = /*#__PURE__*/vue.createStaticVNode('<circle cx="216" cy="200" r="136" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M216 352v128"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M272 416H160"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M432 112V32h-80"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M335.28 128.72L432 32"></path>', 5);

    const _hoisted_7$A = [_hoisted_2$7_];
    vue.defineComponent({
      name: 'MaleFemaleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7_, _hoisted_7$A);
      }
    });

    const _hoisted_1$7Z = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7Z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M330 16v44h42.89l-37.1 37.09A157.67 157.67 0 0 0 216 42c-87.12 0-158 70.88-158 158c0 79.66 59.26 145.72 136 156.46V394h-50v44h50v58h44v-58h50v-44h-50v-37.54c76.74-10.74 136-76.8 136-156.46a157.23 157.23 0 0 0-14-64.93l44-44V134h44V16zM216 314a114 114 0 1 1 114-114a114.13 114.13 0 0 1-114 114z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6U = [_hoisted_2$7Z];
    vue.defineComponent({
      name: 'MaleFemaleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7Z, _hoisted_3$6U);
      }
    });

    const _hoisted_1$7Y = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7Y = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '216',
      cy: '296',
      r: '152',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6T = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M448 160V64h-96'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4k = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M324 188L448 64'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$20 = [_hoisted_2$7Y, _hoisted_3$6T, _hoisted_4$4k];
    vue.defineComponent({
      name: 'MaleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7Y, _hoisted_5$20);
      }
    });

    const _hoisted_1$7X = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7X = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M330 48v44h58.89l-60.39 60.39c-68.2-52.86-167-48-229.54 14.57C31.12 234.81 31.12 345.19 99 413a174.21 174.21 0 0 0 246 0c62.57-62.58 67.43-161.34 14.57-229.54L420 123.11V182h44V48zm-16.08 333.92a130.13 130.13 0 0 1-183.84 0c-50.69-50.68-50.69-133.16 0-183.84s133.16-50.69 183.84 0s50.69 133.16 0 183.84z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6S = [_hoisted_2$7X];
    vue.defineComponent({
      name: 'MaleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7X, _hoisted_3$6S);
      }
    });

    const _hoisted_1$7W = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7W = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '56',
      r: '56',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6R = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M304 128h-96a64.19 64.19 0 0 0-64 64v107.52c0 10.85 8.43 20.08 19.27 20.47A20 20 0 0 0 184 300v-99.73a8.18 8.18 0 0 1 7.47-8.25a8 8 0 0 1 8.53 8V489a23 23 0 0 0 23 23a23 23 0 0 0 23-23V346.34a10.24 10.24 0 0 1 9.33-10.34A10 10 0 0 1 266 346v143a23 23 0 0 0 23 23a23 23 0 0 0 23-23V200.27a8.18 8.18 0 0 1 7.47-8.25a8 8 0 0 1 8.53 8v99.52c0 10.85 8.43 20.08 19.27 20.47A20 20 0 0 0 368 300V192a64.19 64.19 0 0 0-64-64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4j = [_hoisted_2$7W, _hoisted_3$6R];
    vue.defineComponent({
      name: 'Man',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7W, _hoisted_4$4j);
      }
    });

    const _hoisted_1$7V = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7V = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M208 208v264a23.73 23.73 0 0 0 24 24h0a23.73 23.73 0 0 0 24-24',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6Q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 336v136a23.73 23.73 0 0 0 24 24h0a23.73 23.73 0 0 0 24-24V208',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4i = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M208 192v88a23.72 23.72 0 0 1-24 24h0a23.72 23.72 0 0 1-24-24v-88a48 48 0 0 1 48-48h96a48 48 0 0 1 48 48v88a23.72 23.72 0 0 1-24 24h0a23.72 23.72 0 0 1-24-24v-88',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1$ = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '56',
      r: '40',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$Z = [_hoisted_2$7V, _hoisted_3$6Q, _hoisted_4$4i, _hoisted_5$1$];
    vue.defineComponent({
      name: 'ManOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7V, _hoisted_6$Z);
      }
    });

    const _hoisted_1$7U = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7U = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '56',
      r: '56',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6P = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 128H176a32 32 0 0 0-32 32v160h48V192h8v320h52V328h8v184h52V192h8v128h48V160a32 32 0 0 0-32-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4h = [_hoisted_2$7U, _hoisted_3$6P];
    vue.defineComponent({
      name: 'ManSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7U, _hoisted_4$4h);
      }
    });

    const _hoisted_1$7T = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7T = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48.17 113.34A32 32 0 0 0 32 141.24V438a32 32 0 0 0 47 28.37c.43-.23.85-.47 1.26-.74l84.14-55.05a8 8 0 0 0 3.63-6.72V46.45a8 8 0 0 0-12.51-6.63z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6O = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M212.36 39.31A8 8 0 0 0 200 46v357.56a8 8 0 0 0 3.63 6.72l96 62.42A8 8 0 0 0 312 466V108.67a8 8 0 0 0-3.64-6.73z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4g = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464.53 46.47a31.64 31.64 0 0 0-31.5-.88a12.07 12.07 0 0 0-1.25.74l-84.15 55a8 8 0 0 0-3.63 6.72v357.46a8 8 0 0 0 12.52 6.63l107.07-73.46a32 32 0 0 0 16.41-28v-296a32.76 32.76 0 0 0-15.47-28.21z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1_ = [_hoisted_2$7T, _hoisted_3$6O, _hoisted_4$4g];
    vue.defineComponent({
      name: 'Map',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7T, _hoisted_5$1_);
      }
    });

    const _hoisted_1$7S = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7S = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M313.27 124.64L198.73 51.36a32 32 0 0 0-29.28.35L56.51 127.49A16 16 0 0 0 48 141.63v295.8a16 16 0 0 0 23.49 14.14l97.82-63.79a32 32 0 0 1 29.5-.24l111.86 73a32 32 0 0 0 29.27-.11l115.43-75.94a16 16 0 0 0 8.63-14.2V74.57a16 16 0 0 0-23.49-14.14l-98 63.86a32 32 0 0 1-29.24.35z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6N = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M328 128v336'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4f = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M184 48v336'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1Z = [_hoisted_2$7S, _hoisted_3$6N, _hoisted_4$4f];
    vue.defineComponent({
      name: 'MapOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7S, _hoisted_5$1Z);
      }
    });

    const _hoisted_1$7R = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7R = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M327.71 130.93L184 39L32 144v336l152.29-98.93L328 473l152-105V32zM312 421l-112-72V91l112 72z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6M = [_hoisted_2$7R];
    vue.defineComponent({
      name: 'MapSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7R, _hoisted_3$6M);
      }
    });

    const _hoisted_1$7Q = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7Q = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '352',
      r: '32',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6L = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M99.78 32a48 48 0 0 0-42.94 26.53l-31 62A48.26 48.26 0 0 0 24.28 160h278.2a4 4 0 0 0 3.39-1.87l75.5-120A4 4 0 0 0 378 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4e = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M486.17 120.56l-31-62a47.7 47.7 0 0 0-32.79-25.46L342.5 160L298 231.08a128 128 0 0 0-84 0l-23.32-37.2a4 4 0 0 0-3.39-1.88H51.14a4 4 0 0 0-3.36 6.16l82.7 128.73a128 128 0 1 0 251 0L483.62 168a48.22 48.22 0 0 0 2.55-47.44zm-226 295.31a64 64 0 1 1 59.69-59.69a64.08 64.08 0 0 1-59.68 59.69z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1Y = [_hoisted_2$7Q, _hoisted_3$6L, _hoisted_4$4e];
    vue.defineComponent({
      name: 'Medal',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7Q, _hoisted_5$1Y);
      }
    });

    const _hoisted_1$7P = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7P = /*#__PURE__*/vue.createStaticVNode('<circle cx="256" cy="352" r="112" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><circle cx="256" cy="352" r="48" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><path d="M147 323L41.84 159.32a32 32 0 0 1-1.7-31.61l31-62A32 32 0 0 1 99.78 48h312.44a32 32 0 0 1 28.62 17.69l31 62a32 32 0 0 1-1.7 31.61L365 323" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M371 144H37"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M428.74 52.6L305 250"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M140.55 144L207 250"></path>', 6);

    const _hoisted_8$e = [_hoisted_2$7P];
    vue.defineComponent({
      name: 'MedalOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7P, _hoisted_8$e);
      }
    });

    const _hoisted_1$7O = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7O = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M80 32L16 160h289.11l80.22-128H80z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6K = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M496 144L424 32L298 231.08a128 128 0 0 0-84 0L189.53 192H43.82l86.66 134.89a128 128 0 1 0 251 0zM256 422a70 70 0 1 1 70-70a70.08 70.08 0 0 1-70 70z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4d = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '352',
      r: '32',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1X = [_hoisted_2$7O, _hoisted_3$6K, _hoisted_4$4d];
    vue.defineComponent({
      name: 'MedalSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7O, _hoisted_5$1X);
      }
    });

    const _hoisted_1$7N = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7N = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M272 464h-32a32 32 0 0 1-32-32l.05-85.82a4 4 0 0 0-6-3.47l-74.34 43.06a31.48 31.48 0 0 1-43-11.52l-16.5-28.64l-.06-.1a31.65 31.65 0 0 1 11.56-42.8l74.61-43.25a4 4 0 0 0 0-6.92l-74.54-43.21a31.41 31.41 0 0 1-11.55-43l16.44-28.55a31.48 31.48 0 0 1 19.27-14.74a31.14 31.14 0 0 1 23.8 3.2l74.31 43a4 4 0 0 0 6-3.47L208 80a32 32 0 0 1 32-32h32a32 32 0 0 1 32 32v85.72a4 4 0 0 0 6 3.47l74.34-43.06a31.51 31.51 0 0 1 43 11.52l16.49 28.64l.06.09a31.52 31.52 0 0 1-11.64 42.86l-74.53 43.2a4 4 0 0 0 0 6.92l74.53 43.2a31.42 31.42 0 0 1 11.56 43l-16.44 28.55a31.48 31.48 0 0 1-19.27 14.74a31.14 31.14 0 0 1-23.8-3.2l-74.31-43a4 4 0 0 0-6 3.46L304 432a32 32 0 0 1-32 32zm-93.56-197.48zm0-21zm155.1-.08zm0 0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6J = [_hoisted_2$7N];
    vue.defineComponent({
      name: 'Medical',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7N, _hoisted_3$6J);
      }
    });

    const _hoisted_1$7M = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7M = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M429.93 174.27l-16.47-28.59a15.49 15.49 0 0 0-21.15-5.7l-98.39 57a4 4 0 0 1-6-3.5L288 80a16 16 0 0 0-16-16h-32a16 16 0 0 0-16 16l.07 113.57a4 4 0 0 1-6 3.5l-98.39-57a15.49 15.49 0 0 0-21.15 5.7l-16.46 28.6a15.42 15.42 0 0 0 5.69 21.1l98.49 57.08a4 4 0 0 1 0 6.9l-98.49 57.08a15.54 15.54 0 0 0-5.69 21.1l16.47 28.59a15.49 15.49 0 0 0 21.15 5.7l98.39-57a4 4 0 0 1 6 3.5L224 432a16 16 0 0 0 16 16h32a16 16 0 0 0 16-16l-.07-113.67a4 4 0 0 1 6-3.5l98.39 57a15.49 15.49 0 0 0 21.15-5.7l16.47-28.59a15.42 15.42 0 0 0-5.69-21.1l-98.49-57.08a4 4 0 0 1 0-6.9l98.49-57.08a15.51 15.51 0 0 0 5.68-21.11z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6I = [_hoisted_2$7M];
    vue.defineComponent({
      name: 'MedicalOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7M, _hoisted_3$6I);
      }
    });

    const _hoisted_1$7L = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7L = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M351.9 256L460 193.6l-48-83.2l-108 62.4V48h-96v124.8l-108-62.4l-48 83.2L160.1 256L52 318.4l48 83.2l108-62.4V464h96V339.2l108 62.4l48-83.2L351.9 256z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6H = [_hoisted_2$7L];
    vue.defineComponent({
      name: 'MedicalSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7L, _hoisted_3$6H);
      }
    });

    const _hoisted_1$7K = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7K = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 64H176a16 16 0 0 0-16 16v16h192V80a16 16 0 0 0-16-16z',
      fill: 'none'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6G = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M432 96h-48V80a48.05 48.05 0 0 0-48-48H176a48.05 48.05 0 0 0-48 48v16H80a64.07 64.07 0 0 0-64 64v256a64 64 0 0 0 64 64h352a64 64 0 0 0 64-64V160a64.07 64.07 0 0 0-64-64zm-96 208h-64v64a16 16 0 0 1-32 0v-64h-64a16 16 0 0 1 0-32h64v-64a16 16 0 0 1 32 0v64h64a16 16 0 0 1 0 32zm16-208H160V80a16 16 0 0 1 16-16h160a16 16 0 0 1 16 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4c = [_hoisted_2$7K, _hoisted_3$6G];
    vue.defineComponent({
      name: 'Medkit',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7K, _hoisted_4$4c);
      }
    });

    const _hoisted_1$7J = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7J = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '32',
      y: '112',
      width: '448',
      height: '352',
      rx: '48',
      ry: '48',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6F = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M144 112V80a32 32 0 0 1 32-32h160a32 32 0 0 1 32 32v32',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4b = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 208v160'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1W = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M336 288H176'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$Y = [_hoisted_2$7J, _hoisted_3$6F, _hoisted_4$4b, _hoisted_5$1W];
    vue.defineComponent({
      name: 'MedkitOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7J, _hoisted_6$Y);
      }
    });

    const _hoisted_1$7I = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7I = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      d: 'M168 72h176v24H168z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6E = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M484 96H384V40a8 8 0 0 0-8-8H136a8 8 0 0 0-8 8v56H28a12 12 0 0 0-12 12v360a12 12 0 0 0 12 12h456a12 12 0 0 0 12-12V108a12 12 0 0 0-12-12zM168 72h176v24H168zm184 238h-74v74h-44v-74h-74v-44h74v-74h44v74h74z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4a = [_hoisted_2$7I, _hoisted_3$6E];
    vue.defineComponent({
      name: 'MedkitSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7I, _hoisted_4$4a);
      }
    });

    const _hoisted_1$7H = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7H = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 176v.66a17.38 17.38 0 0 1-4.2 11.23v.05C38.4 194.32 32 205.74 32 224c0 16.55 5.3 28.23 11.68 35.91A19 19 0 0 1 48 272a32 32 0 0 0 32 32h8a8 8 0 0 0 8-8V152a8 8 0 0 0-8-8h-8a32 32 0 0 0-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6D = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M452.18 186.55l-.93-.17a4 4 0 0 1-3.25-3.93V62c0-12.64-8.39-24-20.89-28.32c-11.92-4.11-24.34-.76-31.68 8.53a431.18 431.18 0 0 1-51.31 51.69c-23.63 20-46.24 34.25-67 42.31a8 8 0 0 0-5.15 7.47V299a16 16 0 0 0 9.69 14.69c19.34 8.29 40.24 21.83 62 40.28a433.74 433.74 0 0 1 51.68 52.16a26.22 26.22 0 0 0 21.1 9.87a33.07 33.07 0 0 0 10.44-1.74C439.71 410 448 399.05 448 386.4V265.53a4 4 0 0 1 3.33-3.94l.85-.14C461.8 258.84 480 247.67 480 224s-18.2-34.84-27.82-37.45z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$49 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M240 320V152a8 8 0 0 0-8-8h-96a8 8 0 0 0-8 8v304a24 24 0 0 0 24 24h52.45a32.66 32.66 0 0 0 25.93-12.45a31.65 31.65 0 0 0 5.21-29.05c-1.62-5.18-3.63-11-5.77-17.19c-7.91-22.9-18.34-37.07-21.12-69.32A32 32 0 0 0 240 320z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1V = [_hoisted_2$7H, _hoisted_3$6D, _hoisted_4$49];
    vue.defineComponent({
      name: 'Megaphone',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7H, _hoisted_5$1V);
      }
    });

    const _hoisted_1$7G = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7G = /*#__PURE__*/vue.createStaticVNode('<path d="M407.94 52.22S321.3 160 240 160H80a16 16 0 0 0-16 16v96a16 16 0 0 0 16 16h160c81.3 0 167.94 108.23 167.94 108.23c6.06 8 24.06 2.52 24.06-9.83V62c0-12.31-17-18.82-24.06-9.78z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M64 256s-16-6-16-32s16-32 16-32" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M448 246s16-4.33 16-22s-16-22-16-22" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 160v128"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M112 160v128"></path><path d="M144 288v168a8 8 0 0 0 8 8h53a16 16 0 0 0 15.29-20.73C211.91 416.39 192 386.08 192 336h16a16 16 0 0 0 16-16v-16a16 16 0 0 0-16-16h-16" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 6);

    const _hoisted_8$d = [_hoisted_2$7G];
    vue.defineComponent({
      name: 'MegaphoneOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7G, _hoisted_8$d);
      }
    });

    const _hoisted_1$7F = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7F = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M128 144v332a4 4 0 0 0 4 4h100.07a8 8 0 0 0 7.82-9.7L208.71 352H232a8 8 0 0 0 8-8V144z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6C = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M452.18 186.55L448 185.5V36a4 4 0 0 0-4-4h-42.5a4 4 0 0 0-2.63 1L272 144v160l126.87 111a4 4 0 0 0 2.63 1H444a4 4 0 0 0 4-4V262.5l4.18-1.05C461.8 258.84 480 247.67 480 224s-18.2-34.84-27.82-37.45z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$48 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M96 144H52a4 4 0 0 0-4 4v35.59a43 43 0 0 0-4.24 4.35C38.4 194.32 32 205.74 32 224c0 20.19 7.89 33.13 16 40.42V300a4 4 0 0 0 4 4h44z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1U = [_hoisted_2$7F, _hoisted_3$6C, _hoisted_4$48];
    vue.defineComponent({
      name: 'MegaphoneSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7F, _hoisted_5$1U);
      }
    });

    const _hoisted_1$7E = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7E = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '48',
      d: 'M88 152h336'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6B = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '48',
      d: 'M88 256h336'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$47 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '48',
      d: 'M88 360h336'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1T = [_hoisted_2$7E, _hoisted_3$6B, _hoisted_4$47];
    vue.defineComponent({
      name: 'Menu',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7E, _hoisted_5$1T);
      }
    });

    const _hoisted_1$7D = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7D = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M80 160h352'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6A = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M80 256h352'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$46 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M80 352h352'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1S = [_hoisted_2$7D, _hoisted_3$6A, _hoisted_4$46];
    vue.defineComponent({
      name: 'MenuOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7D, _hoisted_5$1S);
      }
    });

    const _hoisted_1$7C = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7C = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M64 384h384v-42.67H64zm0-106.67h384v-42.66H64zM64 128v42.67h384V128z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6z = [_hoisted_2$7C];
    vue.defineComponent({
      name: 'MenuSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7C, _hoisted_3$6z);
      }
    });

    const _hoisted_1$7B = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7B = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M192 448h128'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 208v32c0 70.4-57.6 128-128 128h0c-70.4 0-128-57.6-128-128v-32',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$45 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 368v80'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1R = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 320a78.83 78.83 0 0 1-56.55-24.1A80.89 80.89 0 0 1 176 239V128a79.69 79.69 0 0 1 80-80c44.86 0 80 35.14 80 80v111c0 44.66-35.89 81-80 81z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$X = [_hoisted_2$7B, _hoisted_3$6y, _hoisted_4$45, _hoisted_5$1R];
    vue.defineComponent({
      name: 'Mic',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7B, _hoisted_6$X);
      }
    });

    const _hoisted_1$7A = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7A = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm-48 128a48.14 48.14 0 0 1 48-48a48.14 48.14 0 0 1 48 48v64a48.14 48.14 0 0 1-48 48a48.14 48.14 0 0 1-48-48zm144 72.22c0 23.36-10.94 45.61-30.79 62.66A103.71 103.71 0 0 1 272 334.26V352h16a16 16 0 0 1 0 32h-64a16 16 0 0 1 0-32h16v-17.74a103.71 103.71 0 0 1-49.21-23.38c-19.85-17.05-30.79-39.3-30.79-62.66V224.3a16 16 0 0 1 32 0v23.92c0 25.66 28 55.48 64 55.48c29.6 0 64-24.23 64-55.48V224.3a16 16 0 1 1 32 0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6x = [_hoisted_2$7A];
    vue.defineComponent({
      name: 'MicCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7A, _hoisted_3$6x);
      }
    });

    const _hoisted_1$7z = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7z = /*#__PURE__*/vue.createStaticVNode('<path d="M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M224 368h64"></path><path d="M336 224.3v23.92c0 39.42-40.58 71.48-80 71.48h0c-39.42 0-80-32.06-80-71.48V224.3" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 320v48"></path><rect x="208" y="128" width="96" height="160" rx="48" ry="48" fill="currentColor"></rect>', 5);

    const _hoisted_7$z = [_hoisted_2$7z];
    vue.defineComponent({
      name: 'MicCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7z, _hoisted_7$z);
      }
    });

    const _hoisted_1$7y = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm-48 128a48.14 48.14 0 0 1 48-48a48.14 48.14 0 0 1 48 48v64a48.14 48.14 0 0 1-48 48a48.14 48.14 0 0 1-48-48zm144 72.22c0 23.36-10.94 45.61-30.79 62.66A103.71 103.71 0 0 1 272 334.26V352h32v32h-96v-32h32v-17.74a103.71 103.71 0 0 1-49.21-23.38c-19.85-17.05-30.79-39.3-30.79-62.66V208.3h32v39.92c0 25.66 28 55.48 64 55.48c29.6 0 64-24.23 64-55.48V208.3h32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6w = [_hoisted_2$7y];
    vue.defineComponent({
      name: 'MicCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7y, _hoisted_3$6w);
      }
    });

    const _hoisted_1$7x = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7x = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M432 400L96 64"></path><path d="M400 240v-31.55c0-8.61-6.62-16-15.23-16.43A16 16 0 0 0 368 208v32a111.68 111.68 0 0 1-2.68 24.38a2 2 0 0 0 .53 1.84l22.59 22.59a2 2 0 0 0 3.29-.72A143.27 143.27 0 0 0 400 240z" fill="currentColor"></path><path d="M256 352a112.36 112.36 0 0 1-112-112v-31.55c0-8.61-6.62-16-15.23-16.43A16 16 0 0 0 112 208v32c0 74 56.1 135.12 128 143.11V432h-47.55c-8.61 0-16 6.62-16.43 15.23A16 16 0 0 0 192 464h127.55c8.61 0 16-6.62 16.43-15.23A16 16 0 0 0 320 432h-48v-48.89a143.08 143.08 0 0 0 52-16.22a4 4 0 0 0 .91-6.35l-18.4-18.39a3 3 0 0 0-3.41-.58A111 111 0 0 1 256 352z" fill="currentColor"></path><path d="M257.14 48a79.66 79.66 0 0 0-68.47 36.57a4 4 0 0 0 .54 5L332.59 233a2 2 0 0 0 3.41-1.42V128.91C336 85 301 48.6 257.14 48z" fill="currentColor"></path><path d="M179.41 215a2 2 0 0 0-3.41 1.42V239a80.89 80.89 0 0 0 23.45 56.9a78.55 78.55 0 0 0 77.8 21.19a2 2 0 0 0 .86-3.35z" fill="currentColor"></path>', 5);

    const _hoisted_7$y = [_hoisted_2$7x];
    vue.defineComponent({
      name: 'MicOff',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7x, _hoisted_7$y);
      }
    });

    const _hoisted_1$7w = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7w = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm0 80a48.14 48.14 0 0 1 48 48v64a47.84 47.84 0 0 1-.63 7.71a2 2 0 0 1-3.46 1l-84.42-92.86a4 4 0 0 1-.47-4.77A48.08 48.08 0 0 1 256 128zm32 256h-63.55c-8.61 0-16-6.62-16.43-15.23A16 16 0 0 1 224 352h16v-17.74a103.71 103.71 0 0 1-49.21-23.38c-19.85-17.05-30.79-39.3-30.79-62.66V224a15.91 15.91 0 0 1 16.39-16A16.26 16.26 0 0 1 192 224.4v23.82c0 25.66 28 55.48 64 55.48c1.67 0 3.37-.09 5.06-.24a3.94 3.94 0 0 1 3.29 1.29l21.07 23.19a2 2 0 0 1-.89 3.26a100.33 100.33 0 0 1-12.53 3.06V352h15.55c8.61 0 16 6.62 16.43 15.23A16 16 0 0 1 288 384zm-77.89-138.91l36.46 40.11a1 1 0 0 1-.95 1.66a48.26 48.26 0 0 1-37.25-41a1 1 0 0 1 1.74-.77zm152.65 119.75a16 16 0 0 1-22.6-1.08l-192-210a16 16 0 0 1 23.68-21.52l192 210a16 16 0 0 1-1.08 22.6zM352 248.22a77.12 77.12 0 0 1-11.93 40.87a2 2 0 0 1-3.19.3l-19.19-21.1a4 4 0 0 1-.76-4.16a43.35 43.35 0 0 0 3.07-15.91v-23.8a16.3 16.3 0 0 1 13.64-16.24c9.88-1.48 18.36 6.51 18.36 16.12z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6v = [_hoisted_2$7w];
    vue.defineComponent({
      name: 'MicOffCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7w, _hoisted_3$6v);
      }
    });

    const _hoisted_1$7v = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7v = /*#__PURE__*/vue.createStaticVNode('<path d="M256 464c-114.69 0-208-93.31-208-208S141.31 48 256 48s208 93.31 208 208s-93.31 208-208 208zm0-384c-97 0-176 79-176 176s79 176 176 176s176-78.95 176-176S353.05 80 256 80z" fill="currentColor"></path><path d="M352 369a15.93 15.93 0 0 1-11.84-5.24l-192-210a16 16 0 0 1 23.68-21.52l192 210A16 16 0 0 1 352 369z" fill="currentColor"></path><path d="M352 248.22v-23.8a16.3 16.3 0 0 0-13.64-16.24c-9.88-1.48-18.36 6.51-18.36 16.12v23.92a43.35 43.35 0 0 1-3.07 15.91a4 4 0 0 0 .76 4.16l19.19 21.1a2 2 0 0 0 3.19-.3A77.12 77.12 0 0 0 352 248.22z" fill="currentColor"></path><path d="M304 240v-64a48.14 48.14 0 0 0-48-48a48.08 48.08 0 0 0-41 23.1a4 4 0 0 0 .47 4.77l84.42 92.86a2 2 0 0 0 3.46-1A47.84 47.84 0 0 0 304 240z" fill="currentColor"></path><path d="M246.57 285.2l-36.46-40.11a1 1 0 0 0-1.74.8a48.26 48.26 0 0 0 37.25 41a1 1 0 0 0 .95-1.69z" fill="currentColor"></path><path d="M287.55 352H272v-17.74a100.33 100.33 0 0 0 12.53-3.06a2 2 0 0 0 .89-3.26l-21.07-23.19a3.94 3.94 0 0 0-3.29-1.29c-1.69.15-3.39.24-5.06.24c-36 0-64-29.82-64-55.48V224.4a16.26 16.26 0 0 0-15.61-16.4A15.91 15.91 0 0 0 160 224v24.22c0 23.36 10.94 45.61 30.79 62.66A103.71 103.71 0 0 0 240 334.26V352h-15.55c-8.61 0-16 6.62-16.43 15.23A16 16 0 0 0 224 384h64a16 16 0 0 0 16-16.77c-.42-8.61-7.84-15.23-16.45-15.23z" fill="currentColor"></path>', 6);

    const _hoisted_8$c = [_hoisted_2$7v];
    vue.defineComponent({
      name: 'MicOffCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7v, _hoisted_8$c);
      }
    });

    const _hoisted_1$7u = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7u = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm64 200.22V208h32v40.22a77.53 77.53 0 0 1-13.37 43.11L316 266.4a44.11 44.11 0 0 0 4-18.18zM256 128a48.14 48.14 0 0 1 48 48v64a48.07 48.07 0 0 1-1.44 11.64l-89-97.92A48.13 48.13 0 0 1 256 128zm48 256h-96v-32h32v-17.74a103.71 103.71 0 0 1-49.21-23.38c-19.85-17.05-30.79-39.3-30.79-62.66V208h32v40.22c0 25.66 28 55.48 64 55.48a56.91 56.91 0 0 0 7-.45l24.52 27a99.57 99.57 0 0 1-15.5 4V352h32zm-95.91-141.13l40.5 44.55a48.2 48.2 0 0 1-40.5-44.55zm136.07 124.89l-200.5-218.5l23.68-21.52l200.5 218.5z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6u = [_hoisted_2$7u];
    vue.defineComponent({
      name: 'MicOffCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7u, _hoisted_3$6u);
      }
    });

    const _hoisted_1$7t = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7t = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M432 400L96 64"></path><path d="M400 240v-31.55c0-8.61-6.62-16-15.23-16.43A16 16 0 0 0 368 208v32a111.58 111.58 0 0 1-2.45 23.31a4.05 4.05 0 0 0 1.07 3.69l21.82 21.81a2 2 0 0 0 3.29-.72A143.27 143.27 0 0 0 400 240z" fill="currentColor"></path><path d="M256 352a112.36 112.36 0 0 1-112-112v-31.55c0-8.61-6.62-16-15.23-16.43A16 16 0 0 0 112 208v32c0 74 56.1 135.12 128 143.11V432h-47.55c-8.61 0-16 6.62-16.43 15.23A16 16 0 0 0 192 464h127.55c8.61 0 16-6.62 16.43-15.23A16 16 0 0 0 320 432h-48v-48.89a143.08 143.08 0 0 0 52-16.22a4 4 0 0 0 .91-6.35L307 342.63a4 4 0 0 0-4.51-.78A110.78 110.78 0 0 1 256 352z" fill="currentColor"></path><path d="M256 80a47.18 47.18 0 0 1 48 48v74.72a4 4 0 0 0 1.17 2.82L332.59 233a2 2 0 0 0 3.41-1.42V128.91C336 85 301 48.6 257.14 48a79.66 79.66 0 0 0-68.47 36.57a4 4 0 0 0 .54 5l19.54 19.54a2 2 0 0 0 3.25-.63A47.44 47.44 0 0 1 256 80z" fill="currentColor"></path><path d="M207.27 242.9L179.41 215a2 2 0 0 0-3.41 1.42V239a80.89 80.89 0 0 0 23.45 56.9a78.55 78.55 0 0 0 77.8 21.19a2 2 0 0 0 .86-3.35l-24.91-24.91a4.08 4.08 0 0 0-2.42-1.15c-21.65-2.52-39.48-20.44-42.37-42.43a4 4 0 0 0-1.14-2.35z" fill="currentColor"></path>', 5);

    const _hoisted_7$x = [_hoisted_2$7t];
    vue.defineComponent({
      name: 'MicOffOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7t, _hoisted_7$x);
      }
    });

    const _hoisted_1$7s = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7s = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M432 400L96 64"></path><path d="M368 192v48a111.74 111.74 0 0 1-2.93 25.45L390.65 291a143.07 143.07 0 0 0 9.35-51v-48z" fill="currentColor"></path><path d="M272 432v-48.89a143.11 143.11 0 0 0 56.65-18.83L305 340.65A112.13 112.13 0 0 1 144 240v-48h-32v48c0 74 56.1 135.12 128 143.11V432h-64v32h160v-32z" fill="currentColor"></path><path d="M336 236.37V128c0-44.86-35.14-80-80-80a79.68 79.68 0 0 0-69 39.34" fill="currentColor"></path><path d="M176 211.63V239a80.89 80.89 0 0 0 23.45 56.9a78.55 78.55 0 0 0 81 20.21z" fill="currentColor"></path>', 5);

    const _hoisted_7$w = [_hoisted_2$7s];
    vue.defineComponent({
      name: 'MicOffSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7s, _hoisted_7$w);
      }
    });

    const _hoisted_1$7r = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7r = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M192 448h128'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6t = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 208v32c0 70.4-57.6 128-128 128h0c-70.4 0-128-57.6-128-128v-32',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$44 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 368v80'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1Q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 64a63.68 63.68 0 0 0-64 64v111c0 35.2 29 65 64 65s64-29 64-65V128c0-36-28-64-64-64z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$W = [_hoisted_2$7r, _hoisted_3$6t, _hoisted_4$44, _hoisted_5$1Q];
    vue.defineComponent({
      name: 'MicOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7r, _hoisted_6$W);
      }
    });

    const _hoisted_1$7q = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7q = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M192 448h128'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6s = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 208v32c0 70.4-57.6 128-128 128h0c-70.4 0-128-57.6-128-128v-32',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$43 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M256 368v80'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1P = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 320a78.83 78.83 0 0 1-56.55-24.1A80.89 80.89 0 0 1 176 239V128a79.69 79.69 0 0 1 80-80c44.86 0 80 35.14 80 80v111c0 44.66-35.89 81-80 81z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$V = [_hoisted_2$7q, _hoisted_3$6s, _hoisted_4$43, _hoisted_5$1P];
    vue.defineComponent({
      name: 'MicSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7q, _hoisted_6$V);
      }
    });

    const _hoisted_1$7p = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7p = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M264 480A232 232 0 0 1 32 248c0-94 54-178.28 137.61-214.67a16 16 0 0 1 21.06 21.06C181.07 76.43 176 104.66 176 136c0 110.28 89.72 200 200 200c31.34 0 59.57-5.07 81.61-14.67a16 16 0 0 1 21.06 21.06C442.28 426 358 480 264 480z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6r = [_hoisted_2$7p];
    vue.defineComponent({
      name: 'Moon',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7p, _hoisted_3$6r);
      }
    });

    const _hoisted_1$7o = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7o = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M160 136c0-30.62 4.51-61.61 16-88C99.57 81.27 48 159.32 48 248c0 119.29 96.71 216 216 216c88.68 0 166.73-51.57 200-128c-26.39 11.49-57.38 16-88 16c-119.29 0-216-96.71-216-216z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6q = [_hoisted_2$7o];
    vue.defineComponent({
      name: 'MoonOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7o, _hoisted_3$6q);
      }
    });

    const _hoisted_1$7n = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7n = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M152.62 126.77c0-33 4.85-66.35 17.23-94.77C87.54 67.83 32 151.89 32 247.38C32 375.85 136.15 480 264.62 480c95.49 0 179.55-55.54 215.38-137.85c-28.42 12.38-61.8 17.23-94.77 17.23c-128.47 0-232.61-104.14-232.61-232.61z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6p = [_hoisted_2$7n];
    vue.defineComponent({
      name: 'MoonSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7n, _hoisted_3$6p);
      }
    });

    const _hoisted_1$7m = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7m = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M176 112l80-80l80 80"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M255.98 32l.02 448"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M176 400l80 80l80-80"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M400 176l80 80l-80 80"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M112 176l-80 80l80 80"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M32 256h448"></path>', 6);

    const _hoisted_8$b = [_hoisted_2$7m];
    vue.defineComponent({
      name: 'Move',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7m, _hoisted_8$b);
      }
    });

    const _hoisted_1$7l = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7l = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M176 112l80-80l80 80"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M255.98 32l.02 448"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M176 400l80 80l80-80"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M400 176l80 80l-80 80"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M112 176l-80 80l80 80"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M32 256h448"></path>', 6);

    const _hoisted_8$a = [_hoisted_2$7l];
    vue.defineComponent({
      name: 'MoveOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7l, _hoisted_8$a);
      }
    });

    const _hoisted_1$7k = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7k = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32" d="M176 112l80-80l80 80"></path><path fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32" d="M255.98 32l.02 448"></path><path fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32" d="M176 400l80 80l80-80"></path><path fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32" d="M400 176l80 80l-80 80"></path><path fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32" d="M112 176l-80 80l80 80"></path><path fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32" d="M32 256h448"></path>', 6);

    const _hoisted_8$9 = [_hoisted_2$7k];
    vue.defineComponent({
      name: 'MoveSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7k, _hoisted_8$9);
      }
    });

    const _hoisted_1$7j = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7j = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M183.83 480a55.2 55.2 0 0 1-32.36-10.55A56.64 56.64 0 0 1 128 423.58a50.26 50.26 0 0 1 34.14-47.73L213 358.73a16.25 16.25 0 0 0 11-15.49V92a32.1 32.1 0 0 1 24.09-31.15l108.39-28.14A22 22 0 0 1 384 54v57.75a32.09 32.09 0 0 1-24.2 31.19l-91.65 23.13A16.24 16.24 0 0 0 256 181.91V424a48.22 48.22 0 0 1-32.78 45.81l-21.47 7.23a56 56 0 0 1-17.92 2.96z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6o = [_hoisted_2$7j];
    vue.defineComponent({
      name: 'MusicalNote',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7j, _hoisted_3$6o);
      }
    });

    const _hoisted_1$7i = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7i = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M240 343.31V424a32.28 32.28 0 0 1-21.88 30.65l-21.47 7.23c-25.9 8.71-52.65-10.75-52.65-38.32h0A34.29 34.29 0 0 1 167.25 391l50.87-17.12A32.29 32.29 0 0 0 240 343.24V92a16.13 16.13 0 0 1 12.06-15.66L360.49 48.2A6 6 0 0 1 368 54v57.76a16.13 16.13 0 0 1-12.12 15.67l-91.64 23.13A32.25 32.25 0 0 0 240 181.91v39.39',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6n = [_hoisted_2$7i];
    vue.defineComponent({
      name: 'MusicalNoteOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7i, _hoisted_3$6n);
      }
    });

    const _hoisted_1$7h = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7h = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M381.55 32.05c-18.13 4.28-126.57 31.07-156 38.19a2 2 0 0 0-1.55 1.94V353.3a2 2 0 0 1-1.32 1.88L182 369.88c-29.82 10.66-54 18.94-54 59.06c0 32.47 23.53 47.18 37.95 50a81.77 81.77 0 0 0 15 1.08c8.89 0 31-3.59 47.52-14.24C256 448 256 448 256 415.93V169.16a2 2 0 0 1 1.49-1.94l125-33a2 2 0 0 0 1.49-1.94V34a2 2 0 0 0-2.43-1.95z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6m = [_hoisted_2$7h];
    vue.defineComponent({
      name: 'MusicalNoteSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7h, _hoisted_3$6m);
      }
    });

    const _hoisted_1$7g = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7g = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M421.84 37.37a25.86 25.86 0 0 0-22.6-4.46L199.92 86.49A32.3 32.3 0 0 0 176 118v226c0 6.74-4.36 12.56-11.11 14.83l-.12.05l-52 18C92.88 383.53 80 402 80 423.91a55.54 55.54 0 0 0 23.23 45.63A54.78 54.78 0 0 0 135.34 480a55.82 55.82 0 0 0 17.75-2.93l.38-.13l21.84-7.94A47.84 47.84 0 0 0 208 423.91v-212c0-7.29 4.77-13.21 12.16-15.07l.21-.06L395 150.14a4 4 0 0 1 5 3.86v141.93c0 6.75-4.25 12.38-11.11 14.68l-.25.09l-50.89 18.11A49.09 49.09 0 0 0 304 375.92a55.67 55.67 0 0 0 23.23 45.8a54.63 54.63 0 0 0 49.88 7.35l.36-.12l21.84-7.95A47.83 47.83 0 0 0 432 375.92V58a25.74 25.74 0 0 0-10.16-20.63z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6l = [_hoisted_2$7g];
    vue.defineComponent({
      name: 'MusicalNotes',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7g, _hoisted_3$6l);
      }
    });

    const _hoisted_1$7f = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7f = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M192 218v-6c0-14.84 10-27 24.24-30.59l174.59-46.68A20 20 0 0 1 416 154v22',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6k = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 295.94v80c0 13.91-8.93 25.59-22 30l-22 8c-25.9 8.72-52-10.42-52-38h0a33.37 33.37 0 0 1 23-32l51-18.15c13.07-4.4 22-15.94 22-29.85V58a10 10 0 0 0-12.6-9.61L204 102a16.48 16.48 0 0 0-12 16v226c0 13.91-8.93 25.6-22 30l-52 18c-13.88 4.68-22 17.22-22 32h0c0 27.58 26.52 46.55 52 38l22-8c13.07-4.4 22-16.08 22-30v-80',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$42 = [_hoisted_2$7f, _hoisted_3$6k];
    vue.defineComponent({
      name: 'MusicalNotesOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7f, _hoisted_4$42);
      }
    });

    const _hoisted_1$7e = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7e = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M429.46 32.07c-23.6 6.53-205.55 58.81-250.54 71.43a4 4 0 0 0-2.92 3.83v247a2 2 0 0 1-1.33 1.89l-27.85 9.55c-19 7.44-66.82 16.68-66.82 59.19c0 35.54 24.63 51.54 45.86 54.28a52.06 52.06 0 0 0 7.81.8c7.37 0 36.38-7.08 53.3-18.08C208 448.25 208 448 208 412V202c0-.9.62-.84 1.48-1.07l188-51.92a2 2 0 0 1 2.53 2v155.54a2 2 0 0 1-1.36 1.89c-8.9 3-19.23 6.5-26.48 9.12C341.39 328.68 304 335.65 304 376c0 38.51 28.26 54.58 46.3 55.83a87.37 87.37 0 0 0 21.33-1c9-1.38 24.09-5.9 38.14-14.86C432 401.79 432 401.51 432 360V34a2 2 0 0 0-2.54-1.93z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6j = [_hoisted_2$7e];
    vue.defineComponent({
      name: 'MusicalNotesSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7e, _hoisted_3$6j);
      }
    });

    const _hoisted_1$7d = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7d = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M272 464a16 16 0 0 1-16-16.42V264.13a8 8 0 0 0-8-8H64.41a16.31 16.31 0 0 1-15.49-10.65a16 16 0 0 1 8.41-19.87l384-176.15a16 16 0 0 1 21.22 21.19l-176 384A16 16 0 0 1 272 464z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6i = [_hoisted_2$7d];
    vue.defineComponent({
      name: 'Navigate',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7d, _hoisted_3$6i);
      }
    });

    const _hoisted_1$7c = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7c = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M258.9 48C141.92 46.42 46.42 141.92 48 258.9c1.56 112.19 92.91 203.54 205.1 205.1c117 1.6 212.48-93.9 210.88-210.88C462.44 140.91 371.09 49.56 258.9 48zM351 175.24l-82.24 186.52c-4.79 10.47-20.78 7-20.78-4.56V268a4 4 0 0 0-4-4H154.8c-11.52 0-15-15.87-4.57-20.67L336.76 161A10.73 10.73 0 0 1 351 175.24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6h = [_hoisted_2$7c];
    vue.defineComponent({
      name: 'NavigateCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7c, _hoisted_3$6h);
      }
    });

    const _hoisted_1$7b = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7b = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336.76 161l-186.53 82.35c-10.47 4.8-6.95 20.67 4.57 20.67H244a4 4 0 0 1 4 4v89.18c0 11.52 16 15 20.78 4.56L351 175.24A10.73 10.73 0 0 0 336.76 161z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6g = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$41 = [_hoisted_2$7b, _hoisted_3$6g];
    vue.defineComponent({
      name: 'NavigateCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7b, _hoisted_4$41);
      }
    });

    const _hoisted_1$7a = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7a = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48A208.23 208.23 0 0 0 48 256c0 114.68 93.31 208 208 208a208.23 208.23 0 0 0 208-208c0-114.69-93.31-208-208-208zm-8 361V264H103l259-114.11z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6f = [_hoisted_2$7a];
    vue.defineComponent({
      name: 'NavigateCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7a, _hoisted_3$6f);
      }
    });

    const _hoisted_1$79 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$79 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 64L64 240.14h200a8 8 0 0 1 8 8V448z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6e = [_hoisted_2$79];
    vue.defineComponent({
      name: 'NavigateOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$79, _hoisted_3$6e);
      }
    });

    const _hoisted_1$78 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$78 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 32L32 240h240v240L480 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6d = [_hoisted_2$78];
    vue.defineComponent({
      name: 'NavigateSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$78, _hoisted_3$6d);
      }
    });

    const _hoisted_1$77 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$77 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M439.91 112h-23.82a.09.09 0 0 0-.09.09V416a32 32 0 0 0 32 32a32 32 0 0 0 32-32V152.09A40.09 40.09 0 0 0 439.91 112z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6c = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 416V72a40 40 0 0 0-40-40H72a40 40 0 0 0-40 40v352a56 56 0 0 0 56 56h342.85a1.14 1.14 0 0 0 1.15-1.15a1.14 1.14 0 0 0-.85-1.1A64.11 64.11 0 0 1 384 416zM96 128a16 16 0 0 1 16-16h64a16 16 0 0 1 16 16v64a16 16 0 0 1-16 16h-64a16 16 0 0 1-16-16zm208 272H112.45c-8.61 0-16-6.62-16.43-15.23A16 16 0 0 1 112 368h191.55c8.61 0 16 6.62 16.43 15.23A16 16 0 0 1 304 400zm0-64H112.45c-8.61 0-16-6.62-16.43-15.23A16 16 0 0 1 112 304h191.55c8.61 0 16 6.62 16.43 15.23A16 16 0 0 1 304 336zm0-64H112.45c-8.61 0-16-6.62-16.43-15.23A16 16 0 0 1 112 240h191.55c8.61 0 16 6.62 16.43 15.23A16 16 0 0 1 304 272zm0-64h-63.55c-8.61 0-16-6.62-16.43-15.23A16 16 0 0 1 240 176h63.55c8.61 0 16 6.62 16.43 15.23A16 16 0 0 1 304 208zm0-64h-63.55c-8.61 0-16-6.62-16.43-15.23A16 16 0 0 1 240 112h63.55c8.61 0 16 6.62 16.43 15.23A16 16 0 0 1 304 144z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$40 = [_hoisted_2$77, _hoisted_3$6c];
    vue.defineComponent({
      name: 'Newspaper',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$77, _hoisted_4$40);
      }
    });

    const _hoisted_1$76 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$76 = /*#__PURE__*/vue.createStaticVNode('<path d="M368 415.86V72a24.07 24.07 0 0 0-24-24H72a24.07 24.07 0 0 0-24 24v352a40.12 40.12 0 0 0 40 40h328" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></path><path d="M416 464h0a48 48 0 0 1-48-48V128h72a24 24 0 0 1 24 24v264a48 48 0 0 1-48 48z" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M240 128h64"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M240 192h64"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M112 256h192"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M112 320h192"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M112 384h192"></path><path d="M176 208h-64a16 16 0 0 1-16-16v-64a16 16 0 0 1 16-16h64a16 16 0 0 1 16 16v64a16 16 0 0 1-16 16z" fill="currentColor"></path>', 8);

    const _hoisted_10$4 = [_hoisted_2$76];
    vue.defineComponent({
      name: 'NewspaperOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$76, _hoisted_10$4);
      }
    });

    const _hoisted_1$75 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$75 = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '96',
      y: '112',
      width: '96',
      height: '96',
      rx: '16',
      ry: '16',
      fill: 'none'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6b = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M468 112h-52v304a32 32 0 0 0 32 32a32 32 0 0 0 32-32V124a12 12 0 0 0-12-12z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3$ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M431.15 477.75A64.11 64.11 0 0 1 384 416V44a12 12 0 0 0-12-12H44a12 12 0 0 0-12 12v380a56 56 0 0 0 56 56h342.85a1.14 1.14 0 0 0 .3-2.25zM96 208v-96h96v96zm224 192H96v-32h224zm0-64H96v-32h224zm0-64H96v-32h224zm0-64h-96v-32h96zm0-64h-96v-32h96z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1O = [_hoisted_2$75, _hoisted_3$6b, _hoisted_4$3$];
    vue.defineComponent({
      name: 'NewspaperSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$75, _hoisted_5$1O);
      }
    });

    const _hoisted_1$74 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$74 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M440.08 341.31c-1.66-2-3.29-4-4.89-5.93c-22-26.61-35.31-42.67-35.31-118c0-39-9.33-71-27.72-95c-13.56-17.73-31.89-31.18-56.05-41.12a3 3 0 0 1-.82-.67C306.6 51.49 282.82 32 256 32s-50.59 19.49-59.28 48.56a3.13 3.13 0 0 1-.81.65c-56.38 23.21-83.78 67.74-83.78 136.14c0 75.36-13.29 91.42-35.31 118c-1.6 1.93-3.23 3.89-4.89 5.93a35.16 35.16 0 0 0-4.65 37.62c6.17 13 19.32 21.07 34.33 21.07H410.5c14.94 0 28-8.06 34.19-21a35.17 35.17 0 0 0-4.61-37.66z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6a = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 480a80.06 80.06 0 0 0 70.44-42.13a4 4 0 0 0-3.54-5.87H189.12a4 4 0 0 0-3.55 5.87A80.06 80.06 0 0 0 256 480z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3_ = [_hoisted_2$74, _hoisted_3$6a];
    vue.defineComponent({
      name: 'Notifications',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$74, _hoisted_4$3_);
      }
    });

    const _hoisted_1$73 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$73 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm0 336c-20.9 0-37.52-8.86-39.75-27.58a4 4 0 0 1 4-4.42h71.45a4 4 0 0 1 4 4.48C293.15 374.85 276.68 384 256 384zm98-48H158c-11.84 0-18-15-11.19-23c16.33-19.34 27.87-27.47 27.87-80.8c0-48.87 25.74-66.21 47-74.67a11.35 11.35 0 0 0 6.33-6.68C231.7 138.6 242.14 128 256 128s24.28 10.6 28 22.86a11.39 11.39 0 0 0 6.34 6.68c21.21 8.44 47 25.81 47 74.67c0 53.33 11.53 61.46 27.86 80.8c6.74 7.99.57 22.99-11.2 22.99z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$69 = [_hoisted_2$73];
    vue.defineComponent({
      name: 'NotificationsCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$73, _hoisted_3$69);
      }
    });

    const _hoisted_1$72 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$72 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$68 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M365.2 313c-16.33-19.34-27.86-27.47-27.86-80.8c0-48.86-25.78-66.23-47-74.67a11.39 11.39 0 0 1-6.34-6.68C280.29 138.6 269.88 128 256 128s-24.31 10.6-28 22.86a11.35 11.35 0 0 1-6.33 6.68c-21.24 8.46-47 25.8-47 74.67c0 53.33-11.54 61.46-27.87 80.8c-6.77 8-.65 23 11.19 23H354C365.77 336 371.94 321 365.2 313z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3Z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M220.24 352a4 4 0 0 0-4 4.42C218.49 375.14 235.11 384 256 384c20.67 0 37.14-9.15 39.66-27.52a4 4 0 0 0-4-4.48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1N = [_hoisted_2$72, _hoisted_3$68, _hoisted_4$3Z];
    vue.defineComponent({
      name: 'NotificationsCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$72, _hoisted_5$1N);
      }
    });

    const _hoisted_1$71 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$71 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M295.68 351.43v.57h.32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$67 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 384c22.28 0 39.36-10.63 39.66-32H216c0 21.75 17.53 32 40 32z',
      fill: 'none'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3Y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M295.67 352h.33l-.32-.57c0 .19-.01.38-.01.57z',
      fill: 'none'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1M = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm0 336c-22.48 0-40-10.25-40-32h80c-.3 21.37-17.71 32-40 32zm112-48H144v-28l28-36v-32.3c0-40.41 15.82-75.35 56-84.27l4-27.43h48l4 27.43c40 8.92 56 44 56 84.27V272l28 36z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$U = [_hoisted_2$71, _hoisted_3$67, _hoisted_4$3Y, _hoisted_5$1M];
    vue.defineComponent({
      name: 'NotificationsCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$71, _hoisted_6$U);
      }
    });

    const _hoisted_1$70 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$70 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 464a15.92 15.92 0 0 1-11.31-4.69l-384-384a16 16 0 0 1 22.62-22.62l384 384A16 16 0 0 1 448 464z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$66 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M440.08 341.31c-1.66-2-3.29-4-4.89-5.93c-22-26.61-35.31-42.67-35.31-118c0-39-9.33-71-27.72-95c-13.56-17.73-31.89-31.18-56.05-41.12a3 3 0 0 1-.82-.67C306.6 51.49 282.82 32 256 32s-50.59 19.49-59.28 48.56a3.13 3.13 0 0 1-.81.65a157.88 157.88 0 0 0-21.88 11a8 8 0 0 0-1.49 12.49l261.78 261.74a8 8 0 0 0 13.6-6.63a35.39 35.39 0 0 0-7.84-18.5z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3X = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M112.14 217.35c0 75.36-13.29 91.42-35.31 118c-1.6 1.93-3.23 3.89-4.89 5.93a35.16 35.16 0 0 0-4.65 37.62c6.17 13 19.32 21.07 34.33 21.07H312.8a8 8 0 0 0 5.66-13.66l-192-192a8 8 0 0 0-13.62 5q-.7 8.69-.7 18.04z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1L = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 480a80.06 80.06 0 0 0 70.44-42.13a4 4 0 0 0-3.54-5.87H189.12a4 4 0 0 0-3.55 5.87A80.06 80.06 0 0 0 256 480z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$T = [_hoisted_2$70, _hoisted_3$66, _hoisted_4$3X, _hoisted_5$1L];
    vue.defineComponent({
      name: 'NotificationsOff',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$70, _hoisted_6$T);
      }
    });

    const _hoisted_1$6$ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6$ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zM146.83 313c16.33-19.34 27.86-27.47 27.86-80.8q0-3.75.2-7.26a4 4 0 0 1 7-2.52l98 106.87a4 4 0 0 1-2.94 6.7H158C146.18 336 140.06 321 146.83 313zm148.93 43.41C293.53 375.14 276.92 384 256 384s-37.51-8.86-39.75-27.58a4 4 0 0 1 4-4.42h71.53a4 4 0 0 1 3.98 4.42zm67 17.42a16 16 0 0 1-22.6-1.08l-192-212a16 16 0 0 1 23.68-21.52l192 212a16 16 0 0 1-1.08 22.61zM361 323.21L216.49 165.53a4 4 0 0 1 1.3-6.36c1.31-.58 2.61-1.12 3.89-1.63a11.33 11.33 0 0 0 6.32-6.68c3.72-12.26 14.15-22.86 28-22.86s24.29 10.6 28 22.86a11.34 11.34 0 0 0 6.34 6.68c21.21 8.44 47 25.81 47 74.67c0 53.33 11.54 61.46 27.87 80.8a12.09 12.09 0 0 1 2.76 7.25a4 4 0 0 1-6.97 2.95z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$65 = [_hoisted_2$6$];
    vue.defineComponent({
      name: 'NotificationsOffCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6$, _hoisted_3$65);
      }
    });

    const _hoisted_1$6_ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6_ = /*#__PURE__*/vue.createStaticVNode('<path d="M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path d="M220.24 352a4 4 0 0 0-4 4.42C218.49 375.14 235.11 384 256 384s37.5-8.86 39.73-27.58a4 4 0 0 0-4-4.42z" fill="currentColor"></path><path d="M352 378a15.93 15.93 0 0 1-11.84-5.24l-192-212a16 16 0 0 1 23.68-21.52l192 212A16 16 0 0 1 352 378z" fill="currentColor"></path><path d="M174.68 232.21c0 53.33-11.54 61.46-27.87 80.8c-6.77 8-.65 23 11.19 23h118.83a4 4 0 0 0 2.95-6.7l-98-106.87a4 4 0 0 0-6.94 2.52c-.1 2.33-.16 4.75-.16 7.25z" fill="currentColor"></path><path d="M365.2 313c-16.33-19.34-27.86-27.47-27.86-80.8c0-48.86-25.78-66.23-47-74.67a11.39 11.39 0 0 1-6.34-6.68C280.29 138.6 269.88 128 256 128s-24.31 10.6-28 22.86a11.35 11.35 0 0 1-6.33 6.68c-1.28.51-2.57 1.05-3.88 1.63a4 4 0 0 0-1.3 6.36L361 323.21a4 4 0 0 0 6.94-2.95a12 12 0 0 0-2.74-7.26z" fill="currentColor"></path>', 5);

    const _hoisted_7$v = [_hoisted_2$6_];
    vue.defineComponent({
      name: 'NotificationsOffCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6_, _hoisted_7$v);
      }
    });

    const _hoisted_1$6Z = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6Z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zM144 308l28-36v-32.3a131.83 131.83 0 0 1 2.34-25.42L285.92 336H144zm112.18 76C233.6 384 216 373.75 216 352h80c-.3 21.37-17.45 32-39.82 32zm93.48-3.74l-211-227l23.68-21.52l211 227zM368 330.85l-.32-.38l-155.5-169.63a73.4 73.4 0 0 1 15.82-5.41l4-27.43h48l4 27.43c40 8.92 56 44 56 84.27V272l28 36z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$64 = [_hoisted_2$6Z];
    vue.defineComponent({
      name: 'NotificationsOffCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6Z, _hoisted_3$64);
      }
    });

    const _hoisted_1$6Y = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6Y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M128.51 204.59q-.37 6.15-.37 12.76C128.14 304 110 320 84.33 351.43C73.69 364.45 83 384 101.62 384H320',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$63 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M414.5 335.3c-18.48-23.45-30.62-47.05-30.62-118c0-79.3-40.52-107.57-73.88-121.3c-4.43-1.82-8.6-6-9.95-10.55C294.21 65.54 277.82 48 256 48s-38.2 17.55-44 37.47c-1.35 4.6-5.52 8.71-10 10.53a149.57 149.57 0 0 0-18 8.79',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3W = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 384v16a64 64 0 0 1-128 0v-16',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1K = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M448 448L64 64'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$S = [_hoisted_2$6Y, _hoisted_3$63, _hoisted_4$3W, _hoisted_5$1K];
    vue.defineComponent({
      name: 'NotificationsOffOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6Y, _hoisted_6$S);
      }
    });

    const _hoisted_1$6X = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6X = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M41.37 64l22.628-22.628L470.627 448l-22.628 22.627z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$62 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 480a80.09 80.09 0 0 0 73.3-48H182.7a80.09 80.09 0 0 0 73.3 48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3V = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M112 227.47V288l-48 64v48h268.12L115.87 183.75a236.75 236.75 0 0 0-3.87 43.72z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1J = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 352l-48-64v-60.53C400 157 372.64 95.61 304 80l-8-48h-80l-8 48a117.45 117.45 0 0 0-41.95 18.17l282 282z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$R = [_hoisted_2$6X, _hoisted_3$62, _hoisted_4$3V, _hoisted_5$1J];
    vue.defineComponent({
      name: 'NotificationsOffSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6X, _hoisted_6$R);
      }
    });

    const _hoisted_1$6W = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6W = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M427.68 351.43C402 320 383.87 304 383.87 217.35C383.87 138 343.35 109.73 310 96c-4.43-1.82-8.6-6-9.95-10.55C294.2 65.54 277.8 48 256 48s-38.21 17.55-44 37.47c-1.35 4.6-5.52 8.71-9.95 10.53c-33.39 13.75-73.87 41.92-73.87 121.35C128.13 304 110 320 84.32 351.43C73.68 364.45 83 384 101.61 384h308.88c18.51 0 27.77-19.61 17.19-32.57z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$61 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 384v16a64 64 0 0 1-128 0v-16',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3U = [_hoisted_2$6W, _hoisted_3$61];
    vue.defineComponent({
      name: 'NotificationsOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6W, _hoisted_4$3U);
      }
    });

    const _hoisted_1$6V = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6V = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 480a80.09 80.09 0 0 0 73.3-48H182.7a80.09 80.09 0 0 0 73.3 48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$60 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400 288v-60.53C400 157 372.64 95.61 304 80l-8-48h-80l-8 48c-68.88 15.61-96 76.76-96 147.47V288l-48 64v48h384v-48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3T = [_hoisted_2$6V, _hoisted_3$60];
    vue.defineComponent({
      name: 'NotificationsSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6V, _hoisted_4$3T);
      }
    });

    const _hoisted_1$6U = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6U = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M258.9 48C141.92 46.42 46.42 141.92 48 258.9c1.56 112.19 92.91 203.54 205.1 205.1c117 1.6 212.48-93.9 210.88-210.88C462.44 140.91 371.09 49.56 258.9 48zM429 239.92l-93.08-.1a2 2 0 0 1-1.95-1.57a80.08 80.08 0 0 0-27.44-44.17a2 2 0 0 1-.54-2.43l41.32-83.43a2 2 0 0 1 2.87-.81A176.2 176.2 0 0 1 431 237.71a2 2 0 0 1-2 2.21zm-220.8 20.46a48 48 0 1 1 43.42 43.42a48 48 0 0 1-43.42-43.42zm-43.55-152.16L206 191.65a2 2 0 0 1-.54 2.43A80.08 80.08 0 0 0 178 238.25a2 2 0 0 1-2 1.57l-93.08.1a2 2 0 0 1-2-2.21a176.2 176.2 0 0 1 80.82-130.3a2 2 0 0 1 2.91.81zm-.37 295.34l56.31-74.09a2 2 0 0 1 2.43-.6a79.84 79.84 0 0 0 66 0a2 2 0 0 1 2.43.6l56.31 74.09a2 2 0 0 1-.54 2.92a175.65 175.65 0 0 1-182.36 0a2 2 0 0 1-.58-2.92z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5$ = [_hoisted_2$6U];
    vue.defineComponent({
      name: 'Nuclear',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6U, _hoisted_3$5$);
      }
    });

    const _hoisted_1$6T = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6T = /*#__PURE__*/vue.createStaticVNode('<circle cx="256" cy="256" r="192" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></circle><circle cx="256" cy="256" r="64" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></circle><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M224 192L171 85"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M288 192l53-107"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M327.55 255.81l119.41.13"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M299.09 313.13l72.25 95.06"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M184.45 255.81l-119.41.13"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M212.91 313.13l-72.25 95.06"></path>', 8);

    const _hoisted_10$3 = [_hoisted_2$6T];
    vue.defineComponent({
      name: 'NuclearOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6T, _hoisted_10$3);
      }
    });

    const _hoisted_1$6S = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6S = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '48',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5_ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M223.47 335.59l-51.71 68a169.73 169.73 0 0 0 168.48 0l-51.71-68',
      fill: 'none'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3S = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M403.08 108.92a208 208 0 0 0-294.16 294.16a208 208 0 0 0 294.16-294.16zM342 256a86.13 86.13 0 0 1-53.47 79.59l51.71 68a169.73 169.73 0 0 1-168.48 0l51.71-68a86 86 0 0 1-50.56-101.77l-85.48.09a170.21 170.21 0 0 1 73.83-119l37.94 76.59a85.78 85.78 0 0 1 113.6 0l37.94-76.59a170.21 170.21 0 0 1 73.83 119l-85.48-.09A85.87 85.87 0 0 1 342 256z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1I = [_hoisted_2$6S, _hoisted_3$5_, _hoisted_4$3S];
    vue.defineComponent({
      name: 'NuclearSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6S, _hoisted_5$1I);
      }
    });

    const _hoisted_1$6R = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6R = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M439 166.29c-18.67-32.57-47.46-50.81-85.57-54.23c-20.18-1.8-39 3.37-57.23 8.38c-14.15 3.89-27.52 7.56-40.2 7.56s-26-3.68-40.06-7.57c-18.28-5-37.18-10.26-57.43-8.36c-36.39 3.41-65.51 22.11-84.31 54.08C56.82 195.76 48 236.76 48 288c0 40.4 15 90.49 40 134c12.82 22.25 47 74 87.16 74c30.77 0 47.15-9.44 59.11-16.33c8.3-4.78 13.31-7.67 21.69-7.67s13.39 2.89 21.69 7.67c12 6.89 28.35 16.33 59.15 16.33c40.17 0 74.34-51.76 87.16-74c25.07-43.5 40-93.59 40-134c.04-52.57-8.14-92.38-24.96-121.71zM216 352c-13.25 0-24-21.49-24-48s10.75-48 24-48s24 21.49 24 48s-10.75 48-24 48zm80 0c-13.25 0-24-21.49-24-48s10.75-48 24-48s24 21.49 24 48s-10.75 48-24 48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5Z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M265.1 111.93c13.16-1.75 37.86-7.83 58.83-28.79a98 98 0 0 0 28-58.2a8 8 0 0 0-8.55-8.94c-12.71.95-36.76 5.87-58.73 27.85A97.6 97.6 0 0 0 256 103.2a8 8 0 0 0 9.1 8.73z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3R = [_hoisted_2$6R, _hoisted_3$5Z];
    vue.defineComponent({
      name: 'Nutrition',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6R, _hoisted_4$3R);
      }
    });

    const _hoisted_1$6Q = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6Q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M352 128c-32.26-2.89-64 16-96 16s-63.75-19-96-16c-64 6-96 64-96 160c0 80 64 192 111.2 192s51.94-24 80.8-24s33.59 24 80.8 24S448 368 448 288c0-96-29-154-96-160z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5Y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M323.92 83.14c-21 21-45.66 27-58.82 28.79a8 8 0 0 1-9.1-8.73a97.6 97.6 0 0 1 28.61-59.33c22-22 46-26.9 58.72-27.85a8 8 0 0 1 8.67 8.92a98 98 0 0 1-28.08 58.2z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3Q = /*#__PURE__*/vue.createElementVNode('ellipse', {
      cx: '216',
      cy: '304',
      rx: '24',
      ry: '48',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1H = /*#__PURE__*/vue.createElementVNode('ellipse', {
      cx: '296',
      cy: '304',
      rx: '24',
      ry: '48',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$Q = [_hoisted_2$6Q, _hoisted_3$5Y, _hoisted_4$3Q, _hoisted_5$1H];
    vue.defineComponent({
      name: 'NutritionOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6Q, _hoisted_6$Q);
      }
    });

    const _hoisted_1$6P = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6P = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M438.71 159.43c-17.6-28.31-45.5-43.8-85.28-47.37c-22.82-2-50.23 4.94-72.25 10.55C271.26 125.14 260 128 256 128s-15.18-2.86-25-5.39c-22.08-5.65-49.56-12.69-72.45-10.54c-38.53 3.61-66 19.19-84 47.62S48 229 48 288c0 61.28 29.53 114.58 47.13 140.89C116.82 461.34 149.25 496 175.2 496c18.57 0 34.12-7.23 47.82-13.64C243 473 256 472 256 472s11 0 31.94 10.11C301.65 488.73 317.3 496 336.8 496c26.58 0 59.08-34.69 80.63-67.15C434.82 402.65 464 349.52 464 288c0-60-8-100.83-25.29-128.57zM216 352c-13.25 0-24-21.49-24-48s10.75-48 24-48s24 21.49 24 48s-10.75 48-24 48zm80 0c-13.25 0-24-21.49-24-48s10.75-48 24-48s24 21.49 24 48s-10.75 48-24 48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5X = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M323.72 82.76C353.68 52.82 352 16.18 352 16.14s-35.77-3.76-67.23 27.67S256.06 112 256.06 112s37.68.71 67.66-29.24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3P = [_hoisted_2$6P, _hoisted_3$5X];
    vue.defineComponent({
      name: 'NutritionSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6P, _hoisted_4$3P);
      }
    });

    const _hoisted_1$6O = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6O = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M224 304a16 16 0 0 1-11.31-27.31l157.94-157.94A55.7 55.7 0 0 0 344 112H104a56.06 56.06 0 0 0-56 56v240a56.06 56.06 0 0 0 56 56h240a56.06 56.06 0 0 0 56-56V168a55.7 55.7 0 0 0-6.75-26.63L235.31 299.31A15.92 15.92 0 0 1 224 304z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5W = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 48H336a16 16 0 0 0 0 32h73.37l-38.74 38.75a56.35 56.35 0 0 1 22.62 22.62L432 102.63V176a16 16 0 0 0 32 0V64a16 16 0 0 0-16-16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3O = [_hoisted_2$6O, _hoisted_3$5W];
    var Open = vue.defineComponent({
      name: 'Open',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6O, _hoisted_4$3O);
      }
    });

    const _hoisted_1$6N = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6N = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 224v184a40 40 0 0 1-40 40H104a40 40 0 0 1-40-40V168a40 40 0 0 1 40-40h167.48',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5V = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M336 64h112v112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3N = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M224 288L440 72'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1G = [_hoisted_2$6N, _hoisted_3$5V, _hoisted_4$3N];
    vue.defineComponent({
      name: 'OpenOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6N, _hoisted_5$1G);
      }
    });

    const _hoisted_1$6M = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6M = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M201.37 288l176-176H48v352h352V134.63l-176 176L201.37 288z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5U = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 48v32h89.37l-32 32L400 134.63l32-32V192h32V48H320z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3M = [_hoisted_2$6M, _hoisted_3$5U];
    vue.defineComponent({
      name: 'OpenSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6M, _hoisted_4$3M);
      }
    });

    const _hoisted_1$6L = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6L = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M64 144h226.75a48 48 0 0 0 90.5 0H448a16 16 0 0 0 0-32h-66.75a48 48 0 0 0-90.5 0H64a16 16 0 0 0 0 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5T = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 368h-66.75a48 48 0 0 0-90.5 0H64a16 16 0 0 0 0 32h226.75a48 48 0 0 0 90.5 0H448a16 16 0 0 0 0-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3L = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 240H221.25a48 48 0 0 0-90.5 0H64a16 16 0 0 0 0 32h66.75a48 48 0 0 0 90.5 0H448a16 16 0 0 0 0-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1F = [_hoisted_2$6L, _hoisted_3$5T, _hoisted_4$3L];
    vue.defineComponent({
      name: 'Options',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6L, _hoisted_5$1F);
      }
    });

    const _hoisted_1$6K = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6K = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M368 128h80"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M64 128h240"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M368 384h80"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M64 384h240"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M208 256h240"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M64 256h80"></path><circle cx="336" cy="128" r="32" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><circle cx="176" cy="256" r="32" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><circle cx="336" cy="384" r="32" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle>', 9);

    const _hoisted_11$4 = [_hoisted_2$6K];
    vue.defineComponent({
      name: 'OptionsOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6K, _hoisted_11$4);
      }
    });

    const _hoisted_1$6J = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6J = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M381.25 112a48 48 0 0 0-90.5 0H48v32h242.75a48 48 0 0 0 90.5 0H464v-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5S = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M176 208a48.09 48.09 0 0 0-45.25 32H48v32h82.75a48 48 0 0 0 90.5 0H464v-32H221.25A48.09 48.09 0 0 0 176 208z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3K = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 336a48.09 48.09 0 0 0-45.25 32H48v32h242.75a48 48 0 0 0 90.5 0H464v-32h-82.75A48.09 48.09 0 0 0 336 336z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1E = [_hoisted_2$6J, _hoisted_3$5S, _hoisted_4$3K];
    vue.defineComponent({
      name: 'OptionsSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6J, _hoisted_5$1E);
      }
    });

    const _hoisted_1$6I = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6I = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M473 39.05a24 24 0 0 0-25.5-5.46L47.47 185h-.08a24 24 0 0 0 1 45.16l.41.13l137.3 58.63a16 16 0 0 0 15.54-3.59L422 80a7.07 7.07 0 0 1 10 10L226.66 310.26a16 16 0 0 0-3.59 15.54l58.65 137.38c.06.2.12.38.19.57c3.2 9.27 11.3 15.81 21.09 16.25h1a24.63 24.63 0 0 0 23-15.46L478.39 64.62A24 24 0 0 0 473 39.05z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5R = [_hoisted_2$6I];
    vue.defineComponent({
      name: 'PaperPlane',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6I, _hoisted_3$5R);
      }
    });

    const _hoisted_1$6H = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6H = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M53.12 199.94l400-151.39a8 8 0 0 1 10.33 10.33l-151.39 400a8 8 0 0 1-15-.34l-67.4-166.09a16 16 0 0 0-10.11-10.11L53.46 215a8 8 0 0 1-.34-15.06z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5Q = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M460 52L227 285'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3J = [_hoisted_2$6H, _hoisted_3$5Q];
    vue.defineComponent({
      name: 'PaperPlaneOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6H, _hoisted_4$3J);
      }
    });

    const _hoisted_1$6G = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6G = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M496 16L15.88 208L195 289L448 64L223 317l81 179L496 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5P = [_hoisted_2$6G];
    vue.defineComponent({
      name: 'PaperPlaneSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6G, _hoisted_3$5P);
      }
    });

    const _hoisted_1$6F = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6F = /*#__PURE__*/vue.createStaticVNode('<path d="M340 480H106c-29.5 0-54.92-7.83-73.53-22.64C11.23 440.44 0 415.35 0 384.8c0-26.66 10.08-49.8 29.14-66.91c15.24-13.68 36.17-23.21 59-26.84c.06 0 .08 0 .09-.05c6.44-39 23.83-72.09 50.31-95.68A140.24 140.24 0 0 1 232 160c30.23 0 58.48 9.39 81.71 27.17a142.24 142.24 0 0 1 42.19 53.21a16 16 0 0 0 11.19 9c26 5.61 48.4 17.29 65.17 34C453 304.11 464 331.71 464 363.2c0 32.85-13.13 62.87-37 84.52c-22.89 20.82-53.8 32.28-87 32.28zm19-232.18z" fill="currentColor"></path><path d="M387.89 221.68a168.8 168.8 0 0 1 34.76 14.71a4 4 0 0 0 5.82-2.44a97 97 0 0 0 3.53-26.68c-.39-52.43-43.48-95.22-95.91-95.27A95.46 95.46 0 0 0 281 129.33h-.06a3.38 3.38 0 0 0 1 6a162.45 162.45 0 0 1 51.28 26.4a173.92 173.92 0 0 1 45.32 52.51a16 16 0 0 0 9.35 7.44z" fill="currentColor"></path><path d="M496 224h-32a16 16 0 0 1 0-32h32a16 16 0 0 1 0 32z" fill="currentColor"></path><path d="M336 96a16 16 0 0 1-16-16V48a16 16 0 0 1 32 0v32a16 16 0 0 1-16 16z" fill="currentColor"></path><path d="M245.49 133.49a15.92 15.92 0 0 1-11.31-4.69l-22.63-22.62a16 16 0 0 1 22.63-22.63l22.62 22.63a16 16 0 0 1-11.31 27.31z" fill="currentColor"></path><path d="M426.51 133.49a16 16 0 0 1-11.31-27.31l22.62-22.63a16 16 0 0 1 22.63 22.63l-22.63 22.62a15.92 15.92 0 0 1-11.31 4.69z" fill="currentColor"></path>', 6);

    const _hoisted_8$8 = [_hoisted_2$6F];
    vue.defineComponent({
      name: 'PartlySunny',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6F, _hoisted_8$8);
      }
    });

    const _hoisted_1$6E = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6E = /*#__PURE__*/vue.createStaticVNode('<path d="M90.61 306.85A16.07 16.07 0 0 0 104 293.6C116.09 220.17 169.63 176 232 176c57.93 0 96.62 37.75 112.2 77.74a15.84 15.84 0 0 0 12.2 9.87c50 8.15 91.6 41.54 91.6 99.59c0 59.4-48.6 100.8-108 100.8H106c-49.5 0-90-24.7-90-79.2c0-48.47 38.67-72.22 74.61-77.95z" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></path><path d="M384.8 271.4a80 80 0 1 0-123.55-92" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M464 208h32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M336 48v32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M222.86 94.86l22.63 22.63"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M449.14 94.86l-22.63 22.63"></path>', 6);

    const _hoisted_8$7 = [_hoisted_2$6E];
    vue.defineComponent({
      name: 'PartlySunnyOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6E, _hoisted_8$7);
      }
    });

    const _hoisted_1$6D = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6D = /*#__PURE__*/vue.createStaticVNode('<path d="M340 480H106c-29.5 0-54.92-7.83-73.53-22.64C11.23 440.44 0 415.35 0 384.8c0-26.66 10.08-49.8 29.14-66.91c15.24-13.68 36.17-23.21 59-26.84c.06 0 .08 0 .09-.05c6.44-39 23.83-72.09 50.31-95.68A140.24 140.24 0 0 1 232 160c30.23 0 58.48 9.39 81.71 27.17a142.69 142.69 0 0 1 45.36 60.66c29.41 4.82 54.72 17.11 73.19 35.54C453 304.11 464 331.71 464 363.2c0 32.85-13.13 62.87-37 84.52c-22.89 20.82-53.8 32.28-87 32.28zm19-232.18z" fill="currentColor"></path><path d="M381.5 219.89a169.23 169.23 0 0 1 45.44 19A96 96 0 0 0 281 129.33q-2.85 2-5.54 4.2a162.47 162.47 0 0 1 57.73 28.23a174.53 174.53 0 0 1 48.31 58.13z" fill="currentColor"></path><path d="M448 192h64v32h-64z" fill="currentColor"></path><path d="M320 32h32v64h-32z" fill="currentColor"></path><path d="M255.35 129.63l12.45-12.45l-44.62-44.63l-22.63 22.63l33.17 33.17h.6a172 172 0 0 1 21.03 1.28z" fill="currentColor"></path><path d="M404.203 117.17l44.626-44.625l22.627 22.628l-44.625 44.625z" fill="currentColor"></path>', 6);

    const _hoisted_8$6 = [_hoisted_2$6D];
    vue.defineComponent({
      name: 'PartlySunnySharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6D, _hoisted_8$6);
      }
    });

    const _hoisted_1$6C = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6C = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M208 432h-48a16 16 0 0 1-16-16V96a16 16 0 0 1 16-16h48a16 16 0 0 1 16 16v320a16 16 0 0 1-16 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5O = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M352 432h-48a16 16 0 0 1-16-16V96a16 16 0 0 1 16-16h48a16 16 0 0 1 16 16v320a16 16 0 0 1-16 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3I = [_hoisted_2$6C, _hoisted_3$5O];
    vue.defineComponent({
      name: 'Pause',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6C, _hoisted_4$3I);
      }
    });

    const _hoisted_1$6B = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6B = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm-32 272a16 16 0 0 1-32 0V192a16 16 0 0 1 32 0zm96 0a16 16 0 0 1-32 0V192a16 16 0 0 1 32 0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5N = [_hoisted_2$6B];
    vue.defineComponent({
      name: 'PauseCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6B, _hoisted_3$5N);
      }
    });

    const _hoisted_1$6A = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6A = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5M = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M208 192v128'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3H = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M304 192v128'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1D = [_hoisted_2$6A, _hoisted_3$5M, _hoisted_4$3H];
    vue.defineComponent({
      name: 'PauseCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6A, _hoisted_5$1D);
      }
    });

    const _hoisted_1$6z = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm-32 288h-32V176h32zm96 0h-32V176h32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5L = [_hoisted_2$6z];
    vue.defineComponent({
      name: 'PauseCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6z, _hoisted_3$5L);
      }
    });

    const _hoisted_1$6y = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6y = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M176 96h16v320h-16z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5K = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M320 96h16v320h-16z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3G = [_hoisted_2$6y, _hoisted_3$5K];
    vue.defineComponent({
      name: 'PauseOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6y, _hoisted_4$3G);
      }
    });

    const _hoisted_1$6x = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6x = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M224 432h-80V80h80z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5J = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M368 432h-80V80h80z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3F = [_hoisted_2$6x, _hoisted_3$5J];
    vue.defineComponent({
      name: 'PauseSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6x, _hoisted_4$3F);
      }
    });

    const _hoisted_1$6w = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6w = /*#__PURE__*/vue.createStaticVNode('<path d="M490.39 182.75c-5.55-13.19-14.77-22.7-26.67-27.49l-.16-.06a46.46 46.46 0 0 0-17-3.2h-.64c-27.24.41-55.05 23.56-69.19 57.61c-10.37 24.9-11.56 51.68-3.18 71.64c5.54 13.2 14.78 22.71 26.73 27.5l.13.05a46.53 46.53 0 0 0 17 3.2c27.5 0 55.6-23.15 70-57.65c10.24-24.87 11.37-51.63 2.98-71.6z" fill="currentColor"></path><path d="M381.55 329.61c-15.71-9.44-30.56-18.37-40.26-34.41C314.53 250.8 298.37 224 256 224s-58.57 26.8-85.39 71.2c-9.72 16.06-24.6 25-40.36 34.48c-18.07 10.86-36.74 22.08-44.8 44.16a66.93 66.93 0 0 0-4.65 25c0 35.95 28 65.2 62.4 65.2c17.75 0 36.64-6.15 56.63-12.66c19.22-6.26 39.09-12.73 56.27-12.73s37 6.47 56.15 12.73C332.2 457.85 351 464 368.8 464c34.35 0 62.3-29.25 62.3-65.2a67 67 0 0 0-4.75-25c-8.06-22.1-26.74-33.33-44.8-44.19z" fill="currentColor"></path><path d="M150 188.85c11.9 14.93 27 23.15 42.52 23.15a42.88 42.88 0 0 0 6.33-.47c32.37-4.76 52.54-44.26 45.92-90C242 102.3 234.6 84.39 224 71.11C212.12 56.21 197 48 181.49 48a42.88 42.88 0 0 0-6.33.47c-32.37 4.76-52.54 44.26-45.92 90c2.76 19.2 10.16 37.09 20.76 50.38z" fill="currentColor"></path><path d="M313.16 211.53a42.88 42.88 0 0 0 6.33.47c15.53 0 30.62-8.22 42.52-23.15c10.59-13.29 17.95-31.18 20.75-50.4c6.62-45.72-13.55-85.22-45.92-90a42.88 42.88 0 0 0-6.33-.47C315 48 299.88 56.21 288 71.11c-10.6 13.28-18 31.19-20.76 50.44c-6.62 45.72 13.55 85.22 45.92 89.98z" fill="currentColor"></path><path d="M111.59 308.8l.14-.05c11.93-4.79 21.16-14.29 26.69-27.48c8.38-20 7.2-46.75-3.15-71.65C120.94 175.16 92.85 152 65.38 152a46.4 46.4 0 0 0-17 3.2l-.14.05c-11.9 4.75-21.13 14.29-26.66 27.48c-8.38 20-7.2 46.75 3.15 71.65C39.06 288.84 67.15 312 94.62 312a46.4 46.4 0 0 0 16.97-3.2z" fill="currentColor"></path>', 5);

    const _hoisted_7$u = [_hoisted_2$6w];
    vue.defineComponent({
      name: 'Paw',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6w, _hoisted_7$u);
      }
    });

    const _hoisted_1$6v = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6v = /*#__PURE__*/vue.createStaticVNode('<path d="M457.74 170.1a30.26 30.26 0 0 0-11.16-2.1h-.4c-20.17.3-42.79 19.19-54.66 47.76c-14.23 34.18-7.68 69.15 14.74 78.14a30.21 30.21 0 0 0 11.15 2.1c20.27 0 43.2-19 55.17-47.76c14.13-34.18 7.48-69.15-14.84-78.14z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path d="M327.6 303.48C299.8 257.35 287.8 240 256 240s-43.9 17.46-71.7 63.48c-23.8 39.36-71.9 42.64-83.9 76.07a50.91 50.91 0 0 0-3.6 19.25c0 27.19 20.8 49.2 46.4 49.2c31.8 0 75.1-25.39 112.9-25.39S337 448 368.8 448c25.6 0 46.3-22 46.3-49.2a51 51 0 0 0-3.7-19.25c-12-33.55-60-36.71-83.8-76.07z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path d="M192.51 196a26.53 26.53 0 0 0 4-.3c23.21-3.37 37.7-35.53 32.44-71.85C224 89.61 203.22 64 181.49 64a26.53 26.53 0 0 0-4 .3c-23.21 3.37-37.7 35.53-32.44 71.85C150 170.29 170.78 196 192.51 196z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path d="M366.92 136.15c5.26-36.32-9.23-68.48-32.44-71.85a26.53 26.53 0 0 0-4-.3c-21.73 0-42.47 25.61-47.43 59.85c-5.26 36.32 9.23 68.48 32.44 71.85a26.53 26.53 0 0 0 4 .3c21.73 0 42.51-25.71 47.43-59.85z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path d="M105.77 293.9c22.39-9 28.93-44 14.72-78.14C108.53 187 85.62 168 65.38 168a30.21 30.21 0 0 0-11.15 2.1c-22.39 9-28.93 44-14.72 78.14C51.47 277 74.38 296 94.62 296a30.21 30.21 0 0 0 11.15-2.1z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path>', 5);

    const _hoisted_7$t = [_hoisted_2$6v];
    vue.defineComponent({
      name: 'PawOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6v, _hoisted_7$t);
      }
    });

    const _hoisted_1$6u = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6u = /*#__PURE__*/vue.createStaticVNode('<path d="M442.8 361.82c-8.8-25.1-29.31-37.82-49.11-50.12c-17.23-10.71-33.5-20.83-44.14-39c-29.33-50.33-45.44-80.7-93.49-80.7s-64.21 30.38-93.61 80.69c-10.65 18.21-27 28.35-44.25 39.08c-19.8 12.31-40.27 25-49.1 50.05a78.06 78.06 0 0 0-5.1 28.29C64 430.85 96.45 464 132.4 464s83.31-18.13 123.76-18.13S343.31 464 379.71 464S448 430.85 448 390.11a78.3 78.3 0 0 0-5.2-28.29z" fill="currentColor"></path><ellipse cx="72" cy="216" rx="56" ry="72" fill="currentColor"></ellipse><ellipse cx="184" cy="120" rx="56" ry="72" fill="currentColor"></ellipse><ellipse cx="328" cy="120" rx="56" ry="72" fill="currentColor"></ellipse><ellipse cx="440" cy="216" rx="56" ry="72" fill="currentColor"></ellipse>', 5);

    const _hoisted_7$s = [_hoisted_2$6u];
    vue.defineComponent({
      name: 'PawSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6u, _hoisted_7$s);
      }
    });

    const _hoisted_1$6t = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6t = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '44',
      d: 'M358.62 129.28L86.49 402.08L70 442l39.92-16.49l272.8-272.13l-24.1-24.1z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5I = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M413.07 74.84l-11.79 11.78l24.1 24.1l11.79-11.79a16.51 16.51 0 0 0 0-23.34l-.75-.75a16.51 16.51 0 0 0-23.35 0z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '44'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3E = [_hoisted_2$6t, _hoisted_3$5I];
    vue.defineComponent({
      name: 'Pencil',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6t, _hoisted_4$3E);
      }
    });

    const _hoisted_1$6s = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6s = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M364.13 125.25L87 403l-23 45l44.99-23l277.76-277.13l-22.62-22.62z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5H = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M420.69 68.69l-22.62 22.62l22.62 22.63l22.62-22.63a16 16 0 0 0 0-22.62h0a16 16 0 0 0-22.62 0z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3D = [_hoisted_2$6s, _hoisted_3$5H];
    vue.defineComponent({
      name: 'PencilOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6s, _hoisted_4$3D);
      }
    });

    const _hoisted_1$6r = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6r = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M103 464H48v-55L358.14 98.09l55.77 55.78L103 464z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5G = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M425.72 142L370 86.28l31.66-30.66C406.55 50.7 414.05 48 421 48a25.91 25.91 0 0 1 18.42 7.62l17 17A25.87 25.87 0 0 1 464 91c0 7-2.71 14.45-7.62 19.36zm-7.52-70.83z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3C = [_hoisted_2$6r, _hoisted_3$5G];
    vue.defineComponent({
      name: 'PencilSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6r, _hoisted_4$3C);
      }
    });

    const _hoisted_1$6q = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 256c-20.56 0-40.44-9.18-56-25.84c-15.13-16.25-24.37-37.92-26-61c-1.74-24.62 5.77-47.26 21.14-63.76S312 80 336 80c23.83 0 45.38 9.06 60.7 25.52c15.47 16.62 23 39.22 21.26 63.63c-1.67 23.11-10.9 44.77-26 61C376.44 246.82 356.57 256 336 256zm66-88z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5F = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M467.83 432H204.18a27.71 27.71 0 0 1-22-10.67a30.22 30.22 0 0 1-5.26-25.79c8.42-33.81 29.28-61.85 60.32-81.08C264.79 297.4 299.86 288 336 288c36.85 0 71 9 98.71 26.05c31.11 19.13 52 47.33 60.38 81.55a30.27 30.27 0 0 1-5.32 25.78A27.68 27.68 0 0 1 467.83 432z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3B = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M147 260c-35.19 0-66.13-32.72-69-72.93c-1.42-20.6 5-39.65 18-53.62c12.86-13.83 31-21.45 51-21.45s38 7.66 50.93 21.57c13.1 14.08 19.5 33.09 18 53.52c-2.87 40.2-33.8 72.91-68.93 72.91z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1C = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M212.66 291.45c-17.59-8.6-40.42-12.9-65.65-12.9c-29.46 0-58.07 7.68-80.57 21.62c-25.51 15.83-42.67 38.88-49.6 66.71a27.39 27.39 0 0 0 4.79 23.36A25.32 25.32 0 0 0 41.72 400h111a8 8 0 0 0 7.87-6.57c.11-.63.25-1.26.41-1.88c8.48-34.06 28.35-62.84 57.71-83.82a8 8 0 0 0-.63-13.39c-1.57-.92-3.37-1.89-5.42-2.89z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$P = [_hoisted_2$6q, _hoisted_3$5F, _hoisted_4$3B, _hoisted_5$1C];
    vue.defineComponent({
      name: 'People',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6q, _hoisted_6$P);
      }
    });

    const _hoisted_1$6p = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6p = /*#__PURE__*/vue.createStaticVNode('<path d="M258.9 48C141.92 46.42 46.42 141.92 48 258.9c1.56 112.19 92.91 203.54 205.1 205.1c117 1.6 212.48-93.9 210.88-210.88C462.44 140.91 371.09 49.56 258.9 48zm-3.68 152.11c.21-1.2.44-2.4.71-3.59a66.46 66.46 0 0 1 16.29-31.21c12.89-13.73 31.16-21.31 51.45-21.31a74.05 74.05 0 0 1 25.06 4.26a66.69 66.69 0 0 1 26.27 17.2a68.15 68.15 0 0 1 18 42.14a78.46 78.46 0 0 1 0 11.4a86.19 86.19 0 0 1-8.2 31q-.76 1.59-1.59 3.15c-1.11 2.07-2.3 4.1-3.58 6.06a79.47 79.47 0 0 1-8.63 11c-13.12 14-29.92 21.73-47.31 21.73a59.61 59.61 0 0 1-19.17-3.18a63.47 63.47 0 0 1-6.1-2.43a70.76 70.76 0 0 1-22.07-16.12a83.76 83.76 0 0 1-22-51.32q-.27-3.88-.18-7.68a75.62 75.62 0 0 1 1.05-11.08zm-149.73 24.34a59.87 59.87 0 0 1 5.2-20.64a56.76 56.76 0 0 1 2.78-5.3a54.49 54.49 0 0 1 7.19-9.56a55.62 55.62 0 0 1 14-10.82a56.84 56.84 0 0 1 8.11-3.64a63.85 63.85 0 0 1 33.35-2.39a57 57 0 0 1 30.78 17a57.86 57.86 0 0 1 15.41 38.62c.05 2.11 0 4.23-.15 6.38a71.58 71.58 0 0 1-6 23.84a69.49 69.49 0 0 1-5.73 10.42a65.39 65.39 0 0 1-15.76 16.57c-1.5 1.07-3.06 2.07-4.67 3.07a54.21 54.21 0 0 1-10 4.65a49.31 49.31 0 0 1-16.2 2.76c-.93 0-1.86 0-2.78-.08a47.6 47.6 0 0 1-5.48-.62a51.19 51.19 0 0 1-5.35-1.23a53.54 53.54 0 0 1-7.72-2.89c-.84-.39-1.66-.8-2.48-1.23c-18-9.49-31.57-29.16-34.23-52.12c-.12-1.05-.22-2.1-.29-3.16a66.59 66.59 0 0 1 .02-9.63zm53.92 178.6a177.27 177.27 0 0 1-61.94-70.65a4 4 0 0 1 1.62-5.26C117.67 316.69 141.4 311 163.82 311c17 0 30.7 2 42.69 5.88a8 8 0 0 1 2.59 13.77c-23.35 19-38.4 42.54-45.47 70.75a2.77 2.77 0 0 1-4.22 1.65zM256 432a175.12 175.12 0 0 1-65.7-12.72a4 4 0 0 1-2.4-4.46c.4-2.05.84-3.92 1.23-5.48c7.12-28.43 24.76-52 51-68.18c23.29-14.35 53-22.25 83.52-22.25c31.16 0 60 7.58 83.48 21.91a2.72 2.72 0 0 1 .91 3.67A176.1 176.1 0 0 1 256 432z" fill="currentColor"></path><path d="M161 295.28a47.6 47.6 0 0 1-5.48-.62a47.6 47.6 0 0 0 5.48.62z" fill="currentColor"></path><path d="M134.64 178.13a55.62 55.62 0 0 0-14 10.82a54.49 54.49 0 0 0-7.19 9.56a54.49 54.49 0 0 1 7.19-9.56a55.62 55.62 0 0 1 14-10.82z" fill="currentColor"></path><path d="M216.17 257.89a71.58 71.58 0 0 0 6-23.84c.15-2.15.2-4.27.15-6.38q.08 3.15-.15 6.38a71.58 71.58 0 0 1-6 23.84z" fill="currentColor"></path><path d="M134.64 178.13a56.84 56.84 0 0 1 8.11-3.64a56.84 56.84 0 0 0-8.11 3.64z" fill="currentColor"></path><path d="M150.21 293.43a53.54 53.54 0 0 1-7.72-2.89a53.54 53.54 0 0 0 7.72 2.89z" fill="currentColor"></path><path d="M105.78 237.19c2.66 23 16.26 42.63 34.23 52.12c-18.01-9.49-31.57-29.16-34.23-52.12z" fill="currentColor"></path><path d="M254.34 219a83.76 83.76 0 0 0 22 51.32a70.76 70.76 0 0 0 22.07 16.12a70.76 70.76 0 0 1-22.07-16.12a83.76 83.76 0 0 1-22-51.32q-.27-3.88-.18-7.68q-.09 3.75.18 7.68z" fill="currentColor"></path><path d="M304.5 288.82a63.47 63.47 0 0 1-6.1-2.43a63.47 63.47 0 0 0 6.1 2.43z" fill="currentColor"></path><path d="M255.93 196.54a66.46 66.46 0 0 1 16.29-31.21a66.46 66.46 0 0 0-16.29 31.21z" fill="currentColor"></path><path d="M375 165.46a68.15 68.15 0 0 1 18 42.14a68.15 68.15 0 0 0-18-42.14a66.69 66.69 0 0 0-26.27-17.2a66.69 66.69 0 0 1 26.27 17.2z" fill="currentColor"></path><path d="M393 219a86.19 86.19 0 0 1-8.2 31a86.19 86.19 0 0 0 8.2-31z" fill="currentColor"></path><path d="M254.16 211.27a75.62 75.62 0 0 1 1.06-11.14a75.62 75.62 0 0 0-1.06 11.14z" fill="currentColor"></path><path d="M383.19 253.16z" fill="currentColor"></path><path d="M206.88 189.05a57.86 57.86 0 0 1 15.41 38.62a57.86 57.86 0 0 0-15.41-38.62a57 57 0 0 0-30.78-17a57 57 0 0 1 30.78 17z" fill="currentColor"></path><path d="M190 288a54.21 54.21 0 0 1-10 4.65a54.21 54.21 0 0 0 10-4.65z" fill="currentColor"></path><path d="M105.49 224.45a59.87 59.87 0 0 1 5.2-20.64a59.87 59.87 0 0 0-5.2 20.64z" fill="currentColor"></path><path d="M194.68 284.88C193.17 286 191.61 287 190 288c1.61-1 3.17-2 4.68-3.12z" fill="currentColor"></path><path d="M216.17 257.89a69.49 69.49 0 0 1-5.73 10.42a69.49 69.49 0 0 0 5.73-10.42z" fill="currentColor"></path><path d="M110.69 203.81a56.76 56.76 0 0 1 2.78-5.3a56.76 56.76 0 0 0-2.78 5.3z" fill="currentColor"></path><path d="M194.68 284.88a65.39 65.39 0 0 0 15.76-16.57a65.39 65.39 0 0 1-15.76 16.57z" fill="currentColor"></path>', 21);

    const _hoisted_23 = [_hoisted_2$6p];
    vue.defineComponent({
      name: 'PeopleCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6p, _hoisted_23);
      }
    });

    const _hoisted_1$6o = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6o = /*#__PURE__*/vue.createStaticVNode('<path d="M256 464c-114.69 0-208-93.31-208-208S141.31 48 256 48s208 93.31 208 208s-93.31 208-208 208zm0-384c-97 0-176 79-176 176s79 176 176 176s176-78.95 176-176S353.05 80 256 80z" fill="currentColor"></path><path d="M323.67 292c-17.4 0-34.21-7.72-47.34-21.73a83.76 83.76 0 0 1-22-51.32c-1.47-20.7 4.88-39.75 17.88-53.62S303.38 144 323.67 144c20.14 0 38.37 7.62 51.33 21.46s19.47 33 18 53.51a84 84 0 0 1-22 51.3C357.86 284.28 341.06 292 323.67 292zm55.81-74z" fill="currentColor"></path><path d="M163.82 295.36c-29.76 0-55.93-27.51-58.33-61.33c-1.23-17.32 4.15-33.33 15.17-45.08s26.22-18 43.15-18s32.12 6.44 43.07 18.14s16.5 27.82 15.25 45c-2.44 33.77-28.6 61.27-58.31 61.27z" fill="currentColor"></path><path d="M420.37 355.28c-1.59-4.7-5.46-9.71-13.22-14.46c-23.46-14.33-52.32-21.91-83.48-21.91c-30.57 0-60.23 7.9-83.53 22.25c-26.25 16.17-43.89 39.75-51 68.18c-1.68 6.69-4.13 19.14-1.51 26.11a192.18 192.18 0 0 0 232.75-80.17z" fill="currentColor"></path><path d="M163.63 401.37c7.07-28.21 22.12-51.73 45.47-70.75a8 8 0 0 0-2.59-13.77c-12-3.83-25.7-5.88-42.69-5.88c-23.82 0-49.11 6.45-68.14 18.17c-5.4 3.33-10.7 4.61-14.78 5.75a192.84 192.84 0 0 0 77.78 86.64l1.79-.14a102.82 102.82 0 0 1 3.16-20.02z" fill="currentColor"></path>', 5);

    const _hoisted_7$r = [_hoisted_2$6o];
    vue.defineComponent({
      name: 'PeopleCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6o, _hoisted_7$r);
      }
    });

    const _hoisted_1$6n = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6n = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm69.3 96.17a72.5 72.5 0 1 1-72.6 72.5a72.55 72.55 0 0 1 72.6-72.5zm-155.1 26.36a59.32 59.32 0 1 1-59.4 59.32a59.35 59.35 0 0 1 59.4-59.32zm-75.85 155c24.5-13.29 55.87-19.94 75.85-19.94c15 0 34.32 3 53.33 10.2a133.05 133.05 0 0 0-34 27.11c-13.19 15-20.76 32.92-20.76 50.83v15a177.06 177.06 0 0 1-74.42-83.15zM256 432a175.12 175.12 0 0 1-59.4-10.33v-27.05c0-52.59 85.75-79.09 128.7-79.09c23 0 58.38 7.63 86.21 22.81A176.14 176.14 0 0 1 256 432z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5E = [_hoisted_2$6n];
    vue.defineComponent({
      name: 'PeopleCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6n, _hoisted_3$5E);
      }
    });

    const _hoisted_1$6m = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6m = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M402 168c-2.93 40.67-33.1 72-66 72s-63.12-31.32-66-72c-3-42.31 26.37-72 66-72s69 30.46 66 72z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5D = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 304c-65.17 0-127.84 32.37-143.54 95.41c-2.08 8.34 3.15 16.59 11.72 16.59h263.65c8.57 0 13.77-8.25 11.72-16.59C463.85 335.36 401.18 304 336 304z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3A = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M200 185.94c-2.34 32.48-26.72 58.06-53 58.06s-50.7-25.57-53-58.06C91.61 152.15 115.34 128 147 128s55.39 24.77 53 57.94z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1B = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M206 306c-18.05-8.27-37.93-11.45-59-11.45c-52 0-102.1 25.85-114.65 76.2c-1.65 6.66 2.53 13.25 9.37 13.25H154',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$O = [_hoisted_2$6m, _hoisted_3$5D, _hoisted_4$3A, _hoisted_5$1B];
    vue.defineComponent({
      name: 'PeopleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6m, _hoisted_6$O);
      }
    });

    const _hoisted_1$6l = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6l = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '152',
      cy: '184',
      r: '72',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5C = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M234 296c-28.16-14.3-59.24-20-82-20c-44.58 0-136 27.34-136 82v42h150v-16.07c0-19 8-38.05 22-53.93c11.17-12.68 26.81-24.45 46-34z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M340 288c-52.07 0-156 32.16-156 96v48h312v-48c0-63.84-103.93-96-156-96z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1A = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '340',
      cy: '168',
      r: '88',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$N = [_hoisted_2$6l, _hoisted_3$5C, _hoisted_4$3z, _hoisted_5$1A];
    vue.defineComponent({
      name: 'PeopleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6l, _hoisted_6$N);
      }
    });

    const _hoisted_1$6k = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6k = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M332.64 64.58C313.18 43.57 286 32 256 32c-30.16 0-57.43 11.5-76.8 32.38c-19.58 21.11-29.12 49.8-26.88 80.78C156.76 206.28 203.27 256 256 256s99.16-49.71 103.67-110.82c2.27-30.7-7.33-59.33-27.03-80.6z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5B = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M432 480H80a31 31 0 0 1-24.2-11.13c-6.5-7.77-9.12-18.38-7.18-29.11C57.06 392.94 83.4 353.61 124.8 326c36.78-24.51 83.37-38 131.2-38s94.42 13.5 131.2 38c41.4 27.6 67.74 66.93 76.18 113.75c1.94 10.73-.68 21.34-7.18 29.11A31 31 0 0 1 432 480z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3y = [_hoisted_2$6k, _hoisted_3$5B];
    vue.defineComponent({
      name: 'Person',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6k, _hoisted_4$3y);
      }
    });

    const _hoisted_1$6j = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6j = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M288 256c52.79 0 99.43-49.71 104-110.82c2.27-30.7-7.36-59.33-27.12-80.6C345.33 43.57 318 32 288 32c-30.24 0-57.59 11.5-77 32.38c-19.63 21.11-29.2 49.8-27 80.78C188.49 206.28 235.12 256 288 256z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5A = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M495.38 439.76c-8.44-46.82-34.79-86.15-76.19-113.75C382.42 301.5 335.83 288 288 288s-94.42 13.5-131.19 38c-41.4 27.6-67.75 66.93-76.19 113.75c-1.93 10.73.69 21.34 7.19 29.11A30.94 30.94 0 0 0 112 480h352a30.94 30.94 0 0 0 24.21-11.13c6.48-7.77 9.1-18.38 7.17-29.11z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3x = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M104 288v-40h40a16 16 0 0 0 0-32h-40v-40a16 16 0 0 0-32 0v40H32a16 16 0 0 0 0 32h40v40a16 16 0 0 0 32 0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1z = [_hoisted_2$6j, _hoisted_3$5A, _hoisted_4$3x];
    vue.defineComponent({
      name: 'PersonAdd',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6j, _hoisted_5$1z);
      }
    });

    const _hoisted_1$6i = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6i = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M376 144c-3.92 52.87-44 96-88 96s-84.15-43.12-88-96c-4-55 35-96 88-96s92 42 88 96z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M288 304c-87 0-175.3 48-191.64 138.6c-2 10.92 4.21 21.4 15.65 21.4H464c11.44 0 17.62-10.48 15.65-21.4C463.3 352 375 304 288 304z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3w = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M88 176v112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1y = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M144 232H32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$M = [_hoisted_2$6i, _hoisted_3$5z, _hoisted_4$3w, _hoisted_5$1y];
    vue.defineComponent({
      name: 'PersonAddOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6i, _hoisted_6$M);
      }
    });

    const _hoisted_1$6h = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6h = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M106 304v-54h54v-36h-54v-54H70v54H16v36h54v54h36z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5y = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '288',
      cy: '144',
      r: '112',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3v = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M288 288c-69.42 0-208 42.88-208 128v64h416v-64c0-85.12-138.58-128-208-128z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1x = [_hoisted_2$6h, _hoisted_3$5y, _hoisted_4$3v];
    vue.defineComponent({
      name: 'PersonAddSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6h, _hoisted_5$1x);
      }
    });

    const _hoisted_1$6g = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6g = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm-50.22 116.82C218.45 151.39 236.28 144 256 144s37.39 7.44 50.11 20.94c12.89 13.68 19.16 32.06 17.68 51.82C320.83 256 290.43 288 256 288s-64.89-32-67.79-71.25c-1.47-19.92 4.79-38.36 17.57-51.93zM256 432a175.49 175.49 0 0 1-126-53.22a122.91 122.91 0 0 1 35.14-33.44C190.63 329 222.89 320 256 320s65.37 9 90.83 25.34A122.87 122.87 0 0 1 382 378.78A175.45 175.45 0 0 1 256 432z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5x = [_hoisted_2$6g];
    vue.defineComponent({
      name: 'PersonCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6g, _hoisted_3$5x);
      }
    });

    const _hoisted_1$6f = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6f = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M258.9 48C141.92 46.42 46.42 141.92 48 258.9c1.56 112.19 92.91 203.54 205.1 205.1c117 1.6 212.48-93.9 210.88-210.88C462.44 140.91 371.09 49.56 258.9 48zm126.42 327.25a4 4 0 0 1-6.14-.32a124.27 124.27 0 0 0-32.35-29.59C321.37 329 289.11 320 256 320s-65.37 9-90.83 25.34a124.24 124.24 0 0 0-32.35 29.58a4 4 0 0 1-6.14.32A175.32 175.32 0 0 1 80 259c-1.63-97.31 78.22-178.76 175.57-179S432 158.81 432 256a175.32 175.32 0 0 1-46.68 119.25z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5w = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 144c-19.72 0-37.55 7.39-50.22 20.82s-19 32-17.57 51.93C191.11 256 221.52 288 256 288s64.83-32 67.79-71.24c1.48-19.74-4.8-38.14-17.68-51.82C293.39 151.44 275.59 144 256 144z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3u = [_hoisted_2$6f, _hoisted_3$5w];
    vue.defineComponent({
      name: 'PersonCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6f, _hoisted_4$3u);
      }
    });

    const _hoisted_1$6e = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6e = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm2 96a72 72 0 1 1-72 72a72 72 0 0 1 72-72zm-2 288a175.55 175.55 0 0 1-129.18-56.6C135.66 329.62 215.06 320 256 320s120.34 9.62 129.18 55.39A175.52 175.52 0 0 1 256 432z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5v = [_hoisted_2$6e];
    vue.defineComponent({
      name: 'PersonCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6e, _hoisted_3$5v);
      }
    });

    const _hoisted_1$6d = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6d = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M344 144c-3.92 52.87-44 96-88 96s-84.15-43.12-88-96c-4-55 35-96 88-96s92 42 88 96z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5u = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 304c-87 0-175.3 48-191.64 138.6C62.39 453.52 68.57 464 80 464h352c11.44 0 17.62-10.48 15.65-21.4C431.3 352 343 304 256 304z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3t = [_hoisted_2$6d, _hoisted_3$5u];
    vue.defineComponent({
      name: 'PersonOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6d, _hoisted_4$3t);
      }
    });

    const _hoisted_1$6c = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6c = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M288 256c52.79 0 99.43-49.71 104-110.82c2.27-30.7-7.36-59.33-27.12-80.6C345.33 43.57 318 32 288 32c-30.24 0-57.59 11.5-77 32.38c-19.63 21.11-29.2 49.8-27 80.78C188.49 206.28 235.12 256 288 256z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5t = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M495.38 439.76c-8.44-46.82-34.79-86.15-76.19-113.75C382.42 301.5 335.83 288 288 288s-94.42 13.5-131.19 38c-41.4 27.6-67.75 66.93-76.19 113.75c-1.93 10.73.69 21.34 7.19 29.11A30.94 30.94 0 0 0 112 480h352a30.94 30.94 0 0 0 24.21-11.13c6.48-7.77 9.1-18.38 7.17-29.11z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3s = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M144 216H32a16 16 0 0 0 0 32h112a16 16 0 0 0 0-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1w = [_hoisted_2$6c, _hoisted_3$5t, _hoisted_4$3s];
    vue.defineComponent({
      name: 'PersonRemove',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6c, _hoisted_5$1w);
      }
    });

    const _hoisted_1$6b = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6b = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M376 144c-3.92 52.87-44 96-88 96s-84.15-43.12-88-96c-4-55 35-96 88-96s92 42 88 96z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5s = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M288 304c-87 0-175.3 48-191.64 138.6c-2 10.92 4.21 21.4 15.65 21.4H464c11.44 0 17.62-10.48 15.65-21.4C463.3 352 375 304 288 304z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3r = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M144 232H32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1v = [_hoisted_2$6b, _hoisted_3$5s, _hoisted_4$3r];
    vue.defineComponent({
      name: 'PersonRemoveOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6b, _hoisted_5$1v);
      }
    });

    const _hoisted_1$6a = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6a = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M16 214h144v36H16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5r = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '288',
      cy: '144',
      r: '112',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M288 288c-69.42 0-208 42.88-208 128v64h416v-64c0-85.12-138.58-128-208-128z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1u = [_hoisted_2$6a, _hoisted_3$5r, _hoisted_4$3q];
    vue.defineComponent({
      name: 'PersonRemoveSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6a, _hoisted_5$1u);
      }
    });

    const _hoisted_1$69 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$69 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 256a112 112 0 1 0-112-112a112 112 0 0 0 112 112zm0 32c-69.42 0-208 42.88-208 128v64h416v-64c0-85.12-138.58-128-208-128z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5q = [_hoisted_2$69];
    vue.defineComponent({
      name: 'PersonSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$69, _hoisted_3$5q);
      }
    });

    const _hoisted_1$68 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$68 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M0 176v160a64 64 0 0 0 64 64h384a64 64 0 0 0 64-64V176a64 64 0 0 0-64-64H64a64 64 0 0 0-64 64zm448-32a32 32 0 0 1 32 32v160a32 32 0 0 1-32 32H64a32 32 0 0 1-32-32v-11.35a7.94 7.94 0 0 1 4.75-7.3A32 32 0 0 0 56 288v-64a32 32 0 0 0-19.25-29.35a7.94 7.94 0 0 1-4.75-7.3V176a32 32 0 0 1 32-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5p = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 176a11.88 11.88 0 0 0 4.69 9.53A48 48 0 0 1 72 224v64a48 48 0 0 1-19.31 38.47A11.88 11.88 0 0 0 48 336a16 16 0 0 0 16 16h384a16 16 0 0 0 16-16V176a16 16 0 0 0-16-16H64a16 16 0 0 0-16 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3p = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M0 176v160a64 64 0 0 0 64 64h384a64 64 0 0 0 64-64V176a64 64 0 0 0-64-64H64a64 64 0 0 0-64 64zm448-32a32 32 0 0 1 32 32v160a32 32 0 0 1-32 32H64a32 32 0 0 1-32-32v-11.35a7.94 7.94 0 0 1 4.75-7.3A32 32 0 0 0 56 288v-64a32 32 0 0 0-19.25-29.35a7.94 7.94 0 0 1-4.75-7.3V176a32 32 0 0 1 32-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1t = [_hoisted_2$68, _hoisted_3$5p, _hoisted_4$3p];
    vue.defineComponent({
      name: 'PhoneLandscape',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$68, _hoisted_5$1t);
      }
    });

    const _hoisted_1$67 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$67 = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '128',
      y: '16',
      width: '256',
      height: '480',
      rx: '48',
      ry: '48',
      transform: 'rotate(-90 256 256)',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5o = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M16 336v-24a8 8 0 0 1 8-8h0a16 16 0 0 0 16-16v-64a16 16 0 0 0-16-16h0a8 8 0 0 1-8-8v-24',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3o = [_hoisted_2$67, _hoisted_3$5o];
    vue.defineComponent({
      name: 'PhoneLandscapeOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$67, _hoisted_4$3o);
      }
    });

    const _hoisted_1$66 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$66 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M0 130v252a18 18 0 0 0 18 18h476a18 18 0 0 0 18-18V130a18 18 0 0 0-18-18H18a18 18 0 0 0-18 18zm448 234H64V148h384z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5n = [_hoisted_2$66];
    vue.defineComponent({
      name: 'PhoneLandscapeSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$66, _hoisted_3$5n);
      }
    });

    const _hoisted_1$65 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$65 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 0H176a64 64 0 0 0-64 64v384a64 64 0 0 0 64 64h160a64 64 0 0 0 64-64V64a64 64 0 0 0-64-64zm32 448a32 32 0 0 1-32 32H176a32 32 0 0 1-32-32V64a32 32 0 0 1 32-32h11.35a7.94 7.94 0 0 1 7.3 4.75A32 32 0 0 0 224 56h64a32 32 0 0 0 29.35-19.25a7.94 7.94 0 0 1 7.3-4.75H336a32 32 0 0 1 32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5m = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 48a11.88 11.88 0 0 0-9.53 4.69A48 48 0 0 1 288 72h-64a48 48 0 0 1-38.47-19.31A11.88 11.88 0 0 0 176 48a16 16 0 0 0-16 16v384a16 16 0 0 0 16 16h160a16 16 0 0 0 16-16V64a16 16 0 0 0-16-16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3n = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 0H176a64 64 0 0 0-64 64v384a64 64 0 0 0 64 64h160a64 64 0 0 0 64-64V64a64 64 0 0 0-64-64zm32 448a32 32 0 0 1-32 32H176a32 32 0 0 1-32-32V64a32 32 0 0 1 32-32h11.35a7.94 7.94 0 0 1 7.3 4.75A32 32 0 0 0 224 56h64a32 32 0 0 0 29.35-19.25a7.94 7.94 0 0 1 7.3-4.75H336a32 32 0 0 1 32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1s = [_hoisted_2$65, _hoisted_3$5m, _hoisted_4$3n];
    vue.defineComponent({
      name: 'PhonePortrait',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$65, _hoisted_5$1s);
      }
    });

    const _hoisted_1$64 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$64 = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '128',
      y: '16',
      width: '256',
      height: '480',
      rx: '48',
      ry: '48',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5l = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M176 16h24a8 8 0 0 1 8 8h0a16 16 0 0 0 16 16h64a16 16 0 0 0 16-16h0a8 8 0 0 1 8-8h24',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3m = [_hoisted_2$64, _hoisted_3$5l];
    vue.defineComponent({
      name: 'PhonePortraitOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$64, _hoisted_4$3m);
      }
    });

    const _hoisted_1$63 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$63 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M382 0H130a18 18 0 0 0-18 18v476a18 18 0 0 0 18 18h252a18 18 0 0 0 18-18V18a18 18 0 0 0-18-18zM148 448V64h216v384z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5k = [_hoisted_2$63];
    vue.defineComponent({
      name: 'PhonePortraitSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$63, _hoisted_3$5k);
      }
    });

    const _hoisted_1$62 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$62 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M66.1 357a16 16 0 0 1-14.61-9.46A224 224 0 0 1 256 32a16 16 0 0 1 16 16v208a16 16 0 0 1-9.47 14.61l-189.9 84.95A15.93 15.93 0 0 1 66.1 357z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5j = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M313.59 68.18A8 8 0 0 0 304 76v180a48.07 48.07 0 0 1-28.4 43.82L103.13 377a8 8 0 0 0-3.35 11.81a208.42 208.42 0 0 0 48.46 50.41A206.32 206.32 0 0 0 272 480c114.69 0 208-93.31 208-208c0-100.45-71.58-184.5-166.41-203.82z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3l = [_hoisted_2$62, _hoisted_3$5j];
    vue.defineComponent({
      name: 'PieChart',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$62, _hoisted_4$3l);
      }
    });

    const _hoisted_1$61 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$61 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256.05 80.65Q263.94 80 272 80c106 0 192 86 192 192s-86 192-192 192A192.09 192.09 0 0 1 89.12 330.65',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5i = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.12 48 48 141.12 48 256a207.29 207.29 0 0 0 18.09 85L256 256z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3k = [_hoisted_2$61, _hoisted_3$5i];
    vue.defineComponent({
      name: 'PieChartOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$61, _hoisted_4$3k);
      }
    });

    const _hoisted_1$60 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$60 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M58 362.09l-6.51-14.59A224 224 0 0 1 256 32h16v234.37z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5h = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M304 66.46v220.65L94.62 380.78A208.31 208.31 0 0 0 272 480c114.69 0 208-93.31 208-208c0-103.81-76.45-190.1-176-205.54z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3j = [_hoisted_2$60, _hoisted_3$5h];
    vue.defineComponent({
      name: 'PieChartSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$60, _hoisted_4$3j);
      }
    });

    const _hoisted_1$5$ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5$ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 96a80 80 0 1 0-96 78.39v283.17a32.09 32.09 0 0 0 2.49 12.38l10.07 24a3.92 3.92 0 0 0 6.88 0l10.07-24a32.09 32.09 0 0 0 2.49-12.38V174.39A80.13 80.13 0 0 0 336 96zm-56 0a24 24 0 1 1 24-24a24 24 0 0 1-24 24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5g = [_hoisted_2$5$];
    vue.defineComponent({
      name: 'Pin',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5$, _hoisted_3$5g);
      }
    });

    const _hoisted_1$5_ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5_ = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '96',
      r: '64',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5f = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M272 164a9 9 0 0 0-9-9h-14a9 9 0 0 0-9 9v293.56a32.09 32.09 0 0 0 2.49 12.38l10.07 24a3.92 3.92 0 0 0 6.88 0l10.07-24a32.09 32.09 0 0 0 2.49-12.38z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3i = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '280',
      cy: '72',
      r: '24',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1r = [_hoisted_2$5_, _hoisted_3$5f, _hoisted_4$3i];
    vue.defineComponent({
      name: 'PinOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5_, _hoisted_5$1r);
      }
    });

    const _hoisted_1$5Z = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5Z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M339 99a83 83 0 1 0-102 80.8V464l19 32l19-32V179.8A83.28 83.28 0 0 0 339 99zm-59-6a21 21 0 1 1 21-21a21 21 0 0 1-21 21z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5e = [_hoisted_2$5Z];
    vue.defineComponent({
      name: 'PinSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5Z, _hoisted_3$5e);
      }
    });

    const _hoisted_1$5Y = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5Y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M399 99.29c-.15-2.13-.3-4.35-.44-6.68L395.69 46a32 32 0 0 0-31.91-30H148.21a32 32 0 0 0-31.91 30l-2.91 46.63c-.14 2.31-.29 4.51-.43 6.62c-1.29 19.24-2.23 33.14 3.73 65.66c1.67 9.11 5.22 22.66 9.73 39.82c12.61 48 33.71 128.36 33.71 195.63V472a24 24 0 0 0 24 24h143.74a24 24 0 0 0 24-24v-71.62c0-77.09 21.31-153.29 34-198.81c4.38-15.63 7.83-28 9.41-36.62c5.99-32.51 5.05-46.42 3.72-65.66zm-35-47.54l1.5 24a4 4 0 0 1-4 4.25h-211a4 4 0 0 1-4-4.25l1.48-24A4 4 0 0 1 152 48h208a4 4 0 0 1 4 3.75z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5d = [_hoisted_2$5Y];
    vue.defineComponent({
      name: 'Pint',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5Y, _hoisted_3$5d);
      }
    });

    const _hoisted_1$5X = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5X = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M132.43 162c-6.24-34-4.49-45.55-3.07-68.39L132.27 47a16 16 0 0 1 15.94-15h215.57a16 16 0 0 1 15.94 15l2.91 46.61c1.43 22.86 3.19 34.39-3.06 68.45c-5.93 32.29-43.71 133.27-43.71 238.32V472a8 8 0 0 1-8 8H184.12a8 8 0 0 1-8-8v-71.63c.01-92.47-37.46-204.3-43.69-238.37z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5c = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M135.21 96h241.58'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3h = [_hoisted_2$5X, _hoisted_3$5c];
    vue.defineComponent({
      name: 'PintOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5X, _hoisted_4$3h);
      }
    });

    const _hoisted_1$5W = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5W = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M399 99.29L394 16H118.45L113 99.26c-1.29 19.24-2.23 33.14 3.73 65.66c1.67 9.11 5.22 22.66 9.73 39.82c12.61 48 33.71 128.36 33.71 195.63V496h191.68v-95.62c0-77.09 21.31-153.29 34-198.81c4.38-15.63 7.83-28 9.41-36.62c6.01-32.51 5.07-46.42 3.74-65.66zM146.23 80l2-32h215.52l2 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5b = [_hoisted_2$5W];
    vue.defineComponent({
      name: 'PintSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5W, _hoisted_3$5b);
      }
    });

    const _hoisted_1$5V = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5V = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M441.82 67.83C383.44 44.73 317.3 32 255.56 32C192 32 125.76 44.53 69 67.26C48.7 75.49 45.21 90 48.71 100.82L52.78 111a16 16 0 0 0 21.31 8.69c10.8-4.76 23.93-10.54 27-11.78C145.1 89.64 198.71 80 256 80c57.47 0 108.09 9.24 154.76 28.25c4.42 1.8 14.88 6.42 26.17 11.46a16 16 0 0 0 21.35-8.59L462 102l.34-.9c3.45-10.21.14-25.05-20.52-33.27z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5a = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M409.18 140.86C363.67 122.53 307.68 112 255.56 112a425 425 0 0 0-153.74 28.89c-.53.21-2.06.88-4.29 1.88a16 16 0 0 0-8 21.27c4 8.71 9.42 20.58 15.5 33.89C137.94 270 199.21 404 227.26 462A31.74 31.74 0 0 0 256 480a31.73 31.73 0 0 0 28.76-18.06l.06-.13l137.3-297.57a15.94 15.94 0 0 0-8.31-21.45c-2.26-.95-3.85-1.61-4.5-1.87zm-215.1 83.07a32 32 0 1 1 29.85-29.85a32 32 0 0 1-29.85 29.85zm64 128a32 32 0 1 1 29.85-29.85a32 32 0 0 1-29.85 29.85zm64-112a32 32 0 1 1 29.85-29.85a32 32 0 0 1-29.85 29.85z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3g = [_hoisted_2$5V, _hoisted_3$5a];
    vue.defineComponent({
      name: 'Pizza',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5V, _hoisted_4$3g);
      }
    });

    const _hoisted_1$5U = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5U = /*#__PURE__*/vue.createStaticVNode('<path d="M404.76 123.08C358.37 104.18 309.69 96 256 96s-106.1 9-148.9 26.68c-8.08 3.3-15.26 9-10.07 19.5C101.24 150.71 203 375 241.66 455a15.94 15.94 0 0 0 28.72 0l144.05-312.22c3.19-6.9.9-15.4-9.67-19.7z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path d="M436.38 82.68C384.31 62.08 320.17 48 256 48S128.65 60.78 75.48 82.08C70.79 84 62 88.43 64.41 95.88L74.09 120c4 8.2 8.67 8.2 15.06 8.2c1.79 0 4.29-1 7.28-2.18A442.46 442.46 0 0 1 256 96c56.76 0 114.91 12 159.6 30c3.59 1.4 5.59 2.18 7.28 2.18c6.58 0 10.38 2.19 15-8.1L447.65 96c2.01-6-4.99-10.82-11.27-13.32z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><circle cx="192" cy="192" r="32" fill="currentColor"></circle><circle cx="320" cy="208" r="32" fill="currentColor"></circle><circle cx="256" cy="320" r="32" fill="currentColor"></circle>', 5);

    const _hoisted_7$q = [_hoisted_2$5U];
    vue.defineComponent({
      name: 'PizzaOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5U, _hoisted_7$q);
      }
    });

    const _hoisted_1$5T = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5T = /*#__PURE__*/vue.createStaticVNode('<path d="M442.3 67.82C383.92 44.72 317.78 32 256 32c-63.57 0-129.8 12.51-186.56 35.25C49.18 75.48 42 80 42 80l22 44l37.53-16.14C147.58 89.53 199.19 80 256.51 80c57.49 0 108.09 9.23 154.75 28.25L448 124l22-44s-7-4-27.7-12.18z" fill="currentColor"></path><ellipse cx="320.48" cy="207.99" rx="31.97" ry="32.03" transform="rotate(-44.98 320.503 207.996)" fill="none"></ellipse><ellipse cx="192.48" cy="191.99" rx="31.97" ry="32.03" transform="rotate(-44.98 192.49 191.992)" fill="none"></ellipse><ellipse cx="256.48" cy="319.99" rx="31.97" ry="32.03" transform="rotate(-44.98 256.505 320)" fill="none"></ellipse><path d="M409.66 140.85C364.15 122.52 308.16 112 256 112a425 425 0 0 0-153.7 28.9c-.25.1-9.24 4.23-19 8.71c7.46 16.22 18 39.16 22.2 48.33L256 480l173.74-330.84l-19.92-8.24zm-185.25 53.22a32 32 0 1 1-34-34a32.12 32.12 0 0 1 34 34zm64 128a32 32 0 1 1-34-34a32.12 32.12 0 0 1 34 34zm64-112a32 32 0 1 1-34-34a32.12 32.12 0 0 1 34 34z" fill="currentColor"></path>', 5);

    const _hoisted_7$p = [_hoisted_2$5T];
    vue.defineComponent({
      name: 'PizzaSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5T, _hoisted_7$p);
      }
    });

    const _hoisted_1$5S = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5S = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M96.85 286.62a8 8 0 0 0-12.53 8.25C102.07 373.28 172.3 432 256 432a175.31 175.31 0 0 0 52.41-8a8 8 0 0 0 .79-15a1120 1120 0 0 1-109.48-55.61a1126.24 1126.24 0 0 1-102.87-66.77z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$59 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M492.72 339.51c-4.19-5.58-9.11-11.44-14.7-17.53a15.83 15.83 0 0 0-26.56 5.13c0 .16-.11.31-.17.47a15.75 15.75 0 0 0 3.15 16.06c22.74 25 26.42 38.51 25.48 41.36c-2 2.23-17.05 6.89-58.15-3.53q-8.83-2.24-19.32-5.46q-6.76-2.08-13.79-4.49a176.76 176.76 0 0 0 19.54-27.25c.17-.29.35-.58.52-.88A175.39 175.39 0 0 0 432 256a178.87 178.87 0 0 0-1-19c-9.57-88.17-84.4-157-175-157a175.37 175.37 0 0 0-106.4 35.89a177.4 177.4 0 0 0-45.83 51.84c-.16.29-.34.58-.51.87a175.48 175.48 0 0 0-13.83 30.52q-5.59-4.87-10.79-9.67c-5.39-5-10.17-9.63-14.42-14c-29.57-30.26-33.09-45.61-32.16-48.45c2-2.23 15.54-5.87 48.62 1.31A15.82 15.82 0 0 0 96.22 123l.36-.44a15.74 15.74 0 0 0-8.67-25.43A237.38 237.38 0 0 0 64.13 93c-30.72-3.53-50.83 2.52-59.78 18c-3.24 5.58-6.35 15.09-2.72 28.6C7 159.66 26.14 184 53.23 209.5c8.63 8.13 18.06 16.37 28.12 24.64c7.32 6 15 12.06 22.9 18.08q7.91 6 16.15 12T137.1 276c25.41 17.61 52.26 34.52 78.59 49.69q14.34 8.26 28.64 16t28.37 14.81c21.9 11 43.35 20.92 63.86 29.43q13.19 5.48 25.81 10.16c11.89 4.42 23.37 8.31 34.31 11.59l1.1.33c25.73 7.66 47.42 11.69 64.48 12H464c21.64 0 36.3-6.38 43.58-19c9.09-15.62 4.08-36.32-14.86-61.5z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3f = [_hoisted_2$5S, _hoisted_3$59];
    vue.defineComponent({
      name: 'Planet',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5S, _hoisted_4$3f);
      }
    });

    const _hoisted_1$5R = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5R = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M413.48 284.46c58.87 47.24 91.61 89 80.31 108.55c-17.85 30.85-138.78-5.48-270.1-81.15S.37 149.84 18.21 119c11.16-19.28 62.58-12.32 131.64 14.09',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$58 = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '160',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3e = [_hoisted_2$5R, _hoisted_3$58];
    vue.defineComponent({
      name: 'PlanetOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5R, _hoisted_4$3e);
      }
    });

    const _hoisted_1$5Q = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5Q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M81 274.71C90.36 363 165.26 432 256 432a174.91 174.91 0 0 0 71.49-15.19c-40.3-16.53-84.05-38.17-127.77-63.36C157 328.86 115.84 301.5 81 274.71z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$57 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M492.72 339.51c-8.5-11.31-20-23.8-34-37a205.25 205.25 0 0 1-11 34c28.72 29.5 33.2 45.34 32.17 48.45c-2 2.23-17.05 6.89-58.15-3.53q-8.83-2.24-19.32-5.46q-6.76-2.08-13.79-4.49a176.76 176.76 0 0 0 19.54-27.25c.17-.29.35-.58.52-.88A175.39 175.39 0 0 0 432 256a178.87 178.87 0 0 0-1-19c-9.57-88.17-84.4-157-175-157a175.37 175.37 0 0 0-106.4 35.89a177.4 177.4 0 0 0-45.83 51.84c-.16.29-.34.58-.51.87a175.48 175.48 0 0 0-13.83 30.52q-5.59-4.87-10.79-9.67c-5.39-5-10.17-9.63-14.42-14c-29.57-30.26-33.09-45.61-32.16-48.45c2.16-2.43 18.1-6.54 58.13 3.55a209.88 209.88 0 0 1 24-26.56c-18.86-5.61-35.79-9.35-50.05-11C33.41 89.47 13.3 95.52 4.35 111c-3.24 5.58-6.35 15.09-2.72 28.6C7 159.66 26.14 184 53.23 209.5c8.63 8.13 18.06 16.37 28.12 24.64c7.32 6 15 12.06 22.9 18.08q7.91 6 16.15 12T137.1 276c25.41 17.61 52.26 34.52 78.59 49.69q14.34 8.26 28.64 16t28.37 14.81c21.9 11 43.35 20.92 63.86 29.43q13.19 5.48 25.81 10.16c11.89 4.42 23.37 8.31 34.31 11.59l1.1.33c25.73 7.66 47.42 11.69 64.48 12H464c21.64 0 36.3-6.38 43.58-19c9.09-15.62 4.08-36.32-14.86-61.5z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3d = [_hoisted_2$5Q, _hoisted_3$57];
    vue.defineComponent({
      name: 'PlanetSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5Q, _hoisted_4$3d);
      }
    });

    const _hoisted_1$5P = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5P = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M133 440a35.37 35.37 0 0 1-17.5-4.67c-12-6.8-19.46-20-19.46-34.33V111c0-14.37 7.46-27.53 19.46-34.33a35.13 35.13 0 0 1 35.77.45l247.85 148.36a36 36 0 0 1 0 61l-247.89 148.4A35.5 35.5 0 0 1 133 440z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$56 = [_hoisted_2$5P];
    vue.defineComponent({
      name: 'Play',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5P, _hoisted_3$56);
      }
    });

    const _hoisted_1$5O = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5O = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M30.71 229.47l188.87-113a30.54 30.54 0 0 1 31.09-.39a33.74 33.74 0 0 1 16.76 29.47v79.05l180.72-108.16a30.54 30.54 0 0 1 31.09-.39A33.74 33.74 0 0 1 496 145.52v221A33.73 33.73 0 0 1 479.24 396a30.54 30.54 0 0 1-31.09-.39L267.43 287.4v79.08A33.73 33.73 0 0 1 250.67 396a30.54 30.54 0 0 1-31.09-.39l-188.87-113a31.27 31.27 0 0 1 0-53z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$55 = [_hoisted_2$5O];
    vue.defineComponent({
      name: 'PlayBack',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5O, _hoisted_3$55);
      }
    });

    const _hoisted_1$5N = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5N = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 256c0 114.69 93.31 208 208 208s208-93.31 208-208S370.69 48 256 48S48 141.31 48 256zm69.23-9.3l114.45-69.14a10.78 10.78 0 0 1 16.32 9.31v53.32l103.68-62.63a10.78 10.78 0 0 1 16.32 9.31v138.26a10.78 10.78 0 0 1-16.32 9.31L248 271.81v53.32a10.78 10.78 0 0 1-16.32 9.31L117.23 265.3a10.89 10.89 0 0 1 0-18.6z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$54 = [_hoisted_2$5N];
    vue.defineComponent({
      name: 'PlayBackCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5N, _hoisted_3$54);
      }
    });

    const _hoisted_1$5M = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5M = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 448c106 0 192-86 192-192S362 64 256 64S64 150 64 256s86 192 192 192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$53 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M117.23 246.7l114.45-69.14a10.78 10.78 0 0 1 16.32 9.31v53.32l103.68-62.63a10.78 10.78 0 0 1 16.32 9.31v138.26a10.78 10.78 0 0 1-16.32 9.31L248 271.81v53.32a10.78 10.78 0 0 1-16.32 9.31L117.23 265.3a10.89 10.89 0 0 1 0-18.6z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3c = [_hoisted_2$5M, _hoisted_3$53];
    vue.defineComponent({
      name: 'PlayBackCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5M, _hoisted_4$3c);
      }
    });

    const _hoisted_1$5L = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5L = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 256c0 114.69 93.31 208 208 208s208-93.31 208-208S370.69 48 256 48S48 141.31 48 256zm63.47 0L248 168v72.16l120-72.48v176.45l-120-72.32v71.44z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$52 = [_hoisted_2$5L];
    vue.defineComponent({
      name: 'PlayBackCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5L, _hoisted_3$52);
      }
    });

    const _hoisted_1$5K = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5K = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 145.52v221c0 13.28-13 21.72-23.63 15.35L267.5 268.8c-9.24-5.53-9.24-20.07 0-25.6l188.87-113C467 123.8 480 132.24 480 145.52z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$51 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M251.43 145.52v221c0 13.28-13 21.72-23.63 15.35L38.93 268.8c-9.24-5.53-9.24-20.07 0-25.6l188.87-113c10.64-6.4 23.63 2.04 23.63 15.32z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3b = [_hoisted_2$5K, _hoisted_3$51];
    vue.defineComponent({
      name: 'PlayBackOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5K, _hoisted_4$3b);
      }
    });

    const _hoisted_1$5J = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5J = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M496 400L256 256l240-144v288z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$50 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 400L16 256l240-144v288z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3a = [_hoisted_2$5J, _hoisted_3$50];
    vue.defineComponent({
      name: 'PlayBackSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5J, _hoisted_4$3a);
      }
    });

    const _hoisted_1$5I = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5I = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm74.77 217.3l-114.45 69.14a10.78 10.78 0 0 1-16.32-9.31V186.87a10.78 10.78 0 0 1 16.32-9.31l114.45 69.14a10.89 10.89 0 0 1 0 18.6z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4$ = [_hoisted_2$5I];
    vue.defineComponent({
      name: 'PlayCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5I, _hoisted_3$4$);
      }
    });

    const _hoisted_1$5H = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5H = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4_ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M216.32 334.44l114.45-69.14a10.89 10.89 0 0 0 0-18.6l-114.45-69.14a10.78 10.78 0 0 0-16.32 9.31v138.26a10.78 10.78 0 0 0 16.32 9.31z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$39 = [_hoisted_2$5H, _hoisted_3$4_];
    vue.defineComponent({
      name: 'PlayCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5H, _hoisted_4$39);
      }
    });

    const _hoisted_1$5G = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5G = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm-56 296V168l144 88z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4Z = [_hoisted_2$5G];
    vue.defineComponent({
      name: 'PlayCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5G, _hoisted_3$4Z);
      }
    });

    const _hoisted_1$5F = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5F = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M481.29 229.47l-188.87-113a30.54 30.54 0 0 0-31.09-.39a33.74 33.74 0 0 0-16.76 29.47v79.05L63.85 116.44a30.54 30.54 0 0 0-31.09-.39A33.74 33.74 0 0 0 16 145.52v221A33.74 33.74 0 0 0 32.76 396a30.54 30.54 0 0 0 31.09-.39L244.57 287.4v79.08A33.74 33.74 0 0 0 261.33 396a30.54 30.54 0 0 0 31.09-.39l188.87-113a31.27 31.27 0 0 0 0-53z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4Y = [_hoisted_2$5F];
    vue.defineComponent({
      name: 'PlayForward',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5F, _hoisted_3$4Y);
      }
    });

    const _hoisted_1$5E = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5E = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm138.77 217.3l-114.45 69.14a10.78 10.78 0 0 1-16.32-9.31v-53.32l-103.68 62.63a10.78 10.78 0 0 1-16.32-9.31V186.87a10.78 10.78 0 0 1 16.32-9.31L264 240.19v-53.32a10.78 10.78 0 0 1 16.32-9.31l114.45 69.14a10.89 10.89 0 0 1 0 18.6z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4X = [_hoisted_2$5E];
    vue.defineComponent({
      name: 'PlayForwardCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5E, _hoisted_3$4X);
      }
    });

    const _hoisted_1$5D = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5D = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4W = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M394.77 246.7l-114.45-69.14a10.78 10.78 0 0 0-16.32 9.31v53.32l-103.68-62.63a10.78 10.78 0 0 0-16.32 9.31v138.26a10.78 10.78 0 0 0 16.32 9.31L264 271.81v53.32a10.78 10.78 0 0 0 16.32 9.31l114.45-69.14a10.89 10.89 0 0 0 0-18.6z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$38 = [_hoisted_2$5D, _hoisted_3$4W];
    vue.defineComponent({
      name: 'PlayForwardCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5D, _hoisted_4$38);
      }
    });

    const _hoisted_1$5C = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5C = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm8 295.25v-71.44l-120 72.32V167.71l120 72.48V168l136.53 88z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4V = [_hoisted_2$5C];
    vue.defineComponent({
      name: 'PlayForwardCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5C, _hoisted_3$4V);
      }
    });

    const _hoisted_1$5B = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5B = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M32 145.52v221c0 13.28 13 21.72 23.63 15.35l188.87-113c9.24-5.53 9.24-20.07 0-25.6l-188.87-113C45 123.8 32 132.24 32 145.52z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4U = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M260.57 145.52v221c0 13.28 13 21.72 23.63 15.35l188.87-113c9.24-5.53 9.24-20.07 0-25.6l-188.87-113c-10.64-6.47-23.63 1.97-23.63 15.25z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$37 = [_hoisted_2$5B, _hoisted_3$4U];
    vue.defineComponent({
      name: 'PlayForwardOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5B, _hoisted_4$37);
      }
    });

    const _hoisted_1$5A = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5A = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M16 400l240-144L16 112v288z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4T = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 400l240-144l-240-144v288z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$36 = [_hoisted_2$5A, _hoisted_3$4T];
    vue.defineComponent({
      name: 'PlayForwardSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5A, _hoisted_4$36);
      }
    });

    const _hoisted_1$5z = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M112 111v290c0 17.44 17 28.52 31 20.16l247.9-148.37c12.12-7.25 12.12-26.33 0-33.58L143 90.84c-14-8.36-31 2.72-31 20.16z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4S = [_hoisted_2$5z];
    vue.defineComponent({
      name: 'PlayOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5z, _hoisted_3$4S);
      }
    });

    const _hoisted_1$5y = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M96 448l320-192L96 64v384z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4R = [_hoisted_2$5y];
    vue.defineComponent({
      name: 'PlaySharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5y, _hoisted_3$4R);
      }
    });

    const _hoisted_1$5x = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5x = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M112 64a16 16 0 0 1 16 16v136.43L360.77 77.11a35.13 35.13 0 0 1 35.77-.44c12 6.8 19.46 20 19.46 34.33v290c0 14.37-7.46 27.53-19.46 34.33a35.14 35.14 0 0 1-35.77-.45L128 295.57V432a16 16 0 0 1-32 0V80a16 16 0 0 1 16-16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4Q = [_hoisted_2$5x];
    vue.defineComponent({
      name: 'PlaySkipBack',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5x, _hoisted_3$4Q);
      }
    });

    const _hoisted_1$5w = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5w = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 256c0 114.69 93.31 208 208 208s208-93.31 208-208S370.69 48 256 48S48 141.31 48 256zm128-64a16 16 0 0 1 32 0v53l111.68-67.46a10.78 10.78 0 0 1 16.32 9.33v138.26a10.78 10.78 0 0 1-16.32 9.31L208 267v53a16 16 0 0 1-32 0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4P = [_hoisted_2$5w];
    vue.defineComponent({
      name: 'PlaySkipBackCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5w, _hoisted_3$4P);
      }
    });

    const _hoisted_1$5v = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5v = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 448c106 0 192-86 192-192S362 64 256 64S64 150 64 256s86 192 192 192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4O = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M192 176a16 16 0 0 1 16 16v53l111.68-67.46a10.78 10.78 0 0 1 16.32 9.33v138.26a10.78 10.78 0 0 1-16.32 9.31L208 267v53a16 16 0 0 1-32 0V192a16 16 0 0 1 16-16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$35 = [_hoisted_2$5v, _hoisted_3$4O];
    vue.defineComponent({
      name: 'PlaySkipBackCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5v, _hoisted_4$35);
      }
    });

    const _hoisted_1$5u = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5u = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 256c0 114.69 93.31 208 208 208s208-93.31 208-208S370.69 48 256 48S48 141.31 48 256zm128-80h32v69l128-77.53v176.9L208 267v69h-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4N = [_hoisted_2$5u];
    vue.defineComponent({
      name: 'PlaySkipBackCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5u, _hoisted_3$4N);
      }
    });

    const _hoisted_1$5t = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5t = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400 111v290c0 17.44-17 28.52-31 20.16L121.09 272.79c-12.12-7.25-12.12-26.33 0-33.58L369 90.84c14-8.36 31 2.72 31 20.16z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4M = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M112 80v352'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$34 = [_hoisted_2$5t, _hoisted_3$4M];
    vue.defineComponent({
      name: 'PlaySkipBackOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5t, _hoisted_4$34);
      }
    });

    const _hoisted_1$5s = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5s = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M143.47 64v163.52L416 64v384L143.47 284.48V448H96V64h47.47z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4L = [_hoisted_2$5s];
    vue.defineComponent({
      name: 'PlaySkipBackSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5s, _hoisted_3$4L);
      }
    });

    const _hoisted_1$5r = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5r = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400 64a16 16 0 0 0-16 16v136.43L151.23 77.11a35.13 35.13 0 0 0-35.77-.44C103.46 83.47 96 96.63 96 111v290c0 14.37 7.46 27.53 19.46 34.33a35.14 35.14 0 0 0 35.77-.45L384 295.57V432a16 16 0 0 0 32 0V80a16 16 0 0 0-16-16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4K = [_hoisted_2$5r];
    vue.defineComponent({
      name: 'PlaySkipForward',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5r, _hoisted_3$4K);
      }
    });

    const _hoisted_1$5q = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm80 272a16 16 0 0 1-32 0v-53l-111.68 67.44a10.78 10.78 0 0 1-16.32-9.31V186.87a10.78 10.78 0 0 1 16.32-9.31L304 245v-53a16 16 0 0 1 32 0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4J = [_hoisted_2$5q];
    vue.defineComponent({
      name: 'PlaySkipForwardCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5q, _hoisted_3$4J);
      }
    });

    const _hoisted_1$5p = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5p = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4I = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 176a16 16 0 0 0-16 16v53l-111.68-67.44a10.78 10.78 0 0 0-16.32 9.31v138.26a10.78 10.78 0 0 0 16.32 9.31L304 267v53a16 16 0 0 0 32 0V192a16 16 0 0 0-16-16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$33 = [_hoisted_2$5p, _hoisted_3$4I];
    vue.defineComponent({
      name: 'PlaySkipForwardCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5p, _hoisted_4$33);
      }
    });

    const _hoisted_1$5o = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5o = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm80 288h-32v-69l-128 77.37V167.49L304 245v-69h32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4H = [_hoisted_2$5o];
    vue.defineComponent({
      name: 'PlaySkipForwardCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5o, _hoisted_3$4H);
      }
    });

    const _hoisted_1$5n = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5n = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M112 111v290c0 17.44 17 28.52 31 20.16l247.9-148.37c12.12-7.25 12.12-26.33 0-33.58L143 90.84c-14-8.36-31 2.72-31 20.16z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4G = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M400 80v352'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$32 = [_hoisted_2$5n, _hoisted_3$4G];
    vue.defineComponent({
      name: 'PlaySkipForwardOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5n, _hoisted_4$32);
      }
    });

    const _hoisted_1$5m = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5m = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M368.53 64v163.52L96 64v384l272.53-163.52V448H416V64h-47.47z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4F = [_hoisted_2$5m];
    vue.defineComponent({
      name: 'PlaySkipForwardSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5m, _hoisted_3$4F);
      }
    });

    const _hoisted_1$5l = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5l = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 32H192a32 32 0 0 0-32 32v412a4 4 0 0 0 4 4h184a4 4 0 0 0 4-4V64a32 32 0 0 0-32-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4E = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 192h-72a8 8 0 0 0-8 8v272a8 8 0 0 0 8 8h80a24 24 0 0 0 24-24V224a32 32 0 0 0-32-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$31 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 128a32 32 0 0 0-32 32v296a24 24 0 0 0 24 24h80a8 8 0 0 0 8-8V136a8 8 0 0 0-8-8z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1q = [_hoisted_2$5l, _hoisted_3$4E, _hoisted_4$31];
    vue.defineComponent({
      name: 'Podium',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5l, _hoisted_5$1q);
      }
    });

    const _hoisted_1$5k = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5k = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M32 160v296a8 8 0 0 0 8 8h136V160a16 16 0 0 0-16-16H48a16 16 0 0 0-16 16z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4D = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 48H192a16 16 0 0 0-16 16v400h160V64a16 16 0 0 0-16-16z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$30 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 208H352a16 16 0 0 0-16 16v240h136a8 8 0 0 0 8-8V224a16 16 0 0 0-16-16z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1p = [_hoisted_2$5k, _hoisted_3$4D, _hoisted_4$30];
    vue.defineComponent({
      name: 'PodiumOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5k, _hoisted_5$1p);
      }
    });

    const _hoisted_1$5j = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5j = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M160 32h192v448H160z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4C = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 192h112v288H384z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2$ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M16 128h112v352H16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1o = [_hoisted_2$5j, _hoisted_3$4C, _hoisted_4$2$];
    vue.defineComponent({
      name: 'PodiumSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5j, _hoisted_5$1o);
      }
    });

    const _hoisted_1$5i = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5i = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 464c-114.69 0-208-93.47-208-208.35c0-62.45 27.25-121 74.76-160.55a22 22 0 1 1 28.17 33.8C113.48 160.1 92 206.3 92 255.65C92 346.27 165.57 420 256 420s164-73.73 164-164.35A164 164 0 0 0 360.17 129a22 22 0 1 1 28-33.92A207.88 207.88 0 0 1 464 255.65C464 370.53 370.69 464 256 464z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4B = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 272a22 22 0 0 1-22-22V70a22 22 0 0 1 44 0v180a22 22 0 0 1-22 22z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2_ = [_hoisted_2$5i, _hoisted_3$4B];
    vue.defineComponent({
      name: 'Power',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5i, _hoisted_4$2_);
      }
    });

    const _hoisted_1$5h = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5h = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M378 108a191.41 191.41 0 0 1 70 148c0 106-86 192-192 192S64 362 64 256a192 192 0 0 1 69-148',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4A = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 64v192'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2Z = [_hoisted_2$5h, _hoisted_3$4A];
    vue.defineComponent({
      name: 'PowerOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5h, _hoisted_4$2Z);
      }
    });

    const _hoisted_1$5g = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5g = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 464c-114.69 0-208-93.23-208-207.82a207.44 207.44 0 0 1 74.76-160.13l16.9-14l28.17 33.72l-16.9 14A163.72 163.72 0 0 0 92 256.18c0 90.39 73.57 163.93 164 163.93s164-73.54 164-163.93a163.38 163.38 0 0 0-59.83-126.36l-17-14l28-33.82l17 14A207.13 207.13 0 0 1 464 256.18C464 370.77 370.69 464 256 464z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M234 48h44v224h-44z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2Y = [_hoisted_2$5g, _hoisted_3$4z];
    vue.defineComponent({
      name: 'PowerSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5g, _hoisted_4$2Y);
      }
    });

    const _hoisted_1$5f = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5f = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M467 45.2A44.45 44.45 0 0 0 435.29 32H312.36a30.63 30.63 0 0 0-21.52 8.89L45.09 286.59a44.82 44.82 0 0 0 0 63.32l117 117a44.83 44.83 0 0 0 63.34 0l245.65-245.6A30.6 30.6 0 0 0 480 199.8v-123a44.24 44.24 0 0 0-13-31.6zM384 160a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4y = [_hoisted_2$5f];
    vue.defineComponent({
      name: 'Pricetag',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5f, _hoisted_3$4y);
      }
    });

    const _hoisted_1$5e = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5e = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M435.25 48h-122.9a14.46 14.46 0 0 0-10.2 4.2L56.45 297.9a28.85 28.85 0 0 0 0 40.7l117 117a28.85 28.85 0 0 0 40.7 0L459.75 210a14.46 14.46 0 0 0 4.2-10.2v-123a28.66 28.66 0 0 0-28.7-28.8z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4x = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 160a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2X = [_hoisted_2$5e, _hoisted_3$4x];
    vue.defineComponent({
      name: 'PricetagOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5e, _hoisted_4$2X);
      }
    });

    const _hoisted_1$5d = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5d = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M304 32L16 320l176 176l288-288V32zm80 128a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4w = [_hoisted_2$5d];
    vue.defineComponent({
      name: 'PricetagSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5d, _hoisted_3$4w);
      }
    });

    const _hoisted_1$5c = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5c = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 183.8v-123A44.66 44.66 0 0 0 403.29 16H280.36a30.62 30.62 0 0 0-21.51 8.89L13.09 270.58a44.86 44.86 0 0 0 0 63.34l117 117a44.84 44.84 0 0 0 63.33 0l245.69-245.61A30.6 30.6 0 0 0 448 183.8zM352 144a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4v = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M496 64a16 16 0 0 0-16 16v127.37L218.69 468.69a16 16 0 1 0 22.62 22.62l262-262A29.84 29.84 0 0 0 512 208V80a16 16 0 0 0-16-16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2W = [_hoisted_2$5c, _hoisted_3$4v];
    vue.defineComponent({
      name: 'Pricetags',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5c, _hoisted_4$2W);
      }
    });

    const _hoisted_1$5b = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5b = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M403.29 32H280.36a14.46 14.46 0 0 0-10.2 4.2L24.4 281.9a28.85 28.85 0 0 0 0 40.7l117 117a28.86 28.86 0 0 0 40.71 0L427.8 194a14.46 14.46 0 0 0 4.2-10.2v-123A28.66 28.66 0 0 0 403.29 32z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4u = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M352 144a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2V = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M230 480l262-262a13.81 13.81 0 0 0 4-10V80',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1n = [_hoisted_2$5b, _hoisted_3$4u, _hoisted_4$2V];
    vue.defineComponent({
      name: 'PricetagsOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5b, _hoisted_5$1n);
      }
    });

    const _hoisted_1$5a = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5a = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M288 16L0 304l176 176l288-288V16zm80 128a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4t = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 64v144L216.9 471.1L242 496l270-272V64h-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2U = [_hoisted_2$5a, _hoisted_3$4t];
    vue.defineComponent({
      name: 'PricetagsSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5a, _hoisted_4$2U);
      }
    });

    const _hoisted_1$59 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$59 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M408 112H106a58 58 0 0 0-58 58v158a56 56 0 0 0 56 56h8v39.68A40.32 40.32 0 0 0 152.32 464h207.36A40.32 40.32 0 0 0 400 423.68V384h8a56 56 0 0 0 56-56V168a56 56 0 0 0-56-56zm-40 311.68a8.35 8.35 0 0 1-8.32 8.32H152.32a8.35 8.35 0 0 1-8.32-8.32V264.32a8.35 8.35 0 0 1 8.32-8.32h207.36a8.35 8.35 0 0 1 8.32 8.32zm26-215.76a24 24 0 1 1 22-22a24 24 0 0 1-22 22z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4s = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M344 48H168a56.09 56.09 0 0 0-55.42 48h286.84A56.09 56.09 0 0 0 344 48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2T = [_hoisted_2$59, _hoisted_3$4s];
    vue.defineComponent({
      name: 'Print',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$59, _hoisted_4$2T);
      }
    });

    const _hoisted_1$58 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$58 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 368h24a40.12 40.12 0 0 0 40-40V168a40.12 40.12 0 0 0-40-40H104a40.12 40.12 0 0 0-40 40v160a40.12 40.12 0 0 0 40 40h24',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4r = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '128',
      y: '240',
      width: '256',
      height: '208',
      rx: '24.32',
      ry: '24.32',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2S = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 128v-24a40.12 40.12 0 0 0-40-40H168a40.12 40.12 0 0 0-40 40v24',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1m = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '392',
      cy: '184',
      r: '24',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$L = [_hoisted_2$58, _hoisted_3$4r, _hoisted_4$2S, _hoisted_5$1m];
    vue.defineComponent({
      name: 'PrintOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$58, _hoisted_6$L);
      }
    });

    const _hoisted_1$57 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$57 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400 96V56a8 8 0 0 0-8-8H120a8 8 0 0 0-8 8v40',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4q = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '152',
      y: '264',
      width: '208',
      height: '160',
      rx: '4',
      ry: '4',
      fill: 'none'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2R = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '152',
      y: '264',
      width: '208',
      height: '160',
      rx: '4',
      ry: '4',
      fill: 'none'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1l = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M408 112H104a56 56 0 0 0-56 56v208a8 8 0 0 0 8 8h56v72a8 8 0 0 0 8 8h272a8 8 0 0 0 8-8v-72h56a8 8 0 0 0 8-8V168a56 56 0 0 0-56-56zm-48 308a4 4 0 0 1-4 4H156a4 4 0 0 1-4-4V268a4 4 0 0 1 4-4h200a4 4 0 0 1 4 4zm34-212.08a24 24 0 1 1 22-22a24 24 0 0 1-22 22z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$K = [_hoisted_2$57, _hoisted_3$4q, _hoisted_4$2R, _hoisted_5$1l];
    vue.defineComponent({
      name: 'PrintSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$57, _hoisted_6$K);
      }
    });

    const _hoisted_1$56 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$56 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M487.83 319.44L295.63 36.88a48 48 0 0 0-79.26 0L24.17 319.44a47.1 47.1 0 0 0 16.93 68.13l192.2 102.75a48.05 48.05 0 0 0 45.4 0l192.2-102.75a47.1 47.1 0 0 0 16.93-68.13zm-431.26 41a16.12 16.12 0 0 1-8-10.38a16.8 16.8 0 0 1 2.37-13.62L232.66 69.26c2.18-3.21 7.34-1.72 7.34 2.13v374c0 5.9-6.54 9.63-11.87 6.78z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4p = [_hoisted_2$56];
    vue.defineComponent({
      name: 'Prism',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$56, _hoisted_3$4p);
      }
    });

    const _hoisted_1$55 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$55 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M229.73 45.88L37.53 327.79a31.79 31.79 0 0 0 11.31 46L241 476.26a31.77 31.77 0 0 0 29.92 0l192.2-102.51a31.79 31.79 0 0 0 11.31-46L282.27 45.88a31.8 31.8 0 0 0-52.54 0z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4o = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 32v448'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2Q = [_hoisted_2$55, _hoisted_3$4o];
    vue.defineComponent({
      name: 'PrismOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$55, _hoisted_4$2Q);
      }
    });

    const _hoisted_1$54 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$54 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 16L16 352l240 144l240-144zm-20 96.82v324.53L73.73 340z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4n = [_hoisted_2$54];
    vue.defineComponent({
      name: 'PrismSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$54, _hoisted_3$4n);
      }
    });

    const _hoisted_1$53 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$53 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M432 272a48.09 48.09 0 0 0-45.25 32h-39.22l-28.35-85.06a16 16 0 0 0-30.56.66l-44.51 155.76l-52.33-314a16 16 0 0 0-31.3-1.25L99.51 304H48a16 16 0 0 0 0 32h64a16 16 0 0 0 15.52-12.12l45.34-181.37l51.36 308.12A16 16 0 0 0 239.1 464h.91a16 16 0 0 0 15.37-11.6l49.8-174.28l15.64 46.94A16 16 0 0 0 336 336h50.75A48 48 0 1 0 432 272z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4m = [_hoisted_2$53];
    vue.defineComponent({
      name: 'Pulse',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$53, _hoisted_3$4m);
      }
    });

    const _hoisted_1$52 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$52 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M48 320h64l64-256l64 384l64-224l32 96h64'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4l = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '432',
      cy: '320',
      r: '32',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2P = [_hoisted_2$52, _hoisted_3$4l];
    vue.defineComponent({
      name: 'PulseOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$52, _hoisted_4$2P);
      }
    });

    const _hoisted_1$51 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$51 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M426 266a54.07 54.07 0 0 0-49.3 32h-24.84l-27-81a22 22 0 0 0-42 .92l-37.2 130.2l-48-281.74a22 22 0 0 0-43-1.72L94.82 298H32v44h80a22 22 0 0 0 21.34-16.66L171.69 172l46.61 273.62A22 22 0 0 0 238.76 464H240a22 22 0 0 0 21.15-16l44.47-149.62l9.51 28.62A22 22 0 0 0 336 342h40.7a54 54 0 1 0 49.3-76z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4k = [_hoisted_2$51];
    vue.defineComponent({
      name: 'PulseSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$51, _hoisted_3$4k);
      }
    });

    const _hoisted_1$50 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$50 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M376 352H272V198.63l52.69 52.68a16 16 0 0 0 22.62-22.62l-80-80a16 16 0 0 0-22.62 0l-80 80a16 16 0 0 0 22.62 22.62L240 198.63V352H136a56.06 56.06 0 0 1-56-56V88a56.06 56.06 0 0 1 56-56h240a56.06 56.06 0 0 1 56 56v208a56.06 56.06 0 0 1-56 56z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4j = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M272 464a16 16 0 0 1-32 0V352h32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2O = [_hoisted_2$50, _hoisted_3$4j];
    vue.defineComponent({
      name: 'Push',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$50, _hoisted_4$2O);
      }
    });

    const _hoisted_1$4$ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4$ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 336h40a40 40 0 0 0 40-40V88a40 40 0 0 0-40-40H136a40 40 0 0 0-40 40v208a40 40 0 0 0 40 40h40',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4i = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M176 240l80-80l80 80'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2N = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 464V176'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1k = [_hoisted_2$4$, _hoisted_3$4i, _hoisted_4$2N];
    vue.defineComponent({
      name: 'PushOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4$, _hoisted_5$1k);
      }
    });

    const _hoisted_1$4_ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4_ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M272 352V204.63l64 64L358.63 246L256 143.37L153.37 246L176 268.63l64-64V352H92a12 12 0 0 1-12-12V44a12 12 0 0 1 12-12h328a12 12 0 0 1 12 12v296a12 12 0 0 1-12 12z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4h = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M240 352h32v128h-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2M = [_hoisted_2$4_, _hoisted_3$4h];
    vue.defineComponent({
      name: 'PushSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4_, _hoisted_4$2M);
      }
    });

    const _hoisted_1$4Z = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4Z = /*#__PURE__*/vue.createStaticVNode('<rect x="336" y="336" width="80" height="80" rx="8" ry="8" fill="currentColor"></rect><rect x="272" y="272" width="64" height="64" rx="8" ry="8" fill="currentColor"></rect><rect x="416" y="416" width="64" height="64" rx="8" ry="8" fill="currentColor"></rect><rect x="432" y="272" width="48" height="48" rx="8" ry="8" fill="currentColor"></rect><rect x="272" y="432" width="48" height="48" rx="8" ry="8" fill="currentColor"></rect><path d="M448 32H304a32 32 0 0 0-32 32v144a32 32 0 0 0 32 32h144a32 32 0 0 0 32-32V64a32 32 0 0 0-32-32zm-32 136a8 8 0 0 1-8 8h-64a8 8 0 0 1-8-8v-64a8 8 0 0 1 8-8h64a8 8 0 0 1 8 8z" fill="currentColor"></path><path d="M208 32H64a32 32 0 0 0-32 32v144a32 32 0 0 0 32 32h144a32 32 0 0 0 32-32V64a32 32 0 0 0-32-32zm-32 136a8 8 0 0 1-8 8h-64a8 8 0 0 1-8-8v-64a8 8 0 0 1 8-8h64a8 8 0 0 1 8 8z" fill="currentColor"></path><path d="M208 272H64a32 32 0 0 0-32 32v144a32 32 0 0 0 32 32h144a32 32 0 0 0 32-32V304a32 32 0 0 0-32-32zm-32 136a8 8 0 0 1-8 8h-64a8 8 0 0 1-8-8v-64a8 8 0 0 1 8-8h64a8 8 0 0 1 8 8z" fill="currentColor"></path>', 8);

    const _hoisted_10$2 = [_hoisted_2$4Z];
    vue.defineComponent({
      name: 'QrCode',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4Z, _hoisted_10$2);
      }
    });

    const _hoisted_1$4Y = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4Y = /*#__PURE__*/vue.createStaticVNode('<rect x="336" y="336" width="80" height="80" rx="8" ry="8" fill="currentColor"></rect><rect x="272" y="272" width="64" height="64" rx="8" ry="8" fill="currentColor"></rect><rect x="416" y="416" width="64" height="64" rx="8" ry="8" fill="currentColor"></rect><rect x="432" y="272" width="48" height="48" rx="8" ry="8" fill="currentColor"></rect><rect x="272" y="432" width="48" height="48" rx="8" ry="8" fill="currentColor"></rect><rect x="336" y="96" width="80" height="80" rx="8" ry="8" fill="currentColor"></rect><rect x="288" y="48" width="176" height="176" rx="16" ry="16" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></rect><rect x="96" y="96" width="80" height="80" rx="8" ry="8" fill="currentColor"></rect><rect x="48" y="48" width="176" height="176" rx="16" ry="16" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></rect><rect x="96" y="336" width="80" height="80" rx="8" ry="8" fill="currentColor"></rect><rect x="48" y="288" width="176" height="176" rx="16" ry="16" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></rect>', 11);

    const _hoisted_13$1 = [_hoisted_2$4Y];
    vue.defineComponent({
      name: 'QrCodeOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4Y, _hoisted_13$1);
      }
    });

    const _hoisted_1$4X = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4X = /*#__PURE__*/vue.createStaticVNode('<path d="M336 336h80v80h-80z" fill="currentColor"></path><path d="M272 272h64v64h-64z" fill="currentColor"></path><path d="M416 416h64v64h-64z" fill="currentColor"></path><path d="M432 272h48v48h-48z" fill="currentColor"></path><path d="M272 432h48v48h-48z" fill="currentColor"></path><path d="M336 96h80v80h-80z" fill="currentColor"></path><path d="M480 240H272V32h208zm-164-44h120V76H316z" fill="currentColor"></path><path d="M96 96h80v80H96z" fill="currentColor"></path><path d="M240 240H32V32h208zM76 196h120V76H76z" fill="currentColor"></path><path d="M96 336h80v80H96z" fill="currentColor"></path><path d="M240 480H32V272h208zM76 436h120V316H76z" fill="currentColor"></path>', 11);

    const _hoisted_13 = [_hoisted_2$4X];
    vue.defineComponent({
      name: 'QrCodeSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4X, _hoisted_13);
      }
    });

    const _hoisted_1$4W = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4W = /*#__PURE__*/vue.createStaticVNode('<circle cx="256" cy="256" r="36" fill="currentColor"></circle><path d="M190.24 341.77a22 22 0 0 1-16.46-7.38a118 118 0 0 1 0-156.76a22 22 0 1 1 32.87 29.24a74 74 0 0 0 0 98.29a22 22 0 0 1-16.43 36.61z" fill="currentColor"></path><path d="M321.76 341.77a22 22 0 0 1-16.43-36.61a74 74 0 0 0 0-98.29a22 22 0 1 1 32.87-29.24a118 118 0 0 1 0 156.76a22 22 0 0 1-16.44 7.38z" fill="currentColor"></path><path d="M139.29 392.72a21.92 21.92 0 0 1-16.08-7a190 190 0 0 1 0-259.49a22 22 0 1 1 32.13 30.06a146 146 0 0 0 0 199.38a22 22 0 0 1-16.06 37z" fill="currentColor"></path><path d="M372.71 392.72a22 22 0 0 1-16.06-37a146 146 0 0 0 0-199.38a22 22 0 1 1 32.13-30.06a190 190 0 0 1 0 259.49a21.92 21.92 0 0 1-16.07 6.95z" fill="currentColor"></path><path d="M429 438a22 22 0 0 1-16.39-36.67a218.34 218.34 0 0 0 0-290.66a22 22 0 0 1 32.78-29.34a262.34 262.34 0 0 1 0 349.34A22 22 0 0 1 429 438z" fill="currentColor"></path><path d="M83 438a21.94 21.94 0 0 1-16.41-7.33a262.34 262.34 0 0 1 0-349.34a22 22 0 0 1 32.78 29.34a218.34 218.34 0 0 0 0 290.66A22 22 0 0 1 83 438z" fill="currentColor"></path>', 7);

    const _hoisted_9$4 = [_hoisted_2$4W];
    vue.defineComponent({
      name: 'Radio',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4W, _hoisted_9$4);
      }
    });

    const _hoisted_1$4V = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4V = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4g = [_hoisted_2$4V];
    vue.defineComponent({
      name: 'RadioButtonOff',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4V, _hoisted_3$4g);
      }
    });

    const _hoisted_1$4U = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4U = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4f = [_hoisted_2$4U];
    vue.defineComponent({
      name: 'RadioButtonOffOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4U, _hoisted_3$4f);
      }
    });

    const _hoisted_1$4T = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4T = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4e = [_hoisted_2$4T];
    vue.defineComponent({
      name: 'RadioButtonOffSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4T, _hoisted_3$4e);
      }
    });

    const _hoisted_1$4S = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4S = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4d = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '144',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2L = [_hoisted_2$4S, _hoisted_3$4d];
    vue.defineComponent({
      name: 'RadioButtonOn',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4S, _hoisted_4$2L);
      }
    });

    const _hoisted_1$4R = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4R = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4c = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '144',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2K = [_hoisted_2$4R, _hoisted_3$4c];
    vue.defineComponent({
      name: 'RadioButtonOnOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4R, _hoisted_4$2K);
      }
    });

    const _hoisted_1$4Q = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4Q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4b = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '144',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2J = [_hoisted_2$4Q, _hoisted_3$4b];
    vue.defineComponent({
      name: 'RadioButtonOnSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4Q, _hoisted_4$2J);
      }
    });

    const _hoisted_1$4P = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4P = /*#__PURE__*/vue.createStaticVNode('<circle cx="256" cy="256.02" r="32" fill="currentColor"></circle><path d="M184.25 192.25a96 96 0 0 0 0 127.52" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M327.77 319.77a96 96 0 0 0 0-127.52" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M133.28 141.28a168 168 0 0 0 0 229.44" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M378.72 370.72a168 168 0 0 0 0-229.44" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M435 416a240.34 240.34 0 0 0 0-320" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M77 96a240.34 240.34 0 0 0 0 320" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 7);

    const _hoisted_9$3 = [_hoisted_2$4P];
    vue.defineComponent({
      name: 'RadioOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4P, _hoisted_9$3);
      }
    });

    const _hoisted_1$4O = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4O = /*#__PURE__*/vue.createStaticVNode('<ellipse cx="256" cy="256" rx="36" ry="35.99" fill="currentColor"></ellipse><path d="M188.4 350.8l-14.62-16.44a117.91 117.91 0 0 1 0-156.71l14.62-16.43l32.87 29.24l-14.62 16.43a73.93 73.93 0 0 0 0 98.25l14.62 16.44z" fill="currentColor"></path><path d="M323.6 350.8l-32.89-29.22l14.62-16.44a73.93 73.93 0 0 0 0-98.25l-14.62-16.43l32.87-29.24l14.62 16.43a117.91 117.91 0 0 1 0 156.71z" fill="currentColor"></path><path d="M138.24 401.76l-15-16.06a189.85 189.85 0 0 1 0-259.4l15-16.07l32.14 30.05l-15 16.06a145.88 145.88 0 0 0 0 199.32l15 16.06z" fill="currentColor"></path><path d="M373.76 401.76l-32.14-30l15-16.06a145.88 145.88 0 0 0 0-199.32l-15-16.06l32.14-30l15 16.07a189.85 189.85 0 0 1 0 259.4z" fill="currentColor"></path><path d="M430.73 447l-32.79-29.33l14.66-16.39a218.2 218.2 0 0 0 0-290.56l-14.67-16.38L430.72 65l14.67 16.39a262.18 262.18 0 0 1 0 349.22z" fill="currentColor"></path><path d="M81.27 447L66.6 430.61a262.18 262.18 0 0 1 0-349.22L81.28 65l32.79 29.34l-14.68 16.38a218.2 218.2 0 0 0 0 290.56l14.66 16.39z" fill="currentColor"></path>', 7);

    const _hoisted_9$2 = [_hoisted_2$4O];
    vue.defineComponent({
      name: 'RadioSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4O, _hoisted_9$2);
      }
    });

    const _hoisted_1$4N = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4N = /*#__PURE__*/vue.createStaticVNode('<path d="M456.26 139.37c-16.77-16.73-39.17-28.41-65.17-34a16 16 0 0 1-11.19-9a142.24 142.24 0 0 0-42.19-53.21C314.48 25.39 286.23 16 256 16a140.24 140.24 0 0 0-93.5 35.32c-24.2 21.56-40.91 51.34-48.43 85.83a16.05 16.05 0 0 1-11.72 12.18c-25 6.3-35.71 12.54-49.21 24.56C34 190.93 24 214.14 24 240.8c0 30.55 11.23 55.64 32.47 72.56C75.08 328.17 100.5 336 130 336h234c33.2 0 64.11-11.46 87-32.28c23.84-21.65 37-51.67 37-84.52c0-31.49-11-59.09-31.74-79.83z" fill="currentColor"></path><path d="M112 448a16 16 0 0 1-13.3-24.88l32-48a16 16 0 0 1 26.62 17.76l-32 48A16 16 0 0 1 112 448z" fill="currentColor"></path><path d="M160 496a16 16 0 0 1-13.29-24.88l64-96a16 16 0 0 1 26.62 17.76l-64 96A16 16 0 0 1 160 496z" fill="currentColor"></path><path d="M272 448a16 16 0 0 1-13.3-24.88l32-48a16 16 0 0 1 26.62 17.76l-32 48A16 16 0 0 1 272 448z" fill="currentColor"></path><path d="M320 496a16 16 0 0 1-13.3-24.88l64-96a16 16 0 0 1 26.62 17.76l-64 96A16 16 0 0 1 320 496z" fill="currentColor"></path>', 5);

    const _hoisted_7$o = [_hoisted_2$4N];
    vue.defineComponent({
      name: 'Rainy',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4N, _hoisted_7$o);
      }
    });

    const _hoisted_1$4M = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4M = /*#__PURE__*/vue.createStaticVNode('<path d="M114.61 162.85A16.07 16.07 0 0 0 128 149.6C140.09 76.17 193.63 32 256 32c57.93 0 96.62 37.75 112.2 77.74a15.84 15.84 0 0 0 12.2 9.87c50 8.15 91.6 41.54 91.6 99.59c0 59.4-48.6 100.8-108 100.8H130c-49.5 0-90-24.7-90-79.2c0-48.47 38.67-72.22 74.61-77.95z" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M144 384l-32 48"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M224 384l-64 96"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M304 384l-32 48"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M384 384l-64 96"></path>', 5);

    const _hoisted_7$n = [_hoisted_2$4M];
    vue.defineComponent({
      name: 'RainyOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4M, _hoisted_7$n);
      }
    });

    const _hoisted_1$4L = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4L = /*#__PURE__*/vue.createStaticVNode('<path d="M364 336H130c-29.5 0-54.92-7.83-73.53-22.64C35.23 296.44 24 271.35 24 240.8c0-26.66 10.08-49.8 29.14-66.91c15.24-13.68 36.17-23.21 59-26.84c.06 0 .08 0 .09-.05c6.44-39 23.83-72.09 50.31-95.68A140.24 140.24 0 0 1 256 16c30.23 0 58.48 9.39 81.71 27.17a142.69 142.69 0 0 1 45.36 60.66c29.41 4.82 54.72 17.11 73.19 35.54C477 160.11 488 187.71 488 219.2c0 32.85-13.13 62.87-37 84.52c-22.89 20.82-53.8 32.28-87 32.28zm19-232.18z" fill="currentColor"></path><path d="M93.82 430.422l49.75-74.626l26.626 17.75l-49.751 74.627z" fill="currentColor"></path><path d="M141.816 478.429L223.568 355.8l26.625 17.75l-81.751 122.628z" fill="currentColor"></path><path d="M253.811 430.424l49.751-74.626l26.626 17.75l-49.751 74.627z" fill="currentColor"></path><path d="M301.808 478.43l81.752-122.627l26.625 17.75l-81.751 122.628z" fill="currentColor"></path>', 5);

    const _hoisted_7$m = [_hoisted_2$4L];
    vue.defineComponent({
      name: 'RainySharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4L, _hoisted_7$m);
      }
    });

    const _hoisted_1$4K = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4K = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M368 32H144a64.07 64.07 0 0 0-64 64v320a64.07 64.07 0 0 0 64 64h224a64.07 64.07 0 0 0 64-64V96a64.07 64.07 0 0 0-64-64zM256 304h-80a16 16 0 0 1 0-32h80a16 16 0 0 1 0 32zm80-80H176a16 16 0 0 1 0-32h160a16 16 0 0 1 0 32zm0-80H176a16 16 0 0 1 0-32h160a16 16 0 0 1 0 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4a = [_hoisted_2$4K];
    vue.defineComponent({
      name: 'Reader',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4K, _hoisted_3$4a);
      }
    });

    const _hoisted_1$4J = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4J = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '96',
      y: '48',
      width: '320',
      height: '416',
      rx: '48',
      ry: '48',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$49 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M176 128h160'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2I = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M176 208h160'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1j = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M176 288h80'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$J = [_hoisted_2$4J, _hoisted_3$49, _hoisted_4$2I, _hoisted_5$1j];
    vue.defineComponent({
      name: 'ReaderOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4J, _hoisted_6$J);
      }
    });

    const _hoisted_1$4I = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4I = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M80 44v424a12 12 0 0 0 12 12h328a12 12 0 0 0 12-12V44a12 12 0 0 0-12-12H92a12 12 0 0 0-12 12zm192 260H160v-32h112zm80-80H160v-32h192zm0-80H160v-32h192z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$48 = [_hoisted_2$4I];
    vue.defineComponent({
      name: 'ReaderSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4I, _hoisted_3$48);
      }
    });

    const _hoisted_1$4H = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4H = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M483.82 32.45a16.28 16.28 0 0 0-11.23 1.37L448 46.1l-24.8-12.4a16 16 0 0 0-14.31 0l-25.11 12.41L359 33.7a16 16 0 0 0-14.36 0L320 46.07l-24.45-12.34a16 16 0 0 0-14.35-.06L256 46.12l-24.8-12.43a16.05 16.05 0 0 0-14.33 0L192 46.1l-24.84-12.41a16 16 0 0 0-19.36 3.94a16.25 16.25 0 0 0-3.8 10.65V288l.05.05H336a32 32 0 0 1 32 32V424c0 30.93 33.07 56 64 56h12a52 52 0 0 0 52-52V48a16 16 0 0 0-12.18-15.55zM416 240H288.5c-8.64 0-16.1-6.64-16.48-15.28A16 16 0 0 1 288 208h127.5c8.64 0 16.1 6.64 16.48 15.28A16 16 0 0 1 416 240zm0-80H224.5c-8.64 0-16.1-6.64-16.48-15.28A16 16 0 0 1 224 128h191.5c8.64 0 16.1 6.64 16.48 15.28A16 16 0 0 1 416 160z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$47 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 424v-88a16 16 0 0 0-16-16H48a32.1 32.1 0 0 0-32 32.05c0 50.55 5.78 71.57 14.46 87.57C45.19 466.79 71.86 480 112 480h245.68a4 4 0 0 0 2.85-6.81C351.07 463.7 336 451 336 424z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2H = [_hoisted_2$4H, _hoisted_3$47];
    vue.defineComponent({
      name: 'Receipt',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4H, _hoisted_4$2H);
      }
    });

    const _hoisted_1$4G = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4G = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M160 336V48l32 16l32-16l31.94 16l32.37-16L320 64l31.79-16l31.93 16L416 48l32.01 16L480 48v224'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$46 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 272v112a80 80 0 0 1-80 80h0a80 80 0 0 1-80-80v-48H48a15.86 15.86 0 0 0-16 16c0 64 6.74 112 80 112h288',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2G = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M224 144h192'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1i = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M288 224h128'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$I = [_hoisted_2$4G, _hoisted_3$46, _hoisted_4$2G, _hoisted_5$1i];
    vue.defineComponent({
      name: 'ReceiptOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4G, _hoisted_6$I);
      }
    });

    const _hoisted_1$4F = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4F = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 48l-32-16l-32 16l-32-16l-32 16l-32-16l-32 16l-32-16l-32 16l-48-16v256.05h224V424c0 30.93 33.07 56 64 56h12c30.93 0 52-25.07 52-56V32zM272.5 240l-.5-32h159.5l.5 32zm-64-80l-.5-32h223.5l.5 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$45 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 424V320H16v32c0 50.55 5.78 71.62 14.46 87.63C45.19 466.8 71.86 480 112 480h256s-32-20-32-56z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2F = [_hoisted_2$4F, _hoisted_3$45];
    vue.defineComponent({
      name: 'ReceiptSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4F, _hoisted_4$2F);
      }
    });

    const _hoisted_1$4E = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4E = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M380.79 144.05c-59.1 1.65-107.12 49.71-108.79 108.81a111.64 111.64 0 0 0 30.36 79.77A2 2 0 0 1 301 336h-90a2 2 0 0 1-1.44-3.37A111.64 111.64 0 0 0 240 252.86c-1.63-59.1-49.65-107.16-108.75-108.81A112.12 112.12 0 0 0 16 255.53C15.75 317.77 67 368 129.24 368h253.52C445 368 496.25 317.77 496 255.53a112.12 112.12 0 0 0-115.21-111.48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$44 = [_hoisted_2$4E];
    vue.defineComponent({
      name: 'Recording',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4E, _hoisted_3$44);
      }
    });

    const _hoisted_1$4D = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4D = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '128',
      cy: '256',
      r: '96',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$43 = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '384',
      cy: '256',
      r: '96',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2E = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M128 352h256'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1h = [_hoisted_2$4D, _hoisted_3$43, _hoisted_4$2E];
    vue.defineComponent({
      name: 'RecordingOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4D, _hoisted_5$1h);
      }
    });

    const _hoisted_1$4C = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4C = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 138a117.93 117.93 0 0 0-91.84 192h-72.32A118 118 0 1 0 128 374h256a118 118 0 0 0 0-236zM54 256a74 74 0 1 1 74 74a74.09 74.09 0 0 1-74-74zm330 74a74 74 0 1 1 74-74a74.09 74.09 0 0 1-74 74z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$42 = [_hoisted_2$4C];
    vue.defineComponent({
      name: 'RecordingSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4C, _hoisted_3$42);
      }
    });

    const _hoisted_1$4B = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4B = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 146s24.36-12-64-12a160 160 0 1 0 160 160',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$41 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 58l80 80l-80 80'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2D = [_hoisted_2$4B, _hoisted_3$41];
    vue.defineComponent({
      name: 'Refresh',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4B, _hoisted_4$2D);
      }
    });

    const _hoisted_1$4A = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4A = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.32 48 256c0 114.86 93.14 208 208 208c114.69 0 208-93.31 208-208c0-114.87-93.13-208-208-208zm0 313a94 94 0 0 1 0-188h4.21l-14.11-14.1a14 14 0 0 1 19.8-19.8l40 40a14 14 0 0 1 0 19.8l-40 40a14 14 0 0 1-19.8-19.8l18-18c-2.38-.1-5.1-.1-8.1-.1a66 66 0 1 0 66 66a14 14 0 0 1 28 0a94.11 94.11 0 0 1-94 94z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$40 = [_hoisted_2$4A];
    vue.defineComponent({
      name: 'RefreshCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4A, _hoisted_3$40);
      }
    });

    const _hoisted_1$4z = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M288 193s12.18-6-32-6a80 80 0 1 0 80 80',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '28'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3$ = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '28',
      d: 'M256 149l40 40l-40 40'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2C = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 64C150 64 64 150 64 256s86 192 192 192s192-86 192-192S362 64 256 64z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1g = [_hoisted_2$4z, _hoisted_3$3$, _hoisted_4$2C];
    vue.defineComponent({
      name: 'RefreshCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4z, _hoisted_5$1g);
      }
    });

    const _hoisted_1$4y = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.32 48 256c0 114.86 93.14 208 208 208c114.69 0 208-93.31 208-208c0-114.87-93.13-208-208-208zm94 219a94 94 0 1 1-94-94h4.21l-24-24L256 129.2l59.8 59.8l-59.8 59.8l-19.8-19.8l27.92-27.92c-2.4-.08-5.12-.08-8.12-.08a66 66 0 1 0 66 66v-14h28z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3_ = [_hoisted_2$4y];
    vue.defineComponent({
      name: 'RefreshCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4y, _hoisted_3$3_);
      }
    });

    const _hoisted_1$4x = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4x = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 146s24.36-12-64-12a160 160 0 1 0 160 160',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3Z = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 58l80 80l-80 80'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2B = [_hoisted_2$4x, _hoisted_3$3Z];
    vue.defineComponent({
      name: 'RefreshOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4x, _hoisted_4$2B);
      }
    });

    const _hoisted_1$4w = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4w = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 146s24.36-12-64-12a160 160 0 1 0 160 160',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3Y = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M256 58l80 80l-80 80'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2A = [_hoisted_2$4w, _hoisted_3$3Y];
    vue.defineComponent({
      name: 'RefreshSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4w, _hoisted_4$2A);
      }
    });

    const _hoisted_1$4v = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4v = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400 148l-21.12-24.57A191.43 191.43 0 0 0 240 64C134 64 48 150 48 256s86 192 192 192a192.09 192.09 0 0 0 181.07-128',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3X = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 97.42V208a16 16 0 0 1-16 16H337.42c-14.26 0-21.4-17.23-11.32-27.31L436.69 86.1C446.77 76 464 83.16 464 97.42z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2z = [_hoisted_2$4v, _hoisted_3$3X];
    vue.defineComponent({
      name: 'Reload',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4v, _hoisted_4$2z);
      }
    });

    const _hoisted_1$4u = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4u = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm120 182.15a8.62 8.62 0 0 1-8.62 8.62h-59.54a8.61 8.61 0 0 1-6.09-14.71l22.17-22.17l-5.6-6.51a87.38 87.38 0 1 0-62.94 148a87.55 87.55 0 0 0 82.42-58.25A16 16 0 1 1 368 295.8a119.4 119.4 0 1 1-112.62-159.18a118.34 118.34 0 0 1 86.36 36.95l.56.62l4.31 5l14.68-14.68a8.44 8.44 0 0 1 6-2.54a8.61 8.61 0 0 1 8.68 8.63z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3W = [_hoisted_2$4u];
    vue.defineComponent({
      name: 'ReloadCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4u, _hoisted_3$3W);
      }
    });

    const _hoisted_1$4t = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4t = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3V = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M341.54 197.85l-11.37-13.23a103.37 103.37 0 1 0 22.71 105.84',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M367.32 162a8.44 8.44 0 0 0-6 2.54l-59.54 59.54a8.61 8.61 0 0 0 6.09 14.71h59.54a8.62 8.62 0 0 0 8.62-8.62v-59.56a8.61 8.61 0 0 0-8.68-8.63z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1f = [_hoisted_2$4t, _hoisted_3$3V, _hoisted_4$2y];
    vue.defineComponent({
      name: 'ReloadCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4t, _hoisted_5$1f);
      }
    });

    const _hoisted_1$4s = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4s = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm120 190.77h-89l36.88-36.88l-5.6-6.51a87.38 87.38 0 1 0-62.94 148a87.55 87.55 0 0 0 82.42-58.25l5.37-15.13l30.17 10.67l-5.3 15.13a119.4 119.4 0 1 1-112.62-159.18a118.34 118.34 0 0 1 86.36 36.95l.56.62l4.31 5L376 149.81z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3U = [_hoisted_2$4s];
    vue.defineComponent({
      name: 'ReloadCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4s, _hoisted_3$3U);
      }
    });

    const _hoisted_1$4r = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4r = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400 148l-21.12-24.57A191.43 191.43 0 0 0 240 64C134 64 48 150 48 256s86 192 192 192a192.09 192.09 0 0 0 181.07-128',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3T = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 97.42V208a16 16 0 0 1-16 16H337.42c-14.26 0-21.4-17.23-11.32-27.31L436.69 86.1C446.77 76 464 83.16 464 97.42z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2x = [_hoisted_2$4r, _hoisted_3$3T];
    vue.defineComponent({
      name: 'ReloadOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4r, _hoisted_4$2x);
      }
    });

    const _hoisted_1$4q = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400 148l-21.12-24.57A191.43 191.43 0 0 0 240 64C134 64 48 150 48 256s86 192 192 192a192.09 192.09 0 0 0 181.07-128',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3S = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 68.45V220a4 4 0 0 1-4 4H308.45a4 4 0 0 1-2.83-6.83L457.17 65.62a4 4 0 0 1 6.83 2.83z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2w = [_hoisted_2$4q, _hoisted_3$3S];
    vue.defineComponent({
      name: 'ReloadSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4q, _hoisted_4$2w);
      }
    });

    const _hoisted_1$4p = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4p = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M400 256H112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3R = [_hoisted_2$4p];
    vue.defineComponent({
      name: 'Remove',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4p, _hoisted_3$3R);
      }
    });

    const _hoisted_1$4o = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4o = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm80 224H176a16 16 0 0 1 0-32h160a16 16 0 0 1 0 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3Q = [_hoisted_2$4o];
    vue.defineComponent({
      name: 'RemoveCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4o, _hoisted_3$3Q);
      }
    });

    const _hoisted_1$4n = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4n = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3P = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M336 256H176'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2v = [_hoisted_2$4n, _hoisted_3$3P];
    vue.defineComponent({
      name: 'RemoveCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4n, _hoisted_4$2v);
      }
    });

    const _hoisted_1$4m = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4m = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm96 224H160v-32h192z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3O = [_hoisted_2$4m];
    vue.defineComponent({
      name: 'RemoveCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4m, _hoisted_3$3O);
      }
    });

    const _hoisted_1$4l = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4l = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M400 256H112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3N = [_hoisted_2$4l];
    vue.defineComponent({
      name: 'RemoveOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4l, _hoisted_3$3N);
      }
    });

    const _hoisted_1$4k = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4k = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M400 256H112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3M = [_hoisted_2$4k];
    vue.defineComponent({
      name: 'RemoveSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4k, _hoisted_3$3M);
      }
    });

    const _hoisted_1$4j = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4j = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '44',
      d: 'M102 304h308'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3L = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '44',
      d: 'M102 208h308'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2u = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '44',
      d: 'M102 112h308'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1e = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '44',
      d: 'M102 400h308'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$H = [_hoisted_2$4j, _hoisted_3$3L, _hoisted_4$2u, _hoisted_5$1e];
    vue.defineComponent({
      name: 'ReorderFour',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4j, _hoisted_6$H);
      }
    });

    const _hoisted_1$4i = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4i = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M96 304h320'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3K = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M96 208h320'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2t = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M96 112h320'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1d = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M96 400h320'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$G = [_hoisted_2$4i, _hoisted_3$3K, _hoisted_4$2t, _hoisted_5$1d];
    vue.defineComponent({
      name: 'ReorderFourOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4i, _hoisted_6$G);
      }
    });

    const _hoisted_1$4h = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4h = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-linejoin': 'round',
      'stroke-width': '44',
      d: 'M102 304h308'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3J = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-linejoin': 'round',
      'stroke-width': '44',
      d: 'M102 208h308'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2s = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-linejoin': 'round',
      'stroke-width': '44',
      d: 'M102 112h308'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1c = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-linejoin': 'round',
      'stroke-width': '44',
      d: 'M102 400h308'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$F = [_hoisted_2$4h, _hoisted_3$3J, _hoisted_4$2s, _hoisted_5$1c];
    vue.defineComponent({
      name: 'ReorderFourSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4h, _hoisted_6$F);
      }
    });

    const _hoisted_1$4g = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4g = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '44',
      d: 'M102 256h308'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3I = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '44',
      d: 'M102 176h308'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2r = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '44',
      d: 'M102 336h308'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1b = [_hoisted_2$4g, _hoisted_3$3I, _hoisted_4$2r];
    vue.defineComponent({
      name: 'ReorderThree',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4g, _hoisted_5$1b);
      }
    });

    const _hoisted_1$4f = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4f = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M96 256h320'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3H = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M96 176h320'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2q = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M96 336h320'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1a = [_hoisted_2$4f, _hoisted_3$3H, _hoisted_4$2q];
    vue.defineComponent({
      name: 'ReorderThreeOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4f, _hoisted_5$1a);
      }
    });

    const _hoisted_1$4e = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4e = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-linejoin': 'round',
      'stroke-width': '44',
      d: 'M102 256h308'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3G = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-linejoin': 'round',
      'stroke-width': '44',
      d: 'M102 176h308'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2p = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-linejoin': 'round',
      'stroke-width': '44',
      d: 'M102 336h308'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$19 = [_hoisted_2$4e, _hoisted_3$3G, _hoisted_4$2p];
    vue.defineComponent({
      name: 'ReorderThreeSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4e, _hoisted_5$19);
      }
    });

    const _hoisted_1$4d = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4d = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '44',
      d: 'M118 304h276'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3F = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '44',
      d: 'M118 208h276'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2o = [_hoisted_2$4d, _hoisted_3$3F];
    vue.defineComponent({
      name: 'ReorderTwo',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4d, _hoisted_4$2o);
      }
    });

    const _hoisted_1$4c = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4c = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M112 304h288'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3E = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M112 208h288'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2n = [_hoisted_2$4c, _hoisted_3$3E];
    vue.defineComponent({
      name: 'ReorderTwoOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4c, _hoisted_4$2n);
      }
    });

    const _hoisted_1$4b = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4b = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-linejoin': 'round',
      'stroke-width': '44',
      d: 'M118 304h276'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3D = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-linejoin': 'round',
      'stroke-width': '44',
      d: 'M118 208h276'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2m = [_hoisted_2$4b, _hoisted_3$3D];
    vue.defineComponent({
      name: 'ReorderTwoSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4b, _hoisted_4$2m);
      }
    });

    const _hoisted_1$4a = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4a = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M320 120l48 48l-48 48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3C = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M352 168H144a80.24 80.24 0 0 0-80 80v16',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2l = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M192 392l-48-48l48-48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$18 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M160 344h208a80.24 80.24 0 0 0 80-80v-16',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$E = [_hoisted_2$4a, _hoisted_3$3C, _hoisted_4$2l, _hoisted_5$18];
    vue.defineComponent({
      name: 'Repeat',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4a, _hoisted_6$E);
      }
    });

    const _hoisted_1$49 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$49 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M320 120l48 48l-48 48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3B = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M352 168H144a80.24 80.24 0 0 0-80 80v16',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2k = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M192 392l-48-48l48-48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$17 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M160 344h208a80.24 80.24 0 0 0 80-80v-16',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$D = [_hoisted_2$49, _hoisted_3$3B, _hoisted_4$2k, _hoisted_5$17];
    vue.defineComponent({
      name: 'RepeatOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$49, _hoisted_6$D);
      }
    });

    const _hoisted_1$48 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$48 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M320 120l48 48l-48 48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3A = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M352 168H64v96'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2j = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M192 392l-48-48l48-48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$16 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M160 344h288v-96'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$C = [_hoisted_2$48, _hoisted_3$3A, _hoisted_4$2j, _hoisted_5$16];
    vue.defineComponent({
      name: 'RepeatSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$48, _hoisted_6$C);
      }
    });

    const _hoisted_1$47 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$47 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M304 96h112v112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3z = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M405.77 106.2L111.98 400.02'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2i = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M208 416H96V304'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$15 = [_hoisted_2$47, _hoisted_3$3z, _hoisted_4$2i];
    vue.defineComponent({
      name: 'Resize',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$47, _hoisted_5$15);
      }
    });

    const _hoisted_1$46 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$46 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M304 96h112v112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3y = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M405.77 106.2L111.98 400.02'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2h = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M208 416H96V304'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$14 = [_hoisted_2$46, _hoisted_3$3y, _hoisted_4$2h];
    vue.defineComponent({
      name: 'ResizeOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$46, _hoisted_5$14);
      }
    });

    const _hoisted_1$45 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$45 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M304 96h112v112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3x = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M405.77 106.2L111.98 400.02'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2g = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M208 416H96V304'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$13 = [_hoisted_2$45, _hoisted_3$3x, _hoisted_4$2g];
    vue.defineComponent({
      name: 'ResizeSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$45, _hoisted_5$13);
      }
    });

    const _hoisted_1$44 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$44 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M357.57 223.94a79.48 79.48 0 0 0 56.58-23.44l77-76.95c6.09-6.09 6.65-16 .85-22.39a16 16 0 0 0-23.17-.56l-68.63 68.58a12.29 12.29 0 0 1-17.37 0c-4.79-4.78-4.53-12.86.25-17.64l68.33-68.33a16 16 0 0 0-.56-23.16A15.62 15.62 0 0 0 440.27 56a16.71 16.71 0 0 0-11.81 4.9l-68.27 68.26a12.29 12.29 0 0 1-17.37 0c-4.78-4.78-4.53-12.86.25-17.64l68.33-68.31a16 16 0 0 0-.56-23.16A15.62 15.62 0 0 0 400.26 16a16.73 16.73 0 0 0-11.81 4.9L311.5 97.85a79.49 79.49 0 0 0-23.44 56.59v8.23a16 16 0 0 1-4.69 11.33l-35.61 35.62a4 4 0 0 1-5.66 0L68.82 36.33a16 16 0 0 0-22.58-.06C31.09 51.28 23 72.47 23 97.54c-.1 41.4 21.66 89 56.79 124.08l85.45 85.45A64.79 64.79 0 0 0 211 326a64 64 0 0 0 16.21-2.08a16.24 16.24 0 0 1 4.07-.53a15.93 15.93 0 0 1 10.83 4.25l11.39 10.52a16.12 16.12 0 0 1 4.6 11.23v5.54a47.73 47.73 0 0 0 13.77 33.65l90.05 91.57l.09.1a53.29 53.29 0 0 0 75.36-75.37L302.39 269.9a4 4 0 0 1 0-5.66L338 228.63a16 16 0 0 1 11.32-4.69z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3w = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M211 358a97.32 97.32 0 0 1-68.36-28.25l-13.86-13.86a8 8 0 0 0-11.3 0l-85 84.56c-15.15 15.15-20.56 37.45-13.06 59.29a30.63 30.63 0 0 0 1.49 3.6C31 484 50.58 496 72 496a55.68 55.68 0 0 0 39.64-16.44L225 365.66a4.69 4.69 0 0 0 1.32-3.72v-.26a4.63 4.63 0 0 0-5.15-4.27A97.09 97.09 0 0 1 211 358z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2f = [_hoisted_2$44, _hoisted_3$3w];
    vue.defineComponent({
      name: 'Restaurant',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$44, _hoisted_4$2f);
      }
    });

    const _hoisted_1$43 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$43 = /*#__PURE__*/vue.createStaticVNode('<path d="M57.49 47.74l368.43 368.43a37.28 37.28 0 0 1 0 52.72h0a37.29 37.29 0 0 1-52.72 0l-90-91.55a32 32 0 0 1-9.2-22.43v-5.53a32 32 0 0 0-9.52-22.78l-11.62-10.73a32 32 0 0 0-29.8-7.44h0a48.53 48.53 0 0 1-46.56-12.63l-85.43-85.44C40.39 159.68 21.74 83.15 57.49 47.74z" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></path><path d="M400 32l-77.25 77.25A64 64 0 0 0 304 154.51v14.86a16 16 0 0 1-4.69 11.32L288 192" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M320 224l11.31-11.31a16 16 0 0 1 11.32-4.69h14.86a64 64 0 0 0 45.26-18.75L480 112" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M440 72l-80 80"></path><path d="M200 368l-99.72 100.28a40 40 0 0 1-56.56 0h0a40 40 0 0 1 0-56.56L128 328" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 5);

    const _hoisted_7$l = [_hoisted_2$43];
    vue.defineComponent({
      name: 'RestaurantOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$43, _hoisted_7$l);
      }
    });

    const _hoisted_1$42 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$42 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M342.7 223.94h14.87a79.48 79.48 0 0 0 56.58-23.44L496 118l-22.22-22.4l-83.58 83.58l-17.37-17.37l83.58-83.59l-23-22.31l-83.27 83.26l-17.32-17.37l83.58-83.59L394 16l-82.5 81.85a79.49 79.49 0 0 0-23.44 56.59v14.86l-43.13 43.13L48 16C3.72 70.87 29.87 171.71 79.72 221.57l85.5 85.5c26.55 26.55 31.82 28.92 61.94 16.8c6.49-2.61 8.85-2.32 14.9 3.72l13 12.13c2.93 3 3 3.88 3 9.62v5.54c0 21.08 13.48 33.2 22.36 42.24L384 496l72-72l-156.43-156.93z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3v = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M227.37 354.59c-29.82 6.11-48.11 11.74-83.08-23.23c-.56-.56-1.14-1.1-1.7-1.66l-19.5-19.5L16 416l80 80l144-144z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2e = [_hoisted_2$42, _hoisted_3$3v];
    vue.defineComponent({
      name: 'RestaurantSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$42, _hoisted_4$2e);
      }
    });

    const _hoisted_1$41 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$41 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M112 352l-64-64l64-64'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3u = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M64 288h294c58.76 0 106-49.33 106-108v-20',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2d = [_hoisted_2$41, _hoisted_3$3u];
    vue.defineComponent({
      name: 'ReturnDownBack',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$41, _hoisted_4$2d);
      }
    });

    const _hoisted_1$40 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$40 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M112 352l-64-64l64-64'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3t = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M64 288h294c58.76 0 106-49.33 106-108v-20',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2c = [_hoisted_2$40, _hoisted_3$3t];
    vue.defineComponent({
      name: 'ReturnDownBackOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$40, _hoisted_4$2c);
      }
    });

    const _hoisted_1$3$ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3$ = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M112 352l-64-64l64-64'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3s = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M64 288h400V160'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2b = [_hoisted_2$3$, _hoisted_3$3s];
    vue.defineComponent({
      name: 'ReturnDownBackSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3$, _hoisted_4$2b);
      }
    });

    const _hoisted_1$3_ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3_ = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M400 352l64-64l-64-64'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3r = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 288H154c-58.76 0-106-49.33-106-108v-20',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2a = [_hoisted_2$3_, _hoisted_3$3r];
    vue.defineComponent({
      name: 'ReturnDownForward',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3_, _hoisted_4$2a);
      }
    });

    const _hoisted_1$3Z = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3Z = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M400 352l64-64l-64-64'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 288H154c-58.76 0-106-49.33-106-108v-20',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$29 = [_hoisted_2$3Z, _hoisted_3$3q];
    vue.defineComponent({
      name: 'ReturnDownForwardOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3Z, _hoisted_4$29);
      }
    });

    const _hoisted_1$3Y = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3Y = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M400 352l64-64l-64-64'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3p = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M448 288H48V160'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$28 = [_hoisted_2$3Y, _hoisted_3$3p];
    vue.defineComponent({
      name: 'ReturnDownForwardSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3Y, _hoisted_4$28);
      }
    });

    const _hoisted_1$3X = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3X = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M112 160l-64 64l64 64'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3o = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M64 224h294c58.76 0 106 49.33 106 108v20',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$27 = [_hoisted_2$3X, _hoisted_3$3o];
    vue.defineComponent({
      name: 'ReturnUpBack',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3X, _hoisted_4$27);
      }
    });

    const _hoisted_1$3W = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3W = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M112 160l-64 64l64 64'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3n = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M64 224h294c58.76 0 106 49.33 106 108v20',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$26 = [_hoisted_2$3W, _hoisted_3$3n];
    vue.defineComponent({
      name: 'ReturnUpBackOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3W, _hoisted_4$26);
      }
    });

    const _hoisted_1$3V = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3V = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M112 160l-64 64l64 64'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3m = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M64 224h400v128'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$25 = [_hoisted_2$3V, _hoisted_3$3m];
    vue.defineComponent({
      name: 'ReturnUpBackSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3V, _hoisted_4$25);
      }
    });

    const _hoisted_1$3U = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3U = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M400 160l64 64l-64 64'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3l = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 224H154c-58.76 0-106 49.33-106 108v20',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$24 = [_hoisted_2$3U, _hoisted_3$3l];
    vue.defineComponent({
      name: 'ReturnUpForward',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3U, _hoisted_4$24);
      }
    });

    const _hoisted_1$3T = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3T = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M400 160l64 64l-64 64'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3k = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 224H154c-58.76 0-106 49.33-106 108v20',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$23 = [_hoisted_2$3T, _hoisted_3$3k];
    vue.defineComponent({
      name: 'ReturnUpForwardOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3T, _hoisted_4$23);
      }
    });

    const _hoisted_1$3S = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3S = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M400 160l64 64l-64 64'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3j = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M448 224H48v128'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$22 = [_hoisted_2$3S, _hoisted_3$3j];
    vue.defineComponent({
      name: 'ReturnUpForwardSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3S, _hoisted_4$22);
      }
    });

    const _hoisted_1$3R = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3R = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M269 335.61q-6.33.47-12.78.47c-5.23 0-10.4-.24-15.51-.69a176.11 176.11 0 0 1-127.67-72.94a4 4 0 0 0-6.77.35l-72 129.4c-2.74 5-3.17 11-.28 15.88A16.78 16.78 0 0 0 48.22 416h78a15.28 15.28 0 0 1 13.62 7.33L178.5 488a16.26 16.26 0 0 0 13.75 8c5.94-.33 12.09-4.19 14.56-9.6l66.11-145.15a4 4 0 0 0-3.92-5.64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3i = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M477.64 391.88l-71.53-129.17a4 4 0 0 0-6.74-.36a176.5 176.5 0 0 1-78.31 61.42a16.09 16.09 0 0 0-8.72 8.25l-36.86 81.1a7.92 7.92 0 0 0 0 6.6l30.27 66.59c2.45 5.41 8.59 9.36 14.52 9.69a16.3 16.3 0 0 0 13.7-8.12l38.53-64.58c2.89-4.85 8.13-7.33 13.78-7.3h78.77c6.67 0 11.72-3.48 14-10a16.92 16.92 0 0 0-1.41-14.12z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$21 = /*#__PURE__*/vue.createElementVNode('ellipse', {
      cx: '256.26',
      cy: '160',
      rx: '48.01',
      ry: '48',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$12 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256.26 16c-79.42 0-144 64.59-144 144s64.61 144 144 144s144-64.6 144-144s-64.59-144-144-144zm0 224a80 80 0 1 1 80-80a80.1 80.1 0 0 1-80 80z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$B = [_hoisted_2$3R, _hoisted_3$3i, _hoisted_4$21, _hoisted_5$12];
    vue.defineComponent({
      name: 'Ribbon',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3R, _hoisted_6$B);
      }
    });

    const _hoisted_1$3Q = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3Q = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '160',
      r: '128',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3h = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M143.65 227.82L48 400l86.86-.42a16 16 0 0 1 13.82 7.8L192 480l88.33-194.32',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$20 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M366.54 224L464 400l-86.86-.42a16 16 0 0 0-13.82 7.8L320 480l-64-140.8',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$11 = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '160',
      r: '64',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$A = [_hoisted_2$3Q, _hoisted_3$3h, _hoisted_4$20, _hoisted_5$11];
    vue.defineComponent({
      name: 'RibbonOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3Q, _hoisted_6$A);
      }
    });

    const _hoisted_1$3P = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3P = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 336c-5.22 0-10.4-.24-15.51-.69a176.12 176.12 0 0 1-131.29-78.37L20 416h115l58 96l82.53-177.09A177.53 177.53 0 0 1 256 336z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3g = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M403 256.74a176.9 176.9 0 0 1-88.18 69.14L273.7 415.5L319 512l58-96h115z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1$ = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256.02',
      cy: '160',
      r: '48',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$10 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 16c-79.4 0-144 64.6-144 144s64.6 144 144 144s144-64.6 144-144S335.4 16 256 16zm0 224a80 80 0 1 1 80-80a80.09 80.09 0 0 1-80 80z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$z = [_hoisted_2$3P, _hoisted_3$3g, _hoisted_4$1$, _hoisted_5$10];
    vue.defineComponent({
      name: 'RibbonSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3P, _hoisted_6$z);
      }
    });

    const _hoisted_1$3O = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3O = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M328.85 156.79a26.69 26.69 0 1 0 18.88 7.81a26.6 26.6 0 0 0-18.88-7.81z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3f = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M477.44 50.06a.29.29 0 0 1 0-.09a20.4 20.4 0 0 0-15.13-15.3c-29.8-7.27-76.68.48-128.63 21.28c-52.36 21-101.42 52-134.58 85.22A320.7 320.7 0 0 0 169.55 175c-22.33-1-42 2.18-58.57 9.41c-57.74 25.41-74.23 90.44-78.62 117.14a25 25 0 0 0 27.19 29h.13l64.32-7.02c.08.82.17 1.57.24 2.26a34.36 34.36 0 0 0 9.9 20.72l31.39 31.41a34.27 34.27 0 0 0 20.71 9.91l2.15.23l-7 64.24v.13A25 25 0 0 0 206 480a25.25 25.25 0 0 0 4.15-.34C237 475.34 302 459.05 327.34 401c7.17-16.46 10.34-36.05 9.45-58.34a314.78 314.78 0 0 0 33.95-29.55c33.43-33.26 64.53-81.92 85.31-133.52c20.69-51.36 28.48-98.59 21.39-129.53zM370.38 224.94a58.77 58.77 0 1 1 0-83.07a58.3 58.3 0 0 1 0 83.07z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1_ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M161.93 386.44a16 16 0 0 0-11 2.67c-6.39 4.37-12.81 8.69-19.29 12.9c-13.11 8.52-28.79-6.44-21-20l12.15-21a16 16 0 0 0-15.16-24.91A61.25 61.25 0 0 0 72 353.56c-3.66 3.67-14.79 14.81-20.78 57.26A357.94 357.94 0 0 0 48 447.59A16 16 0 0 0 64 464h.4a359.87 359.87 0 0 0 36.8-3.2c42.47-6 53.61-17.14 57.27-20.8a60.49 60.49 0 0 0 17.39-35.74a16 16 0 0 0-13.93-17.82z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$$ = [_hoisted_2$3O, _hoisted_3$3f, _hoisted_4$1_];
    vue.defineComponent({
      name: 'Rocket',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3O, _hoisted_5$$);
      }
    });

    const _hoisted_1$3N = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3N = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M461.81 53.81a4.4 4.4 0 0 0-3.3-3.39c-54.38-13.3-180 34.09-248.13 102.17a294.9 294.9 0 0 0-33.09 39.08c-21-1.9-42-.3-59.88 7.5c-50.49 22.2-65.18 80.18-69.28 105.07a9 9 0 0 0 9.8 10.4l81.07-8.9a180.29 180.29 0 0 0 1.1 18.3a18.15 18.15 0 0 0 5.3 11.09l31.39 31.39a18.15 18.15 0 0 0 11.1 5.3a179.91 179.91 0 0 0 18.19 1.1l-8.89 81a9 9 0 0 0 10.39 9.79c24.9-4 83-18.69 105.07-69.17c7.8-17.9 9.4-38.79 7.6-59.69a293.91 293.91 0 0 0 39.19-33.09c68.38-68 115.47-190.86 102.37-247.95zM298.66 213.67a42.7 42.7 0 1 1 60.38 0a42.65 42.65 0 0 1-60.38 0z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3e = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M109.64 352a45.06 45.06 0 0 0-26.35 12.84C65.67 382.52 64 448 64 448s65.52-1.67 83.15-19.31A44.73 44.73 0 0 0 160 402.32',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1Z = [_hoisted_2$3N, _hoisted_3$3e];
    vue.defineComponent({
      name: 'RocketOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3N, _hoisted_4$1Z);
      }
    });

    const _hoisted_1$3M = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3M = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M477.64 38.26a4.75 4.75 0 0 0-3.55-3.66c-58.57-14.32-193.9 36.71-267.22 110a317 317 0 0 0-35.63 42.1c-22.61-2-45.22-.33-64.49 8.07C52.38 218.7 36.55 281.14 32.14 308a9.64 9.64 0 0 0 10.55 11.2l87.31-9.63a194.1 194.1 0 0 0 1.19 19.7a19.53 19.53 0 0 0 5.7 12L170.7 375a19.59 19.59 0 0 0 12 5.7a193.53 193.53 0 0 0 19.59 1.19l-9.58 87.2a9.65 9.65 0 0 0 11.2 10.55c26.81-4.3 89.36-20.13 113.15-74.5c8.4-19.27 10.12-41.77 8.18-64.27a317.66 317.66 0 0 0 42.21-35.64C441 232.05 491.74 99.74 477.64 38.26zM294.07 217.93a48 48 0 1 1 67.86 0a47.95 47.95 0 0 1-67.86 0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3d = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M168.4 399.43c-5.48 5.49-14.27 7.63-24.85 9.46c-23.77 4.05-44.76-16.49-40.49-40.52c1.63-9.11 6.45-21.88 9.45-24.88a4.37 4.37 0 0 0-3.65-7.45a60 60 0 0 0-35.13 17.12C50.22 376.69 48 464 48 464s87.36-2.22 110.87-25.75A59.69 59.69 0 0 0 176 403.09c.37-4.18-4.72-6.67-7.6-3.66z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1Y = [_hoisted_2$3M, _hoisted_3$3d];
    vue.defineComponent({
      name: 'RocketSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3M, _hoisted_4$1Y);
      }
    });

    const _hoisted_1$3L = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3L = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M429.55 119.49a16 16 0 0 0-17.06-7.1c-18.64 4.19-37.06 9-54.73 14.22c-35.06 10.39-69.33 23.92-107.85 42.59c-18.62 9.05-26 13.35-48 26.13l-4.5 2.67c-32.95 19-57.09 40-73.79 64.29C105.29 288.89 96 320 96 354.64c0 40.74 15.71 77.1 44.24 102.37C169 482.52 209.06 496 256 496c46.76 0 86.89-14.33 116-41.43c28.35-26.35 44-63.39 44-104.29c0-25-6.19-47-12.17-68.22c-12.59-44.69-23.46-83.29 24.71-144.13a16 16 0 0 0 1.01-18.44z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3c = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M219 119.55C168.46 92.08 101.46 80.69 98.63 80.22A16 16 0 0 0 81 90.55a16.47 16.47 0 0 0 3.79 16.84c31.84 33.78 32.86 68.79 28.65 104.63a4.45 4.45 0 0 0 2.5 4.54a4.44 4.44 0 0 0 5.08-.9c16.39-16.51 36.37-31.52 60.4-45.39l4.48-2.6C208 154.8 216.23 150 236 140.41l2.69-1.3a4 4 0 0 0 .64-6.83A178.59 178.59 0 0 0 219 119.55z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1X = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M234.26 91.45c3.44 1.87 7.09 4 10.9 6.29a189.31 189.31 0 0 1 29.57 22.39a4 4 0 0 0 4.28.76a672 672 0 0 1 69.65-25q7-2.07 14.08-4a4 4 0 0 0 2.53-5.62c-8.27-16.83-14.67-28.9-15.15-29.79A16 16 0 0 0 336 48c-1.91 0-33.28.36-76.87 21.3a279 279 0 0 0-26.39 14.51a4 4 0 0 0 .22 6.94z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$_ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M209.33 60.79c7.3-4.77 14.74-9.22 22.25-13.31a2 2 0 0 0 .24-3.36c-26-19.57-49.73-27-51.15-27.42a16 16 0 0 0-17.56 5.82a217.63 217.63 0 0 0-19.28 32.38a2 2 0 0 0 1.29 2.81c13.61 3.57 29.4 8.29 45.61 14.29a2 2 0 0 0 1.79-.2z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$y = [_hoisted_2$3L, _hoisted_3$3c, _hoisted_4$1X, _hoisted_5$_];
    vue.defineComponent({
      name: 'Rose',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3L, _hoisted_6$y);
      }
    });

    const _hoisted_1$3K = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3K = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 128c-18.9 4.25-36.8 8.94-53.7 13.95c-40.5 12-75.5 27.15-105.4 41.65c-19.3 9.37-26.2 13.51-51.5 28.23c-58.4 33.69-93.4 77.4-93.4 142.81C112 428.55 167.6 480 256 480s144-55.81 144-129.72S339 225.24 416 128z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3b = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M264 180.19c-19.69-27-38.2-38.69-52.7-46.59C162.6 107.1 96 96 96 96c41.5 43.7 37.2 90.1 32 128c0 0-3.87 32.88 1.91 58.41',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1W = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M372 139.15C356.55 102.6 336 64 336 64s-63.32 0-135.69 64',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$Z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M253.48 87.57C221.25 45.81 176 32 176 32c-15.3 20.8-28.79 51.58-34.87 74.17',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$x = [_hoisted_2$3K, _hoisted_3$3b, _hoisted_4$1W, _hoisted_5$Z];
    vue.defineComponent({
      name: 'RoseOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3K, _hoisted_6$x);
      }
    });

    const _hoisted_1$3J = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3J = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 112s-17.62 0-30.51 1.39c-19 2-42.06 8-59.73 13.22c-35.06 10.39-69.33 23.92-107.85 42.59c-18.62 9.05-26 13.35-48 26.13l-4.5 2.67c-32.95 19-57.09 40-73.79 64.3C105.29 288.89 96 320 96 354.64c0 40.74 15.71 77.1 44.24 102.37C169 482.52 209.06 496 256 496c46.76 0 86.89-14.32 116-41.43c28.35-26.35 44-63.39 44-104.29c0-25-6.19-47-12.17-68.22c-12.59-44.69-23.46-83.29 24.71-144.13C432.75 132.62 448 112 448 112z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3a = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M219 119.55C168.47 92.08 104.72 80 80 80c0 0 23.23 28.19 29.15 55.4s6.54 48.61 2.91 88.6c17.94-20.48 40.59-37.15 69.32-53.73l4.48-2.6C208 154.8 216.23 150 236 140.41c2.88-1.4 5.74-2.76 8.58-4.11A170.77 170.77 0 0 0 219 119.55z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1V = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M345.25 48s-42.53.36-86.12 21.3a280.36 280.36 0 0 0-32.27 18.27q3.73 1.89 7.4 3.88c3.44 1.87 7.09 4 10.9 6.29a189.7 189.7 0 0 1 31.46 24.16c24.57-10.41 73-26.1 90.77-31.28c-8-19.15-22.14-42.62-22.14-42.62z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$Y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M176 16c-16 10.83-33.24 41.1-33.24 41.1a494.22 494.22 0 0 1 48.92 15.25l17.65-11.56c8.18-5.35 16.55-10.29 25-14.77C234.31 46 202.59 24.17 176 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$w = [_hoisted_2$3J, _hoisted_3$3a, _hoisted_4$1V, _hoisted_5$Y];
    vue.defineComponent({
      name: 'RoseSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3J, _hoisted_6$w);
      }
    });

    const _hoisted_1$3I = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3I = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M414.39 97.61A224 224 0 1 0 97.61 414.39A224 224 0 1 0 414.39 97.61zM184 208a24 24 0 1 1-24 24a23.94 23.94 0 0 1 24-24zm-23.67 149.83c12-40.3 50.2-69.83 95.62-69.83s83.62 29.53 95.71 69.83a8 8 0 0 1-7.82 10.17H168.15a8 8 0 0 1-7.82-10.17zM328 256a24 24 0 1 1 24-24a23.94 23.94 0 0 1-24 24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$39 = [_hoisted_2$3I];
    vue.defineComponent({
      name: 'Sad',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3I, _hoisted_3$39);
      }
    });

    const _hoisted_1$3H = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3H = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '184',
      cy: '232',
      r: '24',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$38 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 288c45.42 0 83.62 29.53 95.71 69.83a8 8 0 0 1-7.87 10.17H168.15a8 8 0 0 1-7.82-10.17C172.32 317.53 210.53 288 256 288z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1U = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '328',
      cy: '232',
      r: '24',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$X = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '208',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$v = [_hoisted_2$3H, _hoisted_3$38, _hoisted_4$1U, _hoisted_5$X];
    vue.defineComponent({
      name: 'SadOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3H, _hoisted_6$v);
      }
    });

    const _hoisted_1$3G = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3G = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M414.39 97.61A224 224 0 1 0 97.61 414.39A224 224 0 1 0 414.39 97.61zM328 208a24 24 0 1 1-24 24a23.94 23.94 0 0 1 24-24zm-144 0a24 24 0 1 1-24 24a23.94 23.94 0 0 1 24-24zm72 80c45.42 0 83.75 29.49 95.72 69.83c1 3.52 2.33 10.17 2.33 10.17H158s1.31-6.69 2.33-10.17C172.11 317.47 210.53 288 256 288z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$37 = [_hoisted_2$3G];
    vue.defineComponent({
      name: 'SadSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3G, _hoisted_3$37);
      }
    });

    const _hoisted_1$3F = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3F = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M465.94 119.76l-73.7-73.7A47.68 47.68 0 0 0 358.3 32H96a64 64 0 0 0-64 64v320a64 64 0 0 0 64 64h320a64 64 0 0 0 64-64V153.7a47.68 47.68 0 0 0-14.06-33.94zM120 112h176a8 8 0 0 1 8 8v48a8 8 0 0 1-8 8H120a8 8 0 0 1-8-8v-48a8 8 0 0 1 8-8zm139.75 319.91a80 80 0 1 1 76.16-76.16a80.06 80.06 0 0 1-76.16 76.16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$36 = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '352',
      r: '48',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1T = [_hoisted_2$3F, _hoisted_3$36];
    vue.defineComponent({
      name: 'Save',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3F, _hoisted_4$1T);
      }
    });

    const _hoisted_1$3E = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3E = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M380.93 57.37A32 32 0 0 0 358.3 48H94.22A46.21 46.21 0 0 0 48 94.22v323.56A46.21 46.21 0 0 0 94.22 464h323.56A46.36 46.36 0 0 0 464 417.78V153.7a32 32 0 0 0-9.37-22.63zM256 416a64 64 0 1 1 64-64a63.92 63.92 0 0 1-64 64zm48-224H112a16 16 0 0 1-16-16v-64a16 16 0 0 1 16-16h192a16 16 0 0 1 16 16v64a16 16 0 0 1-16 16z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$35 = [_hoisted_2$3E];
    vue.defineComponent({
      name: 'SaveOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3E, _hoisted_3$35);
      }
    });

    const _hoisted_1$3D = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3D = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M380.44 32H64a32 32 0 0 0-32 32v384a32 32 0 0 0 32 32h384a32.09 32.09 0 0 0 32-32V131.56zM112 176v-64h192v64zm223.91 179.76a80 80 0 1 1-83.66-83.67a80.21 80.21 0 0 1 83.66 83.67z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$34 = [_hoisted_2$3D];
    vue.defineComponent({
      name: 'SaveSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3D, _hoisted_3$34);
      }
    });

    const _hoisted_1$3C = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3C = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M368 32H144A112.12 112.12 0 0 0 32 144v224a112.12 112.12 0 0 0 112 112h224a112.12 112.12 0 0 0 112-112V144A112.12 112.12 0 0 0 368 32zm36.21 178l-33.32 39.21A41.76 41.76 0 0 1 339 264.05a42.32 42.32 0 0 1-22.29-6.38c-14.22-8.78-36.3-19.25-60.69-19.25s-46.47 10.47-60.69 19.25a41.86 41.86 0 0 1-54.2-8.46L107.79 210a50.48 50.48 0 0 1 4.49-70.27c27.84-25.35 75.37-55.57 143.72-55.57s115.88 30.22 143.72 55.57a50.48 50.48 0 0 1 4.49 70.27z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$33 = [_hoisted_2$3C];
    vue.defineComponent({
      name: 'Scale',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3C, _hoisted_3$33);
      }
    });

    const _hoisted_1$3B = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3B = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '48',
      y: '48',
      width: '416',
      height: '416',
      rx: '96',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$32 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M388.94 151.56c-24.46-22.28-68.72-51.4-132.94-51.4s-108.48 29.12-132.94 51.4a34.66 34.66 0 0 0-3.06 48.08l33.32 39.21a26.07 26.07 0 0 0 33.6 5.21c15.92-9.83 40.91-21.64 69.1-21.64s53.18 11.81 69.1 21.64a26.07 26.07 0 0 0 33.6-5.21L392 199.64a34.66 34.66 0 0 0-3.06-48.08z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1S = [_hoisted_2$3B, _hoisted_3$32];
    vue.defineComponent({
      name: 'ScaleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3B, _hoisted_4$1S);
      }
    });

    const _hoisted_1$3A = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3A = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M432 32H80a48.05 48.05 0 0 0-48 48v352a48.05 48.05 0 0 0 48 48h352a48.05 48.05 0 0 0 48-48V80a48.05 48.05 0 0 0-48-48zm-16.71 165l-52.46 61.73a27.83 27.83 0 0 1-37.65 4.62c-13-9.29-39.27-24.89-69.18-24.89s-56.18 15.6-69.18 24.89a27.84 27.84 0 0 1-37.65-4.62L96.71 197a32.12 32.12 0 0 1 .42-42c18.93-21.31 72.3-70.87 158.87-70.87S395.94 133.72 414.87 155a32.12 32.12 0 0 1 .42 42z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$31 = [_hoisted_2$3A];
    vue.defineComponent({
      name: 'ScaleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3A, _hoisted_3$31);
      }
    });

    const _hoisted_1$3z = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M342 444h46a56 56 0 0 0 56-56v-46',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '44'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$30 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M444 170v-46a56 56 0 0 0-56-56h-46',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '44'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1R = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M170 444h-46a56 56 0 0 1-56-56v-46',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '44'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$W = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M68 170v-46a56 56 0 0 1 56-56h46',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '44'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$u = [_hoisted_2$3z, _hoisted_3$30, _hoisted_4$1R, _hoisted_5$W];
    vue.defineComponent({
      name: 'Scan',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3z, _hoisted_6$u);
      }
    });

    const _hoisted_1$3y = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm-40 320h-28a44.05 44.05 0 0 1-44-44v-28a16 16 0 0 1 32 0v28a12 12 0 0 0 12 12h28a16 16 0 0 1 0 32zm0-192h-28a12 12 0 0 0-12 12v28a16 16 0 0 1-32 0v-28a44.05 44.05 0 0 1 44-44h28a16 16 0 0 1 0 32zm152 148a44.05 44.05 0 0 1-44 44h-28a16 16 0 0 1 0-32h28a12 12 0 0 0 12-12v-28a16 16 0 0 1 32 0zm0-108a16 16 0 0 1-32 0v-28a12 12 0 0 0-12-12h-28a16 16 0 0 1 0-32h28a44.05 44.05 0 0 1 44 44z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2$ = [_hoisted_2$3y];
    vue.defineComponent({
      name: 'ScanCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3y, _hoisted_3$2$);
      }
    });

    const _hoisted_1$3x = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3x = /*#__PURE__*/vue.createStaticVNode('<path d="M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path d="M296 352h28a28 28 0 0 0 28-28v-28" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M352 216v-28a28 28 0 0 0-28-28h-28" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M216 352h-28a28 28 0 0 1-28-28v-28" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M160 216v-28a28 28 0 0 1 28-28h28" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 5);

    const _hoisted_7$k = [_hoisted_2$3x];
    vue.defineComponent({
      name: 'ScanCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3x, _hoisted_7$k);
      }
    });

    const _hoisted_1$3w = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3w = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm-24 320h-44a44.05 44.05 0 0 1-44-44v-44h32v44a12 12 0 0 0 12 12h44zm0-192h-44a12 12 0 0 0-12 12v44h-32v-44a44.05 44.05 0 0 1 44-44h44zm136 148a44.05 44.05 0 0 1-44 44h-44v-32h44a12 12 0 0 0 12-12v-44h32zm0-92h-32v-44a12 12 0 0 0-12-12h-44v-32h44a44.05 44.05 0 0 1 44 44z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2_ = [_hoisted_2$3w];
    vue.defineComponent({
      name: 'ScanCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3w, _hoisted_3$2_);
      }
    });

    const _hoisted_1$3v = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3v = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 448h56a56 56 0 0 0 56-56v-56',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2Z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 176v-56a56 56 0 0 0-56-56h-56',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1Q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M176 448h-56a56 56 0 0 1-56-56v-56',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$V = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M64 176v-56a56 56 0 0 1 56-56h56',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$t = [_hoisted_2$3v, _hoisted_3$2Z, _hoisted_4$1Q, _hoisted_5$V];
    vue.defineComponent({
      name: 'ScanOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3v, _hoisted_6$t);
      }
    });

    const _hoisted_1$3u = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3u = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M388 466h-68v-44h68a34 34 0 0 0 34-34v-68h44v68a78.09 78.09 0 0 1-78 78z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2Y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M466 192h-44v-68a34 34 0 0 0-34-34h-68V46h68a78.09 78.09 0 0 1 78 78z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1P = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M192 466h-68a78.09 78.09 0 0 1-78-78v-68h44v68a34 34 0 0 0 34 34h68z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$U = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M90 192H46v-68a78.09 78.09 0 0 1 78-78h68v44h-68a34 34 0 0 0-34 34z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$s = [_hoisted_2$3u, _hoisted_3$2Y, _hoisted_4$1P, _hoisted_5$U];
    vue.defineComponent({
      name: 'ScanSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3u, _hoisted_6$s);
      }
    });

    const _hoisted_1$3t = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3t = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 368a16 16 0 0 1-7.94-2.11L108 285.84a8 8 0 0 0-12 6.94V368a16 16 0 0 0 8.23 14l144 80a16 16 0 0 0 15.54 0l144-80a16 16 0 0 0 8.23-14v-75.22a8 8 0 0 0-12-6.94l-140.06 80.05A16 16 0 0 1 256 368z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2X = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M495.92 190.5v-.11a16 16 0 0 0-8-12.28l-224-128a16 16 0 0 0-15.88 0l-224 128a16 16 0 0 0 0 27.78l224 128a16 16 0 0 0 15.88 0L461 221.28a2 2 0 0 1 3 1.74v144.53c0 8.61 6.62 16 15.23 16.43A16 16 0 0 0 496 368V192a14.76 14.76 0 0 0-.08-1.5z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1O = [_hoisted_2$3t, _hoisted_3$2X];
    vue.defineComponent({
      name: 'School',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3t, _hoisted_4$1O);
      }
    });

    const _hoisted_1$3s = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3s = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M32 192L256 64l224 128l-224 128L32 192z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2W = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M112 240v128l144 80l144-80V240'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1N = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M480 368V192'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$T = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 320v128'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$r = [_hoisted_2$3s, _hoisted_3$2W, _hoisted_4$1N, _hoisted_5$T];
    vue.defineComponent({
      name: 'SchoolOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3s, _hoisted_6$r);
      }
    });

    const _hoisted_1$3r = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3r = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 370.43L96 279v98.42l160 88.88l160-88.88V279l-160 91.43z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2V = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M512.25 192L256 45.57L-.25 192L256 338.43l208-118.86V384h48V192.14l.25-.14z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1M = [_hoisted_2$3r, _hoisted_3$2V];
    vue.defineComponent({
      name: 'SchoolSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3r, _hoisted_4$1M);
      }
    });

    const _hoisted_1$3q = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M456.69 421.39L362.6 327.3a173.81 173.81 0 0 0 34.84-104.58C397.44 126.38 319.06 48 222.72 48S48 126.38 48 222.72s78.38 174.72 174.72 174.72A173.81 173.81 0 0 0 327.3 362.6l94.09 94.09a25 25 0 0 0 35.3-35.3zM97.92 222.72a124.8 124.8 0 1 1 124.8 124.8a124.95 124.95 0 0 1-124.8-124.8z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2U = [_hoisted_2$3q];
    vue.defineComponent({
      name: 'Search',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3q, _hoisted_3$2U);
      }
    });

    const _hoisted_1$3p = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3p = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 64C150.13 64 64 150.13 64 256s86.13 192 192 192s192-86.13 192-192S361.87 64 256 64zm91.31 283.31a16 16 0 0 1-22.62 0l-42.84-42.83a88.08 88.08 0 1 1 22.63-22.63l42.83 42.84a16 16 0 0 1 0 22.62z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2T = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '232',
      cy: '232',
      r: '56',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1L = [_hoisted_2$3p, _hoisted_3$2T];
    vue.defineComponent({
      name: 'SearchCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3p, _hoisted_4$1L);
      }
    });

    const _hoisted_1$3o = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3o = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 80a176 176 0 1 0 176 176A176 176 0 0 0 256 80z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2S = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M232 160a72 72 0 1 0 72 72a72 72 0 0 0-72-72z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1K = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M283.64 283.64L336 336'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$S = [_hoisted_2$3o, _hoisted_3$2S, _hoisted_4$1K];
    vue.defineComponent({
      name: 'SearchCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3o, _hoisted_5$S);
      }
    });

    const _hoisted_1$3n = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3n = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 64C150.13 64 64 150.13 64 256s86.13 192 192 192s192-86.13 192-192S361.87 64 256 64zm80 294.63l-54.15-54.15a88.08 88.08 0 1 1 22.63-22.63L358.63 336z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2R = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '232',
      cy: '232',
      r: '56',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1J = [_hoisted_2$3n, _hoisted_3$2R];
    vue.defineComponent({
      name: 'SearchCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3n, _hoisted_4$1J);
      }
    });

    const _hoisted_1$3m = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3m = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M221.09 64a157.09 157.09 0 1 0 157.09 157.09A157.1 157.1 0 0 0 221.09 64z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2Q = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M338.29 338.29L448 448'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1I = [_hoisted_2$3m, _hoisted_3$2Q];
    vue.defineComponent({
      name: 'SearchOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3m, _hoisted_4$1I);
      }
    });

    const _hoisted_1$3l = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3l = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 428L339.92 303.9a160.48 160.48 0 0 0 30.72-94.58C370.64 120.37 298.27 48 209.32 48S48 120.37 48 209.32s72.37 161.32 161.32 161.32a160.48 160.48 0 0 0 94.58-30.72L428 464zM209.32 319.69a110.38 110.38 0 1 1 110.37-110.37a110.5 110.5 0 0 1-110.37 110.37z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2P = [_hoisted_2$3l];
    vue.defineComponent({
      name: 'SearchSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3l, _hoisted_3$2P);
      }
    });

    const _hoisted_1$3k = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3k = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M476.59 227.05l-.16-.07L49.35 49.84A23.56 23.56 0 0 0 27.14 52A24.65 24.65 0 0 0 16 72.59v113.29a24 24 0 0 0 19.52 23.57l232.93 43.07a4 4 0 0 1 0 7.86L35.53 303.45A24 24 0 0 0 16 327v113.31A23.57 23.57 0 0 0 26.59 460a23.94 23.94 0 0 0 13.22 4a24.55 24.55 0 0 0 9.52-1.93L476.4 285.94l.19-.09a32 32 0 0 0 0-58.8z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2O = [_hoisted_2$3k];
    vue.defineComponent({
      name: 'Send',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3k, _hoisted_3$2O);
      }
    });

    const _hoisted_1$3j = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3j = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M470.3 271.15L43.16 447.31a7.83 7.83 0 0 1-11.16-7V327a8 8 0 0 1 6.51-7.86l247.62-47c17.36-3.29 17.36-28.15 0-31.44l-247.63-47a8 8 0 0 1-6.5-7.85V72.59c0-5.74 5.88-10.26 11.16-8L470.3 241.76a16 16 0 0 1 0 29.39z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2N = [_hoisted_2$3j];
    vue.defineComponent({
      name: 'SendOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3j, _hoisted_3$2N);
      }
    });

    const _hoisted_1$3i = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3i = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M16 464l480-208L16 48v160l320 48l-320 48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2M = [_hoisted_2$3i];
    vue.defineComponent({
      name: 'SendSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3i, _hoisted_3$2M);
      }
    });

    const _hoisted_1$3h = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3h = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 428c-52.35 0-111.39-11.61-157.93-31c-17.07-7.19-31.69-18.82-43.64-28a4 4 0 0 0-6.43 3.18v12.58c0 28.07 23.49 53.22 66.14 70.82C152.29 471.33 202.67 480 256 480s103.7-8.67 141.86-24.42C440.51 438 464 412.83 464 384.76v-12.58a4 4 0 0 0-6.43-3.18c-11.95 9.17-26.57 20.81-43.65 28c-46.54 19.39-105.57 31-157.92 31z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2L = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 126.51c-.81-27.65-24.18-52.4-66-69.85C359.74 40.76 309.34 32 256 32s-103.74 8.76-141.91 24.66c-41.78 17.41-65.15 42.11-66 69.69L48 144c0 6.41 5.2 16.48 14.63 24.73c11.13 9.73 27.65 19.33 47.78 27.73C153.24 214.36 207.67 225 256 225s102.76-10.68 145.59-28.58c20.13-8.4 36.65-18 47.78-27.73C458.8 160.49 464 150.42 464 144z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1H = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M413.92 226c-46.53 19.43-105.57 31-157.92 31s-111.39-11.57-157.93-31c-17.07-7.15-31.69-18.79-43.64-28a4 4 0 0 0-6.43 3.22V232c0 6.41 5.2 14.48 14.63 22.73c11.13 9.74 27.65 19.33 47.78 27.74C153.24 300.34 207.67 311 256 311s102.76-10.68 145.59-28.57c20.13-8.41 36.65-18 47.78-27.74C458.8 246.47 464 238.41 464 232v-30.78a4 4 0 0 0-6.43-3.18c-11.95 9.17-26.57 20.81-43.65 27.96z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$R = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M413.92 312c-46.54 19.41-105.57 31-157.92 31s-111.39-11.59-157.93-31c-17.07-7.17-31.69-18.81-43.64-28a4 4 0 0 0-6.43 3.2V317c0 6.41 5.2 14.47 14.62 22.71c11.13 9.74 27.66 19.33 47.79 27.74C153.24 385.32 207.66 396 256 396s102.76-10.68 145.59-28.57c20.13-8.41 36.65-18 47.78-27.74C458.8 331.44 464 323.37 464 317v-29.8a4 4 0 0 0-6.43-3.18c-11.95 9.17-26.57 20.81-43.65 27.98z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$q = [_hoisted_2$3h, _hoisted_3$2L, _hoisted_4$1H, _hoisted_5$R];
    vue.defineComponent({
      name: 'Server',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3h, _hoisted_6$q);
      }
    });

    const _hoisted_1$3g = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3g = /*#__PURE__*/vue.createElementVNode('ellipse', {
      cx: '256',
      cy: '128',
      rx: '192',
      ry: '80',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2K = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 214c0 44.18-86 80-192 80S64 258.18 64 214',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1G = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 300c0 44.18-86 80-192 80S64 344.18 64 300',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$Q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M64 127.24v257.52C64 428.52 150 464 256 464s192-35.48 192-79.24V127.24',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$p = [_hoisted_2$3g, _hoisted_3$2K, _hoisted_4$1G, _hoisted_5$Q];
    vue.defineComponent({
      name: 'ServerOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3g, _hoisted_6$p);
      }
    });

    const _hoisted_1$3f = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3f = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M409.43 389.87C362 410 305.4 421.05 256 421.05s-105.87-11.3-153.44-31.18S48 353.16 48 353.16v38.2c0 31.15 18 43.64 67.32 64.35C153.13 471.59 203.18 480 256 480s102.87-8.41 140.68-24.29C446 435 464 422.51 464 391.36v-38.2s-7.14 16.59-54.57 36.71z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2J = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M63.69 173.22c11.23 9.84 27.82 19.49 48 27.92c42.48 17.76 96.45 28.37 144.36 28.37s101.88-10.61 144.36-28.37c20.13-8.43 36.72-18.08 47.95-27.92c6.06-5.31 10.85-10.12 13.47-12.85a8 8 0 0 0 2.22-5.54v-26.16c-.84-28.79-24.71-54.41-67.21-72.14C358.83 40.71 308.84 32 256 32s-102.83 8.71-140.74 24.53C72.85 74.22 49 99.78 48.05 128.5v26.33a8 8 0 0 0 2.21 5.54c2.58 2.73 7.36 7.54 13.43 12.85z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1F = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M409.43 221.91C365 241 305.4 253.09 256 253.09s-108.87-12.27-153.43-31.18S48 185.2 48 185.2v47.36c.08 7.52 5.5 16.2 15.69 25.13c11.24 9.84 27.82 19.5 48 27.92C154.12 303.38 208.09 314 256 314s101.88-10.6 144.36-28.37c20.13-8.42 36.72-18.08 47.95-27.92c10.25-9 15.68-17.71 15.69-25.27V185.2s-10.13 17.62-54.57 36.71z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$P = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M409.43 306.38C362 326 305.4 337.56 256 337.56s-109.87-12.8-153.43-31.18S48 269.67 48 269.67v46.25c0 7.55 5.44 16.28 15.69 25.26c11.23 9.84 27.81 19.5 48 27.92c42.48 17.77 96.44 28.37 144.36 28.37s101.88-10.6 144.36-28.37c20.13-8.43 36.72-18.08 47.95-27.92c10.19-8.93 15.61-17.61 15.69-25.13v-46.38s-7.18 17.09-54.62 36.71z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$o = [_hoisted_2$3f, _hoisted_3$2J, _hoisted_4$1F, _hoisted_5$P];
    vue.defineComponent({
      name: 'ServerSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3f, _hoisted_6$o);
      }
    });

    const _hoisted_1$3e = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3e = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '48',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2I = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M470.39 300l-.47-.38l-31.56-24.75a16.11 16.11 0 0 1-6.1-13.33v-11.56a16 16 0 0 1 6.11-13.22L469.92 212l.47-.38a26.68 26.68 0 0 0 5.9-34.06l-42.71-73.9a1.59 1.59 0 0 1-.13-.22A26.86 26.86 0 0 0 401 92.14l-.35.13l-37.1 14.93a15.94 15.94 0 0 1-14.47-1.29q-4.92-3.1-10-5.86a15.94 15.94 0 0 1-8.19-11.82l-5.59-39.59l-.12-.72A27.22 27.22 0 0 0 298.76 26h-85.52a26.92 26.92 0 0 0-26.45 22.39l-.09.56l-5.57 39.67a16 16 0 0 1-8.13 11.82a175.21 175.21 0 0 0-10 5.82a15.92 15.92 0 0 1-14.43 1.27l-37.13-15l-.35-.14a26.87 26.87 0 0 0-32.48 11.34l-.13.22l-42.77 73.95a26.71 26.71 0 0 0 5.9 34.1l.47.38l31.56 24.75a16.11 16.11 0 0 1 6.1 13.33v11.56a16 16 0 0 1-6.11 13.22L42.08 300l-.47.38a26.68 26.68 0 0 0-5.9 34.06l42.71 73.9a1.59 1.59 0 0 1 .13.22a26.86 26.86 0 0 0 32.45 11.3l.35-.13l37.07-14.93a15.94 15.94 0 0 1 14.47 1.29q4.92 3.11 10 5.86a15.94 15.94 0 0 1 8.19 11.82l5.56 39.59l.12.72A27.22 27.22 0 0 0 213.24 486h85.52a26.92 26.92 0 0 0 26.45-22.39l.09-.56l5.57-39.67a16 16 0 0 1 8.18-11.82c3.42-1.84 6.76-3.79 10-5.82a15.92 15.92 0 0 1 14.43-1.27l37.13 14.95l.35.14a26.85 26.85 0 0 0 32.48-11.34a2.53 2.53 0 0 1 .13-.22l42.71-73.89a26.7 26.7 0 0 0-5.89-34.11zm-134.48-40.24a80 80 0 1 1-83.66-83.67a80.21 80.21 0 0 1 83.66 83.67z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1E = [_hoisted_2$3e, _hoisted_3$2I];
    vue.defineComponent({
      name: 'Settings',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3e, _hoisted_4$1E);
      }
    });

    const _hoisted_1$3d = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3d = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M262.29 192.31a64 64 0 1 0 57.4 57.4a64.13 64.13 0 0 0-57.4-57.4zM416.39 256a154.34 154.34 0 0 1-1.53 20.79l45.21 35.46a10.81 10.81 0 0 1 2.45 13.75l-42.77 74a10.81 10.81 0 0 1-13.14 4.59l-44.9-18.08a16.11 16.11 0 0 0-15.17 1.75A164.48 164.48 0 0 1 325 400.8a15.94 15.94 0 0 0-8.82 12.14l-6.73 47.89a11.08 11.08 0 0 1-10.68 9.17h-85.54a11.11 11.11 0 0 1-10.69-8.87l-6.72-47.82a16.07 16.07 0 0 0-9-12.22a155.3 155.3 0 0 1-21.46-12.57a16 16 0 0 0-15.11-1.71l-44.89 18.07a10.81 10.81 0 0 1-13.14-4.58l-42.77-74a10.8 10.8 0 0 1 2.45-13.75l38.21-30a16.05 16.05 0 0 0 6-14.08c-.36-4.17-.58-8.33-.58-12.5s.21-8.27.58-12.35a16 16 0 0 0-6.07-13.94l-38.19-30A10.81 10.81 0 0 1 49.48 186l42.77-74a10.81 10.81 0 0 1 13.14-4.59l44.9 18.08a16.11 16.11 0 0 0 15.17-1.75A164.48 164.48 0 0 1 187 111.2a15.94 15.94 0 0 0 8.82-12.14l6.73-47.89A11.08 11.08 0 0 1 213.23 42h85.54a11.11 11.11 0 0 1 10.69 8.87l6.72 47.82a16.07 16.07 0 0 0 9 12.22a155.3 155.3 0 0 1 21.46 12.57a16 16 0 0 0 15.11 1.71l44.89-18.07a10.81 10.81 0 0 1 13.14 4.58l42.77 74a10.8 10.8 0 0 1-2.45 13.75l-38.21 30a16.05 16.05 0 0 0-6.05 14.08c.33 4.14.55 8.3.55 12.47z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2H = [_hoisted_2$3d];
    vue.defineComponent({
      name: 'SettingsOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3d, _hoisted_3$2H);
      }
    });

    const _hoisted_1$3c = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3c = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 176a80 80 0 1 0 80 80a80.24 80.24 0 0 0-80-80zm172.72 80a165.53 165.53 0 0 1-1.64 22.34l48.69 38.12a11.59 11.59 0 0 1 2.63 14.78l-46.06 79.52a11.64 11.64 0 0 1-14.14 4.93l-57.25-23a176.56 176.56 0 0 1-38.82 22.67l-8.56 60.78a11.93 11.93 0 0 1-11.51 9.86h-92.12a12 12 0 0 1-11.51-9.53l-8.56-60.78A169.3 169.3 0 0 1 151.05 393L93.8 416a11.64 11.64 0 0 1-14.14-4.92L33.6 331.57a11.59 11.59 0 0 1 2.63-14.78l48.69-38.12A174.58 174.58 0 0 1 83.28 256a165.53 165.53 0 0 1 1.64-22.34l-48.69-38.12a11.59 11.59 0 0 1-2.63-14.78l46.06-79.52a11.64 11.64 0 0 1 14.14-4.93l57.25 23a176.56 176.56 0 0 1 38.82-22.67l8.56-60.78A11.93 11.93 0 0 1 209.94 26h92.12a12 12 0 0 1 11.51 9.53l8.56 60.78A169.3 169.3 0 0 1 361 119l57.2-23a11.64 11.64 0 0 1 14.14 4.92l46.06 79.52a11.59 11.59 0 0 1-2.63 14.78l-48.69 38.12a174.58 174.58 0 0 1 1.64 22.66z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2G = [_hoisted_2$3c];
    vue.defineComponent({
      name: 'SettingsSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3c, _hoisted_3$2G);
      }
    });

    const _hoisted_1$3b = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3b = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 336H32a16 16 0 0 1-14-23.81l152-272a16 16 0 0 1 27.94 0l152 272A16 16 0 0 1 336 336z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2F = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 160a161.07 161.07 0 0 0-32.57 3.32l74.47 133.27A48 48 0 0 1 336 368H183.33A160 160 0 1 0 336 160z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1D = [_hoisted_2$3b, _hoisted_3$2F];
    vue.defineComponent({
      name: 'Shapes',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3b, _hoisted_4$1D);
      }
    });

    const _hoisted_1$3a = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3a = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M336 320H32L184 48l152 272z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2E = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M265.32 194.51A144 144 0 1 1 192 320',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1C = [_hoisted_2$3a, _hoisted_3$2E];
    vue.defineComponent({
      name: 'ShapesOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3a, _hoisted_4$1C);
      }
    });

    const _hoisted_1$39 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$39 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M363.27 336H4.73L184 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2D = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 160a160.54 160.54 0 0 0-32.55 3.36l87.75 157L417.81 368H183.36C203.8 432.85 264.49 480 336 480c88.22 0 160-71.78 160-160s-71.78-160-160-160z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1B = [_hoisted_2$39, _hoisted_3$2D];
    vue.defineComponent({
      name: 'ShapesSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$39, _hoisted_4$1B);
      }
    });

    const _hoisted_1$38 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$38 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M376 176H272v145a16 16 0 0 1-32 0V176H136a56.06 56.06 0 0 0-56 56v192a56.06 56.06 0 0 0 56 56h240a56.06 56.06 0 0 0 56-56V232a56.06 56.06 0 0 0-56-56z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2C = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M272 86.63l52.69 52.68a16 16 0 0 0 22.62-22.62l-80-80a16 16 0 0 0-22.62 0l-80 80a16 16 0 0 0 22.62 22.62L240 86.63V176h32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1A = [_hoisted_2$38, _hoisted_3$2C];
    vue.defineComponent({
      name: 'Share',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$38, _hoisted_4$1A);
      }
    });

    const _hoisted_1$37 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$37 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 192h40a40 40 0 0 1 40 40v192a40 40 0 0 1-40 40H136a40 40 0 0 1-40-40V232a40 40 0 0 1 40-40h40',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2B = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M336 128l-80-80l-80 80'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1z = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 321V48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$O = [_hoisted_2$37, _hoisted_3$2B, _hoisted_4$1z];
    vue.defineComponent({
      name: 'ShareOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$37, _hoisted_5$O);
      }
    });

    const _hoisted_1$36 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$36 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M272 176v161h-32V176H92a12 12 0 0 0-12 12v280a12 12 0 0 0 12 12h328a12 12 0 0 0 12-12V188a12 12 0 0 0-12-12z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2A = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M272 92.63l64 64L358.63 134L256 31.37L153.37 134L176 156.63l64-64V176h32V92.63z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1y = [_hoisted_2$36, _hoisted_3$2A];
    vue.defineComponent({
      name: 'ShareSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$36, _hoisted_4$1y);
      }
    });

    const _hoisted_1$35 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$35 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 336a63.78 63.78 0 0 0-46.12 19.7l-148-83.27a63.85 63.85 0 0 0 0-32.86l148-83.27a63.8 63.8 0 1 0-15.73-27.87l-148 83.27a64 64 0 1 0 0 88.6l148 83.27A64 64 0 1 0 384 336z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2z = [_hoisted_2$35];
    vue.defineComponent({
      name: 'ShareSocial',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$35, _hoisted_3$2z);
      }
    });

    const _hoisted_1$34 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$34 = /*#__PURE__*/vue.createStaticVNode('<circle cx="128" cy="256" r="48" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><circle cx="384" cy="112" r="48" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><circle cx="384" cy="400" r="48" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M169.83 279.53l172.34 96.94"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M342.17 135.53l-172.34 96.94"></path>', 5);

    const _hoisted_7$j = [_hoisted_2$34];
    vue.defineComponent({
      name: 'ShareSocialOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$34, _hoisted_7$j);
      }
    });

    const _hoisted_1$33 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$33 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M378 324a69.78 69.78 0 0 0-48.83 19.91L202 272.41a69.68 69.68 0 0 0 0-32.82l127.13-71.5A69.76 69.76 0 1 0 308.87 129l-130.13 73.2a70 70 0 1 0 0 107.56L308.87 383A70 70 0 1 0 378 324z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2y = [_hoisted_2$33];
    vue.defineComponent({
      name: 'ShareSocialSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$33, _hoisted_3$2y);
      }
    });

    const _hoisted_1$32 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$32 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M479.07 111.35a16 16 0 0 0-13.15-14.75C379.89 81.18 343.69 69.12 266 34.16c-7.76-2.89-12.57-2.84-20 0c-77.69 35-113.89 47-199.92 62.44a16 16 0 0 0-13.15 14.75c-3.85 61.1 4.34 118 24.36 169.15a348.86 348.86 0 0 0 71.43 112.41c44.67 47.43 94.2 75.12 119.74 85.6a20 20 0 0 0 15.11 0c27-10.92 74.69-37.82 119.71-85.62a348.86 348.86 0 0 0 71.43-112.39c20.02-51.14 28.21-108.05 24.36-169.15z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2x = [_hoisted_2$32];
    vue.defineComponent({
      name: 'Shield',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$32, _hoisted_3$2x);
      }
    });

    const _hoisted_1$31 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$31 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M479.07 111.36a16 16 0 0 0-13.15-14.74c-86.5-15.52-122.61-26.74-203.33-63.2a16 16 0 0 0-13.18 0C168.69 69.88 132.58 81.1 46.08 96.62a16 16 0 0 0-13.15 14.74c-3.85 61.11 4.36 118.05 24.43 169.24A349.47 349.47 0 0 0 129 393.11c53.47 56.73 110.24 81.37 121.07 85.73a16 16 0 0 0 12 0c10.83-4.36 67.6-29 121.07-85.73a349.47 349.47 0 0 0 71.5-112.51c20.07-51.19 28.28-108.13 24.43-169.24zm-131 75.11l-110.8 128a16 16 0 0 1-11.41 5.53h-.66a16 16 0 0 1-11.2-4.57l-49.2-48.2a16 16 0 1 1 22.4-22.86l37 36.29l99.7-115.13a16 16 0 0 1 24.2 20.94z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2w = [_hoisted_2$31];
    vue.defineComponent({
      name: 'ShieldCheckmark',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$31, _hoisted_3$2w);
      }
    });

    const _hoisted_1$30 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$30 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M336 176L225.2 304L176 255.8'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2v = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M463.1 112.37C373.68 96.33 336.71 84.45 256 48c-80.71 36.45-117.68 48.33-207.1 64.37C32.7 369.13 240.58 457.79 256 464c15.42-6.21 223.3-94.87 207.1-351.63z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1x = [_hoisted_2$30, _hoisted_3$2v];
    vue.defineComponent({
      name: 'ShieldCheckmarkOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$30, _hoisted_4$1x);
      }
    });

    const _hoisted_1$2$ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2$ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M479.07 111.36l-.79-12.53l-12.36-2.21c-86.5-15.52-122.61-26.74-203.33-63.2l-6.59-3l-6.59 3C168.69 69.88 132.58 81.1 46.08 96.62l-12.36 2.21l-.79 12.53c-3.85 61.11 4.36 118.05 24.43 169.24A349.47 349.47 0 0 0 129 393.11c53.47 56.73 110.24 81.37 121.07 85.73l6 2.41l6-2.41c10.83-4.36 67.6-29 121.07-85.73a349.47 349.47 0 0 0 71.5-112.51c20.07-51.19 28.28-108.13 24.43-169.24zm-252.91 216L153.37 256l22.4-22.86l48.47 47.49l110.13-127.2l24.2 20.94z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2u = [_hoisted_2$2$];
    vue.defineComponent({
      name: 'ShieldCheckmarkSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2$, _hoisted_3$2u);
      }
    });

    const _hoisted_1$2_ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2_ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48.9 112.37C138.32 96.33 175.29 84.45 256 48c80.71 36.45 117.68 48.33 207.1 64.37C479.3 369.13 271.42 457.79 256 464c-15.42-6.21-223.3-94.87-207.1-351.63z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2t = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48c80.71 36.45 117.68 48.33 207.1 64.37C479.3 369.13 271.42 457.79 256 464z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1w = [_hoisted_2$2_, _hoisted_3$2t];
    vue.defineComponent({
      name: 'ShieldHalf',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2_, _hoisted_4$1w);
      }
    });

    const _hoisted_1$2Z = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2Z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M463.1 112.37C373.68 96.33 336.71 84.45 256 48c-80.71 36.45-117.68 48.33-207.1 64.37C32.7 369.13 240.58 457.79 256 464c15.42-6.21 223.3-94.87 207.1-351.63z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2s = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48c-80.71 36.45-117.68 48.33-207.1 64.37C32.7 369.13 240.58 457.79 256 464z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1v = [_hoisted_2$2Z, _hoisted_3$2s];
    vue.defineComponent({
      name: 'ShieldHalfOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2Z, _hoisted_4$1v);
      }
    });

    const _hoisted_1$2Y = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2Y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 32C174 69.06 121.38 86.46 32 96c0 77.59 5.27 133.36 25.29 184.51a348.86 348.86 0 0 0 71.43 112.41c49.6 52.66 104.17 80.4 127.28 87.08c23.11-6.68 77.68-34.42 127.28-87.08a348.86 348.86 0 0 0 71.43-112.41C474.73 229.36 480 173.59 480 96c-89.38-9.54-142-26.94-224-64zm161.47 233.93a309.18 309.18 0 0 1-63.31 99.56C316 406 276.65 428.31 256 437.36V75.8c38.75 17 68.73 28.3 97.93 36.89a613.12 613.12 0 0 0 85.6 18.52c-1.72 60.22-8.36 99.69-22.06 134.72z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2r = [_hoisted_2$2Y];
    vue.defineComponent({
      name: 'ShieldHalfSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2Y, _hoisted_3$2r);
      }
    });

    const _hoisted_1$2X = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2X = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M463.1 112.37C373.68 96.33 336.71 84.45 256 48c-80.71 36.45-117.68 48.33-207.1 64.37C32.7 369.13 240.58 457.79 256 464c15.42-6.21 223.3-94.87 207.1-351.63z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2q = [_hoisted_2$2X];
    vue.defineComponent({
      name: 'ShieldOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2X, _hoisted_3$2q);
      }
    });

    const _hoisted_1$2W = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2W = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 32C174 69.06 121.38 86.46 32 96c0 77.59 5.27 133.36 25.29 184.51a348.86 348.86 0 0 0 71.43 112.41c49.6 52.66 104.17 80.4 127.28 87.08c23.11-6.68 77.68-34.42 127.28-87.08a348.86 348.86 0 0 0 71.43-112.41C474.73 229.36 480 173.59 480 96c-89.38-9.54-142-26.94-224-64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2p = [_hoisted_2$2W];
    vue.defineComponent({
      name: 'ShieldSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2W, _hoisted_3$2p);
      }
    });

    const _hoisted_1$2V = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2V = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 96c33.08 0 60.71-25.78 64-58c.3-3-3-6-6-6a13 13 0 0 0-4.74.9c-.2.08-21.1 8.1-53.26 8.1s-53.1-8-53.26-8.1a16.21 16.21 0 0 0-5.3-.9h-.06a5.69 5.69 0 0 0-5.38 6c3.35 32.16 31 58 64 58z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2o = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M485.29 89.9L356 44.64a4 4 0 0 0-5.27 3.16a96 96 0 0 1-189.38 0a4 4 0 0 0-5.35-3.16L26.71 89.9A16 16 0 0 0 16.28 108l16.63 88a16 16 0 0 0 13.92 12.9l48.88 5.52a8 8 0 0 1 7.1 8.19l-7.33 240.9a16 16 0 0 0 9.1 14.94A17.49 17.49 0 0 0 112 480h288a17.49 17.49 0 0 0 7.42-1.55a16 16 0 0 0 9.1-14.94l-7.33-240.9a8 8 0 0 1 7.1-8.19l48.88-5.52a16 16 0 0 0 13.92-12.9l16.63-88a16 16 0 0 0-10.43-18.1z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1u = [_hoisted_2$2V, _hoisted_3$2o];
    vue.defineComponent({
      name: 'Shirt',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2V, _hoisted_4$1u);
      }
    });

    const _hoisted_1$2U = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2U = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M314.56 48s-22.78 8-58.56 8s-58.56-8-58.56-8a31.94 31.94 0 0 0-10.57 1.8L32 104l16.63 88l48.88 5.52a24 24 0 0 1 21.29 24.58L112 464h288l-6.8-241.9a24 24 0 0 1 21.29-24.58l48.88-5.52L480 104L325.13 49.8a31.94 31.94 0 0 0-10.57-1.8z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2n = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M333.31 52.66a80 80 0 0 1-154.62 0',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1t = [_hoisted_2$2U, _hoisted_3$2n];
    vue.defineComponent({
      name: 'ShirtOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2U, _hoisted_4$1t);
      }
    });

    const _hoisted_1$2T = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2T = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 42c-33.88 0-64-10-64-10v2a64 64 0 0 0 128 0v-2s-30.12 10-64 10z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2m = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M352 44c-5.49 47.76-46.79 85-96 85s-90.51-37.24-96-85L16 94l18 114l61.71 7.42c7.08.9 7.1.9 7.1 8.19L96 480h320l-6.81-256.39c-.21-7-.21-7 7.1-8.19L478 208l18-114z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1s = [_hoisted_2$2T, _hoisted_3$2m];
    vue.defineComponent({
      name: 'ShirtSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2T, _hoisted_4$1s);
      }
    });

    const _hoisted_1$2S = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2S = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M400 304l48 48l-48 48"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M400 112l48 48l-48 48"></path><path d="M64 352h85.19a80 80 0 0 0 66.56-35.62L256 256" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M64 160h85.19a80 80 0 0 1 66.56 35.62l80.5 120.76A80 80 0 0 0 362.81 352H416" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M416 160h-53.19a80 80 0 0 0-66.56 35.62L288 208" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 5);

    const _hoisted_7$i = [_hoisted_2$2S];
    vue.defineComponent({
      name: 'Shuffle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2S, _hoisted_7$i);
      }
    });

    const _hoisted_1$2R = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2R = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M400 304l48 48l-48 48"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M400 112l48 48l-48 48"></path><path d="M64 352h85.19a80 80 0 0 0 66.56-35.62L256 256" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M64 160h85.19a80 80 0 0 1 66.56 35.62l80.5 120.76A80 80 0 0 0 362.81 352H416" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M416 160h-53.19a80 80 0 0 0-66.56 35.62L288 208" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 5);

    const _hoisted_7$h = [_hoisted_2$2R];
    vue.defineComponent({
      name: 'ShuffleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2R, _hoisted_7$h);
      }
    });

    const _hoisted_1$2Q = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2Q = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M400 304l48 48l-48 48"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M400 112l48 48l-48 48"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M64 352h128l60-92"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M64 160h128l128 192h96"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M416 160h-96l-32 48"></path>', 5);

    const _hoisted_7$g = [_hoisted_2$2Q];
    vue.defineComponent({
      name: 'ShuffleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2Q, _hoisted_7$g);
      }
    });

    const _hoisted_1$2P = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2P = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M402 76.94C362.61 37.63 310.78 16 256 16h-.37A208 208 0 0 0 48 224v100.67A79.62 79.62 0 0 0 98.29 399l23.71 9.42a15.92 15.92 0 0 1 9.75 11.72l10 50.13A32.09 32.09 0 0 0 173.12 496H184a8 8 0 0 0 8-8v-39.55c0-8.61 6.62-16 15.23-16.43A16 16 0 0 1 224 448v40a8 8 0 0 0 8 8a8 8 0 0 0 8-8v-39.55c0-8.61 6.62-16 15.23-16.43A16 16 0 0 1 272 448v40a8 8 0 0 0 8 8a8 8 0 0 0 8-8v-39.55c0-8.61 6.62-16 15.23-16.43A16 16 0 0 1 320 448v40a8 8 0 0 0 8 8h10.88a32.09 32.09 0 0 0 31.38-25.72l10-50.14a16 16 0 0 1 9.74-11.72l23.71-9.42A79.62 79.62 0 0 0 464 324.67v-99c0-56-22-108.81-62-148.73zM171.66 335.88a56 56 0 1 1 52.22-52.22a56 56 0 0 1-52.22 52.22zM281 397.25a16.37 16.37 0 0 1-9.3 2.75h-31.4a16.37 16.37 0 0 1-9.28-2.75a16 16 0 0 1-6.6-16.9l15.91-47.6C243 326 247.25 321 254 320.13c8.26-1 14 2.87 17.61 12.22l16 48a16 16 0 0 1-6.61 16.9zm66.68-61.37a56 56 0 1 1 52.22-52.22a56 56 0 0 1-52.24 52.22z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2l = [_hoisted_2$2P];
    vue.defineComponent({
      name: 'Skull',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2P, _hoisted_3$2l);
      }
    });

    const _hoisted_1$2O = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2O = /*#__PURE__*/vue.createStaticVNode('<path d="M448 225.64v99a64 64 0 0 1-40.23 59.42l-23.68 9.47A32 32 0 0 0 364.6 417l-10 50.14A16 16 0 0 1 338.88 480H173.12a16 16 0 0 1-15.69-12.86L147.4 417a32 32 0 0 0-19.49-23.44l-23.68-9.47A64 64 0 0 1 64 324.67V224c0-105.92 85.77-191.81 191.65-192S448 119.85 448 225.64z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><circle cx="168" cy="280" r="40" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></circle><circle cx="344" cy="280" r="40" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></circle><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 336l-16 48h32l-16-48z"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 448v32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M208 448v32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M304 448v32"></path>', 7);

    const _hoisted_9$1 = [_hoisted_2$2O];
    vue.defineComponent({
      name: 'SkullOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2O, _hoisted_9$1);
      }
    });

    const _hoisted_1$2N = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2N = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 16C141.31 16 48 109.31 48 224v154.83l82 32.81L146.88 496H192v-64h32v64h16v-64h32v64h16v-64h32v64h45.12L382 411.64l82-32.81V224c0-114.69-93.31-208-208-208zm-88 320a56 56 0 1 1 56-56a56.06 56.06 0 0 1-56 56zm51.51 64L244 320h24l24.49 80zM344 336a56 56 0 1 1 56-56a56.06 56.06 0 0 1-56 56zm104 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2k = [_hoisted_2$2N];
    vue.defineComponent({
      name: 'SkullSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2N, _hoisted_3$2k);
      }
    });

    const _hoisted_1$2M = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2M = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M461 349l-34-19.64a89.53 89.53 0 0 1 20.94-16a22 22 0 0 0-21.28-38.51a133.62 133.62 0 0 0-38.55 32.1L300 256l88.09-50.86a133.46 133.46 0 0 0 38.55 32.1a22 22 0 1 0 21.28-38.51a89.74 89.74 0 0 1-20.94-16l34-19.64A22 22 0 1 0 439 125l-34 19.63a89.74 89.74 0 0 1-3.42-26.15A22 22 0 0 0 380 96h-.41a22 22 0 0 0-22 21.59a133.61 133.61 0 0 0 8.5 49.41L278 217.89V116.18a133.5 133.5 0 0 0 47.07-17.33a22 22 0 0 0-22.71-37.69A89.56 89.56 0 0 1 278 71.27V38a22 22 0 0 0-44 0v33.27a89.56 89.56 0 0 1-24.36-10.11a22 22 0 1 0-22.71 37.69A133.5 133.5 0 0 0 234 116.18v101.71L145.91 167a133.61 133.61 0 0 0 8.52-49.43a22 22 0 0 0-22-21.59H132a22 22 0 0 0-21.59 22.41a89.74 89.74 0 0 1-3.41 26.19L73 125a22 22 0 1 0-22 38.1l34 19.64a89.74 89.74 0 0 1-20.94 16a22 22 0 1 0 21.28 38.51a133.62 133.62 0 0 0 38.55-32.1L212 256l-88.09 50.86a133.62 133.62 0 0 0-38.55-32.1a22 22 0 1 0-21.28 38.51a89.74 89.74 0 0 1 20.94 16L51 349a22 22 0 1 0 22 38.1l34-19.63a89.74 89.74 0 0 1 3.42 26.15A22 22 0 0 0 132 416h.41a22 22 0 0 0 22-21.59a133.61 133.61 0 0 0-8.5-49.41L234 294.11v101.71a133.5 133.5 0 0 0-47.07 17.33a22 22 0 1 0 22.71 37.69A89.56 89.56 0 0 1 234 440.73V474a22 22 0 0 0 44 0v-33.27a89.56 89.56 0 0 1 24.36 10.11a22 22 0 0 0 22.71-37.69A133.5 133.5 0 0 0 278 395.82V294.11L366.09 345a133.61 133.61 0 0 0-8.52 49.43a22 22 0 0 0 22 21.59h.43a22 22 0 0 0 21.59-22.41a89.74 89.74 0 0 1 3.41-26.19l34 19.63A22 22 0 1 0 461 349z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2j = [_hoisted_2$2M];
    vue.defineComponent({
      name: 'Snow',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2M, _hoisted_3$2j);
      }
    });

    const _hoisted_1$2L = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2L = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 32v448"></path><path d="M313.72 80A111.47 111.47 0 0 1 256 96a111.47 111.47 0 0 1-57.72-16" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M198.28 432a112.11 112.11 0 0 1 115.44 0" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M449.99 144L62.01 368"></path><path d="M437.27 218a112.09 112.09 0 0 1-57.71-100" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M74.73 294a112.09 112.09 0 0 1 57.71 100" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M62.01 144l387.98 224"></path><path d="M74.73 218a112.09 112.09 0 0 0 57.71-100" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M437.27 294a112.09 112.09 0 0 0-57.71 100" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 9);

    const _hoisted_11$3 = [_hoisted_2$2L];
    vue.defineComponent({
      name: 'SnowOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2L, _hoisted_11$3);
      }
    });

    const _hoisted_1$2K = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2K = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M447.88 313.27l19.25-10.64l-21.28-38.51l-19.25 10.64a133.42 133.42 0 0 0-38.54 32.1L300 256l88.07-50.86a133.42 133.42 0 0 0 38.54 32.1l19.25 10.64l21.28-38.51l-19.25-10.64a89.27 89.27 0 0 1-20.93-16L480 152.05L458 114l-53 30.58a89.07 89.07 0 0 1-3.42-26.15l.41-22l-44-.82l-.41 22a133.62 133.62 0 0 0 8.49 49.39L278 217.89V116.18a133.52 133.52 0 0 0 47.06-17.33L343.9 87.5l-22.71-37.69l-18.84 11.35A89.5 89.5 0 0 1 278 71.27V16h-44v55.27a89.5 89.5 0 0 1-24.35-10.11l-18.84-11.35L168.1 87.5l18.84 11.35A133.52 133.52 0 0 0 234 116.18v101.71L145.93 167a133.62 133.62 0 0 0 8.53-49.43l-.41-22l-44 .82l.41 22a89.07 89.07 0 0 1-3.42 26.15L54 114l-22 38.1l53.05 30.64a89.27 89.27 0 0 1-20.93 16l-19.25 10.63l21.28 38.51l19.25-10.64a133.42 133.42 0 0 0 38.54-32.1L212 256l-88.07 50.86a133.42 133.42 0 0 0-38.54-32.1l-19.24-10.64l-21.28 38.51l19.25 10.64a89.27 89.27 0 0 1 20.93 16L32 360l22 38.1l53.05-30.63a89.07 89.07 0 0 1 3.42 26.15l-.41 22l44 .82l.41-22a133.62 133.62 0 0 0-8.54-49.44L234 294.11v101.71a133.52 133.52 0 0 0-47.06 17.33L168.1 424.5l22.71 37.69l18.84-11.35A89.5 89.5 0 0 1 234 440.73V496h44v-55.27a89.5 89.5 0 0 1 24.35 10.11l18.84 11.35l22.71-37.69l-18.84-11.35A133.52 133.52 0 0 0 278 395.82V294.11L366.07 345a133.62 133.62 0 0 0-8.53 49.43l.41 22l44-.82l-.41-22a89.07 89.07 0 0 1 3.46-26.19l53 30.63L480 360l-53-30.69a89.27 89.27 0 0 1 20.88-16.04z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2i = [_hoisted_2$2K];
    vue.defineComponent({
      name: 'SnowSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2K, _hoisted_3$2i);
      }
    });

    const _hoisted_1$2J = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2J = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M208 512a24.84 24.84 0 0 1-23.34-16l-39.84-103.6a16.06 16.06 0 0 0-9.19-9.19L32 343.34a25 25 0 0 1 0-46.68l103.6-39.84a16.06 16.06 0 0 0 9.19-9.19L184.66 144a25 25 0 0 1 46.68 0l39.84 103.6a16.06 16.06 0 0 0 9.19 9.19l103 39.63a25.49 25.49 0 0 1 16.63 24.1a24.82 24.82 0 0 1-16 22.82l-103.6 39.84a16.06 16.06 0 0 0-9.19 9.19L231.34 496A24.84 24.84 0 0 1 208 512zm66.85-254.84z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2h = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M88 176a14.67 14.67 0 0 1-13.69-9.4l-16.86-43.84a7.28 7.28 0 0 0-4.21-4.21L9.4 101.69a14.67 14.67 0 0 1 0-27.38l43.84-16.86a7.31 7.31 0 0 0 4.21-4.21L74.16 9.79A15 15 0 0 1 86.23.11a14.67 14.67 0 0 1 15.46 9.29l16.86 43.84a7.31 7.31 0 0 0 4.21 4.21l43.84 16.86a14.67 14.67 0 0 1 0 27.38l-43.84 16.86a7.28 7.28 0 0 0-4.21 4.21l-16.86 43.84A14.67 14.67 0 0 1 88 176z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1r = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400 256a16 16 0 0 1-14.93-10.26l-22.84-59.37a8 8 0 0 0-4.6-4.6l-59.37-22.84a16 16 0 0 1 0-29.86l59.37-22.84a8 8 0 0 0 4.6-4.6l22.67-58.95a16.45 16.45 0 0 1 13.17-10.57a16 16 0 0 1 16.86 10.15l22.84 59.37a8 8 0 0 0 4.6 4.6l59.37 22.84a16 16 0 0 1 0 29.86l-59.37 22.84a8 8 0 0 0-4.6 4.6l-22.84 59.37A16 16 0 0 1 400 256z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$N = [_hoisted_2$2J, _hoisted_3$2h, _hoisted_4$1r];
    vue.defineComponent({
      name: 'Sparkles',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2J, _hoisted_5$N);
      }
    });

    const _hoisted_1$2I = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2I = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M259.92 262.91L216.4 149.77a9 9 0 0 0-16.8 0l-43.52 113.14a9 9 0 0 1-5.17 5.17L37.77 311.6a9 9 0 0 0 0 16.8l113.14 43.52a9 9 0 0 1 5.17 5.17l43.52 113.14a9 9 0 0 0 16.8 0l43.52-113.14a9 9 0 0 1 5.17-5.17l113.14-43.52a9 9 0 0 0 0-16.8l-113.14-43.52a9 9 0 0 1-5.17-5.17z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2g = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M108 68L88 16L68 68L16 88l52 20l20 52l20-52l52-20l-52-20z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1q = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M426.67 117.33L400 48l-26.67 69.33L304 144l69.33 26.67L400 240l26.67-69.33L496 144l-69.33-26.67z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$M = [_hoisted_2$2I, _hoisted_3$2g, _hoisted_4$1q];
    vue.defineComponent({
      name: 'SparklesOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2I, _hoisted_5$M);
      }
    });

    const _hoisted_1$2H = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2H = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M208 512l-52.38-139.62L16 320l139.62-52.38L208 128l52.38 139.62L400 320l-139.62 52.38z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2f = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M88 176l-23.57-64.43L0 88l64.43-23.57L88 0l23.57 64.43L176 88l-64.43 23.57z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1p = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400 256l-31.11-80.89L288 144l80.89-31.11L400 32l31.11 80.89L512 144l-80.89 31.11z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$L = [_hoisted_2$2H, _hoisted_3$2f, _hoisted_4$1p];
    vue.defineComponent({
      name: 'SparklesSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2H, _hoisted_5$L);
      }
    });

    const _hoisted_1$2G = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2G = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M425.7 118.25A240 240 0 0 0 76.32 447l.18.2c.33.35.64.71 1 1.05c.74.84 1.58 1.79 2.57 2.78a41.17 41.17 0 0 0 60.36-.42a157.13 157.13 0 0 1 231.26 0a41.18 41.18 0 0 0 60.65.06l3.21-3.5l.18-.2a239.93 239.93 0 0 0-10-328.76zM240 128a16 16 0 0 1 32 0v32a16 16 0 0 1-32 0zM128 304H96a16 16 0 0 1 0-32h32a16 16 0 0 1 0 32zm48.8-95.2a16 16 0 0 1-22.62 0l-22.63-22.62a16 16 0 0 1 22.63-22.63l22.62 22.63a16 16 0 0 1 0 22.62zm149.3 23.1l-47.5 75.5a31 31 0 0 1-7 7a30.11 30.11 0 0 1-35-49l75.5-47.5a10.23 10.23 0 0 1 11.7 0a10.06 10.06 0 0 1 2.3 14zm31.72-23.1a16 16 0 0 1-22.62-22.62l22.62-22.63a16 16 0 0 1 22.63 22.63zm65.88 227.6zM416 304h-32a16 16 0 0 1 0-32h32a16 16 0 0 1 0 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2e = [_hoisted_2$2G];
    vue.defineComponent({
      name: 'Speedometer',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2G, _hoisted_3$2e);
      }
    });

    const _hoisted_1$2F = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2F = /*#__PURE__*/vue.createStaticVNode('<path d="M326.1 231.9l-47.5 75.5a31 31 0 0 1-7 7a30.11 30.11 0 0 1-35-49l75.5-47.5a10.23 10.23 0 0 1 11.7 0a10.06 10.06 0 0 1 2.3 14z" fill="currentColor"></path><path d="M256 64C132.3 64 32 164.2 32 287.9a223.18 223.18 0 0 0 56.3 148.5c1.1 1.2 2.1 2.4 3.2 3.5a25.19 25.19 0 0 0 37.1-.1a173.13 173.13 0 0 1 254.8 0a25.19 25.19 0 0 0 37.1.1l3.2-3.5A223.18 223.18 0 0 0 480 287.9C480 164.2 379.7 64 256 64z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M256 128v32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M416 288h-32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M128 288H96"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M165.49 197.49l-22.63-22.63"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M346.51 197.49l22.63-22.63"></path>', 7);

    const _hoisted_9 = [_hoisted_2$2F];
    vue.defineComponent({
      name: 'SpeedometerOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2F, _hoisted_9);
      }
    });

    const _hoisted_1$2E = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2E = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C123.46 48 16 156.55 16 290.56a243.3 243.3 0 0 0 60.32 160.87c1.18 1.3 2.25 2.6 3.43 3.79C89.2 464 92.07 464 99.57 464s12.43 0 19.93-8.88C152 416.64 202 400 256 400s104.07 16.71 136.5 55.12C400 464 404.82 464 412.43 464s11.3 0 19.82-8.78c1.22-1.25 2.25-2.49 3.43-3.79A243.3 243.3 0 0 0 496 290.56C496 156.55 388.54 48 256 48zm-16 64h32v64h-32zm-96 192H80v-32h64zm21.49-83.88l-45.25-45.26l22.62-22.62l45.26 45.25zM278.6 307.4a31 31 0 0 1-7 7a30.11 30.11 0 0 1-35-49L320 224zm45.28-109.91l45.26-45.25l22.62 22.62l-45.25 45.26zM432 304h-64v-32h64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2d = [_hoisted_2$2E];
    vue.defineComponent({
      name: 'SpeedometerSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2E, _hoisted_3$2d);
      }
    });

    const _hoisted_1$2D = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2D = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 464H96a48.05 48.05 0 0 1-48-48V96a48.05 48.05 0 0 1 48-48h320a48.05 48.05 0 0 1 48 48v320a48.05 48.05 0 0 1-48 48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2c = [_hoisted_2$2D];
    vue.defineComponent({
      name: 'Square',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2D, _hoisted_3$2c);
      }
    });

    const _hoisted_1$2C = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2C = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 448H96a32.09 32.09 0 0 1-32-32V96a32.09 32.09 0 0 1 32-32h320a32.09 32.09 0 0 1 32 32v320a32.09 32.09 0 0 1-32 32z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2b = [_hoisted_2$2C];
    vue.defineComponent({
      name: 'SquareOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2C, _hoisted_3$2b);
      }
    });

    const _hoisted_1$2B = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2B = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 48h416v416H48z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2a = [_hoisted_2$2B];
    vue.defineComponent({
      name: 'SquareSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2B, _hoisted_3$2a);
      }
    });

    const _hoisted_1$2A = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2A = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M394 480a16 16 0 0 1-9.39-3L256 383.76L127.39 477a16 16 0 0 1-24.55-18.08L153 310.35L23 221.2a16 16 0 0 1 9-29.2h160.38l48.4-148.95a16 16 0 0 1 30.44 0l48.4 149H480a16 16 0 0 1 9.05 29.2L359 310.35l50.13 148.53A16 16 0 0 1 394 480z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$29 = [_hoisted_2$2A];
    vue.defineComponent({
      name: 'Star',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2A, _hoisted_3$29);
      }
    });

    const _hoisted_1$2z = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 208H308L256 48l-52 160H32l140 96l-54 160l138-100l138 100l-54-160z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$28 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48v316L118 464l54-160l-140-96h172l52-160z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1o = [_hoisted_2$2z, _hoisted_3$28];
    vue.defineComponent({
      name: 'StarHalf',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2z, _hoisted_4$1o);
      }
    });

    const _hoisted_1$2y = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 208H308L256 48l-52 160H32l140 96l-54 160l138-100l138 100l-54-160z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$27 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48v316L118 464l54-160l-140-96h172l52-160z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1n = [_hoisted_2$2y, _hoisted_3$27];
    vue.defineComponent({
      name: 'StarHalfOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2y, _hoisted_4$1n);
      }
    });

    const _hoisted_1$2x = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2x = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M496 203.3H312.36L256 32l-56.36 171.3H16l150.21 105.4l-58.5 171.3L256 373.84L404.29 480l-58.61-171.3zM274.63 347.82L256 334.49v-200.1l26 78.91l7.24 22h105.39l-67.32 47.2l-19.69 13.81l7.78 22.75l26.26 76.75z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$26 = [_hoisted_2$2x];
    vue.defineComponent({
      name: 'StarHalfSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2x, _hoisted_3$26);
      }
    });

    const _hoisted_1$2w = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2w = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 208H308L256 48l-52 160H32l140 96l-54 160l138-100l138 100l-54-160z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$25 = [_hoisted_2$2w];
    vue.defineComponent({
      name: 'StarOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2w, _hoisted_3$25);
      }
    });

    const _hoisted_1$2v = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2v = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M496 203.3H312.36L256 32l-56.36 171.3H16l150.21 105.4l-58.5 171.3L256 373.84L404.29 480l-58.61-171.3z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$24 = [_hoisted_2$2v];
    vue.defineComponent({
      name: 'StarSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2v, _hoisted_3$24);
      }
    });

    const _hoisted_1$2u = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2u = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M104 496H72a24 24 0 0 1-24-24V328a24 24 0 0 1 24-24h32a24 24 0 0 1 24 24v144a24 24 0 0 1-24 24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$23 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M328 496h-32a24 24 0 0 1-24-24V232a24 24 0 0 1 24-24h32a24 24 0 0 1 24 24v240a24 24 0 0 1-24 24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1m = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M440 496h-32a24 24 0 0 1-24-24V120a24 24 0 0 1 24-24h32a24 24 0 0 1 24 24v352a24 24 0 0 1-24 24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$K = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M216 496h-32a24 24 0 0 1-24-24V40a24 24 0 0 1 24-24h32a24 24 0 0 1 24 24v432a24 24 0 0 1-24 24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$n = [_hoisted_2$2u, _hoisted_3$23, _hoisted_4$1m, _hoisted_5$K];
    vue.defineComponent({
      name: 'StatsChart',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2u, _hoisted_6$n);
      }
    });

    const _hoisted_1$2t = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2t = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '64',
      y: '320',
      width: '48',
      height: '160',
      rx: '8',
      ry: '8',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$22 = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '288',
      y: '224',
      width: '48',
      height: '256',
      rx: '8',
      ry: '8',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1l = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '400',
      y: '112',
      width: '48',
      height: '368',
      rx: '8',
      ry: '8',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$J = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '176',
      y: '32',
      width: '48',
      height: '448',
      rx: '8',
      ry: '8',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$m = [_hoisted_2$2t, _hoisted_3$22, _hoisted_4$1l, _hoisted_5$J];
    vue.defineComponent({
      name: 'StatsChartOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2t, _hoisted_6$m);
      }
    });

    const _hoisted_1$2s = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2s = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M128 496H48V304h80z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$21 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M352 496h-80V208h80z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1k = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 496h-80V96h80z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$I = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M240 496h-80V16h80z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$l = [_hoisted_2$2s, _hoisted_3$21, _hoisted_4$1k, _hoisted_5$I];
    vue.defineComponent({
      name: 'StatsChartSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2s, _hoisted_6$l);
      }
    });

    const _hoisted_1$2r = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2r = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M392 432H120a40 40 0 0 1-40-40V120a40 40 0 0 1 40-40h272a40 40 0 0 1 40 40v272a40 40 0 0 1-40 40z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$20 = [_hoisted_2$2r];
    vue.defineComponent({
      name: 'Stop',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2r, _hoisted_3$20);
      }
    });

    const _hoisted_1$2q = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm80 262.4a25.62 25.62 0 0 1-25.6 25.6H201.6a25.62 25.62 0 0 1-25.6-25.6V201.6a25.62 25.62 0 0 1 25.6-25.6h108.8a25.62 25.62 0 0 1 25.6 25.6z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1$ = [_hoisted_2$2q];
    vue.defineComponent({
      name: 'StopCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2q, _hoisted_3$1$);
      }
    });

    const _hoisted_1$2p = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2p = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1_ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M310.4 336H201.6a25.62 25.62 0 0 1-25.6-25.6V201.6a25.62 25.62 0 0 1 25.6-25.6h108.8a25.62 25.62 0 0 1 25.6 25.6v108.8a25.62 25.62 0 0 1-25.6 25.6z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1j = [_hoisted_2$2p, _hoisted_3$1_];
    vue.defineComponent({
      name: 'StopCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2p, _hoisted_4$1j);
      }
    });

    const _hoisted_1$2o = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2o = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.31 48 48 141.31 48 256s93.31 208 208 208s208-93.31 208-208S370.69 48 256 48zm80 288H176V176h160z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1Z = [_hoisted_2$2o];
    vue.defineComponent({
      name: 'StopCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2o, _hoisted_3$1Z);
      }
    });

    const _hoisted_1$2n = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2n = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '96',
      y: '96',
      width: '320',
      height: '320',
      rx: '24',
      ry: '24',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1Y = [_hoisted_2$2n];
    vue.defineComponent({
      name: 'StopOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2n, _hoisted_3$1Y);
      }
    });

    const _hoisted_1$2m = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2m = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M80 80h352v352H80z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1X = [_hoisted_2$2m];
    vue.defineComponent({
      name: 'StopSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2m, _hoisted_3$1X);
      }
    });

    const _hoisted_1$2l = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2l = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '272',
      r: '16',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1W = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M280 81.5V72a24 24 0 0 0-48 0v9.5a191 191 0 0 0-84.43 32.13L137 103a24 24 0 0 0-34 34l8.6 8.6A191.17 191.17 0 0 0 64 272c0 105.87 86.13 192 192 192s192-86.13 192-192c0-97.74-73.42-178.66-168-190.5zM256 320a48 48 0 0 1-16-93.25V152a16 16 0 0 1 32 0v74.75A48 48 0 0 1 256 320z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1i = [_hoisted_2$2l, _hoisted_3$1W];
    vue.defineComponent({
      name: 'Stopwatch',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2l, _hoisted_4$1i);
      }
    });

    const _hoisted_1$2k = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2k = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 232v-80"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="48" d="M256 88V72"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="48" d="M132 132l-12-12"></path><circle cx="256" cy="272" r="32" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></circle><path d="M256 96a176 176 0 1 0 176 176A176 176 0 0 0 256 96z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path>', 5);

    const _hoisted_7$f = [_hoisted_2$2k];
    vue.defineComponent({
      name: 'StopwatchOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2k, _hoisted_7$f);
      }
    });

    const _hoisted_1$2j = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2j = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M280 81.5V48h-48v33.5a191 191 0 0 0-84.43 32.13L120 86l-34 34l25.59 25.59A191.17 191.17 0 0 0 64 272c0 105.87 86.13 192 192 192s192-86.13 192-192c0-97.74-73.42-178.66-168-190.5zM256 320a48 48 0 0 1-16-93.25V136h32v90.75A48 48 0 0 1 256 320z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1V = [_hoisted_2$2j];
    vue.defineComponent({
      name: 'StopwatchSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2j, _hoisted_3$1V);
      }
    });

    const _hoisted_1$2i = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2i = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 448h-12a4 4 0 0 1-4-4V273.51a4 4 0 0 0-5.24-3.86a104.92 104.92 0 0 1-28.32 4.78c-1.18 0-2.3.05-3.4.05a108.22 108.22 0 0 1-52.85-13.64a8.23 8.23 0 0 0-8 0a108.18 108.18 0 0 1-52.84 13.64a106.11 106.11 0 0 1-52.46-13.79a8.21 8.21 0 0 0-8.09 0a108.14 108.14 0 0 1-53.16 13.8a106.19 106.19 0 0 1-52.77-14a8.25 8.25 0 0 0-8.16 0a106.19 106.19 0 0 1-52.77 14c-1.09 0-2.19 0-3.37-.05h-.06a104.91 104.91 0 0 1-29.28-5.09a4 4 0 0 0-5.23 3.8V444a4 4 0 0 1-4 4H32.5c-8.64 0-16.1 6.64-16.48 15.28A16 16 0 0 0 32 480h447.5c8.64 0 16.1-6.64 16.48-15.28A16 16 0 0 0 480 448zm-256-68a4 4 0 0 1-4 4h-88a4 4 0 0 1-4-4v-64a12 12 0 0 1 12-12h72a12 12 0 0 1 12 12zm156 68h-72a4 4 0 0 1-4-4V316a12 12 0 0 1 12-12h56a12 12 0 0 1 12 12v128a4 4 0 0 1-4 4z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1U = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M492.57 170.28l-42.92-98.49C438.41 47.62 412.74 32 384.25 32H127.7c-28.49 0-54.16 15.62-65.4 39.79l-42.92 98.49c-9 19.41 2.89 39.34 2.9 39.35l.28.45c.49.78 1.36 2 1.89 2.78c.05.06.09.13.14.2l5 6.05a7.45 7.45 0 0 0 .6.65l5 4.83l.42.36a69.65 69.65 0 0 0 9.39 6.78v.05a74 74 0 0 0 36 10.67h2.47a76.08 76.08 0 0 0 51.89-20.31l.33-.31a7.94 7.94 0 0 1 10.89 0l.33.31a77.3 77.3 0 0 0 104.46 0a8 8 0 0 1 10.87 0a77.31 77.31 0 0 0 104.21.23a7.88 7.88 0 0 1 10.71 0a76.81 76.81 0 0 0 52.31 20.08h2.49a71.35 71.35 0 0 0 35-10.7c.95-.57 1.86-1.17 2.78-1.77A71.33 71.33 0 0 0 488 212.17l1.74-2.63q.26-.4.48-.84c1.66-3.38 10.56-20.76 2.35-38.42z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1h = [_hoisted_2$2i, _hoisted_3$1U];
    vue.defineComponent({
      name: 'Storefront',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2i, _hoisted_4$1h);
      }
    });

    const _hoisted_1$2h = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2h = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M448 448V240"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M64 240v208"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M382.47 48H129.53c-21.79 0-41.47 12-49.93 30.46L36.3 173c-14.58 31.81 9.63 67.85 47.19 69h2c31.4 0 56.85-25.18 56.85-52.23c0 27 25.46 52.23 56.86 52.23s56.8-23.38 56.8-52.23c0 27 25.45 52.23 56.85 52.23s56.86-23.38 56.86-52.23c0 28.85 25.45 52.23 56.85 52.23h1.95c37.56-1.17 61.77-37.21 47.19-69l-43.3-94.54C423.94 60 404.26 48 382.47 48z"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M32 464h448"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M136 288h80a24 24 0 0 1 24 24v88h0h-128h0v-88a24 24 0 0 1 24-24z"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M288 464V312a24 24 0 0 1 24-24h64a24 24 0 0 1 24 24v152"></path>', 6);

    const _hoisted_8$5 = [_hoisted_2$2h];
    vue.defineComponent({
      name: 'StorefrontOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2h, _hoisted_8$5);
      }
    });

    const _hoisted_1$2g = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2g = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 448V267.85a104.76 104.76 0 0 1-33.56 6.58c-1.18 0-2.3.05-3.4.05a108 108 0 0 1-56.86-16a108 108 0 0 1-56.85 16a106.16 106.16 0 0 1-56.51-16.2a107.84 107.84 0 0 1-57.2 16.2a106.14 106.14 0 0 1-56.85-16.42a106.14 106.14 0 0 1-56.85 16.42c-1.09 0-2.19 0-3.37-.05h-.06A104.66 104.66 0 0 1 48 267.49V448H16v32h480v-32zm-240-64h-96v-76a4 4 0 0 1 4-4h88a4 4 0 0 1 4 4zm160 64h-80V308a4 4 0 0 1 4-4h72a4 4 0 0 1 4 4z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1T = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M492.57 170.28L445.89 64C432 32 432 32 400 32H112c-32 0-32 0-45.94 32L19.38 170.28c-9 19.41 2.89 39.34 2.9 39.35l.41.66c.42.66 1.13 1.75 1.62 2.37c.1.13.19.27.28.4l5.24 6.39l5.31 5.14l.42.36a69.65 69.65 0 0 0 9.44 6.78v.05a74 74 0 0 0 36 10.67h2.47a76.08 76.08 0 0 0 51.89-20.31a72.38 72.38 0 0 0 5.77-6a74.18 74.18 0 0 0 5.78 6a76.08 76.08 0 0 0 51.89 20.31c23.28 0 44.07-10 57.63-25.56a.11.11 0 0 1 .15 0l5.66 5.26a76.09 76.09 0 0 0 51.9 20.31c23.29 0 44.11-10 57.66-25.61c13.56 15.61 34.37 25.61 57.67 25.61h2.49a71.35 71.35 0 0 0 35-10.7c.95-.57 1.86-1.17 2.78-1.77A71.33 71.33 0 0 0 488 212.17l2-3c.9-2.04 11.21-20.3 2.57-38.89z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1g = [_hoisted_2$2g, _hoisted_3$1T];
    vue.defineComponent({
      name: 'StorefrontSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2g, _hoisted_4$1g);
      }
    });

    const _hoisted_1$2f = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2f = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M352 16H160a64.07 64.07 0 0 0-64 64v256a64.07 64.07 0 0 0 64 64h192a64.07 64.07 0 0 0 64-64V80a64.07 64.07 0 0 0-64-64zM208 64h96a16 16 0 0 1 0 32h-96a16 16 0 0 1 0-32zm-32 288a32 32 0 1 1 32-32a32 32 0 0 1-32 32zm160 0a32 32 0 1 1 32-32a32 32 0 0 1-32 32zm48-160a16 16 0 0 1-16 16H144a16 16 0 0 1-16-16v-32a16 16 0 0 1 16-16h224a16 16 0 0 1 16 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1S = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M347.31 420.69a16 16 0 0 0-22.62 22.62l4.68 4.69H182.63l4.68-4.69a16 16 0 0 0-22.62-22.62l-48 48a16 16 0 1 0 22.62 22.62L150.63 480h210.74l11.32 11.31a16 16 0 0 0 22.62-22.62z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1f = [_hoisted_2$2f, _hoisted_3$1S];
    vue.defineComponent({
      name: 'Subway',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2f, _hoisted_4$1f);
      }
    });

    const _hoisted_1$2e = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2e = /*#__PURE__*/vue.createStaticVNode('<rect x="112" y="32" width="288" height="352" rx="48" ry="48" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></rect><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M208 80h96"></path><rect x="112" y="128" width="288" height="96" rx="32" ry="32" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></rect><circle cx="176" cy="320" r="16" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></circle><circle cx="336" cy="320" r="16" fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32"></circle><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M144 464h224"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M336 432l48 48"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M176 432l-48 48"></path>', 8);

    const _hoisted_10$1 = [_hoisted_2$2e];
    vue.defineComponent({
      name: 'SubwayOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2e, _hoisted_10$1);
      }
    });

    const _hoisted_1$2d = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2d = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M392 16H120a24 24 0 0 0-24 24v336a24 24 0 0 0 24 24h272a24 24 0 0 0 24-24V40a24 24 0 0 0-24-24zM208 64h95.55c8.61 0 16 6.62 16.43 15.23A16 16 0 0 1 304 96h-95.55c-8.61 0-16-6.62-16.43-15.23A16 16 0 0 1 208 64zm-28.53 287.82a32 32 0 1 1 28.35-28.35a32 32 0 0 1-28.35 28.35zm160 0a32 32 0 1 1 28.35-28.35a32 32 0 0 1-28.35 28.35zM384 144v64H128v-64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1R = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M298 416l31.37 32H182.63L214 416h-44l-80.57 80h45.2l16-16h210.74l16 16h45.3L343 416h-45z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1e = [_hoisted_2$2d, _hoisted_3$1R];
    vue.defineComponent({
      name: 'SubwaySharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2d, _hoisted_4$1e);
      }
    });

    const _hoisted_1$2c = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2c = /*#__PURE__*/vue.createStaticVNode('<path d="M256 118a22 22 0 0 1-22-22V48a22 22 0 0 1 44 0v48a22 22 0 0 1-22 22z" fill="currentColor"></path><path d="M256 486a22 22 0 0 1-22-22v-48a22 22 0 0 1 44 0v48a22 22 0 0 1-22 22z" fill="currentColor"></path><path d="M369.14 164.86a22 22 0 0 1-15.56-37.55l33.94-33.94a22 22 0 0 1 31.11 31.11l-33.94 33.94a21.93 21.93 0 0 1-15.55 6.44z" fill="currentColor"></path><path d="M108.92 425.08a22 22 0 0 1-15.55-37.56l33.94-33.94a22 22 0 1 1 31.11 31.11l-33.94 33.94a21.94 21.94 0 0 1-15.56 6.45z" fill="currentColor"></path><path d="M464 278h-48a22 22 0 0 1 0-44h48a22 22 0 0 1 0 44z" fill="currentColor"></path><path d="M96 278H48a22 22 0 0 1 0-44h48a22 22 0 0 1 0 44z" fill="currentColor"></path><path d="M403.08 425.08a21.94 21.94 0 0 1-15.56-6.45l-33.94-33.94a22 22 0 0 1 31.11-31.11l33.94 33.94a22 22 0 0 1-15.55 37.56z" fill="currentColor"></path><path d="M142.86 164.86a21.89 21.89 0 0 1-15.55-6.44l-33.94-33.94a22 22 0 0 1 31.11-31.11l33.94 33.94a22 22 0 0 1-15.56 37.55z" fill="currentColor"></path><path d="M256 358a102 102 0 1 1 102-102a102.12 102.12 0 0 1-102 102z" fill="currentColor"></path>', 9);

    const _hoisted_11$2 = [_hoisted_2$2c];
    vue.defineComponent({
      name: 'Sunny',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2c, _hoisted_11$2);
      }
    });

    const _hoisted_1$2b = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2b = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M256 48v48"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M256 416v48"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M403.08 108.92l-33.94 33.94"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M142.86 369.14l-33.94 33.94"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M464 256h-48"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M96 256H48"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M403.08 403.08l-33.94-33.94"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M142.86 142.86l-33.94-33.94"></path><circle cx="256" cy="256" r="80" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></circle>', 9);

    const _hoisted_11$1 = [_hoisted_2$2b];
    vue.defineComponent({
      name: 'SunnyOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2b, _hoisted_11$1);
      }
    });

    const _hoisted_1$2a = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2a = /*#__PURE__*/vue.createStaticVNode('<path d="M234 26h44v92h-44z" fill="currentColor"></path><path d="M234 394h44v92h-44z" fill="currentColor"></path><path d="M338.025 142.857l65.054-65.054l31.113 31.113l-65.054 65.054z" fill="currentColor"></path><path d="M77.815 403.074l65.054-65.054l31.113 31.113l-65.054 65.054z" fill="currentColor"></path><path d="M394 234h92v44h-92z" fill="currentColor"></path><path d="M26 234h92v44H26z" fill="currentColor"></path><path d="M338.029 369.14l31.112-31.113l65.054 65.054l-31.112 31.112z" fill="currentColor"></path><path d="M77.802 108.92l31.113-31.113l65.054 65.054l-31.113 31.112z" fill="currentColor"></path><path d="M256 358a102 102 0 1 1 102-102a102.12 102.12 0 0 1-102 102z" fill="currentColor"></path>', 9);

    const _hoisted_11 = [_hoisted_2$2a];
    vue.defineComponent({
      name: 'SunnySharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2a, _hoisted_11);
      }
    });

    const _hoisted_1$29 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$29 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M304 48l112 112l-112 112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1Q = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M398.87 160H96'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1d = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M208 464L96 352l112-112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$H = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M114 352h302'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$k = [_hoisted_2$29, _hoisted_3$1Q, _hoisted_4$1d, _hoisted_5$H];
    vue.defineComponent({
      name: 'SwapHorizontal',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$29, _hoisted_6$k);
      }
    });

    const _hoisted_1$28 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$28 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M304 48l112 112l-112 112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1P = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M398.87 160H96'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1c = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M208 464L96 352l112-112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$G = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M114 352h302'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$j = [_hoisted_2$28, _hoisted_3$1P, _hoisted_4$1c, _hoisted_5$G];
    vue.defineComponent({
      name: 'SwapHorizontalOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$28, _hoisted_6$j);
      }
    });

    const _hoisted_1$27 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$27 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M304 48l112 112l-112 112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1O = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M398.87 160H96'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1b = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M208 464L96 352l112-112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$F = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M114 352h302'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$i = [_hoisted_2$27, _hoisted_3$1O, _hoisted_4$1b, _hoisted_5$F];
    vue.defineComponent({
      name: 'SwapHorizontalSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$27, _hoisted_6$i);
      }
    });

    const _hoisted_1$26 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$26 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M464 208L352 96L240 208'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1N = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M352 113.13V416'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1a = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M48 304l112 112l112-112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$E = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M160 398V96'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$h = [_hoisted_2$26, _hoisted_3$1N, _hoisted_4$1a, _hoisted_5$E];
    vue.defineComponent({
      name: 'SwapVertical',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$26, _hoisted_6$h);
      }
    });

    const _hoisted_1$25 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$25 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M464 208L352 96L240 208'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1M = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M352 113.13V416'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$19 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M48 304l112 112l112-112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$D = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M160 398V96'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$g = [_hoisted_2$25, _hoisted_3$1M, _hoisted_4$19, _hoisted_5$D];
    vue.defineComponent({
      name: 'SwapVerticalOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$25, _hoisted_6$g);
      }
    });

    const _hoisted_1$24 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$24 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M464 208L352 96L240 208'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1L = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M352 113.13V416'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$18 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M48 304l112 112l112-112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$C = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M160 398V96'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$f = [_hoisted_2$24, _hoisted_3$1L, _hoisted_4$18, _hoisted_5$C];
    vue.defineComponent({
      name: 'SwapVerticalSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$24, _hoisted_6$f);
      }
    });

    const _hoisted_1$23 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$23 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M434.67 285.59v-29.8c0-98.73-80.24-178.79-179.2-178.79a179 179 0 0 0-140.14 67.36m-38.53 82v29.8C76.8 355 157 435 256 435a180.45 180.45 0 0 0 140-66.92',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1K = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M32 256l44-44l46 44'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$17 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M480 256l-44 44l-46-44'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$B = [_hoisted_2$23, _hoisted_3$1K, _hoisted_4$17];
    vue.defineComponent({
      name: 'Sync',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$23, _hoisted_5$B);
      }
    });

    const _hoisted_1$22 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$22 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.13 48 48 141.13 48 256s93.13 208 208 208s208-93.13 208-208S370.87 48 256 48zm83.69 282.65a112.24 112.24 0 0 1-195-61.29a16 16 0 0 1-20.13-24.67l23.6-23.6a16 16 0 0 1 22.37-.25l24.67 23.6a16 16 0 0 1-18 26a80.25 80.25 0 0 0 138.72 38.83a16 16 0 0 1 23.77 21.41zm47.76-63.34l-23.6 23.6a16 16 0 0 1-22.37.25l-24.67-23.6a16 16 0 0 1 17.68-26.11A80.17 80.17 0 0 0 196 202.64a16 16 0 1 1-23.82-21.37a112.17 112.17 0 0 1 194.88 61.57a16 16 0 0 1 20.39 24.47z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1J = [_hoisted_2$22];
    vue.defineComponent({
      name: 'SyncCircle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$22, _hoisted_3$1J);
      }
    });

    const _hoisted_1$21 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$21 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256c0-106-86-192-192-192S64 150 64 256s86 192 192 192s192-86 192-192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1I = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M351.82 271.87v-16A96.15 96.15 0 0 0 184.09 192m-24.2 48.17v16A96.22 96.22 0 0 0 327.81 320',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$16 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M135.87 256l23.59-23.6l24.67 23.6'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$A = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M376.13 256l-23.59 23.6l-24.67-23.6'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$e = [_hoisted_2$21, _hoisted_3$1I, _hoisted_4$16, _hoisted_5$A];
    vue.defineComponent({
      name: 'SyncCircleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$21, _hoisted_6$e);
      }
    });

    const _hoisted_1$20 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$20 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.13 48 48 141.13 48 256s93.13 208 208 208s208-93.13 208-208S370.87 48 256 48zm0 320a112.19 112.19 0 0 1-111.27-98.23l-8.86 8.86L113.24 256l46-46l47.55 45.48l-22.12 23.12l-7.2-6.88a80.26 80.26 0 0 0 138.48 37.5l23.77 21.41A112.82 112.82 0 0 1 256 368zm96.79-66l-47.55-45.5l22.12-23.12l6.86 6.55A80.2 80.2 0 0 0 196 202.64l-23.82-21.37A112.18 112.18 0 0 1 367 242.49l9.11-9.12L398.76 256z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1H = [_hoisted_2$20];
    vue.defineComponent({
      name: 'SyncCircleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$20, _hoisted_3$1H);
      }
    });

    const _hoisted_1$1$ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1$ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M434.67 285.59v-29.8c0-98.73-80.24-178.79-179.2-178.79a179 179 0 0 0-140.14 67.36m-38.53 82v29.8C76.8 355 157 435 256 435a180.45 180.45 0 0 0 140-66.92',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1G = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M32 256l44-44l46 44'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$15 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M480 256l-44 44l-46-44'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$z = [_hoisted_2$1$, _hoisted_3$1G, _hoisted_4$15];
    vue.defineComponent({
      name: 'SyncOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1$, _hoisted_5$z);
      }
    });

    const _hoisted_1$1_ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1_ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M434.67 285.59v-29.8c0-98.73-80.24-178.79-179.2-178.79a179 179 0 0 0-140.14 67.36m-38.53 82v29.8C76.8 355 157 435 256 435a180.45 180.45 0 0 0 140-66.92',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1F = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M32 256l44-44l46 44'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$14 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M480 256l-44 44l-46-44'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$y = [_hoisted_2$1_, _hoisted_3$1F, _hoisted_4$14];
    vue.defineComponent({
      name: 'SyncSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1_, _hoisted_5$y);
      }
    });

    const _hoisted_1$1Z = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1Z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M512 128v256a64.07 64.07 0 0 1-64 64H64a64.07 64.07 0 0 1-64-64V128a64.07 64.07 0 0 1 64-64h384a64.07 64.07 0 0 1 64 64zM32 384a32 32 0 0 0 32 32h384a32 32 0 0 0 32-32V128a32 32 0 0 0-32-32H64a32 32 0 0 0-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1E = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M0 128a64.07 64.07 0 0 1 64-64h384a64.07 64.07 0 0 1 64 64v256a64.07 64.07 0 0 1-64 64H64a64.07 64.07 0 0 1-64-64V128m480 256V128a32 32 0 0 0-32-32H64a32 32 0 0 0-32 32v256a32 32 0 0 0 32 32h384a32 32 0 0 0 32-32m-16 0a16 16 0 0 1-16 16H64a16 16 0 0 1-16-16V128a16 16 0 0 1 16-16h384a16 16 0 0 1 16 16v256z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$13 = [_hoisted_2$1Z, _hoisted_3$1E];
    vue.defineComponent({
      name: 'TabletLandscape',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1Z, _hoisted_4$13);
      }
    });

    const _hoisted_1$1Y = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1Y = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '80',
      y: '16',
      width: '352',
      height: '480',
      rx: '48',
      ry: '48',
      transform: 'rotate(-90 256 256)',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1D = [_hoisted_2$1Y];
    vue.defineComponent({
      name: 'TabletLandscapeOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1Y, _hoisted_3$1D);
      }
    });

    const _hoisted_1$1X = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1X = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M0 82v348a18 18 0 0 0 18 18h476a18 18 0 0 0 18-18V82a18 18 0 0 0-18-18H18A18 18 0 0 0 0 82zm448 330H64V100h384z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1C = [_hoisted_2$1X];
    vue.defineComponent({
      name: 'TabletLandscapeSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1X, _hoisted_3$1C);
      }
    });

    const _hoisted_1$1W = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1W = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 512H128a64.07 64.07 0 0 1-64-64V64a64.07 64.07 0 0 1 64-64h256a64.07 64.07 0 0 1 64 64v384a64.07 64.07 0 0 1-64 64zM128 32a32 32 0 0 0-32 32v384a32 32 0 0 0 32 32h256a32 32 0 0 0 32-32V64a32 32 0 0 0-32-32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1B = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 0a64.07 64.07 0 0 1 64 64v384a64.07 64.07 0 0 1-64 64H128a64.07 64.07 0 0 1-64-64V64a64.07 64.07 0 0 1 64-64h256M128 480h256a32 32 0 0 0 32-32V64a32 32 0 0 0-32-32H128a32 32 0 0 0-32 32v384a32 32 0 0 0 32 32m0-16a16 16 0 0 1-16-16V64a16 16 0 0 1 16-16h256a16 16 0 0 1 16 16v384a16 16 0 0 1-16 16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$12 = [_hoisted_2$1W, _hoisted_3$1B];
    vue.defineComponent({
      name: 'TabletPortrait',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1W, _hoisted_4$12);
      }
    });

    const _hoisted_1$1V = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1V = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '80',
      y: '16',
      width: '352',
      height: '480',
      rx: '48',
      ry: '48',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1A = [_hoisted_2$1V];
    vue.defineComponent({
      name: 'TabletPortraitOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1V, _hoisted_3$1A);
      }
    });

    const _hoisted_1$1U = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1U = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M430 0H82a18 18 0 0 0-18 18v476a18 18 0 0 0 18 18h348a18 18 0 0 0 18-18V18a18 18 0 0 0-18-18zM100 448V64h312v384z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1z = [_hoisted_2$1U];
    vue.defineComponent({
      name: 'TabletPortraitSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1U, _hoisted_3$1z);
      }
    });

    const _hoisted_1$1T = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1T = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M107.56 250a16 16 0 0 0-21.85-5.86L36 272.81a39.71 39.71 0 0 0-18.8 24.91a40.9 40.9 0 0 0 4.55 30.35l4.36 7.54a40 40 0 0 0 54.62 14.62l49.67-28.63a16 16 0 0 0 5.87-21.86z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M382.84 440.8L288.72 254a2 2 0 0 1 .79-2.63l8.3-4.79a16 16 0 0 0 5.86-21.86l-47.53-82.33a16 16 0 0 0-21.86-5.87l-86.38 49.8a39.73 39.73 0 0 0-18.65 24.28a34.82 34.82 0 0 0-1.37 9.76c.06 7.6 9.2 22.7 18.12 38.28c9.59 16.75 19.24 33.88 26.34 38.15c4.52 2.72 12.5 4.9 19.21 4.9h.84l-79.32 171.6a16 16 0 1 0 29.05 13.42l93.68-202.65a7.94 7.94 0 0 1 3.26-3.57l19.21-11.08a2 2 0 0 1 2.78.84l93.21 185a16 16 0 0 0 28.58-14.4z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$11 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M490.21 115.74L444.09 36a40.08 40.08 0 0 0-54.63-14.62l-93.34 53.78a39.69 39.69 0 0 0-18.65 24.28a32.76 32.76 0 0 0-1.27 13.25c1.74 12.62 13 30.4 26.41 53.89c13.58 23.73 28.91 50.48 36.93 56.27a40.18 40.18 0 0 0 23.18 7.37a39.77 39.77 0 0 0 19.92-5.34L476 171.07a39.72 39.72 0 0 0 18.79-24.84a41 41 0 0 0-4.58-30.49z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$x = [_hoisted_2$1T, _hoisted_3$1y, _hoisted_4$11];
    vue.defineComponent({
      name: 'Telescope',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1T, _hoisted_5$x);
      }
    });

    const _hoisted_1$1S = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1S = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M39.93 327.56l-4.71-8.13A24 24 0 0 1 44 286.64l86.87-50.07a16 16 0 0 1 21.89 5.86l12.71 22a16 16 0 0 1-5.86 21.85l-86.85 50.07a24.06 24.06 0 0 1-32.83-8.79z"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M170.68 273.72L147.12 233a24 24 0 0 1 8.8-32.78l124.46-71.75a16 16 0 0 1 21.89 5.86l31.57 54.59a16 16 0 0 1-5.84 21.84L203.51 282.5a24 24 0 0 1-32.83-8.78z"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M341.85 202.21l-46.51-80.43a24 24 0 0 1 8.8-32.78l93.29-53.78A24.07 24.07 0 0 1 430.27 44l46.51 80.43a24 24 0 0 1-8.8 32.79L374.69 211a24.06 24.06 0 0 1-32.84-8.79z"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M127.59 480l96.14-207.99"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M271.8 256.02L368.55 448"></path>', 5);

    const _hoisted_7$e = [_hoisted_2$1S];
    vue.defineComponent({
      name: 'TelescopeOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1S, _hoisted_7$e);
      }
    });

    const _hoisted_1$1R = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1R = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M1.41 292.9l44.82 76.97l98.14-56.38l-44.73-77.37L1.41 292.9z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1x = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M287.87 252.34l23.67-13.81l-63.42-110l-132.92 77C133.75 237.51 176 310 176 310l15.53-8.32c.24-.13.55 0 .83 0L102.65 496h35.16l99.05-214.25l23.24-13.4L358 464h36z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$10 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M262.08 96c24.81 42.23 60.25 104.25 86.4 148.76L510.79 151L424.07 1.41z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$w = [_hoisted_2$1R, _hoisted_3$1x, _hoisted_4$10];
    vue.defineComponent({
      name: 'TelescopeSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1R, _hoisted_5$w);
      }
    });

    const _hoisted_1$1Q = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1Q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 256a192.55 192.55 0 0 0 32-2.68A224 224 0 0 0 258.68 32A192.55 192.55 0 0 0 256 64c0 105.87 86.13 192 192 192z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1w = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M253.35 480c.94-5.67 1.65-11.4 2.09-17.18c.37-4.88.56-9.86.56-14.79c0-105.87-86.13-192-192-192a192.55 192.55 0 0 0-32 2.68A224 224 0 0 0 253.35 480z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$$ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M289.61 222.39A222.53 222.53 0 0 1 224 64a226.07 226.07 0 0 1 2-30A224.1 224.1 0 0 0 34 226a226.07 226.07 0 0 1 30-2a222.53 222.53 0 0 1 158.39 65.61A222.53 222.53 0 0 1 288 448c0 5.74-.22 11.53-.65 17.22q-.5 6.42-1.36 12.79A224.12 224.12 0 0 0 478 286a226.07 226.07 0 0 1-30 2a222.53 222.53 0 0 1-158.39-65.61z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$v = [_hoisted_2$1Q, _hoisted_3$1w, _hoisted_4$$];
    vue.defineComponent({
      name: 'Tennisball',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1Q, _hoisted_5$v);
      }
    });

    const _hoisted_1$1P = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1P = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '256',
      r: '208',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1v = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M461.43 271.44c-5.09.37-8.24.56-13.43.56c-114.88 0-208-93.12-208-208c0-5.37.2-8.69.6-14',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$_ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M49.65 240.56S58.84 240 64 240c114.88 0 208 93.12 208 208c0 5.38-.61 14-.61 14',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$u = [_hoisted_2$1P, _hoisted_3$1v, _hoisted_4$_];
    vue.defineComponent({
      name: 'TennisballOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1P, _hoisted_5$u);
      }
    });

    const _hoisted_1$1O = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1O = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M246.4 480a181 181 0 0 0 3.22-22.86c.35-4.61.53-9.31.53-14c0-100-81.34-181.32-181.32-181.32A181.72 181.72 0 0 0 32 265.61A224.2 224.2 0 0 0 246.4 480z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1u = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M284.63 227.37A222.73 222.73 0 0 1 219 68.83a227.09 227.09 0 0 1 2.62-34.42A224.41 224.41 0 0 0 34.41 221.58A227.09 227.09 0 0 1 68.83 219a222.73 222.73 0 0 1 158.54 65.67A222.73 222.73 0 0 1 293 443.17c0 5.74-.22 11.54-.65 17.23s-1.11 11.51-2 17.2a224.42 224.42 0 0 0 187.24-187.18a227.09 227.09 0 0 1-34.42 2.58a222.73 222.73 0 0 1-158.54-65.63z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$Z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M443.17 250.15a181.72 181.72 0 0 0 36.83-3.76A224.2 224.2 0 0 0 265.61 32a181.72 181.72 0 0 0-3.76 36.83c0 99.98 81.34 181.32 181.32 181.32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$t = [_hoisted_2$1O, _hoisted_3$1u, _hoisted_4$Z];
    vue.defineComponent({
      name: 'TennisballSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1O, _hoisted_5$t);
      }
    });

    const _hoisted_1$1N = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1N = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M432 32H80a64.07 64.07 0 0 0-64 64v320a64.07 64.07 0 0 0 64 64h352a64.07 64.07 0 0 0 64-64V96a64.07 64.07 0 0 0-64-64zM96 256a16 16 0 0 1-10-28.49L150.39 176L86 124.49a16 16 0 1 1 20-25l80 64a16 16 0 0 1 0 25l-80 64A16 16 0 0 1 96 256zm160 0h-64a16 16 0 0 1 0-32h64a16 16 0 0 1 0 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1t = [_hoisted_2$1N];
    vue.defineComponent({
      name: 'Terminal',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1N, _hoisted_3$1t);
      }
    });

    const _hoisted_1$1M = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1M = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '32',
      y: '48',
      width: '448',
      height: '416',
      rx: '48',
      ry: '48',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1s = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M96 112l80 64l-80 64'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$Y = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M192 240h64'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$s = [_hoisted_2$1M, _hoisted_3$1s, _hoisted_4$Y];
    vue.defineComponent({
      name: 'TerminalOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1M, _hoisted_5$s);
      }
    });

    const _hoisted_1$1L = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1L = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M16 44v424a12 12 0 0 0 12 12h456a12 12 0 0 0 12-12V44a12 12 0 0 0-12-12H28a12 12 0 0 0-12 12zm57.51 193.5l76.88-61.5l-76.88-61.5l20-25l108.1 86.5L93.5 262.49zM272 256h-96v-32h96z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1r = [_hoisted_2$1L];
    vue.defineComponent({
      name: 'TerminalSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1L, _hoisted_3$1r);
      }
    });

    const _hoisted_1$1K = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1K = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M292.6 407.78l-120-320a22 22 0 0 0-41.2 0l-120 320a22 22 0 0 0 41.2 15.44l36.16-96.42a2 2 0 0 1 1.87-1.3h122.74a2 2 0 0 1 1.87 1.3l36.16 96.42a22 22 0 0 0 41.2-15.44zm-185.84-129l43.37-115.65a2 2 0 0 1 3.74 0l43.37 115.67a2 2 0 0 1-1.87 2.7h-86.74a2 2 0 0 1-1.87-2.7z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400.77 169.5c-41.72-.3-79.08 23.87-95 61.4a22 22 0 0 0 40.5 17.2c8.88-20.89 29.77-34.44 53.32-34.6c32.32-.22 58.41 26.5 58.41 58.85a1.5 1.5 0 0 1-1.45 1.5c-21.92.61-47.92 2.07-71.12 4.8c-54.75 6.44-87.43 36.29-87.43 79.85c0 23.19 8.76 44 24.67 58.68C337.6 430.93 358 438.5 380 438.5c31 0 57.69-8 77.94-23.22h.06a22 22 0 1 0 44 .19v-143c0-56.18-45-102.56-101.23-102.97zM380 394.5c-17.53 0-38-9.43-38-36c0-10.67 3.83-18.14 12.43-24.23c8.37-5.93 21.2-10.16 36.14-11.92c21.12-2.49 44.82-3.86 65.14-4.47a2 2 0 0 1 2 2.1C455 370.1 429.46 394.5 380 394.5z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$X = [_hoisted_2$1K, _hoisted_3$1q];
    vue.defineComponent({
      name: 'Text',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1K, _hoisted_4$X);
      }
    });

    const _hoisted_1$1J = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1J = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M32 415.5l120-320l120 320'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1p = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M230 303.5H74'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$W = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M326 239.5c12.19-28.69 41-48 74-48h0c46 0 80 32 80 80v144',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$r = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 358.5c0 36 26.86 58 60 58c54 0 100-27 100-106v-15c-20 0-58 1-92 5c-32.77 3.86-68 19-68 58z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$d = [_hoisted_2$1J, _hoisted_3$1p, _hoisted_4$W, _hoisted_5$r];
    vue.defineComponent({
      name: 'TextOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1J, _hoisted_6$d);
      }
    });

    const _hoisted_1$1I = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1I = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M404.42 170c-41.23 0-78.07 24.06-93.85 61.3L304 246.52l40.33 17.18l6.56-15.22c8.9-21 29.91-34.55 53.53-34.55c34.55 0 57.76 23.27 57.76 57.91v2.3c-22.12.59-48.65 2.05-72.27 4.84c-54.52 6.43-87.06 36.23-87.06 79.72c0 23.16 8.72 44 24.56 58.59C342.28 431 362.55 438 384.51 438c30.86 0 57.5-7.33 77.67-22.64V438H506V271.84C506 212.83 463.28 170 404.42 170zm-19.91 225.07c-17.46 0-37.85-9.84-37.85-36.37c0-10.65 3.82-18.11 12.38-24.19c8.34-5.92 21.12-10.15 36-11.9c21.78-2.57 46.31-3.95 67-4.52c-2.16 51.49-27.57 76.98-77.53 76.98z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1o = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M93.25 325.87h125.5L260.94 438H308L155 48L4 438h47.06zM156 160.71L202.25 282h-92.5z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$V = [_hoisted_2$1I, _hoisted_3$1o];
    vue.defineComponent({
      name: 'TextSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1I, _hoisted_4$V);
      }
    });

    const _hoisted_1$1H = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1H = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 287.18V81c0-35.12-27.89-64.42-63-64.95a64.08 64.08 0 0 0-65 64v207.13a8 8 0 0 1-3.18 6.37A113.48 113.48 0 0 0 144 384a112 112 0 0 0 224 0a113.48 113.48 0 0 0-44.82-90.45a8 8 0 0 1-3.18-6.37zM254.07 432a48 48 0 0 1-22-89.54a16 16 0 0 0 8-13.84V112.45c0-8.61 6.62-16 15.23-16.43A16 16 0 0 1 272 112v216.58a16.18 16.18 0 0 0 8.15 13.94A48 48 0 0 1 254.07 432z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1n = [_hoisted_2$1H];
    vue.defineComponent({
      name: 'Thermometer',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1H, _hoisted_3$1n);
      }
    });

    const _hoisted_1$1G = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1G = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M307.72 302.27a8 8 0 0 1-3.72-6.75V80a48 48 0 0 0-48-48h0a48 48 0 0 0-48 48v215.52a8 8 0 0 1-3.71 6.74a97.51 97.51 0 0 0-44.19 86.07A96 96 0 0 0 352 384a97.49 97.49 0 0 0-44.28-81.73z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1m = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M256 112v272'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$U = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256',
      cy: '384',
      r: '48',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$q = [_hoisted_2$1G, _hoisted_3$1m, _hoisted_4$U];
    vue.defineComponent({
      name: 'ThermometerOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1G, _hoisted_5$q);
      }
    });

    const _hoisted_1$1F = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1F = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 291.24V80a64 64 0 1 0-128 0v211.24A113.39 113.39 0 0 0 144 384a112 112 0 0 0 224 0a113.39 113.39 0 0 0-48-92.76zM256 432a48 48 0 0 1-16-93.26V96h32v242.74A48 48 0 0 1 256 432z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1l = [_hoisted_2$1F];
    vue.defineComponent({
      name: 'ThermometerSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1F, _hoisted_3$1l);
      }
    });

    const _hoisted_1$1E = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1E = /*#__PURE__*/vue.createStaticVNode('<path d="M39.94 178l144.16 6.12c4.61.36 23.9 1.22 23.9 25.88c0 23.8-19.16 25.33-24.14 25.88L39.94 242C27.27 241.87 16 227.56 16 210s11.27-31.87 23.94-32zm141.45 131.66L74.65 318C62 318 48 301.31 48 284.12v-.33c0-16.33 11.14-29.63 24.88-29.79l108.45 1.72C208 259 208 275.16 208 282.12c0 22.88-21.8 27.14-26.61 27.54zM90.15 32l89.37 8.93C204 41.86 208 58.18 208 68.4c0 18.39-13.41 24.6-26.67 24.6l-91 3C75.78 95.78 64 81.51 64 64s11.68-31.66 26.15-32zm-34.36 71.5l126.4 6.22c9.39.63 25.81 3 25.81 26.36c0 12-4.35 25.62-25 27.53L55.79 167.5C42.65 167.35 32 154 32 136.08s10.65-32.43 23.79-32.58z" fill="currentColor"></path><path d="M378.45 273.93A15.84 15.84 0 0 1 386 272a15.93 15.93 0 0 0-7.51 1.91z" fill="none"></path><path d="M337.86 343.22l-.13.22a2.53 2.53 0 0 1 .13-.22c20.5-35.51 30.36-55 33.82-62c-3.47 7.06-13.34 26.51-33.82 62z" fill="none"></path><path d="M372.66 279.16l-1 2a16.29 16.29 0 0 1 6.77-7.26a16.48 16.48 0 0 0-5.77 5.26z" fill="currentColor"></path><path d="M195.94 459.38C205.37 472.67 221 480 240 480a16 16 0 0 0 14.31-8.85c3-6.06 15.25-24 28.19-42.9c18-26.33 40.35-59.08 55.23-84.81l.13-.22c20.48-35.49 30.35-54.94 33.82-62l1-2a16.48 16.48 0 0 1 5.79-5.23A15.93 15.93 0 0 1 386 272h25.32A84.7 84.7 0 0 0 496 187.3v-38.6A84.7 84.7 0 0 0 411.31 64h-48.79a17.46 17.46 0 0 1-9.58-2.89C330 46.13 286.66 32 240 32c-7.45 0-14.19.14-20.27.38a8 8 0 0 0-6.2 12.68l.1.14C222.2 57.59 224 71 224 80a61.16 61.16 0 0 1-5.19 24.77a17.38 17.38 0 0 0 0 14.06a63.81 63.81 0 0 1 0 50.39a17.32 17.32 0 0 0 0 14a62.13 62.13 0 0 1 0 49.58a18.13 18.13 0 0 0 0 14.68A60.41 60.41 0 0 1 224 273c0 8.2-2 21.3-8 31.18a15.66 15.66 0 0 0-1.14 13.65c.38 1 .76 2.06 1.13 3.17a24.8 24.8 0 0 1 .86 11.57c-3 19.35-9.67 36.3-16.74 54.16c-3.08 7.78-6.27 15.82-9.22 24.27c-6.14 17.56-4.3 35.2 5.05 48.38z" fill="currentColor"></path>', 5);

    const _hoisted_7$d = [_hoisted_2$1E];
    vue.defineComponent({
      name: 'ThumbsDown',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1E, _hoisted_7$d);
      }
    });

    const _hoisted_1$1D = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1D = /*#__PURE__*/vue.createStaticVNode('<path d="M192 53.84S208 48 256 48s74 16 96 32h64a64 64 0 0 1 64 64v48a64 64 0 0 1-64 64h-30a32.34 32.34 0 0 0-27.37 15.4S350 290.19 324 335.22S248 448 240 464c-29 0-43-22-34-47.71c10.28-29.39 23.71-54.38 27.46-87.09c.54-4.78-3.14-12-8-12L96 307" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M96 241l80 2c20 1.84 32 12.4 32 30h0c0 17.6-14 28.84-32 30l-80 4c-17.6 0-32-16.4-32-34v-.17A32 32 0 0 1 96 241z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path d="M64 176l112 2c18 .84 32 12.41 32 30h0c0 17.61-14 28.86-32 30l-112 2a32.1 32.1 0 0 1-32-32h0a32.1 32.1 0 0 1 32-32z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path d="M112 48l64 3c21 1.84 32 11.4 32 29h0c0 17.6-14.4 30-32 30l-64 2a32.09 32.09 0 0 1-32-32h0a32.09 32.09 0 0 1 32-32z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path d="M80 112l96 2c19 .84 32 12.4 32 30h0c0 17.6-13 28.84-32 30l-96 2a32.09 32.09 0 0 1-32-32h0a32.09 32.09 0 0 1 32-32z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path>', 5);

    const _hoisted_7$c = [_hoisted_2$1D];
    vue.defineComponent({
      name: 'ThumbsDownOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1D, _hoisted_7$c);
      }
    });

    const _hoisted_1$1C = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1C = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M56 320l156.05 12l-23 89.4c-6.08 26.6.7 41.87 22.39 48.62l34.69 9.85a4 4 0 0 0 4.4-1.72l129-202.34a8 8 0 0 1 6.81-3.81H496V64H378.39a48 48 0 0 1-15.18-2.46l-76.3-25.43a80 80 0 0 0-25.3-4.11H83.68c-19 0-31.5 13.52-35.23 32.16L16 206.42V280c0 22.06 18 38 40 40z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1k = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M378.45 273.93A15.84 15.84 0 0 1 386 272a15.93 15.93 0 0 0-7.51 1.91z',
      fill: 'none'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$T = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M337.86 343.22l-.13.22a2.53 2.53 0 0 1 .13-.22c20.5-35.51 30.36-55 33.82-62c-3.47 7.06-13.34 26.51-33.82 62z',
      fill: 'none'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$p = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M372.66 279.16l-1 2a16.29 16.29 0 0 1 6.77-7.26a16.48 16.48 0 0 0-5.77 5.26z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$c = [_hoisted_2$1C, _hoisted_3$1k, _hoisted_4$T, _hoisted_5$p];
    vue.defineComponent({
      name: 'ThumbsDownSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1C, _hoisted_6$c);
      }
    });

    const _hoisted_1$1B = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1B = /*#__PURE__*/vue.createStaticVNode('<path d="M472.06 334l-144.16-6.13c-4.61-.36-23.9-1.21-23.9-25.87c0-23.81 19.16-25.33 24.14-25.88L472.06 270c12.67.13 23.94 14.43 23.94 32s-11.27 31.87-23.94 32zM330.61 202.33L437.35 194C450 194 464 210.68 464 227.88v.33c0 16.32-11.14 29.62-24.88 29.79l-108.45-1.73C304 253 304 236.83 304 229.88c0-22.88 21.8-27.15 26.61-27.55zM421.85 480l-89.37-8.93C308 470.14 304 453.82 304 443.59c0-18.38 13.41-24.6 26.67-24.6l91-3c14.54.23 26.32 14.5 26.32 32s-11.67 31.67-26.14 32.01zm34.36-71.5l-126.4-6.21c-9.39-.63-25.81-3-25.81-26.37c0-12 4.35-25.61 25-27.53l127.19-3.88c13.16.14 23.81 13.49 23.81 31.4s-10.65 32.43-23.79 32.58z" fill="currentColor"></path><path d="M133.55 238.06A15.85 15.85 0 0 1 126 240a15.82 15.82 0 0 0 7.51-1.92z" fill="none"></path><path d="M174.14 168.78l.13-.23l-.13.23c-20.5 35.51-30.36 54.95-33.82 62c3.47-7.07 13.34-26.51 33.82-62z" fill="none"></path><path d="M139.34 232.84l1-2a16.27 16.27 0 0 1-6.77 7.25a16.35 16.35 0 0 0 5.77-5.25z" fill="currentColor"></path><path d="M316.06 52.62C306.63 39.32 291 32 272 32a16 16 0 0 0-14.31 8.84c-3 6.07-15.25 24-28.19 42.91c-18 26.33-40.35 59.07-55.23 84.8l-.13.23c-20.48 35.49-30.35 54.93-33.82 62l-1 2a16.35 16.35 0 0 1-5.79 5.22a15.82 15.82 0 0 1-7.53 2h-25.31A84.69 84.69 0 0 0 16 324.69v38.61a84.69 84.69 0 0 0 84.69 84.7h48.79a17.55 17.55 0 0 1 9.58 2.89C182 465.87 225.34 480 272 480c7.45 0 14.19-.14 20.27-.38a8 8 0 0 0 6.2-12.68l-.1-.14C289.8 454.41 288 441 288 432a61.2 61.2 0 0 1 5.19-24.77a17.36 17.36 0 0 0 0-14.05a63.81 63.81 0 0 1 0-50.39a17.32 17.32 0 0 0 0-14a62.15 62.15 0 0 1 0-49.59a18.13 18.13 0 0 0 0-14.68A60.33 60.33 0 0 1 288 239c0-8.2 2-21.3 8-31.19a15.63 15.63 0 0 0 1.14-13.64c-.38-1-.76-2.07-1.13-3.17a24.84 24.84 0 0 1-.86-11.58c3-19.34 9.67-36.29 16.74-54.16c3.08-7.78 6.27-15.82 9.22-24.26c6.14-17.57 4.3-35.2-5.05-48.38z" fill="currentColor"></path>', 5);

    const _hoisted_7$b = [_hoisted_2$1B];
    vue.defineComponent({
      name: 'ThumbsUp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1B, _hoisted_7$b);
      }
    });

    const _hoisted_1$1A = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1A = /*#__PURE__*/vue.createStaticVNode('<path d="M320 458.16S304 464 256 464s-74-16-96-32H96a64 64 0 0 1-64-64v-48a64 64 0 0 1 64-64h30a32.34 32.34 0 0 0 27.37-15.4S162 221.81 188 176.78S264 64 272 48c29 0 43 22 34 47.71c-10.28 29.39-23.71 54.38-27.46 87.09c-.54 4.78 3.14 12 7.95 12L416 205" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M416 271l-80-2c-20-1.84-32-12.4-32-30h0c0-17.6 14-28.84 32-30l80-4c17.6 0 32 16.4 32 34v.17A32 32 0 0 1 416 271z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path d="M448 336l-112-2c-18-.84-32-12.41-32-30h0c0-17.61 14-28.86 32-30l112-2a32.1 32.1 0 0 1 32 32h0a32.1 32.1 0 0 1-32 32z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path d="M400 464l-64-3c-21-1.84-32-11.4-32-29h0c0-17.6 14.4-30 32-30l64-2a32.09 32.09 0 0 1 32 32h0a32.09 32.09 0 0 1-32 32z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path><path d="M432 400l-96-2c-19-.84-32-12.4-32-30h0c0-17.6 13-28.84 32-30l96-2a32.09 32.09 0 0 1 32 32h0a32.09 32.09 0 0 1-32 32z" fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32"></path>', 5);

    const _hoisted_7$a = [_hoisted_2$1A];
    vue.defineComponent({
      name: 'ThumbsUpOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1A, _hoisted_7$a);
      }
    });

    const _hoisted_1$1z = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M456 192l-156-12l23-89.4c6-26.6-.78-41.87-22.47-48.6l-34.69-9.85a4 4 0 0 0-4.4 1.72l-129 202.34a8 8 0 0 1-6.81 3.81H16V448h117.61a48 48 0 0 1 15.18 2.46l76.3 25.43a80 80 0 0 0 25.3 4.11h177.93c19 0 31.5-13.52 35.23-32.16L496 305.58V232c0-22.06-18-38-40-40z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1j = [_hoisted_2$1z];
    vue.defineComponent({
      name: 'ThumbsUpSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1z, _hoisted_3$1j);
      }
    });

    const _hoisted_1$1y = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1y = /*#__PURE__*/vue.createStaticVNode('<path d="M96 416a16 16 0 0 1-14.3-23.16l24-48a16 16 0 0 1 28.62 14.32l-24 48A16 16 0 0 1 96 416z" fill="currentColor"></path><path d="M120 480a16 16 0 0 1-14.3-23.16l16-32a16 16 0 0 1 28.62 14.32l-16 32A16 16 0 0 1 120 480z" fill="currentColor"></path><path d="M376 416a16 16 0 0 1-14.3-23.16l24-48a16 16 0 0 1 28.62 14.32l-24 48A16 16 0 0 1 376 416z" fill="currentColor"></path><path d="M400 480a16 16 0 0 1-14.3-23.16l16-32a16 16 0 0 1 28.62 14.32l-16 32A16 16 0 0 1 400 480z" fill="currentColor"></path><path d="M405.84 136.9a151.25 151.25 0 0 0-47.6-81.9a153 153 0 0 0-241.81 51.86C60.5 110.16 16 156.65 16 213.33C16 272.15 63.91 320 122.8 320h66.31l-12.89 77.37A16 16 0 0 0 192 416h32v64a16 16 0 0 0 29 9.3l80-112a16 16 0 0 0-13-25.3h-27.51l8-32h103.84a91.56 91.56 0 0 0 1.51-183.1z" fill="currentColor"></path>', 5);

    const _hoisted_7$9 = [_hoisted_2$1y];
    vue.defineComponent({
      name: 'Thunderstorm',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1y, _hoisted_7$9);
      }
    });

    const _hoisted_1$1x = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1x = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M120 352l-24 48"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M136 432l-16 32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M400 352l-24 48"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M416 432l-16 32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M208 304l-16 96h48v80l80-112h-48l16-64"></path><path d="M404.33 152.89H392.2C384.71 84.85 326.14 32 256 32a136.39 136.39 0 0 0-128.63 90.67h-4.57c-49.94 0-90.8 40.8-90.8 90.66h0C32 263.2 72.86 304 122.8 304h281.53C446 304 480 270 480 228.44h0c0-41.55-34-75.55-75.67-75.55z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 6);

    const _hoisted_8$4 = [_hoisted_2$1x];
    vue.defineComponent({
      name: 'ThunderstormOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1x, _hoisted_8$4);
      }
    });

    const _hoisted_1$1w = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1w = /*#__PURE__*/vue.createStaticVNode('<path d="M405.84 136.9a151.25 151.25 0 0 0-47.6-81.9a153 153 0 0 0-241.81 51.86C60.5 110.16 16 156.65 16 213.33C16 272.15 63.91 320 122.8 320h72.31L176 416h48v80l112-144h-43.51l8-32h103.84a91.56 91.56 0 0 0 1.51-183.1z" fill="currentColor"></path><path d="M74.53 407.177l38.32-76.622l28.62 14.313l-38.32 76.623z" fill="currentColor"></path><path d="M98.52 471.189l30.318-60.622l28.62 14.313l-30.317 60.622z" fill="currentColor"></path><path d="M354.541 407.189l38.32-76.623l28.62 14.314l-38.32 76.622z" fill="currentColor"></path><path d="M378.542 471.2l30.317-60.622l28.62 14.314l-30.317 60.621z" fill="currentColor"></path>', 5);

    const _hoisted_7$8 = [_hoisted_2$1w];
    vue.defineComponent({
      name: 'ThunderstormSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1w, _hoisted_7$8);
      }
    });

    const _hoisted_1$1v = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1v = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M490.18 181.4l-44.13-44.13a20 20 0 0 0-27-1a30.81 30.81 0 0 1-41.68-1.6a30.81 30.81 0 0 1-1.6-41.67a20 20 0 0 0-1-27L330.6 21.82a19.91 19.91 0 0 0-28.13 0l-70.35 70.34a39.87 39.87 0 0 0-9.57 15.5a7.71 7.71 0 0 1-4.83 4.83a39.78 39.78 0 0 0-15.5 9.58l-180.4 180.4a19.91 19.91 0 0 0 0 28.13L66 374.73a20 20 0 0 0 27 1a30.69 30.69 0 0 1 43.28 43.28a20 20 0 0 0 1 27l44.13 44.13a19.91 19.91 0 0 0 28.13 0l180.4-180.4a39.82 39.82 0 0 0 9.58-15.49a7.69 7.69 0 0 1 4.84-4.84a39.84 39.84 0 0 0 15.49-9.57l70.34-70.35a19.91 19.91 0 0 0-.01-28.09zm-228.37-29.65a16 16 0 0 1-22.63 0l-11.51-11.51a16 16 0 0 1 22.63-22.62l11.51 11.5a16 16 0 0 1 0 22.63zm44 44a16 16 0 0 1-22.62 0l-11-11a16 16 0 1 1 22.63-22.63l11 11a16 16 0 0 1 .01 22.66zm44 44a16 16 0 0 1-22.63 0l-11-11a16 16 0 0 1 22.63-22.62l11 11a16 16 0 0 1 .05 22.67zm44.43 44.54a16 16 0 0 1-22.63 0l-11.44-11.5a16 16 0 1 1 22.68-22.57l11.45 11.49a16 16 0 0 1-.01 22.63z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1i = [_hoisted_2$1v];
    vue.defineComponent({
      name: 'Ticket',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1v, _hoisted_3$1i);
      }
    });

    const _hoisted_1$1u = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1u = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32" d="M366.05 146a46.7 46.7 0 0 1-2.42-63.42a3.87 3.87 0 0 0-.22-5.26l-44.13-44.18a3.89 3.89 0 0 0-5.5 0l-70.34 70.34a23.62 23.62 0 0 0-5.71 9.24h0a23.66 23.66 0 0 1-14.95 15h0a23.7 23.7 0 0 0-9.25 5.71L33.14 313.78a3.89 3.89 0 0 0 0 5.5l44.13 44.13a3.87 3.87 0 0 0 5.26.22a46.69 46.69 0 0 1 65.84 65.84a3.87 3.87 0 0 0 .22 5.26l44.13 44.13a3.89 3.89 0 0 0 5.5 0l180.4-180.39a23.7 23.7 0 0 0 5.71-9.25h0a23.66 23.66 0 0 1 14.95-15h0a23.62 23.62 0 0 0 9.24-5.71l70.34-70.34a3.89 3.89 0 0 0 0-5.5l-44.13-44.13a3.87 3.87 0 0 0-5.26-.22a46.7 46.7 0 0 1-63.42-2.32z"></path><path fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32" stroke-linecap="round" d="M250.5 140.44l-16.51-16.51"></path><path fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32" stroke-linecap="round" d="M294.52 184.46l-11.01-11"></path><path fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32" stroke-linecap="round" d="M338.54 228.49l-11-11.01"></path><path fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="32" stroke-linecap="round" d="M388.07 278.01l-16.51-16.51"></path>', 5);

    const _hoisted_7$7 = [_hoisted_2$1u];
    vue.defineComponent({
      name: 'TicketOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1u, _hoisted_7$7);
      }
    });

    const _hoisted_1$1t = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1t = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M426.24 127.72l-10.94 10.94a29.67 29.67 0 0 1-42-42l10.94-10.94L314.52 16l-88 88l-4 12.09l-12.09 4L16 314.52l69.76 69.76l10.94-10.94a29.67 29.67 0 0 1 42 42l-10.94 10.94L197.48 496l194.4-194.4l4-12.09l12.09-4l88-88zm-208.56 5.43l21.87-21.87l33 33l-21.88 21.87zm43 43l21.88-21.88l32.52 32.52l-21.88 21.88zm42.56 42.56l21.88-21.88l32.52 32.52l-21.84 21.93zm75.57 75.56l-33-33l21.87-21.88l33 33z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1h = [_hoisted_2$1t];
    vue.defineComponent({
      name: 'TicketSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1t, _hoisted_3$1h);
      }
    });

    const _hoisted_1$1s = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1s = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.13 48 48 141.13 48 256s93.13 208 208 208s208-93.13 208-208S370.87 48 256 48zm96 240h-96a16 16 0 0 1-16-16V128a16 16 0 0 1 32 0v128h80a16 16 0 0 1 0 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1g = [_hoisted_2$1s];
    vue.defineComponent({
      name: 'Time',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1s, _hoisted_3$1g);
      }
    });

    const _hoisted_1$1r = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1r = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 64C150 64 64 150 64 256s86 192 192 192s192-86 192-192S362 64 256 64z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1f = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 128v144h96'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$S = [_hoisted_2$1r, _hoisted_3$1f];
    vue.defineComponent({
      name: 'TimeOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1r, _hoisted_4$S);
      }
    });

    const _hoisted_1$1q = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.13 48 48 141.13 48 256c0 114.69 93.32 208 208 208c114.86 0 208-93.14 208-208c0-114.69-93.31-208-208-208zm108 240H244a4 4 0 0 1-4-4V116a4 4 0 0 1 4-4h24a4 4 0 0 1 4 4v140h92a4 4 0 0 1 4 4v24a4 4 0 0 1-4 4z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1e = [_hoisted_2$1q];
    vue.defineComponent({
      name: 'TimeSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1q, _hoisted_3$1e);
      }
    });

    const _hoisted_1$1p = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1p = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.12 48 48 141.12 48 256s93.12 208 208 208s208-93.12 208-208S370.88 48 256 48zm-82.33 114.34l105 71a32.5 32.5 0 0 1-37.25 53.26a33.21 33.21 0 0 1-8-8l-71-105a8.13 8.13 0 0 1 11.32-11.32zM256 432c-97 0-176-78.95-176-176a174.55 174.55 0 0 1 53.87-126.72a14.15 14.15 0 1 1 19.64 20.37A146.53 146.53 0 0 0 108.3 256c0 81.44 66.26 147.7 147.7 147.7S403.7 337.44 403.7 256c0-76.67-58.72-139.88-133.55-147v55a14.15 14.15 0 1 1-28.3 0V94.15A14.15 14.15 0 0 1 256 80c97.05 0 176 79 176 176s-78.95 176-176 176z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1d = [_hoisted_2$1p];
    vue.defineComponent({
      name: 'Timer',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1p, _hoisted_3$1d);
      }
    });

    const _hoisted_1$1o = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1o = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M112.91 128A191.85 191.85 0 0 0 64 254c-1.18 106.35 85.65 193.8 192 194c106.2.2 192-85.83 192-192c0-104.54-83.55-189.61-187.5-192a4.36 4.36 0 0 0-4.5 4.37V152',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1c = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M233.38 278.63l-79-113a8.13 8.13 0 0 1 11.32-11.32l113 79a32.5 32.5 0 0 1-37.25 53.26a33.21 33.21 0 0 1-8.07-7.94z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$R = [_hoisted_2$1o, _hoisted_3$1c];
    vue.defineComponent({
      name: 'TimerOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1o, _hoisted_4$R);
      }
    });

    const _hoisted_1$1n = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1n = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 48C141.12 48 48 141.12 48 256s93.12 208 208 208s208-93.12 208-208S370.88 48 256 48zm0 384c-97 0-176-78.95-176-176a174.55 174.55 0 0 1 53.87-126.72L279 233l-19 30l-125-91c-13 23-26.7 46-26.7 84c0 81.44 66.26 147.7 147.7 147.7S403.7 337.44 403.7 256c0-76.67-58.72-139.88-133.55-147v55h-28.3V79.89c4.24.07 8.94.11 14.15.11c97.05 0 176 79 176 176s-78.95 176-176 176z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1b = [_hoisted_2$1n];
    vue.defineComponent({
      name: 'TimerSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1n, _hoisted_3$1b);
      }
    });

    const _hoisted_1$1m = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1m = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 64h-16V48.45c0-8.61-6.62-16-15.23-16.43A16 16 0 0 0 368 48v16H144V48.45c0-8.61-6.62-16-15.23-16.43A16 16 0 0 0 112 48v16H96a64 64 0 0 0-64 64v12a4 4 0 0 0 4 4h440a4 4 0 0 0 4-4v-12a64 64 0 0 0-64-64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1a = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M477 176H35a3 3 0 0 0-3 3v237a64 64 0 0 0 64 64h320a64 64 0 0 0 64-64V179a3 3 0 0 0-3-3zM224 307.43A28.57 28.57 0 0 1 195.43 336h-70.86A28.57 28.57 0 0 1 96 307.43v-70.86A28.57 28.57 0 0 1 124.57 208h70.86A28.57 28.57 0 0 1 224 236.57z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$Q = [_hoisted_2$1m, _hoisted_3$1a];
    vue.defineComponent({
      name: 'Today',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1m, _hoisted_4$Q);
      }
    });

    const _hoisted_1$1l = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1l = /*#__PURE__*/vue.createStaticVNode('<rect fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32" x="48" y="80" width="416" height="384" rx="48"></rect><path fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32" stroke-linecap="round" d="M128 48v32"></path><path fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32" stroke-linecap="round" d="M384 48v32"></path><rect fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32" stroke-linecap="round" x="112" y="224" width="96" height="96" rx="13"></rect><path fill="none" stroke="currentColor" stroke-linejoin="round" stroke-width="32" stroke-linecap="round" d="M464 160H48"></path>', 5);

    const _hoisted_7$6 = [_hoisted_2$1l];
    vue.defineComponent({
      name: 'TodayOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1l, _hoisted_7$6);
      }
    });

    const _hoisted_1$1k = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1k = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M32 456a24 24 0 0 0 24 24h400a24 24 0 0 0 24-24V176H32zm80-238.86a9.14 9.14 0 0 1 9.14-9.14h109.72a9.14 9.14 0 0 1 9.14 9.14v109.72a9.14 9.14 0 0 1-9.14 9.14H121.14a9.14 9.14 0 0 1-9.14-9.14z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$19 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M456 64h-55.92V32h-48v32H159.92V32h-48v32H56a23.8 23.8 0 0 0-24 23.77V144h448V87.77A23.8 23.8 0 0 0 456 64z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$P = [_hoisted_2$1k, _hoisted_3$19];
    vue.defineComponent({
      name: 'TodaySharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1k, _hoisted_4$P);
      }
    });

    const _hoisted_1$1j = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1j = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M368 112H144C64.6 112 0 176.6 0 256s64.6 144 144 144h224c79.4 0 144-64.6 144-144s-64.6-144-144-144zm0 256a112 112 0 1 1 112-112a112.12 112.12 0 0 1-112 112z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$18 = [_hoisted_2$1j];
    vue.defineComponent({
      name: 'Toggle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1j, _hoisted_3$18);
      }
    });

    const _hoisted_1$1i = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1i = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '368',
      cy: '256',
      r: '128',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$17 = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '16',
      y: '128',
      width: '480',
      height: '256',
      rx: '128',
      ry: '128',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$O = [_hoisted_2$1i, _hoisted_3$17];
    vue.defineComponent({
      name: 'ToggleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1i, _hoisted_4$O);
      }
    });

    const _hoisted_1$1h = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1h = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M368 112H144a144 144 0 0 0 0 288h224a144 144 0 0 0 0-288zm0 230a86 86 0 1 1 86-86a85.88 85.88 0 0 1-86 86z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$16 = [_hoisted_2$1h];
    vue.defineComponent({
      name: 'ToggleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1h, _hoisted_3$16);
      }
    });

    const _hoisted_1$1g = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1g = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M491.31 324.69L432 265.37a31.8 31.8 0 0 0-22.63-9.37H272v-32h144a32 32 0 0 0 32-32V96a32 32 0 0 0-32-32H272V48a16 16 0 0 0-32 0v16H102.63A31.8 31.8 0 0 0 80 73.37l-59.31 59.32a16 16 0 0 0 0 22.62L80 214.63a31.8 31.8 0 0 0 22.63 9.37H240v32H96a32 32 0 0 0-32 32v96a32 32 0 0 0 32 32h144v48a16 16 0 0 0 32 0v-48h137.37a31.8 31.8 0 0 0 22.63-9.37l59.31-59.32a16 16 0 0 0 0-22.62z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$15 = [_hoisted_2$1g];
    vue.defineComponent({
      name: 'TrailSign',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1g, _hoisted_3$15);
      }
    });

    const _hoisted_1$1f = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1f = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 400v64"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 208v64"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 48v32"></path><path d="M416 208H102.63a16 16 0 0 1-11.32-4.69L32 144l59.31-59.31A16 16 0 0 1 102.63 80H416a16 16 0 0 1 16 16v96a16 16 0 0 1-16 16z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M96 400h313.37a16 16 0 0 0 11.32-4.69L480 336l-59.31-59.31a16 16 0 0 0-11.32-4.69H96a16 16 0 0 0-16 16v96a16 16 0 0 0 16 16z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 5);

    const _hoisted_7$5 = [_hoisted_2$1f];
    vue.defineComponent({
      name: 'TrailSignOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1f, _hoisted_7$5);
      }
    });

    const _hoisted_1$1e = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1e = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M502.63 336l-80-80H278v-32h170V64H278V32h-44v32H89.37l-80 80l80 80H234v32H64v160h170v64h44v-64h144.63z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$14 = [_hoisted_2$1e];
    vue.defineComponent({
      name: 'TrailSignSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1e, _hoisted_3$14);
      }
    });

    const _hoisted_1$1d = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1d = /*#__PURE__*/vue.createElementVNode('ellipse', {
      cx: '256',
      cy: '304',
      rx: '32.05',
      ry: '31.94',
      transform: 'rotate(-45 256.001 304)',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$13 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M352 32h-15a10 10 0 0 1-7.87-3.78A31.94 31.94 0 0 0 304 16h-96a32 32 0 0 0-26.11 13.52A6 6 0 0 1 177 32h-17c-36.81 0-64 28.84-64 64v255c0 23.27 25.6 42.06 83 60.94a753 753 0 0 0 73.77 19.73a16 16 0 0 0 6.46 0A753 753 0 0 0 333 411.94c57.4-18.88 83-37.67 83-60.94V96a64 64 0 0 0-64-64zm-168 96h144a8 8 0 0 1 8 8v48a8 8 0 0 1-8 8H184a8 8 0 0 1-8-8v-48a8 8 0 0 1 8-8zm76.18 239.87a64 64 0 1 1 59.69-59.69a64.07 64.07 0 0 1-59.69 59.69z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$N = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M395.31 468.69L347.63 421c-6.09-6.1-16-6.66-22.38-.86a16 16 0 0 0-.56 23.16l4.68 4.69H182.63l4.36-4.37c6.1-6.09 6.66-16 .86-22.38a16 16 0 0 0-23.16-.56l-48 48a16 16 0 1 0 22.62 22.62l11.32-11.3h210.74l11.32 11.31a16 16 0 0 0 22.62-22.62z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$o = [_hoisted_2$1d, _hoisted_3$13, _hoisted_4$N];
    vue.defineComponent({
      name: 'Train',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1d, _hoisted_5$o);
      }
    });

    const _hoisted_1$1c = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1c = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M344 48h-24a16 16 0 0 0-16-16h-96a16 16 0 0 0-16 16h-24a56.16 56.16 0 0 0-56 56v247c0 35.3 144 65 144 65s144-29.7 144-65V104a56 56 0 0 0-56-56zm-88 304a48 48 0 1 1 48-48a48 48 0 0 1-48 48zm96-160a16 16 0 0 1-16 16H176a16 16 0 0 1-16-16v-64a16 16 0 0 1 16-16h160a16 16 0 0 1 16 16z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$12 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M144 464h224'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$M = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M336 432l48 48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$n = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M176 432l-48 48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$b = [_hoisted_2$1c, _hoisted_3$12, _hoisted_4$M, _hoisted_5$n];
    vue.defineComponent({
      name: 'TrainOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1c, _hoisted_6$b);
      }
    });

    const _hoisted_1$1b = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1b = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 32h-64a16 16 0 0 0-16-16h-96a16 16 0 0 0-16 16h-64c-16 0-32 16-32 32v288c0 23.92 160 80 160 80s160-56.74 160-80V64c0-16-16-32-32-32zM256 352a48 48 0 1 1 48-48a48 48 0 0 1-48 48zm112-152a8 8 0 0 1-8 8H152a8 8 0 0 1-8-8v-80a8 8 0 0 1 8-8h208a8 8 0 0 1 8 8z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$11 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M314 432l15.32 16H182.58L198 432l-32-13l-76.62 77h45.2l16-16h210.74l16 16h45.3l-76.36-77.75L314 432z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$L = [_hoisted_2$1b, _hoisted_3$11];
    vue.defineComponent({
      name: 'TrainSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1b, _hoisted_4$L);
      }
    });

    const _hoisted_1$1a = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1a = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M458 32h-68a22 22 0 0 0 0 44h14.89l-59.57 59.57a149.69 149.69 0 0 0-178.64 0l-7.57-7.57l26.45-26.44a22 22 0 0 0-31.12-31.12L128 96.89L107.11 76H122a22 22 0 0 0 0-44H54a22 22 0 0 0-22 22v68a22 22 0 0 0 44 0v-14.89L96.89 128l-26.42 26.42a22 22 0 1 0 31.11 31.11L128 159.11l7.57 7.57A149.19 149.19 0 0 0 106 256c0 82.71 67.29 150 150 150a149.2 149.2 0 0 0 89.46-29.67L369 399.9l-26.54 26.54a22 22 0 0 0 31.12 31.12l26.49-26.5l42.37 42.48a22 22 0 0 0 31.16-31.08L431.17 400l26.39-26.39a22 22 0 0 0-31.12-31.12l-26.35 26.35l-23.55-23.62a149.68 149.68 0 0 0-.11-178.49L436 107.11V122a22 22 0 0 0 44 0V54a22 22 0 0 0-22-22zM150 256a106 106 0 1 1 106 106a106.12 106.12 0 0 1-106-106z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$10 = [_hoisted_2$1a];
    vue.defineComponent({
      name: 'Transgender',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1a, _hoisted_3$10);
      }
    });

    const _hoisted_1$19 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$19 = /*#__PURE__*/vue.createStaticVNode('<circle cx="256" cy="256" r="128" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M448 352l-96 96"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M176 80l-95.98 95.98"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M464 128V48h-80"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M48 128V48h80"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M464 48L346.5 165.5"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M48 48l117.49 117.49"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M464 464L346.65 346.37"></path>', 8);

    const _hoisted_10 = [_hoisted_2$19];
    vue.defineComponent({
      name: 'TransgenderOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$19, _hoisted_10);
      }
    });

    const _hoisted_1$18 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$18 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M480 448.94l-48.94-49.08L464 366.92l-31.1-31.11l-32.9 32.9l-23.55-23.61a149.64 149.64 0 0 0-.1-178.45l59.55-59.56V144h44V32h-112v44h36.87l-59.55 59.55a149.65 149.65 0 0 0-178.59 0l-7.55-7.55l33-33L161 63.88l-33 33L107.09 76H144V32H32v112h44v-36.91L96.87 128l-33 33L95 192.05l33-33l7.56 7.57A149.18 149.18 0 0 0 106 255.94c0 82.69 67.27 150 150 150a149.12 149.12 0 0 0 89.44-29.67l23.51 23.58l-33.14 33.05l31.11 31.1l33-33l48.9 49zm-330-193a106 106 0 1 1 106 106a106.09 106.09 0 0 1-106-106z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$$ = [_hoisted_2$18];
    vue.defineComponent({
      name: 'TransgenderSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$18, _hoisted_3$$);
      }
    });

    const _hoisted_1$17 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$17 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M296 64h-80a7.91 7.91 0 0 0-8 8v24h96V72a7.91 7.91 0 0 0-8-8z',
      fill: 'none'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$_ = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M432 96h-96V72a40 40 0 0 0-40-40h-80a40 40 0 0 0-40 40v24H80a16 16 0 0 0 0 32h17l19 304.92c1.42 26.85 22 47.08 48 47.08h184c26.13 0 46.3-19.78 48-47l19-305h17a16 16 0 0 0 0-32zM192.57 416H192a16 16 0 0 1-16-15.43l-8-224a16 16 0 1 1 32-1.14l8 224A16 16 0 0 1 192.57 416zM272 400a16 16 0 0 1-32 0V176a16 16 0 0 1 32 0zm32-304h-96V72a7.91 7.91 0 0 1 8-8h80a7.91 7.91 0 0 1 8 8zm32 304.57A16 16 0 0 1 320 416h-.58A16 16 0 0 1 304 399.43l8-224a16 16 0 1 1 32 1.14z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$K = [_hoisted_2$17, _hoisted_3$_];
    vue.defineComponent({
      name: 'Trash',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$17, _hoisted_4$K);
      }
    });

    const _hoisted_1$16 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$16 = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '32',
      y: '48',
      width: '448',
      height: '80',
      rx: '32',
      ry: '32',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$Z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M74.45 160a8 8 0 0 0-8 8.83l26.31 252.56a1.5 1.5 0 0 0 0 .22A48 48 0 0 0 140.45 464h231.09a48 48 0 0 0 47.67-42.39v-.21l26.27-252.57a8 8 0 0 0-8-8.83zm248.86 180.69a16 16 0 1 1-22.63 22.62L256 318.63l-44.69 44.68a16 16 0 0 1-22.63-22.62L233.37 296l-44.69-44.69a16 16 0 0 1 22.63-22.62L256 273.37l44.68-44.68a16 16 0 0 1 22.63 22.62L278.62 296z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$J = [_hoisted_2$16, _hoisted_3$Z];
    vue.defineComponent({
      name: 'TrashBin',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$16, _hoisted_4$J);
      }
    });

    const _hoisted_1$15 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$15 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M432 144l-28.67 275.74A32 32 0 0 1 371.55 448H140.46a32 32 0 0 1-31.78-28.26L80 144',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$Y = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '32',
      y: '64',
      width: '448',
      height: '80',
      rx: '16',
      ry: '16',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$I = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M312 240L200 352'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$m = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M312 352L200 240'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$a = [_hoisted_2$15, _hoisted_3$Y, _hoisted_4$I, _hoisted_5$m];
    vue.defineComponent({
      name: 'TrashBinOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$15, _hoisted_6$a);
      }
    });

    const _hoisted_1$14 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$14 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      d: 'M337.46 240L312 214.54l-56 56l-56-56L174.54 240l56 56l-56 56L200 377.46l56-56l56 56L337.46 352l-56-56l56-56z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$X = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      d: 'M337.46 240L312 214.54l-56 56l-56-56L174.54 240l56 56l-56 56L200 377.46l56-56l56 56L337.46 352l-56-56l56-56z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$H = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M64 160l29.74 282.51A24 24 0 0 0 117.61 464h276.78a24 24 0 0 0 23.87-21.49L448 160zm248 217.46l-56-56l-56 56L174.54 352l56-56l-56-56L200 214.54l56 56l56-56L337.46 240l-56 56l56 56z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$l = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '32',
      y: '48',
      width: '448',
      height: '80',
      rx: '12',
      ry: '12',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$9 = [_hoisted_2$14, _hoisted_3$X, _hoisted_4$H, _hoisted_5$l];
    vue.defineComponent({
      name: 'TrashBinSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$14, _hoisted_6$9);
      }
    });

    const _hoisted_1$13 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$13 = /*#__PURE__*/vue.createStaticVNode('<path d="M112 112l20 320c.95 18.49 14.4 32 32 32h184c17.67 0 30.87-13.51 32-32l20-320" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M80 112h352" fill="currentColor"></path><path d="M192 112V72h0a23.93 23.93 0 0 1 24-24h80a23.93 23.93 0 0 1 24 24h0v40" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 176v224"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M184 176l8 224"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M328 176l-8 224"></path>', 6);

    const _hoisted_8$3 = [_hoisted_2$13];
    vue.defineComponent({
      name: 'TrashOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$13, _hoisted_8$3);
      }
    });

    const _hoisted_1$12 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$12 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M296 64h-80a7.91 7.91 0 0 0-8 8v24h96V72a7.91 7.91 0 0 0-8-8z',
      fill: 'none'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$W = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M292 64h-72a4 4 0 0 0-4 4v28h80V68a4 4 0 0 0-4-4z',
      fill: 'none'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$G = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M447.55 96H336V48a16 16 0 0 0-16-16H192a16 16 0 0 0-16 16v48H64.45L64 136h33l20.09 314A32 32 0 0 0 149 480h214a32 32 0 0 0 31.93-29.95L415 136h33zM176 416l-9-256h33l9 256zm96 0h-32V160h32zm24-320h-80V68a4 4 0 0 1 4-4h72a4 4 0 0 1 4 4zm40 320h-33l9-256h33z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$k = [_hoisted_2$12, _hoisted_3$W, _hoisted_4$G];
    vue.defineComponent({
      name: 'TrashSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$12, _hoisted_5$k);
      }
    });

    const _hoisted_1$11 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$11 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M352 368h112V256'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$V = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 144l121.37 121.37a32 32 0 0 0 45.26 0l50.74-50.74a32 32 0 0 1 45.26 0L448 352',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$F = [_hoisted_2$11, _hoisted_3$V];
    vue.defineComponent({
      name: 'TrendingDown',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$11, _hoisted_4$F);
      }
    });

    const _hoisted_1$10 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$10 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M352 368h112V256'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$U = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 144l121.37 121.37a32 32 0 0 0 45.26 0l50.74-50.74a32 32 0 0 1 45.26 0L448 352',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$E = [_hoisted_2$10, _hoisted_3$U];
    vue.defineComponent({
      name: 'TrendingDownOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$10, _hoisted_4$E);
      }
    });

    const _hoisted_1$$ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$$ = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M352 368h112V256'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$T = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M48 144l144 144l96-96l160 160'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$D = [_hoisted_2$$, _hoisted_3$T];
    vue.defineComponent({
      name: 'TrendingDownSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$$, _hoisted_4$D);
      }
    });

    const _hoisted_1$_ = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$_ = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M352 144h112v112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$S = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 368l121.37-121.37a32 32 0 0 1 45.26 0l50.74 50.74a32 32 0 0 0 45.26 0L448 160',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$C = [_hoisted_2$_, _hoisted_3$S];
    vue.defineComponent({
      name: 'TrendingUp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$_, _hoisted_4$C);
      }
    });

    const _hoisted_1$Z = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$Z = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M352 144h112v112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$R = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M48 368l121.37-121.37a32 32 0 0 1 45.26 0l50.74 50.74a32 32 0 0 0 45.26 0L448 160',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$B = [_hoisted_2$Z, _hoisted_3$R];
    vue.defineComponent({
      name: 'TrendingUpOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$Z, _hoisted_4$B);
      }
    });

    const _hoisted_1$Y = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$Y = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M352 144h112v112'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$Q = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M48 368l144-144l96 96l160-160'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$A = [_hoisted_2$Y, _hoisted_3$Q];
    vue.defineComponent({
      name: 'TrendingUpSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$Y, _hoisted_4$A);
      }
    });

    const _hoisted_1$X = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$X = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 464H48a16 16 0 0 1-14.07-23.62l208-384a16 16 0 0 1 28.14 0l208 384A16 16 0 0 1 464 464z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$P = [_hoisted_2$X];
    vue.defineComponent({
      name: 'Triangle',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$X, _hoisted_3$P);
      }
    });

    const _hoisted_1$W = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$W = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M48 448L256 64l208 384H48z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$O = [_hoisted_2$W];
    vue.defineComponent({
      name: 'TriangleOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$W, _hoisted_3$O);
      }
    });

    const _hoisted_1$V = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$V = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 32L20 464h472L256 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$N = [_hoisted_2$V];
    vue.defineComponent({
      name: 'TriangleSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$V, _hoisted_3$N);
      }
    });

    const _hoisted_1$U = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$U = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 80h-60.1a4 4 0 0 1-4-4V63.92a32 32 0 0 0-32-31.92l-223.79.26a32 32 0 0 0-31.94 31.93V76a4 4 0 0 1-4 4H48a16 16 0 0 0-16 16v16c0 54.53 30 112.45 76.52 125.35a7.82 7.82 0 0 1 5.55 5.9c5.77 26.89 23.52 52.5 51.41 73.61c20.91 15.83 45.85 27.5 68.27 32.48a8 8 0 0 1 6.25 7.8V444a4 4 0 0 1-4 4h-59.55c-8.61 0-16 6.62-16.43 15.23A16 16 0 0 0 176 480h159.55c8.61 0 16-6.62 16.43-15.23A16 16 0 0 0 336 448h-60a4 4 0 0 1-4-4v-86.86a8 8 0 0 1 6.25-7.8c22.42-5 47.36-16.65 68.27-32.48c27.89-21.11 45.64-46.72 51.41-73.61a7.82 7.82 0 0 1 5.55-5.9C450 224.45 480 166.53 480 112V96a16 16 0 0 0-16-16zM112 198.22a4 4 0 0 1-6 3.45c-10.26-6.11-17.75-15.37-22.14-21.89c-11.91-17.69-19-40.67-19.79-63.63a4 4 0 0 1 4-4.15h40a4 4 0 0 1 4 4c-.02 27.45-.07 58.87-.07 82.22zm316.13-18.44c-4.39 6.52-11.87 15.78-22.13 21.89a4 4 0 0 1-6-3.46c0-26.51 0-56.63-.05-82.21a4 4 0 0 1 4-4h40a4 4 0 0 1 4 4.15c-.79 22.96-7.9 45.94-19.81 63.63z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$M = [_hoisted_2$U];
    vue.defineComponent({
      name: 'Trophy',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$U, _hoisted_3$M);
      }
    });

    const _hoisted_1$T = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$T = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M176 464h160"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M256 464V336"></path><path d="M384 224c0-50.64-.08-134.63-.12-160a16 16 0 0 0-16-16l-223.79.26a16 16 0 0 0-16 15.95c0 30.58-.13 129.17-.13 159.79c0 64.28 83 112 128 112S384 288.28 384 224z" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M128 96H48v16c0 55.22 33.55 112 80 112" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M384 96h80v16c0 55.22-33.55 112-80 112" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path>', 5);

    const _hoisted_7$4 = [_hoisted_2$T];
    vue.defineComponent({
      name: 'TrophyOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$T, _hoisted_7$4);
      }
    });

    const _hoisted_1$S = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$S = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M399.9 80V32H112v48H32v38c0 32 9.5 62.79 26.76 86.61c13.33 18.4 34.17 31.1 52.91 37.21c5.44 29.29 20.2 57.13 50.19 79.83c22 16.66 48.45 28.87 72.14 33.86V436h-74v44h192v-44h-74v-80.49c23.69-5 50.13-17.2 72.14-33.86c30-22.7 44.75-50.54 50.19-79.83c18.74-6.11 39.58-18.81 52.91-37.21C470.5 180.79 480 150 480 118V80zM94.4 178.8c-10.68-14.68-17.17-34.4-18.24-54.8H112v67.37c-3.94-1.14-12.92-6.12-17.6-12.57zm323.2 0c-4.6 6.61-11.6 12.58-17.6 12.58c0-22.4 0-46.29-.05-67.38h35.9c-1.08 20.4-7.85 39.9-18.25 54.8z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$L = [_hoisted_2$S];
    vue.defineComponent({
      name: 'TrophySharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$S, _hoisted_3$L);
      }
    });

    const _hoisted_1$R = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$R = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M447.86 384H64.14A48.2 48.2 0 0 1 16 335.86V128.14A48.2 48.2 0 0 1 64.14 80h383.72A48.2 48.2 0 0 1 496 128.14v207.72A48.2 48.2 0 0 1 447.86 384z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$K = /*#__PURE__*/vue.createElementVNode('path', {
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M128 416h256',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$z = [_hoisted_2$R, _hoisted_3$K];
    vue.defineComponent({
      name: 'Tv',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$R, _hoisted_4$z);
      }
    });

    const _hoisted_1$Q = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$Q = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '32',
      y: '96',
      width: '448',
      height: '272',
      rx: '32.14',
      ry: '32.14',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$J = /*#__PURE__*/vue.createElementVNode('path', {
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M128 416h256',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$y = [_hoisted_2$Q, _hoisted_3$J];
    vue.defineComponent({
      name: 'TvOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$Q, _hoisted_4$y);
      }
    });

    const _hoisted_1$P = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$P = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M488 384H24a8 8 0 0 1-8-8V88a8 8 0 0 1 8-8h464a8 8 0 0 1 8 8v288a8 8 0 0 1-8 8z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$I = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '112',
      y: '400',
      width: '288',
      height: '32',
      rx: '4',
      ry: '4',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$x = [_hoisted_2$P, _hoisted_3$I];
    vue.defineComponent({
      name: 'TvSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$P, _hoisted_4$x);
      }
    });

    const _hoisted_1$O = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$O = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M414.39 113.61a222.26 222.26 0 0 0-136.33-64.54a8.09 8.09 0 0 1-6.88-5.62a15.79 15.79 0 0 0-30.36 0a8.09 8.09 0 0 1-6.88 5.62A224 224 0 0 0 32 271.52a16.41 16.41 0 0 0 7.24 13.87a16 16 0 0 0 20.07-2.08a51.89 51.89 0 0 1 73.31-.06a15.94 15.94 0 0 0 22.6.15a62.59 62.59 0 0 1 81.49-5.87a8.24 8.24 0 0 1 3.29 6.59v147.42c0 8.6-6.6 16-15.19 16.44A16 16 0 0 1 208 432a16 16 0 0 0-16.29-16c-9 .16-15.9 8.11-15.7 17.1a48.06 48.06 0 0 0 47.37 46.9c26.88.34 48.62-21.93 48.62-48.81V284.12a8.24 8.24 0 0 1 3.29-6.59a62.59 62.59 0 0 1 81.4 5.78a16 16 0 0 0 22.62 0a51.91 51.91 0 0 1 73.38 0a16 16 0 0 0 19.54 2.41a16.4 16.4 0 0 0 7.77-14.21a222.54 222.54 0 0 0-65.61-157.9z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$H = [_hoisted_2$O];
    vue.defineComponent({
      name: 'Umbrella',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$O, _hoisted_3$H);
      }
    });

    const _hoisted_1$N = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$N = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 272v160a32 32 0 0 1-32 32h0a32 32 0 0 1-32-32',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$G = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 272c0-114.88-93.12-208-208-208S48 157.12 48 272h0a67.88 67.88 0 0 1 96 0h0a78.28 78.28 0 0 1 102.31-7.27L256 272l9.69-7.27A78.28 78.28 0 0 1 368 272h0a67.88 67.88 0 0 1 96 0z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$w = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 64V48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$j = [_hoisted_2$N, _hoisted_3$G, _hoisted_4$w];
    vue.defineComponent({
      name: 'UmbrellaOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$N, _hoisted_5$j);
      }
    });

    const _hoisted_1$M = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$M = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M128.93 280l-.26-.3c-.9-.74-1.83-1.43-2.77-2.1z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$F = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M383.08 280l2.62-2.12c-.79.58-1.57 1.17-2.34 1.79z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$v = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M463.14 186.44A224.55 224.55 0 0 0 272 48.57V32h-32v16.57A223.58 223.58 0 0 0 32 272v22.52l12.25-11.21a62.63 62.63 0 0 1 81.43-5.88l.22.17c.94.67 1.87 1.36 2.77 2.1q2.09 1.69 4 3.61L144 294.63l11.31-11.32a62.59 62.59 0 0 1 81.4-5.78L240 280v152a16 16 0 0 1-32 0v-16h-32v16a48 48 0 0 0 96 0V280l3.29-2.47a62.59 62.59 0 0 1 81.4 5.78L368 294.63l11.31-11.32q1.95-1.94 4.05-3.64c.77-.62 1.55-1.21 2.34-1.79l.26-.21c24.63-18.47 60-16.13 81.81 5.64l12.23 11.2V272a223.62 223.62 0 0 0-16.86-85.56z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$i = [_hoisted_2$M, _hoisted_3$F, _hoisted_4$v];
    vue.defineComponent({
      name: 'UmbrellaSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$M, _hoisted_5$i);
      }
    });

    const _hoisted_1$L = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$L = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M200.66 352H144a96 96 0 0 1 0-192h55.41',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$E = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M312.59 160H368a96 96 0 0 1 0 192h-56.66',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$u = [_hoisted_2$L, _hoisted_3$E];
    vue.defineComponent({
      name: 'Unlink',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$L, _hoisted_4$u);
      }
    });

    const _hoisted_1$K = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$K = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M208 352h-64a96 96 0 0 1 0-192h64',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '36'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$D = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M304 160h64a96 96 0 0 1 0 192h-64',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '36'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$t = [_hoisted_2$K, _hoisted_3$D];
    vue.defineComponent({
      name: 'UnlinkOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$K, _hoisted_4$t);
      }
    });

    const _hoisted_1$J = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$J = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M200.66 352H144a96 96 0 0 1 0-192h55.41',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-linejoin': 'round',
      'stroke-width': '48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$C = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M312.59 160H368a96 96 0 0 1 0 192h-56.66',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-linejoin': 'round',
      'stroke-width': '48'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$s = [_hoisted_2$J, _hoisted_3$C];
    vue.defineComponent({
      name: 'UnlinkSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$J, _hoisted_4$s);
      }
    });

    const _hoisted_1$I = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$I = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 384.39a32 32 0 0 1-13-2.77a15.77 15.77 0 0 1-2.71-1.54l-82.71-58.22A32 32 0 0 1 352 295.7v-79.4a32 32 0 0 1 13.58-26.16l82.71-58.22a15.77 15.77 0 0 1 2.71-1.54a32 32 0 0 1 45 29.24v192.76a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$B = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M268 400H84a68.07 68.07 0 0 1-68-68V180a68.07 68.07 0 0 1 68-68h184.48A67.6 67.6 0 0 1 336 179.52V332a68.07 68.07 0 0 1-68 68z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$r = [_hoisted_2$I, _hoisted_3$B];
    vue.defineComponent({
      name: 'Videocam',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$I, _hoisted_4$r);
      }
    });

    const _hoisted_1$H = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$H = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 179.52A67.52 67.52 0 0 0 268.48 112h-79.2a4 4 0 0 0-2.82 6.83l142.71 142.71a4 4 0 0 0 6.83-2.82z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$A = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M16 180v152a68 68 0 0 0 68 68h184a67.66 67.66 0 0 0 42.84-15.24a4 4 0 0 0 .33-6L54.41 122a4 4 0 0 0-4.87-.62A68 68 0 0 0 16 180z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M464 384.39a32 32 0 0 1-13-2.77a15.77 15.77 0 0 1-2.71-1.54l-82.71-58.22A32 32 0 0 1 352 295.7v-79.4a32 32 0 0 1 13.58-26.16l82.71-58.22a15.77 15.77 0 0 1 2.71-1.54a32 32 0 0 1 45 29.24v192.76a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$h = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-miterlimit': '10',
      'stroke-width': '32',
      d: 'M416 416L80 80'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$8 = [_hoisted_2$H, _hoisted_3$A, _hoisted_4$q, _hoisted_5$h];
    vue.defineComponent({
      name: 'VideocamOff',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$H, _hoisted_6$8);
      }
    });

    const _hoisted_1$G = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$G = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-width': '32',
      'stroke-linejoin': 'round',
      d: 'M374.79 308.78L457.5 367a16 16 0 0 0 22.5-14.62V159.62A16 16 0 0 0 457.5 145l-82.71 58.22A16 16 0 0 0 368 216.3v79.4a16 16 0 0 0 6.79 13.08z'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$z = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-width': '32',
      'stroke-miterlimit': '10',
      d: 'M50.19 140.57A51.94 51.94 0 0 0 32 180v152a52.15 52.15 0 0 0 52 52h184a51.6 51.6 0 0 0 22-4.9'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$p = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-width': '32',
      'stroke-miterlimit': '10',
      d: 'M208 128h60.48A51.68 51.68 0 0 1 320 179.52V248'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$g = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-width': '32',
      'stroke-miterlimit': '10',
      d: 'M416 416L80 80'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$7 = [_hoisted_2$G, _hoisted_3$z, _hoisted_4$p, _hoisted_5$g];
    vue.defineComponent({
      name: 'VideocamOffOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$G, _hoisted_6$7);
      }
    });

    const _hoisted_1$F = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$F = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M57.376 79.998l22.627-22.627l358.63 358.63l-22.627 22.628z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M32 112a16 16 0 0 0-16 16v256a16 16 0 0 0 16 16h288a15.89 15.89 0 0 0 9.34-3l-285-285z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$o = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 208v-80a16 16 0 0 0-16-16H179.63l245.44 245.44L496 400V112z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$f = [_hoisted_2$F, _hoisted_3$y, _hoisted_4$o];
    vue.defineComponent({
      name: 'VideocamOffSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$F, _hoisted_5$f);
      }
    });

    const _hoisted_1$E = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$E = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M374.79 308.78L457.5 367a16 16 0 0 0 22.5-14.62V159.62A16 16 0 0 0 457.5 145l-82.71 58.22A16 16 0 0 0 368 216.3v79.4a16 16 0 0 0 6.79 13.08z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$x = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M268 384H84a52.15 52.15 0 0 1-52-52V180a52.15 52.15 0 0 1 52-52h184.48A51.68 51.68 0 0 1 320 179.52V332a52.15 52.15 0 0 1-52 52z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$n = [_hoisted_2$E, _hoisted_3$x];
    vue.defineComponent({
      name: 'VideocamOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$E, _hoisted_4$n);
      }
    });

    const _hoisted_1$D = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$D = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 208v-80a16 16 0 0 0-16-16H32a16 16 0 0 0-16 16v256a16 16 0 0 0 16 16h288a16 16 0 0 0 16-16v-80l160 96V112z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$w = [_hoisted_2$D];
    vue.defineComponent({
      name: 'VideocamSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$D, _hoisted_3$w);
      }
    });

    const _hoisted_1$C = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$C = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M232 416a23.88 23.88 0 0 1-14.2-4.68a8.27 8.27 0 0 1-.66-.51L125.76 336H56a24 24 0 0 1-24-24V200a24 24 0 0 1 24-24h69.75l91.37-74.81a8.27 8.27 0 0 1 .66-.51A24 24 0 0 1 256 120v272a24 24 0 0 1-24 24zm-106.18-80zm-.27-159.86z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$v = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 336a16 16 0 0 1-14.29-23.19c9.49-18.87 14.3-38 14.3-56.81c0-19.38-4.66-37.94-14.25-56.73a16 16 0 0 1 28.5-14.54C346.19 208.12 352 231.44 352 256c0 23.86-6 47.81-17.7 71.19A16 16 0 0 1 320 336z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$m = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M368 384a16 16 0 0 1-13.86-24C373.05 327.09 384 299.51 384 256c0-44.17-10.93-71.56-29.82-103.94a16 16 0 0 1 27.64-16.12C402.92 172.11 416 204.81 416 256c0 50.43-13.06 83.29-34.13 120a16 16 0 0 1-13.87 8z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$e = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 432a16 16 0 0 1-13.39-24.74C429.85 365.47 448 323.76 448 256c0-66.5-18.18-108.62-45.49-151.39a16 16 0 1 1 27-17.22C459.81 134.89 480 181.74 480 256c0 64.75-14.66 113.63-50.6 168.74A16 16 0 0 1 416 432z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$6 = [_hoisted_2$C, _hoisted_3$v, _hoisted_4$m, _hoisted_5$e];
    vue.defineComponent({
      name: 'VolumeHigh',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$C, _hoisted_6$6);
      }
    });

    const _hoisted_1$B = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$B = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M126 192H56a8 8 0 0 0-8 8v112a8 8 0 0 0 8 8h69.65a15.93 15.93 0 0 1 10.14 3.54l91.47 74.89A8 8 0 0 0 240 392V120a8 8 0 0 0-12.74-6.43l-91.47 74.89A15 15 0 0 1 126 192z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$u = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 320c9.74-19.38 16-40.84 16-64c0-23.48-6-44.42-16-64',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$l = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M368 368c19.48-33.92 32-64.06 32-112s-12-77.74-32-112',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$d = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 416c30-46 48-91.43 48-160s-18-113-48-160',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$5 = [_hoisted_2$B, _hoisted_3$u, _hoisted_4$l, _hoisted_5$d];
    vue.defineComponent({
      name: 'VolumeHighOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$B, _hoisted_6$5);
      }
    });

    const _hoisted_1$A = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$A = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M320 320c9.74-19.38 16-40.84 16-64c0-23.48-6-44.42-16-64',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$t = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M368 368c19.48-33.92 32-64.06 32-112s-12-77.74-32-112',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$k = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M416 416c30-46 48-91.43 48-160s-18-113-48-160',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$c = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M125.65 176.1H32v159.8h93.65L256 440V72L125.65 176.1z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$4 = [_hoisted_2$A, _hoisted_3$t, _hoisted_4$k, _hoisted_5$c];
    vue.defineComponent({
      name: 'VolumeHighSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$A, _hoisted_6$4);
      }
    });

    const _hoisted_1$z = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$z = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M296 416.19a23.92 23.92 0 0 1-14.21-4.69l-.66-.51l-91.46-75H120a24 24 0 0 1-24-24V200a24 24 0 0 1 24-24h69.65l91.46-75l.66-.51A24 24 0 0 1 320 119.83v272.34a24 24 0 0 1-24 24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$s = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 336a16 16 0 0 1-14.29-23.18c9.49-18.9 14.3-38 14.3-56.82c0-19.36-4.66-37.92-14.25-56.73a16 16 0 0 1 28.5-14.54C410.2 208.16 416 231.47 416 256c0 23.83-6 47.78-17.7 71.18A16 16 0 0 1 384 336z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$j = [_hoisted_2$z, _hoisted_3$s];
    vue.defineComponent({
      name: 'VolumeLow',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$z, _hoisted_4$j);
      }
    });

    const _hoisted_1$y = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$y = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M189.65 192H120a8 8 0 0 0-8 8v112a8 8 0 0 0 8 8h69.65a16 16 0 0 1 10.14 3.63l91.47 75a8 8 0 0 0 12.74-6.46V119.83a8 8 0 0 0-12.74-6.44l-91.47 75a16 16 0 0 1-10.14 3.61z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$r = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 320c9.74-19.41 16-40.81 16-64c0-23.51-6-44.4-16-64',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$i = [_hoisted_2$y, _hoisted_3$r];
    vue.defineComponent({
      name: 'VolumeLowOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$y, _hoisted_4$i);
      }
    });

    const _hoisted_1$x = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$x = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M391.12 341.48l-28.6-14.36l7.18-14.3c9.49-18.9 14.3-38 14.3-56.82c0-19.36-4.66-37.92-14.25-56.73L362.48 185L391 170.48l7.26 14.25C410.2 208.16 416 231.47 416 256c0 23.83-6 47.78-17.7 71.18z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M189.65 176.1H96v159.8h93.65L320 440V72L189.65 176.1z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$h = [_hoisted_2$x, _hoisted_3$q];
    vue.defineComponent({
      name: 'VolumeLowSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$x, _hoisted_4$h);
      }
    });

    const _hoisted_1$w = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$w = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M264 416.19a23.92 23.92 0 0 1-14.21-4.69l-.66-.51l-91.46-75H88a24 24 0 0 1-24-24V200a24 24 0 0 1 24-24h69.65l91.46-75l.66-.51A24 24 0 0 1 288 119.83v272.34a24 24 0 0 1-24 24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$p = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M352 336a16 16 0 0 1-14.29-23.18c9.49-18.9 14.3-38 14.3-56.82c0-19.36-4.66-37.92-14.25-56.73a16 16 0 0 1 28.5-14.54C378.2 208.16 384 231.47 384 256c0 23.83-6 47.78-17.7 71.18A16 16 0 0 1 352 336z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$g = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400 384a16 16 0 0 1-13.87-24C405 327.05 416 299.45 416 256c0-44.12-10.94-71.52-29.83-103.95A16 16 0 0 1 413.83 136C434.92 172.16 448 204.88 448 256c0 50.36-13.06 83.24-34.12 120a16 16 0 0 1-13.88 8z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$b = [_hoisted_2$w, _hoisted_3$p, _hoisted_4$g];
    vue.defineComponent({
      name: 'VolumeMedium',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$w, _hoisted_5$b);
      }
    });

    const _hoisted_1$v = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$v = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M157.65 192H88a8 8 0 0 0-8 8v112a8 8 0 0 0 8 8h69.65a16 16 0 0 1 10.14 3.63l91.47 75a8 8 0 0 0 12.74-6.46V119.83a8 8 0 0 0-12.74-6.44l-91.47 75a16 16 0 0 1-10.14 3.61z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$o = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M352 320c9.74-19.41 16-40.81 16-64c0-23.51-6-44.4-16-64',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$f = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400 368c19.48-34 32-64 32-112s-12-77.7-32-112',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$a = [_hoisted_2$v, _hoisted_3$o, _hoisted_4$f];
    vue.defineComponent({
      name: 'VolumeMediumOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$v, _hoisted_5$a);
      }
    });

    const _hoisted_1$u = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$u = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M157.65 176.1H64v159.8h93.65L288 440V72L157.65 176.1z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$n = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M352 320c9.74-19.41 16-40.81 16-64c0-23.51-6-44.4-16-64',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$e = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400 368c19.48-34 32-64 32-112s-12-77.7-32-112',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$9 = [_hoisted_2$u, _hoisted_3$n, _hoisted_4$e];
    vue.defineComponent({
      name: 'VolumeMediumSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$u, _hoisted_5$9);
      }
    });

    const _hoisted_1$t = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$t = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M416 432L64 80"></path><path d="M243.33 98.86a23.89 23.89 0 0 0-25.55 1.82l-.66.51l-28.52 23.35a8 8 0 0 0-.59 11.85l54.33 54.33a8 8 0 0 0 13.66-5.66v-64.49a24.51 24.51 0 0 0-12.67-21.71z" fill="currentColor"></path><path d="M251.33 335.29L96.69 180.69A16 16 0 0 0 85.38 176H56a24 24 0 0 0-24 24v112a24 24 0 0 0 24 24h69.76l92 75.31a23.9 23.9 0 0 0 25.87 1.69A24.51 24.51 0 0 0 256 391.45v-44.86a16 16 0 0 0-4.67-11.3z" fill="currentColor"></path><path d="M352 256c0-24.56-5.81-47.87-17.75-71.27a16 16 0 1 0-28.5 14.55C315.34 218.06 320 236.62 320 256q0 4-.31 8.13a8 8 0 0 0 2.32 6.25l14.36 14.36a8 8 0 0 0 13.55-4.31A146 146 0 0 0 352 256z" fill="currentColor"></path><path d="M416 256c0-51.18-13.08-83.89-34.18-120.06a16 16 0 0 0-27.64 16.12C373.07 184.44 384 211.83 384 256c0 23.83-3.29 42.88-9.37 60.65a8 8 0 0 0 1.9 8.26L389 337.4a8 8 0 0 0 13.13-2.79C411 311.76 416 287.26 416 256z" fill="currentColor"></path><path d="M480 256c0-74.25-20.19-121.11-50.51-168.61a16 16 0 1 0-27 17.22C429.82 147.38 448 189.5 448 256c0 46.19-8.43 80.27-22.43 110.53a8 8 0 0 0 1.59 9l11.92 11.92a8 8 0 0 0 12.92-2.16C471.6 344.9 480 305 480 256z" fill="currentColor"></path>', 6);

    const _hoisted_8$2 = [_hoisted_2$t];
    vue.defineComponent({
      name: 'VolumeMute',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$t, _hoisted_8$2);
      }
    });

    const _hoisted_1$s = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$s = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32" d="M416 432L64 80"></path><path d="M224 136.92v33.8a4 4 0 0 0 1.17 2.82l24 24a4 4 0 0 0 6.83-2.82v-74.15a24.53 24.53 0 0 0-12.67-21.72a23.91 23.91 0 0 0-25.55 1.83a8.27 8.27 0 0 0-.66.51l-31.94 26.15a4 4 0 0 0-.29 5.92l17.05 17.06a4 4 0 0 0 5.37.26z" fill="currentColor"></path><path d="M224 375.08l-78.07-63.92a32 32 0 0 0-20.28-7.16H64v-96h50.72a4 4 0 0 0 2.82-6.83l-24-24a4 4 0 0 0-2.82-1.17H56a24 24 0 0 0-24 24v112a24 24 0 0 0 24 24h69.76l91.36 74.8a8.27 8.27 0 0 0 .66.51a23.93 23.93 0 0 0 25.85 1.69A24.49 24.49 0 0 0 256 391.45v-50.17a4 4 0 0 0-1.17-2.82l-24-24a4 4 0 0 0-6.83 2.82zM125.82 336z" fill="currentColor"></path><path d="M352 256c0-24.56-5.81-47.88-17.75-71.27a16 16 0 0 0-28.5 14.54C315.34 218.06 320 236.62 320 256q0 4-.31 8.13a8 8 0 0 0 2.32 6.25l19.66 19.67a4 4 0 0 0 6.75-2A146.89 146.89 0 0 0 352 256z" fill="currentColor"></path><path d="M416 256c0-51.19-13.08-83.89-34.18-120.06a16 16 0 0 0-27.64 16.12C373.07 184.44 384 211.83 384 256c0 23.83-3.29 42.88-9.37 60.65a8 8 0 0 0 1.9 8.26l16.77 16.76a4 4 0 0 0 6.52-1.27C410.09 315.88 416 289.91 416 256z" fill="currentColor"></path><path d="M480 256c0-74.26-20.19-121.11-50.51-168.61a16 16 0 1 0-27 17.22C429.82 147.38 448 189.5 448 256c0 47.45-8.9 82.12-23.59 113a4 4 0 0 0 .77 4.55L443 391.39a4 4 0 0 0 6.4-1C470.88 348.22 480 307 480 256z" fill="currentColor"></path>', 6);

    const _hoisted_8$1 = [_hoisted_2$s];
    vue.defineComponent({
      name: 'VolumeMuteOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$s, _hoisted_8$1);
      }
    });

    const _hoisted_1$r = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$r = /*#__PURE__*/vue.createStaticVNode('<path fill="none" stroke="currentColor" stroke-linecap="square" stroke-miterlimit="10" stroke-width="32" d="M416 432L64 80"></path><path d="M352 256c0-24.56-5.81-47.88-17.75-71.27L327 170.47L298.48 185l7.27 14.25C315.34 218.06 320 236.62 320 256a112.91 112.91 0 0 1-.63 11.74l27.32 27.32A148.8 148.8 0 0 0 352 256z" fill="currentColor"></path><path d="M416 256c0-51.19-13.08-83.89-34.18-120.06l-8.06-13.82l-27.64 16.12l8.06 13.82C373.07 184.44 384 211.83 384 256c0 25.93-3.89 46.21-11 65.33l24.5 24.51C409.19 319.68 416 292.42 416 256z" fill="currentColor"></path><path d="M480 256c0-74.26-20.19-121.11-50.51-168.61l-8.61-13.49l-27 17.22l8.61 13.49C429.82 147.38 448 189.5 448 256c0 48.76-9.4 84-24.82 115.55l23.7 23.7C470.16 351.39 480 309 480 256z" fill="currentColor"></path><path d="M256 72l-73.6 58.78l73.6 73.59V72z" fill="currentColor"></path><path d="M32 176.1v159.8h93.65L256 440V339.63L92.47 176.1H32z" fill="currentColor"></path>', 6);

    const _hoisted_8 = [_hoisted_2$r];
    vue.defineComponent({
      name: 'VolumeMuteSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$r, _hoisted_8);
      }
    });

    const _hoisted_1$q = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$q = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M344 416a23.92 23.92 0 0 1-14.21-4.69c-.23-.16-.44-.33-.66-.51l-91.46-74.9H168a24 24 0 0 1-24-24V200.07a24 24 0 0 1 24-24h69.65l91.46-74.9c.22-.18.43-.35.66-.51A24 24 0 0 1 368 120v272a24 24 0 0 1-24 24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$m = [_hoisted_2$q];
    vue.defineComponent({
      name: 'VolumeOff',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$q, _hoisted_3$m);
      }
    });

    const _hoisted_1$p = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$p = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M237.65 192H168a8 8 0 0 0-8 8v112a8 8 0 0 0 8 8h69.65a16 16 0 0 1 10.14 3.63l91.47 75a8 8 0 0 0 12.74-6.46V119.83a8 8 0 0 0-12.74-6.44l-91.47 75a16 16 0 0 1-10.14 3.61z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$l = [_hoisted_2$p];
    vue.defineComponent({
      name: 'VolumeOffOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$p, _hoisted_3$l);
      }
    });

    const _hoisted_1$o = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$o = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M237.65 176.1H144v159.8h93.65L368 440V72L237.65 176.1z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$k = [_hoisted_2$o];
    vue.defineComponent({
      name: 'VolumeOffSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$o, _hoisted_3$k);
      }
    });

    const _hoisted_1$n = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$n = /*#__PURE__*/vue.createStaticVNode('<path d="M312.55 479.9l-56.42-114l-44.62-57a72.37 72.37 0 0 1-10.06-36.9V143.64H217a40 40 0 0 1 40 40v182.21" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" fill="currentColor"></path><path d="M127.38 291.78v-74.07s37-74.07 74.07-74.07" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M368.09 291.78a18.49 18.49 0 0 1-10.26-3.11L297.7 250a21.18 21.18 0 0 1-9.7-17.79v-23.7a5.65 5.65 0 0 1 8.69-4.77l81.65 54.11a18.52 18.52 0 0 1-10.29 33.93z" fill="currentColor"></path><path d="M171.91 493.47a18.5 18.5 0 0 1-14.83-7.41c-6.14-8.18-4-17.18 3.7-25.92l59.95-74.66a7.41 7.41 0 0 1 10.76 2.06c1.56 2.54 3.38 5.65 5.19 9.09c5.24 9.95 6 16.11-1.68 25.7c-8 10-52 67.44-52 67.44c-2.62 2.98-7.23 3.7-11.09 3.7z" fill="currentColor"></path><circle cx="257" cy="69.56" r="37.04" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="16" fill="currentColor"></circle>', 5);

    const _hoisted_7$3 = [_hoisted_2$n];
    vue.defineComponent({
      name: 'Walk',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$n, _hoisted_7$3);
      }
    });

    const _hoisted_1$m = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$m = /*#__PURE__*/vue.createStaticVNode('<path d="M314.21 482.32l-56.77-114.74l-44.89-57.39a72.82 72.82 0 0 1-10.13-37.05V144h15.67a40.22 40.22 0 0 1 40.23 40.22v183.36" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path d="M127.9 293.05v-74.52S165.16 144 202.42 144" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M370.1 274.42L304 231"></path><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M170.53 478.36L224 400"></path><circle cx="258.32" cy="69.48" r="37.26" fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32"></circle>', 5);

    const _hoisted_7$2 = [_hoisted_2$m];
    vue.defineComponent({
      name: 'WalkOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$m, _hoisted_7$2);
      }
    });

    const _hoisted_1$l = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$l = /*#__PURE__*/vue.createStaticVNode('<path d="M315.09 481.38l-56.95-115.12l-45-57.56a73.11 73.11 0 0 1-10.16-37.17V142h15.73A40.36 40.36 0 0 1 259 182.32v162.52" stroke="currentColor" stroke-linecap="square" stroke-linejoin="round" stroke-width="32" fill="currentColor"></path><path fill="none" stroke="currentColor" stroke-linecap="square" stroke-linejoin="round" stroke-width="32" d="M128.18 291.5v-74.77l64.95-65.1"></path><path d="M376.35 295.73l-83.95-56.38v-44.68l104.68 72.95l-20.73 28.11z" fill="currentColor"></path><path d="M175.13 498.58l-21.43-26.91l80.33-81.54l15.53 32.07l-74.43 76.38z" fill="currentColor"></path><circle cx="259.02" cy="67.21" r="37.38" stroke="currentColor" stroke-linecap="square" stroke-linejoin="round" stroke-width="16" fill="currentColor"></circle>', 5);

    const _hoisted_7$1 = [_hoisted_2$l];
    vue.defineComponent({
      name: 'WalkSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$l, _hoisted_7$1);
      }
    });

    const _hoisted_1$k = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$k = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M95.5 104h320a87.73 87.73 0 0 1 11.18.71a66 66 0 0 0-77.51-55.56L86 94.08h-.3a66 66 0 0 0-41.07 26.13A87.57 87.57 0 0 1 95.5 104z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$j = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M415.5 128h-320a64.07 64.07 0 0 0-64 64v192a64.07 64.07 0 0 0 64 64h320a64.07 64.07 0 0 0 64-64V192a64.07 64.07 0 0 0-64-64zM368 320a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$d = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M32 259.5V160c0-21.67 12-58 53.65-65.87C121 87.5 156 87.5 156 87.5s23 16 4 16s-18.5 24.5 0 24.5s0 23.5 0 23.5L85.5 236z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$8 = [_hoisted_2$k, _hoisted_3$j, _hoisted_4$d];
    vue.defineComponent({
      name: 'Wallet',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$k, _hoisted_5$8);
      }
    });

    const _hoisted_1$j = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$j = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '48',
      y: '144',
      width: '416',
      height: '288',
      rx: '48',
      ry: '48',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$i = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M411.36 144v-30A50 50 0 0 0 352 64.9L88.64 109.85A50 50 0 0 0 48 159v49',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$c = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M368 320a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$7 = [_hoisted_2$j, _hoisted_3$i, _hoisted_4$c];
    vue.defineComponent({
      name: 'WalletOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$j, _hoisted_5$7);
      }
    });

    const _hoisted_1$i = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$i = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M47.5 104H432V51.52a16 16 0 0 0-19.14-15.69l-368 60.48a16 16 0 0 0-12 10.47A39.69 39.69 0 0 1 47.5 104z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$h = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M463.5 128h-416a16 16 0 0 0-16 16v288a16 16 0 0 0 16 16h416a16 16 0 0 0 16-16V144a16 16 0 0 0-16-16zM368 320a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$b = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M31.33 259.5V116c0-12.33 5.72-18.48 15.42-20c35.2-5.53 108.58-8.5 108.58-8.5s-8.33 16-27.33 16V128c18.5 0 31.33 23.5 31.33 23.5L84.83 236z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$6 = [_hoisted_2$i, _hoisted_3$h, _hoisted_4$b];
    vue.defineComponent({
      name: 'WalletSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$i, _hoisted_5$6);
      }
    });

    const _hoisted_1$h = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$h = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M449.07 399.08L278.64 82.58c-12.08-22.44-44.26-22.44-56.35 0L51.87 399.08A32 32 0 0 0 80 446.25h340.89a32 32 0 0 0 28.18-47.17zm-198.6-1.83a20 20 0 1 1 20-20a20 20 0 0 1-20 20zm21.72-201.15l-5.74 122a16 16 0 0 1-32 0l-5.74-121.95a21.73 21.73 0 0 1 21.5-22.69h.21a21.74 21.74 0 0 1 21.73 22.7z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$g = [_hoisted_2$h];
    vue.defineComponent({
      name: 'Warning',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$h, _hoisted_3$g);
      }
    });

    const _hoisted_1$g = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$g = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M85.57 446.25h340.86a32 32 0 0 0 28.17-47.17L284.18 82.58c-12.09-22.44-44.27-22.44-56.36 0L57.4 399.08a32 32 0 0 0 28.17 47.17z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$f = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M250.26 195.39l5.74 122l5.73-121.95a5.74 5.74 0 0 0-5.79-6h0a5.74 5.74 0 0 0-5.68 5.95z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$a = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 397.25a20 20 0 1 1 20-20a20 20 0 0 1-20 20z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$5 = [_hoisted_2$g, _hoisted_3$f, _hoisted_4$a];
    vue.defineComponent({
      name: 'WarningOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$g, _hoisted_5$5);
      }
    });

    const _hoisted_1$f = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$f = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M479 447.77L268.43 56.64a8 8 0 0 0-14.09 0L43.73 447.77a8 8 0 0 0 7.05 11.79H472a8 8 0 0 0 7-11.79zm-197.62-36.29h-40v-40h40zm-4-63.92h-32l-6-160h44z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$e = [_hoisted_2$f];
    vue.defineComponent({
      name: 'WarningSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$f, _hoisted_3$e);
      }
    });

    const _hoisted_1$e = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$e = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '136',
      y: '136',
      width: '240',
      height: '240',
      rx: '56',
      ry: '56',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$d = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 96V32a16 16 0 0 0-16-16H192a16 16 0 0 0-16 16v64a80.09 80.09 0 0 0-80 80v160a80.09 80.09 0 0 0 80 80v64a16 16 0 0 0 16 16h128a16 16 0 0 0 16-16v-64a80.09 80.09 0 0 0 80-80V176a80.09 80.09 0 0 0-80-80zm56 224a72.08 72.08 0 0 1-72 72H192a72.08 72.08 0 0 1-72-72V192a72.08 72.08 0 0 1 72-72h128a72.08 72.08 0 0 1 72 72z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$9 = [_hoisted_2$e, _hoisted_3$d];
    vue.defineComponent({
      name: 'Watch',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$e, _hoisted_4$9);
      }
    });

    const _hoisted_1$d = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$d = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '112',
      y: '112',
      width: '288',
      height: '288',
      rx: '64',
      ry: '64',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$c = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M176 112V40a8 8 0 0 1 8-8h144a8 8 0 0 1 8 8v72',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$8 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M336 400v72a8 8 0 0 1-8 8H184a8 8 0 0 1-8-8v-72',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$4 = [_hoisted_2$d, _hoisted_3$c, _hoisted_4$8];
    vue.defineComponent({
      name: 'WatchOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$d, _hoisted_5$4);
      }
    });

    const _hoisted_1$c = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$c = /*#__PURE__*/vue.createElementVNode('rect', {
      x: '136',
      y: '136',
      width: '240',
      height: '240',
      rx: '8',
      ry: '8',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$b = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M384 96h-48V16H176v80h-48a32 32 0 0 0-32 32v256a32 32 0 0 0 32 32h48v80h160v-80h48a32 32 0 0 0 32-32V128a32 32 0 0 0-32-32zm8 272a24 24 0 0 1-24 24H144a24 24 0 0 1-24-24V144a24 24 0 0 1 24-24h224a24 24 0 0 1 24 24z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$7 = [_hoisted_2$c, _hoisted_3$b];
    vue.defineComponent({
      name: 'WatchSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$c, _hoisted_4$7);
      }
    });

    const _hoisted_1$b = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$b = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M265.12 60.12a12 12 0 0 0-18.23 0C215.23 97.15 112 225.17 112 320c0 88.37 55.64 144 144 144s144-55.63 144-144c0-94.83-103.23-222.85-134.88-259.88zM272 412a12 12 0 0 1-11.34-16a11.89 11.89 0 0 1 11.41-8A60.06 60.06 0 0 0 332 328.07a11.89 11.89 0 0 1 8-11.41A12 12 0 0 1 356 328a84.09 84.09 0 0 1-84 84z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$a = [_hoisted_2$b];
    vue.defineComponent({
      name: 'Water',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$b, _hoisted_3$a);
      }
    });

    const _hoisted_1$a = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$a = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M400 320c0 88.37-55.63 144-144 144s-144-55.63-144-144c0-94.83 103.23-222.85 134.89-259.88a12 12 0 0 1 18.23 0C296.77 97.15 400 225.17 400 320z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-miterlimit': '10',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$9 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M344 328a72 72 0 0 1-72 72',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$6 = [_hoisted_2$a, _hoisted_3$9];
    vue.defineComponent({
      name: 'WaterOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$a, _hoisted_4$6);
      }
    });

    const _hoisted_1$9 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$9 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 43.91s-144 158.3-144 270.3c0 88.36 55.64 144 144 144s144-55.64 144-144c0-112-144-270.3-144-270.3zm16 362.3v-24a60.07 60.07 0 0 0 60-60h24a84.09 84.09 0 0 1-84 84z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$8 = [_hoisted_2$9];
    vue.defineComponent({
      name: 'WaterSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$9, _hoisted_3$8);
      }
    });

    const _hoisted_1$8 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$8 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M346.65 304.3a136 136 0 0 0-180.71 0a21 21 0 1 0 27.91 31.38a94 94 0 0 1 124.89 0a21 21 0 0 0 27.91-31.4z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$7 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256.28 183.7a221.47 221.47 0 0 0-151.8 59.92a21 21 0 1 0 28.68 30.67a180.28 180.28 0 0 1 246.24 0a21 21 0 1 0 28.68-30.67a221.47 221.47 0 0 0-151.8-59.92z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$5 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M462 175.86a309 309 0 0 0-411.44 0a21 21 0 1 0 28 31.29a267 267 0 0 1 355.43 0a21 21 0 0 0 28-31.31z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$3 = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '256.28',
      cy: '393.41',
      r: '32',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$3 = [_hoisted_2$8, _hoisted_3$7, _hoisted_4$5, _hoisted_5$3];
    vue.defineComponent({
      name: 'Wifi',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$8, _hoisted_6$3);
      }
    });

    const _hoisted_1$7 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$7 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M332.41 310.59a115 115 0 0 0-152.8 0',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$6 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M393.46 249.54a201.26 201.26 0 0 0-274.92 0',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$4 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M447.72 182.11a288 288 0 0 0-383.44 0',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$2 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M256 416a32 32 0 1 1 32-32a32 32 0 0 1-32 32z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$2 = [_hoisted_2$7, _hoisted_3$6, _hoisted_4$4, _hoisted_5$2];
    vue.defineComponent({
      name: 'WifiOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$7, _hoisted_6$2);
      }
    });

    const _hoisted_1$6 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$6 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M332.69 320a115 115 0 0 0-152.8 0',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-linejoin': 'round',
      'stroke-width': '42'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$5 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M393.74 259a201.26 201.26 0 0 0-274.92 0',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-linejoin': 'round',
      'stroke-width': '42'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$3 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M448 191.52a288 288 0 0 0-383.44 0',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'square',
      'stroke-linejoin': 'round',
      'stroke-width': '42'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5$1 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M300.67 384L256 433l-44.34-49a56.73 56.73 0 0 1 88.92 0z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6$1 = [_hoisted_2$6, _hoisted_3$5, _hoisted_4$3, _hoisted_5$1];
    vue.defineComponent({
      name: 'WifiSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$6, _hoisted_6$1);
      }
    });

    const _hoisted_1$5 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$5 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M414.56 94.92V80a16 16 0 0 0-16-16H113.44a16 16 0 0 0-16 16v14.92c-1.46 11.37-9.65 90.74 36.93 144.69c24.87 28.8 60.36 44.85 105.63 47.86V416h-80a16 16 0 0 0 0 32h192a16 16 0 0 0 0-32h-80V287.47c45.27-3 80.76-19.06 105.63-47.86c46.58-53.95 38.37-133.32 36.93-144.69zm-285.3 3.41a15.14 15.14 0 0 0 .18-2.33h253.12a15.14 15.14 0 0 0 .18 2.33a201.91 201.91 0 0 1 0 45.67H129.32a204.29 204.29 0 0 1-.06-45.67z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$4 = [_hoisted_2$5];
    vue.defineComponent({
      name: 'Wine',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$5, _hoisted_3$4);
      }
    });

    const _hoisted_1$4 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$4 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M398.57 80H113.43v16S87.51 272 256 272S398.57 96 398.57 96z',
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$3 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M256 272v160'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$2 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linecap': 'round',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M352 432H160'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_5 = /*#__PURE__*/vue.createElementVNode('path', {
      fill: 'none',
      stroke: 'currentColor',
      'stroke-linejoin': 'round',
      'stroke-width': '32',
      d: 'M112 160h288'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_6 = [_hoisted_2$4, _hoisted_3$3, _hoisted_4$2, _hoisted_5];
    vue.defineComponent({
      name: 'WineOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$4, _hoisted_6);
      }
    });

    const _hoisted_1$3 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$3 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M453 112V66.33H60.75V112l175.13 176v118H124.75v42H389v-42H277.88V288zm-336.65-3.67h281l-37.81 38H154.16z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$2 = [_hoisted_2$3];
    vue.defineComponent({
      name: 'WineSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$3, _hoisted_3$2);
      }
    });

    const _hoisted_1$2 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$2 = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '255.75',
      cy: '56',
      r: '56',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3$1 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M394.63 277.9l-10.33-34.41v-.11l-22.46-74.86h-.05l-2.51-8.45a44.87 44.87 0 0 0-43-32.08h-120a44.84 44.84 0 0 0-43 32.08l-2.51 8.45h-.06l-22.46 74.86v.11l-10.37 34.41c-3.12 10.39 2.3 21.66 12.57 25.14a20 20 0 0 0 25.6-13.18l25.58-85.25l2.17-7.23a8 8 0 0 1 15.53 2.62a7.78 7.78 0 0 1-.17 1.61L155.43 347.4a16 16 0 0 0 15.32 20.6h29v114.69c0 16.46 10.53 29.31 24 29.31s24-12.85 24-29.31V368h16v114.69c0 16.46 10.53 29.31 24 29.31s24-12.85 24-29.31V368h30a16 16 0 0 0 15.33-20.6l-43.74-145.81a7.52 7.52 0 0 1-.16-1.59a8 8 0 0 1 15.54-2.63l2.17 7.23l25.57 85.25A20 20 0 0 0 382.05 303c10.27-3.44 15.69-14.71 12.58-25.1z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4$1 = [_hoisted_2$2, _hoisted_3$1];
    vue.defineComponent({
      name: 'Woman',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$2, _hoisted_4$1);
      }
    });

    const _hoisted_1$1 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2$1 = /*#__PURE__*/vue.createStaticVNode('<path d="M208 368v104a23.73 23.73 0 0 0 24 24h0a23.73 23.73 0 0 0 24-24" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><path d="M256 368v104a23.73 23.73 0 0 0 24 24h0a23.73 23.73 0 0 0 24-24V368" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><path d="M183 274a23.73 23.73 0 0 1-29.84 16.18h0a23.72 23.72 0 0 1-16.17-29.84l25-84.28A44.85 44.85 0 0 1 205 144h102a44.85 44.85 0 0 1 43 32.08l25 84.28a23.72 23.72 0 0 1-16.17 29.84h0a23.73 23.73 0 0 1-29.78-16.2" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></path><circle cx="256" cy="56" r="40" fill="none" stroke="currentColor" stroke-linecap="round" stroke-miterlimit="10" stroke-width="32"></circle><path fill="none" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="32" d="M208 192l-48 160h192l-48-160"></path>', 5);

    const _hoisted_7 = [_hoisted_2$1];
    vue.defineComponent({
      name: 'WomanOutline',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1$1, _hoisted_7);
      }
    });

    const _hoisted_1 = {
      xmlns: 'http://www.w3.org/2000/svg',
      'xmlns:xlink': 'http://www.w3.org/1999/xlink',
      viewBox: '0 0 512 512'
    };

    const _hoisted_2 = /*#__PURE__*/vue.createElementVNode('circle', {
      cx: '255.75',
      cy: '56',
      r: '56',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_3 = /*#__PURE__*/vue.createElementVNode('path', {
      d: 'M310.28 191.4h.05l7.66-2.3l36.79 122.6l46-13.8l-16.21-54.16c0-.12 0-.24-.07-.36l-16.84-56.12l-4.71-15.74l-.9-3H362l-2.51-8.45a44.84 44.84 0 0 0-43-32.08H195.24a44.84 44.84 0 0 0-43 32.08l-2.51 8.45h-.06l-.9 3l-4.71 15.74l-16.84 56.12c0 .12 0 .24-.07.36l-16.21 54.16l46 13.8l36.76-122.6l7.54 2.26L148.25 368h51.5v144h52V368h8v144h52V368h51.51z',
      fill: 'currentColor'
    }, null, -1
    /* HOISTED */
    );

    const _hoisted_4 = [_hoisted_2, _hoisted_3];
    vue.defineComponent({
      name: 'WomanSharp',
      render: function render(_ctx, _cache) {
        return vue.openBlock(), vue.createElementBlock('svg', _hoisted_1, _hoisted_4);
      }
    });

    const ColorWandIcon = /* @__PURE__ */ React.createElement("svg", {
      viewBox: "0 0 16 16",
      fill: "none",
      xmlns: "http://www.w3.org/2000/svg",
      style: { width: "1em", height: "1em", color: "currentColor" }
    }, /* @__PURE__ */ React.createElement("path", {
      d: "M13.5 1C13.7761 1 14 1.22386 14 1.5V2H14.5C14.7761 2 15 2.22386 15 2.5C15 2.77614 14.7761 3 14.5 3H14V3.5C14 3.77614 13.7761 4 13.5 4C13.2239 4 13 3.77614 13 3.5V3H12.5C12.2239 3 12 2.77614 12 2.5C12 2.22386 12.2239 2 12.5 2H13V1.5C13 1.22386 13.2239 1 13.5 1Z",
      fill: "currentColor"
    }), /* @__PURE__ */ React.createElement("path", {
      d: "M3.5 3C3.77615 3 4 3.22386 4 3.5V4H4.5C4.77615 4 5 4.22386 5 4.5C5 4.77614 4.77615 5 4.5 5H4V5.5C4 5.77614 3.77615 6 3.5 6C3.22386 6 3 5.77614 3 5.5V5H2.5C2.22386 5 2 4.77614 2 4.5C2 4.22386 2.22386 4 2.5 4H3V3.5C3 3.22386 3.22386 3 3.5 3Z",
      fill: "currentColor"
    }), /* @__PURE__ */ React.createElement("path", {
      d: "M12.5 12C12.7761 12 13 11.7761 13 11.5C13 11.2239 12.7761 11 12.5 11H12V10.5C12 10.2239 11.7761 10 11.5 10C11.2239 10 11 10.2239 11 10.5V11H10.5C10.2239 11 10 11.2239 10 11.5C10 11.7761 10.2239 12 10.5 12H11V12.5C11 12.7761 11.2239 13 11.5 13C11.7761 13 12 12.7761 12 12.5V12H12.5Z",
      fill: "currentColor"
    }), /* @__PURE__ */ React.createElement("path", {
      d: "M8.72956 4.56346C9.4771 3.81592 10.6891 3.81592 11.4367 4.56347C12.1842 5.31102 12.1842 6.52303 11.4367 7.27058L4.26679 14.4404C3.51924 15.1879 2.30723 15.1879 1.55968 14.4404C0.812134 13.6928 0.812138 12.4808 1.55969 11.7333L8.72956 4.56346ZM8.25002 6.4572L2.26679 12.4404C1.90977 12.7974 1.90977 13.3763 2.26679 13.7333C2.62381 14.0903 3.20266 14.0903 3.55968 13.7333L9.54292 7.75009L8.25002 6.4572ZM10.25 7.04299L10.7295 6.56347C11.0866 6.20645 11.0866 5.6276 10.7296 5.27057C10.3725 4.91355 9.79368 4.91355 9.43666 5.27057L8.95713 5.7501L10.25 7.04299Z",
      fill: "currentColor"
    }));
    const showColorPicker = (key) => {
      if (key.includes("pacity"))
        return false;
      if (key.includes("color") || key.includes("Color"))
        return true;
      return false;
    };
    var ThemeEditor = vue.defineComponent({
      name: "ThemeEditor",
      inheritAttrs: false,
      setup() {
        const isOpen = vue.ref(false);
        const fileInputRef = vue.ref(null);
        const NConfigProvider2 = vue.inject(configProviderInjectionKey, null);
        const theme = vue.computed(() => {
          const mergedTheme = NConfigProvider2?.mergedThemeRef.value || lightTheme;
          const mergedThemeOverrides = NConfigProvider2?.mergedThemeOverridesRef.value;
          const common = lodash.exports.merge(
            {},
            mergedTheme.common || lightTheme.common,
            mergedThemeOverrides?.common,
            overridesRef.value.common || {}
          );
          const overrides = {
            common
          };
          for (const key of Object.keys(lightTheme)) {
            if (key === "common")
              continue;
            overrides[key] = mergedTheme[key]?.self?.(common) || lightTheme[key].self?.(common);
            if (mergedThemeOverrides && overrides[key]) {
              lodash.exports.merge(overrides[key], mergedThemeOverrides[key]);
            }
          }
          return overrides;
        });
        const themeCommonDefaultRef = vue.computed(() => {
          return NConfigProvider2?.mergedThemeRef.value?.common || lightTheme.common;
        });
        const showPanelRef = vue.ref(false);
        const overridesRef = vue.ref(
          JSON.parse(localStorage["naive-ui-theme-overrides"] || "{}")
        );
        const tempOverridesRef = vue.ref(
          JSON.parse(localStorage["naive-ui-theme-overrides"] || "{}")
        );
        const varNamePatternRef = vue.ref("");
        const compNamePatternRef = vue.ref("");
        const tempVarNamePatternRef = vue.ref("");
        const tempCompNamePatternRef = vue.ref("");
        function applyTempOverrides() {
          overridesRef.value = lodash.exports.cloneDeep(vue.toRaw(tempOverridesRef.value));
        }
        function setTempOverrides(compName, varName, value) {
          const { value: tempOverrides } = tempOverridesRef;
          if (!(compName in tempOverrides))
            tempOverrides[compName] = {};
          const compOverrides = tempOverrides[compName];
          if (value) {
            compOverrides[varName] = value;
          } else {
            delete compOverrides[varName];
          }
        }
        function handleClearAllClick() {
          tempOverridesRef.value = {};
          overridesRef.value = {};
        }
        function handleImportClick() {
          const { value: fileInput } = fileInputRef;
          if (!fileInput)
            return;
          fileInput.click();
        }
        function handleOpen() {
          isOpen.value = !isOpen.value;
        }
        function handleInputFileChange() {
          const { value: fileInput } = fileInputRef;
          if (!fileInput)
            return;
          const fileList = fileInput.files;
          const file = fileList?.[0];
          if (!file)
            return;
          file.text().then((value) => {
            overridesRef.value = JSON.parse(value);
            tempOverridesRef.value = JSON.parse(value);
          }).catch((e) => {
            alert("Imported File is Invalid");
            console.error(e);
          }).finally(() => {
            fileInput.value = "";
          });
        }
        function handleExportClick() {
          const url = URL.createObjectURL(
            new Blob([JSON.stringify(overridesRef.value, void 0, 2)])
          );
          const a = document.createElement("a");
          a.href = url;
          a.download = "naive-ui-theme-overrides.json";
          document.body.appendChild(a);
          a.click();
          document.body.removeChild(a);
          URL.revokeObjectURL(url);
        }
        vue.watch(overridesRef, (value) => {
          localStorage["naive-ui-theme-overrides"] = JSON.stringify(value);
        });
        return {
          locale: useLocale("ThemeEditor").localeRef,
          themeCommonDefault: themeCommonDefaultRef,
          theme,
          showPanel: showPanelRef,
          tempOverrides: tempOverridesRef,
          overrides: overridesRef,
          compNamePattern: compNamePatternRef,
          tempCompNamePattern: tempCompNamePatternRef,
          varNamePattern: varNamePatternRef,
          tempVarNamePattern: tempVarNamePatternRef,
          fileInputRef,
          applyTempOverrides,
          setTempOverrides,
          handleClearAllClick,
          handleExportClick,
          handleImportClick,
          handleInputFileChange,
          handleOpen,
          isOpen
        };
      },
      render() {
        return /* @__PURE__ */ React.createElement(NConfigProvider, {
          themeOverrides: this.overrides
        }, {
          default: () => [
            /* @__PURE__ */ React.createElement(NPopover, {
              scrollable: true,
              arrowPointToCenter: true,
              trigger: "manual",
              show: this.showPanel,
              displayDirective: "show",
              placement: "top-end",
              style: {
                width: this.isOpen ? "calc(100vw - 80px)" : "288px",
                height: "calc(100vh - 200px)",
                padding: 0
              }
            }, {
              trigger: () => /* @__PURE__ */ React.createElement(NElement, {
                style: [
                  {
                    position: "fixed",
                    zIndex: 10,
                    bottom: "40px",
                    right: `calc(40px + ${lockHtmlScrollRightCompensationRef.value})`,
                    width: "44px",
                    height: "44px",
                    fontSize: "26px",
                    display: "flex",
                    alignItems: "center",
                    justifyContent: "center",
                    borderRadius: "50%",
                    backgroundColor: "var(--popover-color)",
                    color: "var(--text-color-2)",
                    transition: "color .3s var(--cubic-bezier-ease-in-out), background-color .3s var(--cubic-bezier-ease-in-out), box-shadow .3s var(--cubic-bezier-ease-in-out)",
                    boxShadow: "0 2px 8px 0px rgba(0, 0, 0, .12)",
                    cursor: "pointer"
                  },
                  this.$attrs.style
                ],
                onClick: () => {
                  this.showPanel = !this.showPanel;
                }
              }, { default: () => ColorWandIcon }),
              default: () => /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement("input", {
                type: "file",
                ref: "fileInputRef",
                style: {
                  display: "block",
                  width: 0,
                  height: 0,
                  visibility: "hidden"
                },
                onChange: this.handleInputFileChange
              }), /* @__PURE__ */ React.createElement(NSpace, {
                vertical: true
              }, {
                default: () => /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(NSpace, {
                  align: "center",
                  justify: "space-between",
                  style: {
                    marginBottom: "8px",
                    fontSize: "18px",
                    fontWeight: 500
                  }
                }, /* @__PURE__ */ React.createElement("span", null, this.locale.title), /* @__PURE__ */ React.createElement(NButton, {
                  onClick: this.handleOpen,
                  strong: true,
                  secondary: true,
                  circle: true,
                  type: this.isOpen ? "success" : void 0
                }, {
                  icon: () => /* @__PURE__ */ React.createElement(NIcon, {
                    size: "18",
                    component: Open
                  })
                })), this.locale.filterCompName, /* @__PURE__ */ React.createElement(NInput, {
                  onChange: () => {
                    this.compNamePattern = this.tempCompNamePattern;
                  },
                  onInput: (value) => {
                    this.tempCompNamePattern = value;
                  },
                  value: this.tempCompNamePattern,
                  placeholder: this.locale.filterCompName
                }), this.locale.filterVarName, /* @__PURE__ */ React.createElement(NInput, {
                  onChange: (value) => {
                    this.varNamePattern = value;
                  },
                  onInput: (value) => {
                    this.tempVarNamePattern = value;
                  },
                  value: this.tempVarNamePattern,
                  placeholder: this.locale.filterVarName
                }), /* @__PURE__ */ React.createElement(NButton, {
                  size: "small",
                  onClick: () => {
                    this.compNamePattern = "";
                    this.varNamePattern = "";
                    this.tempCompNamePattern = "";
                    this.tempVarNamePattern = "";
                  },
                  block: true
                }, { default: () => this.locale.clearSearch }), /* @__PURE__ */ React.createElement(NButton, {
                  size: "small",
                  onClick: this.handleClearAllClick,
                  block: true
                }, {
                  default: () => this.locale.clearAllVars
                }), /* @__PURE__ */ React.createElement(NSpace, {
                  itemStyle: { flex: 1 }
                }, {
                  default: () => /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(NButton, {
                    block: true,
                    size: "small",
                    onClick: this.handleImportClick
                  }, {
                    default: () => this.locale.import
                  }), /* @__PURE__ */ React.createElement(NButton, {
                    block: true,
                    size: "small",
                    onClick: this.handleExportClick
                  }, {
                    default: () => this.locale.export
                  }))
                }))
              }), /* @__PURE__ */ React.createElement(NDivider, null), /* @__PURE__ */ React.createElement(NCollapse, null, {
                default: () => {
                  const { theme, compNamePattern, varNamePattern } = this;
                  const themeKeys = Object.keys(theme);
                  const compNamePatternLower = compNamePattern.toLowerCase();
                  const varNamePatternLower = varNamePattern.toLowerCase();
                  let filteredItemsCount = 0;
                  const collapsedItems = themeKeys.filter((themeKey) => {
                    return themeKey.toLowerCase().includes(compNamePatternLower);
                  }).map((themeKey) => {
                    const componentTheme = themeKey === "common" ? this.themeCommonDefault : theme[themeKey];
                    if (componentTheme === void 0) {
                      return null;
                    }
                    const varKeys = Object.keys(
                      componentTheme
                    ).filter((key) => {
                      return key !== "name" && key.toLowerCase().includes(varNamePatternLower);
                    });
                    if (!varKeys.length) {
                      return null;
                    }
                    filteredItemsCount += 1;
                    return /* @__PURE__ */ React.createElement(NCollapseItem, {
                      title: themeKey,
                      name: themeKey
                    }, {
                      default: () => {
                        return /* @__PURE__ */ React.createElement(NSpace, {
                          size: [32, 16]
                        }, {
                          default: () => varKeys.map((varKey) => {
                            return /* @__PURE__ */ React.createElement("div", {
                              style: {
                                minWidth: "246px"
                              }
                            }, /* @__PURE__ */ React.createElement("div", {
                              key: `${varKey}Label`,
                              style: {
                                wordBreak: "break-word"
                              }
                            }, varKey), showColorPicker(varKey) ? /* @__PURE__ */ React.createElement(NColorPicker, {
                              key: varKey,
                              modes: ["rgb", "hex"],
                              value: this.tempOverrides?.[themeKey]?.[varKey] || componentTheme[varKey],
                              onComplete: this.applyTempOverrides,
                              onUpdateValue: (value) => {
                                this.setTempOverrides(
                                  themeKey,
                                  varKey,
                                  value
                                );
                              }
                            }, {
                              action: () => /* @__PURE__ */ React.createElement(NButton, {
                                size: "small",
                                disabled: componentTheme[varKey] === this.tempOverrides?.[themeKey]?.[varKey],
                                onClick: () => {
                                  this.setTempOverrides(
                                    themeKey,
                                    varKey,
                                    componentTheme[varKey]
                                  );
                                  this.applyTempOverrides();
                                }
                              }, {
                                default: () => this.locale.restore
                              })
                            }) : /* @__PURE__ */ React.createElement(NInput, {
                              key: varKey,
                              onChange: this.applyTempOverrides,
                              onUpdateValue: (value) => {
                                this.setTempOverrides(
                                  themeKey,
                                  varKey,
                                  value
                                );
                              },
                              value: this.tempOverrides?.[themeKey]?.[varKey] || "",
                              placeholder: componentTheme[varKey]
                            }));
                          })
                        });
                      }
                    });
                  });
                  if (!filteredItemsCount)
                    return /* @__PURE__ */ React.createElement(NEmpty, null);
                  return collapsedItems;
                }
              }))
            }),
            this.$slots.default?.()
          ]
        });
      }
    });

    exports.NA = a;
    exports.NAffix = NAffix;
    exports.NAlert = Alert;
    exports.NAnchor = AnchorAdapter;
    exports.NAnchorLink = Link;
    exports.NAutoComplete = AutoComplete;
    exports.NAvatar = NAvatar;
    exports.NAvatarGroup = AvatarGroup;
    exports.NBackTop = BackTop;
    exports.NBadge = Badge;
    exports.NBlockquote = blockquote;
    exports.NBreadcrumb = Breadcrumb;
    exports.NBreadcrumbItem = BreadcrumbItem;
    exports.NButton = NButton;
    exports.NButtonGroup = NButtonGroup;
    exports.NCalendar = Calendar;
    exports.NCard = NCard;
    exports.NCarousel = Carousel;
    exports.NCarouselItem = NCarouselItem;
    exports.NCascader = Cascader;
    exports.NCheckbox = NCheckbox;
    exports.NCheckboxGroup = NCheckboxGroup;
    exports.NCode = NCode;
    exports.NCol = NCol;
    exports.NCollapse = NCollapse;
    exports.NCollapseItem = NCollapseItem;
    exports.NCollapseTransition = CollapseTransition;
    exports.NColorPicker = NColorPicker;
    exports.NConfigProvider = NConfigProvider;
    exports.NCountdown = Countdown;
    exports.NDataTable = DataTable;
    exports.NDatePicker = DatePicker;
    exports.NDescriptions = Descriptions;
    exports.NDescriptionsItem = DescriptionsItem;
    exports.NDialog = NDialog;
    exports.NDialogProvider = NDialogProvider;
    exports.NDivider = NDivider;
    exports.NDrawer = Drawer;
    exports.NDrawerContent = DrawerContent;
    exports.NDropdown = NDropdown;
    exports.NDynamicInput = DynamicInput;
    exports.NDynamicTags = DynamicTags;
    exports.NEl = NElement;
    exports.NElement = NElement;
    exports.NEllipsis = NEllipsis;
    exports.NEmpty = NEmpty;
    exports.NForm = Form;
    exports.NFormItem = NFormItem;
    exports.NFormItemCol = NFormItemCol;
    exports.NFormItemGi = FormItemGridItem;
    exports.NFormItemGridItem = FormItemGridItem;
    exports.NFormItemRow = FormItemRow;
    exports.NGi = NGridItem;
    exports.NGlobalStyle = GlobalStyle;
    exports.NGradientText = GradientText;
    exports.NGrid = Grid;
    exports.NGridItem = NGridItem;
    exports.NH1 = NH1;
    exports.NH2 = NH2;
    exports.NH3 = NH3;
    exports.NH4 = NH4;
    exports.NH5 = NH5;
    exports.NH6 = NH6;
    exports.NHr = hr;
    exports.NIcon = NIcon;
    exports.NIconWrapper = NIconWrapper;
    exports.NImage = NImage;
    exports.NImageGroup = NImageGroup;
    exports.NInput = NInput;
    exports.NInputGroup = NInputGroup;
    exports.NInputGroupLabel = InputGroupLabel;
    exports.NInputNumber = InputNumber;
    exports.NLayout = Layout;
    exports.NLayoutContent = LayoutContent;
    exports.NLayoutFooter = LayoutFooter;
    exports.NLayoutHeader = LayoutHeader;
    exports.NLayoutSider = LayoutSider;
    exports.NLegacyTransfer = Transfer$1;
    exports.NLi = li;
    exports.NList = List;
    exports.NListItem = ListItem;
    exports.NLoadingBarProvider = NLoadingBarProvider;
    exports.NLog = Log;
    exports.NMention = Mention;
    exports.NMenu = Menu;
    exports.NMessageProvider = NMessageProvider;
    exports.NModal = NModal;
    exports.NNotificationProvider = NNotificationProvider;
    exports.NNumberAnimation = NumberAnimation;
    exports.NOl = ol;
    exports.NP = p;
    exports.NPageHeader = PageHeader;
    exports.NPagination = NPagination;
    exports.NPopconfirm = Popconfirm;
    exports.NPopover = NPopover;
    exports.NPopselect = NPopselect;
    exports.NProgress = NProgress;
    exports.NRadio = NRadio;
    exports.NRadioButton = RadioButton;
    exports.NRadioGroup = NRadioGroup;
    exports.NRate = Rate;
    exports.NResult = Result;
    exports.NRow = NRow;
    exports.NScrollbar = Scrollbar$1;
    exports.NSelect = NSelect;
    exports.NSkeleton = Skeleton;
    exports.NSlider = Slider;
    exports.NSpace = NSpace;
    exports.NSpin = Spin;
    exports.NStatistic = Statistic;
    exports.NStep = Step;
    exports.NSteps = Steps;
    exports.NSwitch = Switch;
    exports.NTab = Tab;
    exports.NTabPane = TabPane;
    exports.NTable = Table;
    exports.NTabs = Tabs;
    exports.NTag = NTag;
    exports.NTbody = Tbody;
    exports.NTd = Td;
    exports.NText = text;
    exports.NTh = Th;
    exports.NThead = Thead;
    exports.NThemeEditor = ThemeEditor;
    exports.NThing = Thing;
    exports.NTime = Time;
    exports.NTimePicker = NTimePicker;
    exports.NTimeline = Timeline;
    exports.NTimelineItem = TimelineItem;
    exports.NTooltip = NTooltip;
    exports.NTr = Tr;
    exports.NTransfer = Transfer;
    exports.NTree = NTree;
    exports.NTreeSelect = TreeSelect;
    exports.NUl = ul;
    exports.NUpload = Upload;
    exports.NUploadDragger = NUploadDragger;
    exports.NUploadFileList = NUploadFileList;
    exports.NUploadTrigger = NUploadTrigger;
    exports.NWatermark = Watermark;
    exports.NxButton = XButton;
    exports.aProps = aProps;
    exports.affixProps = affixProps;
    exports.alertDark = alertDark$1;
    exports.alertProps = alertProps;
    exports.anchorDark = anchorDark$1;
    exports.anchorLinkProps = anchorLinkProps;
    exports.anchorProps = anchorProps;
    exports.autoCompleteDark = autoCompleteDark$1;
    exports.autoCompleteProps = autoCompleteProps;
    exports.avatarDark = avatarDark$1;
    exports.avatarGroupProps = avatarGroupProps;
    exports.avatarProps = avatarProps;
    exports.backTopDark = backTopDark$1;
    exports.backTopProps = backTopProps;
    exports.badgeDark = badgeDark$1;
    exports.badgeProps = badgeProps;
    exports.blockquoteProps = blockquoteProps;
    exports.breadcrumbDark = breadcrumbDark$1;
    exports.breadcrumbItemProps = breadcrumbItemProps;
    exports.breadcrumbProps = breadcrumbProps;
    exports.buttonDark = buttonDark$1;
    exports.buttonGroupDark = buttonGroupDark$1;
    exports.buttonGroupProps = buttonGroupProps;
    exports.buttonProps = buttonProps;
    exports.c = c$1;
    exports.cB = cB;
    exports.cE = cE;
    exports.cM = cM;
    exports.cNotM = cNotM;
    exports.calendarProps = calendarProps;
    exports.cardDark = cardDark$1;
    exports.cardProps = cardProps;
    exports.carouselProps = carouselProps;
    exports.cascaderDark = cascaderDark$1;
    exports.cascaderProps = cascaderProps;
    exports.checkboxDark = checkboxDark$1;
    exports.checkboxGroupProps = checkboxGroupProps;
    exports.checkboxProps = checkboxProps;
    exports.codeDark = codeDark$1;
    exports.codeProps = codeProps;
    exports.colProps = colProps;
    exports.collapseDark = collapseDark$1;
    exports.collapseItemProps = collapseItemProps;
    exports.collapseProps = collapseProps;
    exports.collapseTransitionProps = collapseTransitionProps;
    exports.colorPickerProps = colorPickerProps;
    exports.commonDark = commonDark;
    exports.commonLight = commonLight;
    exports.configProviderProps = configProviderProps;
    exports.countdownProps = countdownProps;
    exports.create = create;
    exports.createDiscreteApi = createDiscreteApi;
    exports.createLocale = createLocale;
    exports.createTheme = createTheme;
    exports.darkTheme = darkTheme;
    exports.dataTableDark = dataTableDark$1;
    exports.dataTableProps = dataTableProps;
    exports.dateDeDE = dateDeDE$1;
    exports.dateEnGB = dateEnGB$1;
    exports.dateEnUS = dateEnUS;
    exports.dateEo = dateEo$1;
    exports.dateEsAR = dateEsAR$1;
    exports.dateFrFR = dateFrFR$1;
    exports.dateIdID = dateIdID$1;
    exports.dateItIT = dateItIT$1;
    exports.dateJaJP = dateJaJP$1;
    exports.dateKoKR = dateKoKR$1;
    exports.dateNbNO = dateNbNO$1;
    exports.dateNlNL = dateNlNL$1;
    exports.datePickerDark = datePickerDark$1;
    exports.datePickerProps = datePickerProps;
    exports.datePlPL = datePlPL$1;
    exports.datePtBR = datePtBr$1;
    exports.dateRuRU = dateRuRU$1;
    exports.dateSkSK = dateSkSK$1;
    exports.dateThTH = dateThTH$1;
    exports.dateUkUA = dateUkUA$1;
    exports.dateViVN = dateVi$1;
    exports.dateZhCN = dateZhCN$1;
    exports.dateZhTW = datezhTW$1;
    exports.deDE = deDE$1;
    exports["default"] = naive$1;
    exports.descriptionsDark = descriptionsDark$1;
    exports.descriptionsItemProps = descriptionsItemProps;
    exports.descriptionsProps = descriptionsProps;
    exports.dialogDark = dialogDark$1;
    exports.dialogProps = dialogProps;
    exports.dialogProviderProps = dialogProviderProps;
    exports.dividerDark = dividerDark$1;
    exports.dividerProps = dividerProps;
    exports.drawerContentProps = drawerContentProps;
    exports.drawerDark = drawerDark$1;
    exports.drawerProps = drawerProps;
    exports.dropdownDark = dropdownDark$1;
    exports.dropdownProps = dropdownProps;
    exports.dynamicInputDark = dynamicInputDark$1;
    exports.dynamicInputProps = dynamicInputProps;
    exports.dynamicTagsDark = dynamicTagsDark$1;
    exports.dynamicTagsProps = dynamicTagsProps;
    exports.elementDark = elementDark$1;
    exports.elementProps = elementProps;
    exports.ellipsisProps = ellipsisProps;
    exports.emptyDark = emptyDark$1;
    exports.emptyProps = emptyProps;
    exports.enGB = enGB$1;
    exports.enUS = enUS$2;
    exports.eo = eo$1;
    exports.esAR = esAR$1;
    exports.formDark = formDark;
    exports.formItemGiProps = formItemGiProps;
    exports.formItemGridItemProps = formItemGiProps;
    exports.formItemProps = formItemProps;
    exports.formProps = formProps;
    exports.frFR = frFR$1;
    exports.giProps = gridItemProps;
    exports.gradientTextDark = gradientTextDark$1;
    exports.gradientTextProps = gradientTextProps;
    exports.gridItemProps = gridItemProps;
    exports.gridProps = gridProps;
    exports.h1Props = headerProps;
    exports.h2Props = headerProps;
    exports.h3Props = headerProps;
    exports.h4Props = headerProps;
    exports.h5Props = headerProps;
    exports.h6Props = headerProps;
    exports.iconDark = iconDark$2;
    exports.iconProps = iconProps;
    exports.iconWrapperProps = iconWrapperProps;
    exports.idID = idID$1;
    exports.imageGroupProps = imageGroupProps;
    exports.imageProps = imageProps;
    exports.inputDark = inputDark$1;
    exports.inputGroupLabelProps = inputGroupLabelProps;
    exports.inputGroupProps = inputGroupProps;
    exports.inputNumberDark = inputNumberDark$1;
    exports.inputNumberProps = inputNumberProps;
    exports.inputProps = inputProps;
    exports.install = install;
    exports.internalSelectMenuDark = internalSelectMenuDark$1;
    exports.internalSelectionDark = internalSelectionDark$1;
    exports.itIT = itIT$1;
    exports.jaJP = jaJP$1;
    exports.koKR = koKR$1;
    exports.layoutContentProps = layoutProps;
    exports.layoutDark = layoutDark$1;
    exports.layoutFooterProps = layoutFooterProps;
    exports.layoutHeaderProps = headerProps$1;
    exports.layoutProps = layoutProps;
    exports.layoutSiderProps = layoutSiderProps;
    exports.legacyTransferProps = transferProps$1;
    exports.lightTheme = lightTheme;
    exports.listDark = listDark$2;
    exports.listProps = listProps;
    exports.loadingBarDark = loadingBarDark$1;
    exports.loadingBarProviderProps = loadingBarProviderProps;
    exports.logDark = logDark$1;
    exports.logProps = logProps;
    exports.mentionDark = mentionDark;
    exports.mentionProps = mentionProps;
    exports.menuDark = menuDark$1;
    exports.menuProps = menuProps;
    exports.messageDark = messageDark$1;
    exports.messageProviderProps = messageProviderProps;
    exports.modalDark = modalDark$1;
    exports.modalProps = modalProps;
    exports.nbNO = nbNO$1;
    exports.nlNL = nlNL$1;
    exports.notificationDark = notificationDark$1;
    exports.notificationProviderProps = notificationProviderProps;
    exports.numberAnimationProps = numberAnimationProps;
    exports.olProps = olProps;
    exports.pProps = pProps;
    exports.pageHeaderProps = pageHeaderProps;
    exports.paginationDark = paginationDark$1;
    exports.paginationProps = paginationProps;
    exports.plPL = plPL$1;
    exports.popconfirmDark = popconfirmDark$1;
    exports.popconfirmProps = popconfirmProps;
    exports.popoverDark = popoverDark$1;
    exports.popoverProps = popoverProps;
    exports.popselectDark = popselectDark;
    exports.popselectProps = popselectProps;
    exports.progressDark = progressDark$1;
    exports.progressProps = progressProps;
    exports.ptBR = ptBR$1;
    exports.radioButtonProps = radioButtonProps;
    exports.radioDark = radioDark$1;
    exports.radioGroupProps = radioGroupProps;
    exports.radioProps = radioProps;
    exports.rateDark = rateDark$1;
    exports.rateProps = rateProps;
    exports.resultDark = resultDark$1;
    exports.resultProps = resultProps;
    exports.rowProps = rowProps;
    exports.ruRU = ruRu$1;
    exports.scrollbarDark = scrollbarDark$1;
    exports.scrollbarProps = scrollbarProps;
    exports.selectDark = selectDark$1;
    exports.selectProps = selectProps;
    exports.skSK = skSK$1;
    exports.skeletonProps = skeletonProps;
    exports.sliderDark = sliderDark$1;
    exports.sliderProps = sliderProps;
    exports.spaceDark = spaceDark$1;
    exports.spaceProps = spaceProps;
    exports.spinDark = spinDark$1;
    exports.spinProps = spinProps;
    exports.statisticDark = statisticDark$1;
    exports.statisticProps = statisticProps;
    exports.stepProps = stepProps;
    exports.stepsDark = stepsDark$1;
    exports.stepsProps = stepsProps;
    exports.switchDark = switchDark$1;
    exports.switchProps = switchProps;
    exports.tabPaneProps = tabPaneProps;
    exports.tabProps = tabProps;
    exports.tableDark = tableDark$1;
    exports.tableProps = tableProps;
    exports.tabsDark = tabsDark$1;
    exports.tabsProps = tabsProps;
    exports.tagDark = tagDark$1;
    exports.tagProps = tagProps;
    exports.textProps = textProps;
    exports.thTH = thTH$1;
    exports.thingDark = thingDark$1;
    exports.thingProps = thingProps;
    exports.timePickerDark = timePickerDark$1;
    exports.timePickerProps = timePickerProps;
    exports.timeProps = timeProps;
    exports.timelineDark = timelineDark$1;
    exports.timelineItemProps = timelineItemProps;
    exports.timelineProps = timelineProps;
    exports.tooltipDark = tooltipDark$1;
    exports.tooltipProps = tooltipProps;
    exports.transferDark = transferDark$2;
    exports.transferProps = transferProps;
    exports.treeDark = treeDark$1;
    exports.treeProps = treeProps;
    exports.treeSelectDark = treeSelectDark$1;
    exports.treeSelectProps = treeSelectProps;
    exports.typographyDark = typographyDark$1;
    exports.ukUA = ukUA$1;
    exports.ulProps = ulProps;
    exports.unstableAlertRtl = alertRtl;
    exports.unstableAvatarGroupRtl = avatarGroupRtl;
    exports.unstableBadgeRtl = badgeRtl;
    exports.unstableButtonGroupRtl = buttonGroupRtl;
    exports.unstableButtonRtl = buttonRtl;
    exports.unstableCardRtl = cardRtl;
    exports.unstableCheckboxRtl = checkboxRtl;
    exports.unstableCollapseRtl = collapseRtl;
    exports.unstableCollapseTransitionRtl = collapseTransitionRtl;
    exports.unstableDrawerRtl = drawerRtl$1;
    exports.unstableDynamicInputRtl = dynamicInputRtl;
    exports.unstableInputNumberRtl = inputNumberRtl;
    exports.unstableInputRtl = inputRtl;
    exports.unstableListRtl = listRtl;
    exports.unstableMessageRtl = messageRtl;
    exports.unstableNotificationRtl = notificationRtl;
    exports.unstablePageHeaderRtl = rtl;
    exports.unstablePaginationRtl = paginationRtl;
    exports.unstableRadioRtl = radioRtl;
    exports.unstableRowRtl = rowRtl;
    exports.unstableScrollbarRtl = scrollbarRtl$1;
    exports.unstableSpaceRtl = spaceRtl;
    exports.unstableStatisticRtl = statisticRtl;
    exports.unstableStepsRtl = stepsRtl;
    exports.unstableTableRtl = tableRtl;
    exports.unstableTagRtl = tagRtl;
    exports.unstableThingRtl = thingRtl;
    exports.unstableTreeRtl = treeRtl;
    exports.uploadDark = uploadDark$1;
    exports.uploadProps = uploadProps;
    exports.useDialog = useDialog;
    exports.useDialogReactiveList = useDialogReactiveList;
    exports.useLoadingBar = useLoadingBar;
    exports.useMessage = useMessage;
    exports.useNotification = useNotification;
    exports.useOsTheme = useOsTheme;
    exports.useThemeVars = useThemeVars;
    exports.version = version;
    exports.viVN = viVN$1;
    exports.watermarkDark = watermarkDark$1;
    exports.watermarkProps = watermarkProps;
    exports.zhCN = zhCN$1;
    exports.zhTW = zhTW$1;

    Object.defineProperty(exports, '__esModule', { value: true });

}));
